# Autogenerated with SMOP 0.31
from smop.core import *
# 

    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hsv_map} =} rgb2hsv (@var{rgb})
## @deftypefnx {Function File} {@var{hsv_map} =} rgb2hsv (@var{rgb})
## Transform a colormap or image from red-green-blue (RGB) space to
## hue-saturation-value (HSV) space.
##
## A color in the RGB space consists of red, green, and blue intensities.
##
## A color in HSV space is represented by hue, saturation, and value
## (brightness) levels.  Value gives the amount of light in the color.  Hue
## describes the dominant wavelength.  Saturation is the amount of hue mixed
## into the color.
## @seealso{hsv2rgb, rgb2ind, rgb2ntsc}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def rgb2hsv(rgb=None,*args,**kwargs):
    varargin = rgb2hsv.varargin
    nargin = rgb2hsv.nargin

    if (nargin != 1):
        print_usage()
    
    cls=class_(rgb)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:43
    if (logical_not(any(strcmp(cls,cellarray(['uint8','uint16','single','double']))))):
        error('rgb2hsv: invalid data type \'%s\'',cls)
    else:
        if (isfloat(rgb) and (any(ravel(rgb) < 0) or any(ravel(rgb) > 1))):
            error('rgb2hsv: floating point images may only contain values between 0 and 1')
    
    ## If we have an image convert it into a color map.
    if (isreal(rgb) and ndims(rgb) == 3):
        is_image=copy(true)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:52
        sz=size(rgb)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:53
        rgb=matlabarray(cat(ravel(rgb[:,:,1]),ravel(rgb[:,:,2]),ravel(rgb[:,:,3])))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:54
        if (isinteger(rgb)):
            low=double(intmin(cls))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:57
            high=double(intmax(cls))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:58
            rgb=(double(rgb) - low) / (high - low)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:59
    else:
        is_image=copy(false)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:62
    
    if (logical_not(ismatrix(rgb)) or columns(rgb) != 3 or issparse(rgb)):
        error('rgb2hsv: input must be a matrix of size Nx3 or MxNx3')
    
    ## get the max and min for each row
    s=min(rgb,[],2)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:70
    v=max(rgb,[],2)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:71
    
    h=zeros(rows(rgb),1)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:74
    notgray=(s != v)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:75
    
    idx=(v == logical_and(rgb[:,3],notgray))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:78
    if (any(idx)):
        h[idx]=2 / 3 + dot(1 / 6,(rgb[idx,1] - rgb[idx,2])) / (v[idx] - s[idx])
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:80
    
    ## green hue
    idx=(v == logical_and(rgb[:,2],notgray))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:84
    if (any(idx)):
        h[idx]=1 / 3 + dot(1 / 6,(rgb[idx,3] - rgb[idx,1])) / (v[idx] - s[idx])
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:86
    
    ## red hue
    idx=(v == logical_and(rgb[:,1],notgray))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:90
    if (any(idx)):
        h[idx]=dot(1 / 6,(rgb[idx,2] - rgb[idx,3])) / (v[idx] - s[idx])
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:92
    
    h[h < 0] += 1
    
    ## set the saturation
    s[logical_not(notgray)]=0
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:97
    s[notgray]=1 - s[notgray] / v[notgray]
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:98
    hsv_map=matlabarray(cat(h,s,v))
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:100
    
    ##        Should it also convert back to uint8, uint16 for integer images?
  ## If input was an image, convert it back into one.
    if (is_image):
        hsv_map=reshape(hsv_map,sz)
# /home/lei/octave-4.0.2/scripts/image/rgb2hsv.m:106
    
    return hsv_map
    
if __name__ == '__main__':
    pass
    
    ## Test pure colors and gray
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hsv (@var{n})
## Create color colormap.  This colormap begins with red, changes through
## yellow, green, cyan, blue, and magenta, before returning to red.
##
## It is useful for displaying periodic functions.  The map is obtained by
## linearly varying the hue through all possible values while keeping constant
## maximum saturation and value.  The equivalent code is
## @code{hsv2rgb ([(0:N-1)'/N, ones(N,2)])}.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "hsv");
## PKG_DEL: colormap ("unregister", "hsv");
    
    
@function
def hsv(n=rows(colormap()),*args,**kwargs):
    varargin = hsv.varargin
    nargin = hsv.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('hsv: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/hsv.m:46
    if (n == 1):
        map=matlabarray(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/image/hsv.m:49
    else:
        if (n > 1):
            hue=cat(arange(0,n - 1)).T / n
# /home/lei/octave-4.0.2/scripts/image/hsv.m:51
            map=hsv2rgb(cat(hue,ones(n,1),ones(n,1)))
# /home/lei/octave-4.0.2/scripts/image/hsv.m:52
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/hsv.m:54
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} imshow (@var{im})
## @deftypefnx {Function File} {} imshow (@var{im}, @var{limits})
## @deftypefnx {Function File} {} imshow (@var{im}, @var{map})
## @deftypefnx {Function File} {} imshow (@var{rgb}, @dots{})
## @deftypefnx {Function File} {} imshow (@var{filename})
## @deftypefnx {Function File} {} imshow (@dots{}, @var{string_param1}, @var{value1}, @dots{})
## @deftypefnx {Function File} {@var{h} =} imshow (@dots{})
## Display the image @var{im}, where @var{im} can be a 2-dimensional
## (grayscale image) or a 3-dimensional (RGB image) matrix.
##
## If @var{limits} is a 2-element vector @code{[@var{low}, @var{high}]}, the
## image is shown using a display range between @var{low} and @var{high}.  If
## an empty matrix is passed for @var{limits}, the display range is computed
## as the range between the minimal and the maximal value in the image.
##
## If @var{map} is a valid color map, the image will be shown as an indexed
## image using the supplied color map.
##
## If a file name is given instead of an image, the file will be read and shown.
##
## If given, the parameter @var{string_param1} has value @var{value1}.
## @var{string_param1} can be any of the following:
##
## @table @asis
## @item @qcode{"displayrange"}
## @var{value1} is the display range as described above.
##
## @item @qcode{"colormap"}
## @var{value1} is the colormap to use when displaying an indexed image.
##
## @item @qcode{"xdata"}
## If @var{value1} is a two element vector, it must contain horizontal axis
## limits in the form [xmin xmax]; Otherwise @var{value1} must be a vector and
## only the first and last elements will be used for xmin and xmax respectively.
##
## @item @qcode{"ydata"}
## If @var{value1} is a two element vector, it must contain vertical axis
## limits in the form [ymin ymax]; Otherwise @var{value1} must be a vector and
## only the first and last elements will be used for ymin and ymax respectively.
##
## @end table
##
## The optional return value @var{h} is a graphics handle to the image.
## @seealso{image, imagesc, colormap, gray2ind, rgb2ind}
## @end deftypefn
    
    ## Author: Stefan van der Walt  <stefan@sun.ac.za>
## Author: Soren Hauberg <hauberg at gmail dot com>
## Adapted-By: jwe
    
    
@function
def imshow(im=None,varargin=None,*args,**kwargs):
    varargin = imshow.varargin
    nargin = imshow.nargin

    if (nargin == 0):
        print_usage()
    
    display_range=copy(NA)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:76
    truecolor=copy(false)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:77
    indexed=copy(false)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:78
    xdata=ydata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imshow.m:79
# /home/lei/octave-4.0.2/scripts/image/imshow.m:79
    
    if (ischar(im)):
        im,map=imread(im,nargout=2)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:83
        indexed=copy(true)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:84
        colormap(map)
    
    nd=ndims(im)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:88
    if (logical_not(((isnumeric(im) or islogical(im)) and (nd == 2 or nd == 3)))):
        error('imshow: IM must be an image or the filename of an image')
    
    if (nd == 2):
        if (logical_not(indexed)):
            colormap(gray())
    else:
        if (size(im,3) == 3):
            if (ismember(class_(im),cellarray(['uint8','uint16','double','single']))):
                truecolor=copy(true)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:100
            else:
                error('imshow: TrueColor image must be uint8, uint16, double, or single')
        else:
            error('imshow: expecting MxN or MxNx3 matrix for image')
    
    narg=1
# /home/lei/octave-4.0.2/scripts/image/imshow.m:108
    while (narg <= numel(varargin)):

        arg=varargin[narg]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:110
        if (isnumeric(arg)):
            if (numel(arg) == 2 or isempty(arg)):
                display_range=copy(arg)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:113
            else:
                if (columns(arg) == 3):
                    indexed=copy(true)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:115
                    if (iscolormap(arg)):
                        colormap(arg)
                    else:
                        error('imshow: invalid colormap MAP')
                else:
                    if (logical_not(isempty(arg))):
                        error('imshow: argument number %d is invalid',narg)
        else:
            if (ischar(arg)):
                if 'colormap' == (tolower(arg)):
                    map=varargin[narg]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:127
                    if (iscolormap(map)):
                        colormap(map)
                    else:
                        error('imshow: invalid colormap')
                else:
                    if 'displayrange' == (tolower(arg)):
                        display_range=varargin[narg]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:134
                    else:
                        if 'parent' == (tolower(arg)):
                            warning('imshow: parent argument is not implemented')
                        else:
                            if cellarray(['truesize','initialmagnification']) == (tolower(arg)):
                                warning('image: zoom argument ignored -- use GUI features')
                            else:
                                if 'xdata' == (tolower(arg)):
                                    xdata=varargin[narg]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:140
                                    if (logical_not(isvector(xdata))):
                                        error('imshow: xdata must be a vector')
                                    xdata=matlabarray(cat(xdata[1],xdata[end()]))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:144
                                else:
                                    if 'ydata' == (tolower(arg)):
                                        ydata=varargin[narg]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:146
                                        if (logical_not(isvector(ydata))):
                                            error('imshow: ydata must be a vector')
                                        ydata=matlabarray(cat(ydata[1],ydata[end()]))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:150
                                    else:
                                        warning('imshow: unrecognized property %s',arg)
                                        narg
            else:
                error('imshow: argument number %d is invalid',narg)

    
    ## Check for complex images.
    if (iscomplex(im)):
        warning('imshow: only showing real part of complex image')
        im=real(im)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:163
    
    ## Set default display range if display_range not set yet.
    if (isempty(display_range)):
        display_range=matlabarray(cat(min(ravel(im)),max(ravel(im))))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:168
    else:
        if (isna(display_range)):
            t=class_(im)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:170
            if cellarray(['double','single','logical']) == (t):
                display_range=matlabarray(cat(0,1))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:173
            else:
                if cellarray(['uint8','uint16','int16']) == (t):
                    display_range=matlabarray(cat(intmin(t),intmax(t)))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:175
                else:
                    error('imshow: invalid data type for image')
    
    if (isfloat(im)):
        nans=isnan(ravel(im))
# /home/lei/octave-4.0.2/scripts/image/imshow.m:182
        if (any(nans)):
            warning('Octave:imshow-NaN','imshow: pixels with NaN or NA values are set to minimum pixel value')
            im[nans]=display_range[1]
# /home/lei/octave-4.0.2/scripts/image/imshow.m:186
    
    ## FIXME: Commented out 2014/05/01.  imagesc and 'clim' will automatically
  ## take care of displaying out-of-range data clamped to the limits.
  ## Eventually, this can be deleted if no problems arise.
  ## Clamp the image to the range boundaries
  ##if (! (truecolor || indexed || islogical (im)))
  ##  low = display_range(1);
  ##  high = display_range(2);
  ##  im(im < low) = low;
  ##  im(im > high) = high;
  ##endif
    
    if (truecolor or indexed):
        htmp=image(xdata,ydata,im)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:202
    else:
        htmp=imagesc(xdata,ydata,im,display_range)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:204
        set(gca(),'clim',display_range)
    
    set(gca(),'visible','off','view',cat(0,90),'ydir','reverse','layer','top')
    axis('image')
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/image/imshow.m:212
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} colorcube ()
## @deftypefnx {Function File} {@var{map} =} colorcube (@var{n})
## Create color colormap.  This colormap is composed of as many equally
## spaced colors (not grays) in the RGB color space as possible.
##
## If there are not a perfect number @var{n} of regularly spaced colors then the
## remaining entries in the colormap are gradients of pure red, green, blue,
## and gray.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    
@function
def colorcube(n=None,*args,**kwargs):
    varargin = colorcube.varargin
    nargin = colorcube.nargin

    if (nargin == 0):
        n=rows(colormap)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:37
    else:
        if (nargin == 1):
            if (logical_not(isscalar(n))):
                error('colorcube: N must be a scalar')
        else:
            print_usage()
    
    if (n < 9):
        map=gray(n)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:47
        return map
    
    ## Create colorcube of evenly spaced points with side length of n^1/3
    cubelen=fix(cbrt(n))
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:52
    reserve=n - cubelen ** 3
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:53
    if (reserve == 0):
        ## Steal space from blue to put the gray gradient
        r,g,b=meshgrid(linspace(0,1,cubelen),linspace(0,1,cubelen),linspace(0,1,cubelen - 1),nargout=3)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:57
    else:
        r,g,b=meshgrid(linspace(0,1,cubelen),linspace(0,1,cubelen),linspace(0,1,cubelen),nargout=3)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:61
    
    ## Create map and weed out grays
    map=matlabarray(cat(ravel(r),ravel(g),ravel(b)))
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:67
    idx=any(bsxfun(ne,map[:,1],map[:,2:3]),2)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:68
    map=map[idx,:]
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:69
    
    idx=sum(map == 0,2)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:72
    map=map[idx != 2,:]
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:73
    
    reserve=n - rows(map) - 1
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:76
    csteps=fix(reserve / 4)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:77
    cstepsz=1 / csteps
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:78
    cgrad=(arange(cstepsz,1,cstepsz)).T
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:79
    gsteps=reserve - dot(3,csteps)
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:80
    gstepsz=1 / gsteps
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:81
    ggrad=(arange(gstepsz,1,gstepsz)).T
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:82
    map=matlabarray(cat(map,cgrad,zeros(csteps,1),zeros(csteps,1),zeros(csteps,1),cgrad,zeros(csteps,1),zeros(csteps,1),zeros(csteps,1),cgrad,0,0,0,ggrad,ggrad,ggrad))
# /home/lei/octave-4.0.2/scripts/image/colorcube.m:83
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} jet ()
## @deftypefnx {Function File} {@var{map} =} jet (@var{n})
## Create color colormap.  This colormap ranges from dark blue through blue,
## cyan, green, yellow, red, to dark red.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "jet");
## PKG_DEL: colormap ("unregister", "jet");
    
    
@function
def jet(n=rows(colormap()),*args,**kwargs):
    varargin = jet.varargin
    nargin = jet.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('jet: N must be a scalar')
    
    if (n == 1):
        map=matlabarray(cat(0,1,1))
# /home/lei/octave-4.0.2/scripts/image/jet.m:44
    else:
        if (n == 2):
            map=matlabarray(cat(0,0,1,0,1,1))
# /home/lei/octave-4.0.2/scripts/image/jet.m:46
        else:
            if (n > 2):
                nel=ceil(n / 4)
# /home/lei/octave-4.0.2/scripts/image/jet.m:49
                idx1=ceil(dot(3 / 8,n)) + 1
# /home/lei/octave-4.0.2/scripts/image/jet.m:50
                if (mod(n,8) == 2):
                    idx1
                idx2=idx1 + nel - 1
# /home/lei/octave-4.0.2/scripts/image/jet.m:54
                idx3=min(idx2 + nel,n)
# /home/lei/octave-4.0.2/scripts/image/jet.m:55
                r=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/jet.m:57
                r[idx1:idx2,1]=cat(arange(1,nel)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:58
                r[idx2:idx3,1]=1
# /home/lei/octave-4.0.2/scripts/image/jet.m:59
                nel2=n - idx3
# /home/lei/octave-4.0.2/scripts/image/jet.m:60
                r[idx3:(idx3 + nel2),1]=cat(arange(nel,(nel - nel2),- 1)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:61
                idx1=idx1 - nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:63
                idx2=idx1 + nel - 1
# /home/lei/octave-4.0.2/scripts/image/jet.m:64
                idx3=min(idx2 + nel,n)
# /home/lei/octave-4.0.2/scripts/image/jet.m:65
                g=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/jet.m:67
                g[idx1:idx2,1]=cat(arange(1,nel)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:68
                g[idx2:idx3,1]=1
# /home/lei/octave-4.0.2/scripts/image/jet.m:69
                nel2=min(nel,n - idx3)
# /home/lei/octave-4.0.2/scripts/image/jet.m:70
                g[idx3:(idx3 + nel2),1]=cat(arange(nel,(nel - nel2),- 1)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:71
                idx1=max(idx2 - nel,1)
# /home/lei/octave-4.0.2/scripts/image/jet.m:73
                idx2=copy(idx2)
# /home/lei/octave-4.0.2/scripts/image/jet.m:74
                idx3=copy(idx3)
# /home/lei/octave-4.0.2/scripts/image/jet.m:75
                b=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/jet.m:77
                nel2=min(nel,idx1 - 1)
# /home/lei/octave-4.0.2/scripts/image/jet.m:78
                b[1:idx1,1]=cat(arange((nel - nel2),nel)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:79
                b[idx1:idx2,1]=1
# /home/lei/octave-4.0.2/scripts/image/jet.m:80
                nel2=min(nel,n - idx3)
# /home/lei/octave-4.0.2/scripts/image/jet.m:81
                b[idx2:(idx2 + nel2),1]=cat(arange(nel,(nel - nel2),- 1)) / nel
# /home/lei/octave-4.0.2/scripts/image/jet.m:82
                map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/jet.m:84
            else:
                map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/jet.m:86
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{cmap} =} contrast (@var{x})
## @deftypefnx {Function File} {@var{cmap} =} contrast (@var{x}, @var{n})
## Return a gray colormap that maximizes the contrast in an image.
##
## The returned colormap will have @var{n} rows.  If @var{n} is not defined
## then the size of the current colormap is used.
## @seealso{colormap, brighten}
## @end deftypefn
    
    
@function
def contrast(x=None,n=None,*args,**kwargs):
    varargin = contrast.varargin
    nargin = contrast.nargin

    if (nargin == 1):
        n=rows(colormap())
# /home/lei/octave-4.0.2/scripts/image/contrast.m:32
    else:
        if (nargin == 2):
            if (logical_not(isscalar(n))):
                error('contrast: N must be a scalar')
        else:
            print_usage()
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/image/contrast.m:41
    minx=min(x)
# /home/lei/octave-4.0.2/scripts/image/contrast.m:42
    cmap=find(diff(sort(cat([round(dot(n,((x - minx) / (max(x) - minx))))],[cat(arange(0,n)).T]))))
# /home/lei/octave-4.0.2/scripts/image/contrast.m:43
    minm=min(cmap)
# /home/lei/octave-4.0.2/scripts/image/contrast.m:44
    cmap=(cmap - minm) / (max(cmap) - minm)
# /home/lei/octave-4.0.2/scripts/image/contrast.m:45
    cmap=matlabarray(cat(cmap,cmap,cmap))
# /home/lei/octave-4.0.2/scripts/image/contrast.m:46
    return cmap
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{I} =} ind2gray (@var{x}, @var{map})
## Convert a color indexed image to a grayscale intensity image.
##
## The image @var{x} must be an indexed image which will be converted using the
## colormap @var{cmap}.  If @var{cmap} does not contain enough colors for the
## image, pixels in @var{x} outside the range are mapped to the last color in
## the map before conversion to grayscale.
##
## The output @var{I} is of the same class as the input @var{x} and may be
## one of @code{uint8}, @code{uint16}, @code{single}, or @code{double}.
##
## Implementation Note: There are several ways of converting colors to
## grayscale intensities.  This functions uses the luminance value obtained
## from @code{rgb2ntsc} which is @code{I = 0.299*R + 0.587*G + 0.114*B}.
## Other possibilities include the value component from @code{rgb2hsv} or
## using a single color channel from @code{ind2rgb}.
## @seealso{gray2ind, ind2rgb}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def ind2gray(x=None,map=None,*args,**kwargs):
    varargin = ind2gray.varargin
    nargin = ind2gray.nargin

    if (nargin != 2):
        print_usage()
    
    x,map=ind2x('ind2gray',x,map,nargout=2)
# /home/lei/octave-4.0.2/scripts/image/ind2gray.m:48
    
    map *= cat([0.29894],[0.58704],[0.11402])
    
    ## will produce output of the same type as the input.
    cls=class_(x)
# /home/lei/octave-4.0.2/scripts/image/ind2gray.m:55
    if (isinteger(x)):
        ## if we later add support for int16 images, this will not work. Look into
    ## im2int16 from image package for such case
        map *= intmax(cls)
    else:
        if (strcmp(cls,'single')):
            map=single(map)
# /home/lei/octave-4.0.2/scripts/image/ind2gray.m:61
    
    ## Replace indices in the input matrix with the indexed luminance value.
    I=reshape(map[ravel(x)],size(x))
# /home/lei/octave-4.0.2/scripts/image/ind2gray.m:65
    return I
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} rainbow ()
## @deftypefnx {Function File} {@var{map} =} rainbow (@var{n})
## Create color colormap.  This colormap ranges from red through orange,
## yellow, green, blue, to violet.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## this colormap is not part of matlab, it is like the prism
## colormap map but with a continuous map
    
    ## PKG_ADD: colormap ("register", "rainbow");
## PKG_DEL: colormap ("unregister", "rainbow");
    
    
@function
def rainbow(n=rows(colormap()),*args,**kwargs):
    varargin = rainbow.varargin
    nargin = rainbow.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('rainbow: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:45
    if (n == 1):
        map=matlabarray(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:48
    else:
        if (n > 1):
            x=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:50
            r=((x < 2 / 5) + multiply((x >= logical_and(2 / 5,x) < 3 / 5),(dot(- 5,x) + 3)) + multiply((x >= 4 / 5),(dot(10 / 3,x) - 8 / 3)))
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:52
            g=(multiply((x < 2 / 5),(dot(5 / 2,x))) + (x >= logical_and(2 / 5,x) < 3 / 5) + multiply((x >= logical_and(3 / 5,x) < 4 / 5),(dot(- 5,x) + 4)))
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:56
            b=(multiply((x >= logical_and(3 / 5,x) < 4 / 5),(dot(5,x) - 3)) + (x >= 4 / 5))
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:60
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:63
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/rainbow.m:65
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Soren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{info} =} imfinfo (@var{filename})
## @deftypefnx {Function File} {@var{info} =} imfinfo (@var{url})
## @deftypefnx {Function File} {@var{info} =} imfinfo (@dots{}, @var{ext})
## Read image information from a file.
##
## @code{imfinfo} returns a structure containing information about the image
## stored in the file @var{filename}.  If there is no file @var{filename},
## and @var{ext} was specified, it will look for a file named @var{filename}
## and extension @var{ext}, i.e., a file named @var{filename}.@var{ext}.
##
## The output structure @var{info} contains the following fields:
##
## @table @samp
## @item Filename
## The full name of the image file.
##
## @item FileModDate
## Date of last modification to the file.
##
## @item FileSize
## Number of bytes of the image on disk
##
## @item Format
## Image format (e.g., @qcode{"jpeg"}).
##
## @item Height
## Image height in pixels.
##
## @item Width
## Image Width in pixels.
##
## @item BitDepth
## Number of bits per channel per pixel.
##
## @item ColorType
## Image type.  Value is @qcode{"grayscale"}, @qcode{"indexed"},
## @qcode{"truecolor"}, @qcode{"CMYK"}, or @qcode{"undefined"}.
##
## @item XResolution
## X resolution of the image.
##
## @item YResolution
## Y resolution of the image.
##
## @item ResolutionUnit
## Units of image resolution.  Value is @qcode{"Inch"},
## @qcode{"Centimeter"}, or @qcode{"undefined"}.
##
## @item DelayTime
## Time in 1/100ths of a second (0 to 65535) which must expire before
## displaying the next image in an animated sequence.
##
## @item LoopCount
## Number of iterations to loop an animation.
##
## @item ByteOrder
## Endian option for formats that support it.  Value is @qcode{"little-endian"},
## @qcode{"big-endian"}, or @qcode{"undefined"}.
##
## @item Gamma
## Gamma level of the image.  The same color image displayed on two different
## workstations may look different due to differences in the display monitor.
##
## @item Quality
## JPEG/MIFF/PNG compression level.  Value is an integer in the range [0 100].
##
## @item DisposalMethod
## Only valid for GIF images, control how successive frames are rendered (how
## the preceding frame is disposed of) when creating a GIF animation.  Values
## can be @qcode{"doNotSpecify"}, @qcode{"leaveInPlace"}, @qcode{"restoreBG"},
## or @qcode{"restorePrevious"}.  For non-GIF files, value is an empty string.
##
## @item Chromaticities
## Value is a 1x8 Matrix with the x,y chromaticity values for white, red,
## green, and blue points, in that order.
##
## @item Comment
## Image comment.
##
## @item Compression
## Compression type.  Value can be @qcode{"none"}, @qcode{"bzip"},
## @qcode{"fax3"}, @qcode{"fax4"}, @qcode{"jpeg"}, @qcode{"lzw"},
## @qcode{"rle"}, @qcode{"deflate"}, @qcode{"lzma"}, @qcode{"jpeg2000"},
## @qcode{"jbig2"}, @qcode{"jbig2"}, or @qcode{"undefined"}.
##
## @item Colormap
## Colormap for each image.
##
## @item Orientation
## The orientation of the image with respect to the rows and columns.  Value
## is an integer between 1 and 8 as defined in the TIFF 6 specifications, and
## for @sc{matlab} compatibility.
##
## @item Software
## Name and version of the software or firmware of the camera or image input
## device used to generate the image.
##
## @item Make
## The manufacturer of the recording equipment.  This is the manufacture of the
## @nospell{DSC}, scanner, video digitizer or other equipment that generated
## the image.
##
## @item Model
## The model name or model number of the recording equipment as mentioned on
## the field @qcode{"Make"}.
##
## @item DateTime
## The date and time of image creation as defined by the Exif standard, i.e.,
## it is the date and time the file was changed.
##
## @item ImageDescription
## The title of the image as defined by the Exif standard.
##
## @item Artist
## Name of the camera owner, photographer or image creator.
##
## @item Copyright
## Copyright notice of the person or organization claiming rights to the image.
##
## @item DigitalCamera
## A struct with information retrieved from the Exif tag.
##
## @item GPSInfo
## A struct with geotagging information retrieved from the Exif tag.
## @end table
##
## @seealso{imread, imwrite, imshow, imformats}
## @end deftypefn
    
    ## Author: Soren Hauberg <hauberg@gmail.com>
    
    
@function
def imfinfo(filename=None,varargin=None,*args,**kwargs):
    varargin = imfinfo.varargin
    nargin = imfinfo.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not(ischar(filename))):
            error('imfinfo: FILENAME must be a string')
        else:
            if (nargin > 1 and logical_not(ischar(ext))):
                error('imfinfo: EXT must be a string')
    
    info=imageIO('imfinfo',__imfinfo__,'info',filename,varargin[:])
# /home/lei/octave-4.0.2/scripts/image/imfinfo.m:159
    return info
    
if __name__ == '__main__':
    pass
    
    ## This test is the same as the similar one in imread. imfinfo must check
## if file exists before calling __imfinfo_. This test confirm this.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} cool ()
## @deftypefnx {Function File} {@var{map} =} cool (@var{n})
## Create color colormap.  The colormap varies from cyan to magenta.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "cool");
## PKG_DEL: colormap ("unregister", "cool");
    
    
@function
def cool(n=rows(colormap()),*args,**kwargs):
    varargin = cool.varargin
    nargin = cool.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('cool: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/cool.m:41
    if (n == 1):
        map=matlabarray(cat(0,1,1))
# /home/lei/octave-4.0.2/scripts/image/cool.m:44
    else:
        if (n > 1):
            r=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/cool.m:46
            g=1 - r
# /home/lei/octave-4.0.2/scripts/image/cool.m:47
            b=ones(n,1)
# /home/lei/octave-4.0.2/scripts/image/cool.m:48
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/cool.m:49
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/cool.m:51
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} hot ()
## @deftypefnx {Function File} {@var{map} =} hot (@var{n})
## Create color colormap.  This colormap ranges from black through dark red,
## red, orange, yellow, to white.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "hot");
## PKG_DEL: colormap ("unregister", "hot");
    
    
@function
def hot(n=rows(colormap()),*args,**kwargs):
    varargin = hot.varargin
    nargin = hot.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('hot: N must be a scalar')
    
    if (n == 1):
        map=matlabarray(cat(1,1,1))
# /home/lei/octave-4.0.2/scripts/image/hot.m:44
    else:
        if (n == 2):
            map=matlabarray(cat(1,1,1 / 2,1,1,1))
# /home/lei/octave-4.0.2/scripts/image/hot.m:46
        else:
            if (n > 2):
                idx=floor(dot(3 / 8,n))
# /home/lei/octave-4.0.2/scripts/image/hot.m:49
                nel=copy(idx)
# /home/lei/octave-4.0.2/scripts/image/hot.m:50
                r=ones(n,1)
# /home/lei/octave-4.0.2/scripts/image/hot.m:52
                r[1:idx,1]=cat(arange(1,nel)).T / nel
# /home/lei/octave-4.0.2/scripts/image/hot.m:53
                g=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/hot.m:55
                g[idx + 1:dot(2,idx),1]=r[1:idx]
# /home/lei/octave-4.0.2/scripts/image/hot.m:56
                g[dot(2,idx) + 1:end(),1]=1
# /home/lei/octave-4.0.2/scripts/image/hot.m:57
                idx=dot(2,idx) + 1
# /home/lei/octave-4.0.2/scripts/image/hot.m:59
                nel=n - idx + 1
# /home/lei/octave-4.0.2/scripts/image/hot.m:60
                b=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/hot.m:62
                b[idx:end(),1]=cat(arange(1,nel)).T / nel
# /home/lei/octave-4.0.2/scripts/image/hot.m:63
                map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/hot.m:65
            else:
                map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/hot.m:67
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} copper ()
## @deftypefnx {Function File} {@var{map} =} copper (@var{n})
## Create color colormap.  This colormap varies from black to a light copper
## tone.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "copper");
## PKG_DEL: colormap ("unregister", "copper");
    
    
@function
def copper(n=rows(colormap()),*args,**kwargs):
    varargin = copper.varargin
    nargin = copper.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('copper: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/copper.m:42
    if (n == 1):
        map=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/image/copper.m:45
    else:
        if (n > 1):
            x=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/copper.m:47
            r=multiply((x < 4 / 5),(dot(5 / 4,x))) + (x >= 4 / 5)
# /home/lei/octave-4.0.2/scripts/image/copper.m:48
            g=dot(0.7812,x)
# /home/lei/octave-4.0.2/scripts/image/copper.m:50
            b=dot(0.4975,x)
# /home/lei/octave-4.0.2/scripts/image/copper.m:51
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/copper.m:52
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/copper.m:54
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 John W. Eaton
## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} imwrite (@var{img}, @var{filename})
## @deftypefnx {Function File} {} imwrite (@var{img}, @var{filename}, @var{ext})
## @deftypefnx {Function File} {} imwrite (@var{img}, @var{map}, @var{filename})
## @deftypefnx {Function File} {} imwrite (@dots{}, @var{param1}, @var{val1}, @dots{})
## Write images in various file formats.
##
## The image @var{img} can be a binary, grayscale, RGB, or multi-dimensional
## image.  The size and class of @var{img} should be the same as what should
## be expected when reading it with @code{imread}: the 3rd and 4th dimensions
## reserved for color space, and multiple pages respectively.  If it's an
## indexed image, the colormap @var{map} must also be specified.
##
## If @var{ext} is not supplied, the file extension of @var{filename} is used
## to determine the format.  The actual supported formats are dependent on
## options made during the build of Octave.  Use @code{imformats} to check
## the support of the different image formats.
##
## Depending on the file format, it is possible to configure the writing of
## images with @var{param}, @var{val} pairs.  The following options are
## supported:
##
## @table @samp
## @item Alpha
## Alpha (transparency) channel for the image.  This must be a matrix with
## same class, and number of rows and columns of @var{img}.  In case of a
## multipage image, the size of the 4th dimension must also match and the third
## dimension must be a singleton.  By default, image will be completely opaque.
##
## @item DelayTime
## For formats that accept animations (such as GIF), controls for how long a
## frame is displayed until it moves to the next one.  The value must be scalar
## (which will applied to all frames in @var{img}), or a vector of length
## equal to the number of frames in @var{im}.  The value is in seconds, must
## be between 0 and 655.35, and defaults to 0.5.
##
## @item DisposalMethod
## For formats that accept animations (such as GIF), controls what happens to
## a frame before drawing the next one.  Its value can be one of the
## following strings: "doNotSpecify" (default); "leaveInPlace"; "restoreBG";
## and "restorePrevious", or a cell array of those string with length equal
## to the number of frames in @var{img}.
##
## @item LoopCount
## For formats that accept animations (such as GIF), controls how many times
## the sequence is repeated.  A value of Inf means an infinite loop (default),
## a value of 0 or 1 that the sequence is played only once (loops zero times),
## while a value of 2 or above loops that number of times (looping twice means
## it plays the complete sequence 3 times).  This option is ignored when there
## is only a single image at the end of writing the file.
##
## @item Quality
## Set the quality of the compression.  The value should be an integer
## between 0 and 100, with larger values indicating higher visual quality and
## lower compression.  Defaults to 75.
##
## @item WriteMode
## Some file formats, such as TIFF and GIF, are able to store multiple images
## in a single file.  This option specifies if @var{img} should be appended
## to the file (if it exists) or if a new file should be created for it
## (possibly overwriting an existing file).  The value should be the string
## @qcode{"Overwrite"} (default), or @qcode{"Append"}.
##
## Despite this option, the most efficient method of writing a multipage
## image is to pass a 4 dimensional @var{img} to @code{imwrite}, the same
## matrix that could be expected when using @code{imread} with the option
## @qcode{"Index"} set to @qcode{"all"}.
##
## @end table
##
## @seealso{imread, imfinfo, imformats}
## @end deftypefn
    
    
@function
def imwrite(varargin=None,*args,**kwargs):
    varargin = imwrite.varargin
    nargin = imwrite.nargin

    if (nargin < 2):
        print_usage()
    
    filename,ext=imwrite_filename(varargin[2:end()],nargout=2)
# /home/lei/octave-4.0.2/scripts/image/imwrite.m:97
    fmt=imformats(ext)
# /home/lei/octave-4.0.2/scripts/image/imwrite.m:99
    
    ## no fields, so we can't just use `isempty (fmt)'.
    if (numfields(fmt) == 0):
        if (isempty(ext)):
            error('imwrite: no extension found for %s to identify the image format',filename)
        warning('imwrite: unlisted image format %s (see imformats). Trying to save anyway.',ext)
        __imwrite__(varargin[:])
    else:
        fmt.write(varargin[:])
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    
    
    
    
    
    
    
    
    
    ## typical usage with grayscale uint8 images
    
    
    
    ## grayscale uint8 images with alpha channel
    
    
    
    
    
    ## multipage grayscale uint8 images
    
    
    
    ## multipage RGB uint8 images with alpha channel
    
    
    
    
    
    ## typical usage with RGB uint8 images
    
    
    
    ## RGB uint8 images with alpha channel
    
    
    
    
    
    ## multipage RGB uint8 images
    
    
    
    ## multipage RGB uint8 images with alpha channel
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} pink ()
## @deftypefnx {Function File} {@var{map} =} pink (@var{n})
## Create color colormap.  This colormap varies from black to white with
## shades of gray-pink.
##
## This colormap gives a sepia tone when used on grayscale images.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "pink");
## PKG_DEL: colormap ("unregister", "pink");
    
    
@function
def pink(n=rows(colormap()),*args,**kwargs):
    varargin = pink.varargin
    nargin = pink.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('pink: N must be a scalar')
    
    if (n == 1):
        map=sqrt(cat(1 / 3,1 / 3,1 / 3))
# /home/lei/octave-4.0.2/scripts/image/pink.m:46
    else:
        if (n == 2):
            map=sqrt(cat(1 / 3,1 / 3,1 / 6,1,1,1))
# /home/lei/octave-4.0.2/scripts/image/pink.m:48
        else:
            if (n > 2):
                x=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/pink.m:51
                idx=floor(dot(3 / 8,n))
# /home/lei/octave-4.0.2/scripts/image/pink.m:52
                base=1 / (dot(3,idx))
# /home/lei/octave-4.0.2/scripts/image/pink.m:53
                nel=copy(idx)
# /home/lei/octave-4.0.2/scripts/image/pink.m:55
                r[1:idx,1]=linspace(base,dot(2 / 3,x[idx]) + 1 / 3,nel)
# /home/lei/octave-4.0.2/scripts/image/pink.m:56
                r[idx + 1:n,1]=dot(2 / 3,x[idx + 1:n]) + 1 / 3
# /home/lei/octave-4.0.2/scripts/image/pink.m:57
                g[1:idx,1]=dot(2 / 3,x[1:idx])
# /home/lei/octave-4.0.2/scripts/image/pink.m:59
                g[idx:dot(2,idx),1]=linspace(dot(2 / 3,x[idx]),dot(2 / 3,x[dot(2,idx)]) + 1 / 3,nel + 1)
# /home/lei/octave-4.0.2/scripts/image/pink.m:60
                g[dot(2,idx) + 1:n,1]=dot(2 / 3,x[dot(2,idx) + 1:n]) + 1 / 3
# /home/lei/octave-4.0.2/scripts/image/pink.m:61
                nel=n - dot(2,idx) + 1
# /home/lei/octave-4.0.2/scripts/image/pink.m:63
                b[1:dot(2,idx),1]=dot(2 / 3,x[1:dot(2,idx)])
# /home/lei/octave-4.0.2/scripts/image/pink.m:64
                b[dot(2,idx):n,1]=linspace(dot(2 / 3,x[dot(2,idx)]),1,nel)
# /home/lei/octave-4.0.2/scripts/image/pink.m:65
                map=sqrt(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/pink.m:67
            else:
                map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/pink.m:69
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} autumn ()
## @deftypefnx {Function File} {@var{map} =} autumn (@var{n})
## Create color colormap.
## This colormap ranges from red through orange to yellow.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "autumn");
## PKG_DEL: colormap ("unregister", "autumn");
    
    
@function
def autumn(n=rows(colormap()),*args,**kwargs):
    varargin = autumn.varargin
    nargin = autumn.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('autumn: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/autumn.m:42
    if (n == 1):
        map=matlabarray(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/image/autumn.m:45
    else:
        if (n > 1):
            r=ones(n,1)
# /home/lei/octave-4.0.2/scripts/image/autumn.m:47
            g=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/autumn.m:48
            b=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/autumn.m:49
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/autumn.m:50
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/autumn.m:52
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{yiq_map} =} rgb2ntsc (@var{rgb_map})
## @deftypefnx {Function File} {@var{yiq_img} =} rgb2ntsc (@var{rgb_img})
## Transform a colormap or image from red-green-blue (RGB) color space to
## luminance-chrominance (NTSC) space.  The input may be of class uint8,
## uint16, single, or double.  The output is of class double.
##
## Implementation Note:
## The reference matrix for the transformation is
##
## @example
## @group
## /Y\     0.299  0.587  0.114  /R\
## |I|  =  0.596 -0.274 -0.322  |G|
## \Q/     0.211 -0.523  0.312  \B/
## @end group
## @end example
##
## @noindent
## as documented in @url{http://en.wikipedia.org/wiki/YIQ} and truncated to 3
## significant figures.  Note: The FCC version of NTSC uses only 2 significant
## digits and is slightly different.
## @seealso{ntsc2rgb, rgb2hsv, rgb2ind}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def rgb2ntsc(rgb=None,*args,**kwargs):
    varargin = rgb2ntsc.varargin
    nargin = rgb2ntsc.nargin

    if (nargin != 1):
        print_usage()
    
    cls=class_(rgb)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:54
    if (logical_not(any(strcmp(cls,cellarray(['uint8','uint16','single','double']))))):
        error('rgb2ntsc: invalid data type \'%s\'',cls)
    else:
        if (isfloat(rgb) and (any(ravel(rgb) < 0) or any(ravel(rgb) > 1))):
            error('rgb2ntsc: floating point images may only contain values between 0 and 1')
    
    ## If we have an image convert it into a color map.
    if (isreal(rgb) and ndims(rgb) == 3):
        is_image=copy(true)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:63
        sz=size(rgb)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:64
        rgb=matlabarray(cat(ravel(rgb[:,:,1]),ravel(rgb[:,:,2]),ravel(rgb[:,:,3])))
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:65
        if (isinteger(rgb)):
            low=double(intmin(cls))
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:68
            high=double(intmax(cls))
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:69
            rgb=(double(rgb) - low) / (high - low)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:70
        else:
            if (isa(rgb,'single')):
                rgb=double(rgb)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:72
    else:
        is_image=copy(false)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:75
    
    if (logical_not(isreal(rgb)) or columns(rgb) != 3 or issparse(rgb)):
        error('rgb2ntsc: input must be a matrix of size Nx3 or NxMx3')
    
    ## Reference matrix for transformation from http://en.wikipedia.org/wiki/YIQ
  ## and truncated to 3 significant figures.  Matlab uses this matrix for their
  ## conversion.
    trans=matlabarray(cat([0.299,0.596,0.211],[0.587,- 0.274,- 0.523],[0.114,- 0.322,0.312]))
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:85
    
    yiq=dot(rgb,trans)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:90
    
    if (is_image):
        yiq=reshape(yiq,sz)
# /home/lei/octave-4.0.2/scripts/image/rgb2ntsc.m:94
    
    return yiq
    
if __name__ == '__main__':
    pass
    
    ## Test pure RED, GREEN, BLUE colors
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1994-2016 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{img} =} gray2ind (@var{I})
## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{I}, @var{n})
## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{BW})
## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{BW}, @var{n})
## @deftypefnx {Function File} {[@var{img}, @var{map}] =} gray2ind (@dots{})
## Convert a grayscale or binary intensity image to an indexed image.
##
## The indexed image will consist of @var{n} different intensity values.
## If not given @var{n} defaults to 64 for grayscale images or 2 for binary
## black and white images.
##
## The output @var{img} is of class uint8 if @var{n} is less than or equal to
## 256; Otherwise the return class is uint16.
## @seealso{ind2gray, rgb2ind}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def gray2ind(I=None,n=64,*args,**kwargs):
    varargin = gray2ind.varargin
    nargin = gray2ind.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not(isreal(I)) or issparse(I) or logical_not(ismatrix(I))):
            error('gray2ind: I must be a grayscale or binary image')
        else:
            if (logical_not(isscalar(n)) or n < 1 or n > 65536):
                error('gray2ind: N must be a positive integer in the range [1, 65536]')
    
    ## default n is different if image is logical
    if (nargin == 1 and islogical(I)):
        n=2
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:52
    
    cls=class_(I)
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:55
    if (logical_not(any(strcmp(cls,cellarray(['logical','uint8','uint16','int16','single','double']))))):
        error('gray2ind: invalid data type \'%s\'',cls)
    else:
        if (isfloat(I) and (min(ravel(I) < 0) or max(ravel(I) > 1))):
            error('gray2ind: floating point images may only contain values between 0 and 1')
    
    map=gray(n)
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:63
    
    if (isinteger(I)):
        low=double(intmin(cls))
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:67
        scale=double(intmax(cls)) - low
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:68
        I=double(I) - low
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:69
    else:
        scale=1
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:71
    
    I *= (n - 1) / scale
    
    ##       type conversion does that automatically.
    if (n <= 256):
        I=uint8(I)
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:78
    else:
        I=uint16(I)
# /home/lei/octave-4.0.2/scripts/image/gray2ind.m:80
    
    return I,map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{rgb_map} =} hsv2rgb (@var{hsv_map})
## @deftypefnx {Function File} {@var{rgb_img} =} hsv2rgb (@var{hsv_img})
## Transform a colormap or image from hue-saturation-value (HSV) space to
## red-green-blue (RGB) space.
##
## A color in HSV space is represented by hue, saturation and value
## (brightness) levels.  Value gives the amount of light in the color.  Hue
## describes the dominant wavelength.  Saturation is the amount of hue mixed
## into the color.
##
## A color in the RGB space consists of red, green, and blue intensities.
## @seealso{rgb2hsv, ind2rgb, ntsc2rgb}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def hsv2rgb(hsv_map=None,*args,**kwargs):
    varargin = hsv2rgb.varargin
    nargin = hsv2rgb.nargin

    ## Each color value x = (r,g,b) is calculated with
  ## x = (1-sat)*val+sat*val*f_x(hue)
  ## where f_x(hue) is a piecewise defined function for
  ## each color with f_r(hue-2/3) = f_g(hue) = f_b(hue-1/3).
    
    if (nargin != 1):
        print_usage()
    
    cls=class_(hsv_map)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:48
    if (logical_not(any(strcmp(cls,cellarray(['uint8','uint16','single','double']))))):
        error('hsv2rgb: invalid data type \'%s\'',cls)
    else:
        if (isfloat(hsv_map) and (any(ravel(hsv_map) < 0) or any(ravel(hsv_map) > 1))):
            error('hsv2rgb: floating point images may only contain values between 0 and 1')
    
    ## If we have an image convert it into a color map.
    if (isreal(hsv_map) and ndims(hsv_map) == 3):
        is_image=copy(true)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:57
        sz=size(hsv_map)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:58
        hsv_map=matlabarray(cat(ravel(hsv_map[:,:,1]),ravel(hsv_map[:,:,2]),ravel(hsv_map[:,:,3])))
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:59
        if (isinteger(hsv_map)):
            low=double(intmin(cls))
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:62
            high=double(intmax(cls))
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:63
            hsv_map=(double(hsv_map) - low) / (high - low)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:64
    else:
        is_image=copy(false)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:67
    
    if (logical_not(isreal(hsv_map)) or columns(hsv_map) != 3 or issparse(hsv_map)):
        error('hsv2rgb: input must be a matrix of size Nx3 or MxNx3')
    
    ## FIXME: Currently input is validated and an error results if values
  ##        are outside range [0, 1].  We could also simply allow those values
  ##        and re-instate this code to produce saturating semantics.
  ## Trim map to range [0, 1]
  ## hsv_map(hsv_map < 0) = 0;
  ## hsv_map(hsv_map > 1) = 1;
    
    h=hsv_map[:,1]
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:81
    s=hsv_map[:,2]
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:82
    v=hsv_map[:,3]
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:83
    
    rgb_map=repmat(multiply(v,(1 - s)),1,3)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:85
    
    ## Apply modulo 1 for red and blue to keep within range [0, 1]
    hue=matlabarray(cat(mod(h - 2 / 3,1),h,mod(h - 1 / 3,1)))
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:89
    
    f=repmat(multiply(s,v),1,3)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:92
    
    rgb_map += multiply(f,(multiply(dot(6,(hue < 1 / 6)),hue) + (hue >= logical_and(1 / 6,hue) < 1 / 2) + multiply((hue >= logical_and(1 / 2,hue) < 2 / 3),(4 - dot(6,hue)))))
    
    ##        Should it also convert back to uint8, uint16 for integer images?
  ## If input was an image, convert it back into one.
    if (is_image):
        rgb_map=reshape(rgb_map,sz)
# /home/lei/octave-4.0.2/scripts/image/hsv2rgb.m:103
    
    return rgb_map
    
if __name__ == '__main__':
    pass
    
    ## Test pure colors
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} summer ()
## @deftypefnx {Function File} {@var{map} =} summer (@var{n})
## Create color colormap.  This colormap varies from green to yellow.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
## Date:  06/03/2000
    
    ## PKG_ADD: colormap ("register", "summer");
## PKG_DEL: colormap ("unregister", "summer");
    
    
@function
def summer(n=rows(colormap()),*args,**kwargs):
    varargin = summer.varargin
    nargin = summer.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('summer: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/summer.m:42
    if (n == 1):
        map=matlabarray(cat(0,0.5,0.4))
# /home/lei/octave-4.0.2/scripts/image/summer.m:45
    else:
        if (n > 1):
            r=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/summer.m:47
            g=0.5 + r / 2
# /home/lei/octave-4.0.2/scripts/image/summer.m:48
            b=dot(0.4,ones(n,1))
# /home/lei/octave-4.0.2/scripts/image/summer.m:49
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/summer.m:50
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/summer.m:52
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} imagesc (@var{img})
## @deftypefnx {Function File} {} imagesc (@var{x}, @var{y}, @var{img})
## @deftypefnx {Function File} {} imagesc (@dots{}, @var{climits})
## @deftypefnx {Function File} {} imagesc (@dots{}, "@var{prop}", @var{val}, @dots{})
## @deftypefnx {Function File} {} imagesc ("@var{prop1}", @var{val1}, @dots{})
## @deftypefnx {Function File} {} imagesc (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} imagesc (@dots{})
## Display a scaled version of the matrix @var{img} as a color image.
##
## The colormap is scaled so that the entries of the matrix occupy the entire
## colormap.  If @code{@var{climits} = [@var{lo}, @var{hi}]} is given, then
## that range is set to the @qcode{"clim"} of the current axes.
##
## The axis values corresponding to the matrix elements are specified in
## @var{x} and @var{y}, either as pairs giving the minimum and maximum
## values for the respective axes, or as values for each row and column
## of the matrix @var{img}.
##
## The optional return value @var{h} is a graphics handle to the image.
##
## Calling Forms: The @code{imagesc} function can be called in two forms:
## High-Level and Low-Level.  When invoked with normal options, the High-Level
## form is used which first calls @code{newplot} to prepare the graphic figure
## and axes.  When the only inputs to @code{image} are property/value pairs
## the Low-Level form is used which creates a new instance of an image object
## and inserts it in the current axes.
##
## @seealso{image, imshow, caxis}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def imagesc(varargin=None,*args,**kwargs):
    varargin = imagesc.varargin
    nargin = imagesc.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('imagesc',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:56
    chararg=find(cellfun('isclass',varargin,'char'),1,'first')
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:58
    do_new=copy(true)
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:60
    if (nargin == 0):
        print_usage()
    else:
        if (chararg == 1):
            ## Low-Level syntax
            do_new=copy(false)
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:65
            img=x=y=climits=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:66
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:66
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:66
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:66
        else:
            if (nargin == 1 or chararg == 2):
                img=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:68
                x=y=climits=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:69
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:69
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:69
            else:
                if (nargin == 2 or chararg == 3):
                    img=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:71
                    climits=varargin[2]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:72
                    x=y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:73
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:73
                else:
                    if (nargin == 3 or chararg == 4):
                        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:75
                        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:76
                        img=varargin[3]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:77
                        climits=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:78
                    else:
                        if (nargin == 4 or chararg == 5):
                            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:80
                            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:81
                            img=varargin[3]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:82
                            climits=varargin[4]
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:83
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:86
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:88
    
    try:
        if (do_new):
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:92
        else:
            if (isempty(hax)):
                hax=gca()
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:94
        if (do_new):
            htmp=image(x,y,img,'cdatamapping','scaled',varargin[chararg:end()])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:98
        else:
            htmp=image('cdatamapping','scaled',varargin[:])
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:100
        if (do_new and logical_not(ishold(hax))):
            ## use given climits or guess them from the matrix
            if (numel(climits) == 2 and climits[1] <= climits[2]):
                set(hax,'clim',climits)
            else:
                if (logical_not(isempty(climits))):
                    error('imagesc: CLIMITS must be in form [lo, hi]')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/image/imagesc.m:118
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004 Josep Mones i Teixidor
## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{Y}, @var{newmap}] =} cmpermute (@var{X}, @var{map})
## @deftypefnx {Function File} {[@var{Y}, @var{newmap}] =} cmpermute (@var{X}, @var{map}, @var{index})
## Reorder colors in a colormap.
##
## When called with only two arguments, @code{cmpermute} randomly rearranges
## the colormap @var{map} and returns a new colormap @var{newmap}.  It also
## returns the indexed image @var{Y} which is the equivalent of the original
## input image @var{X} when displayed using @var{newmap}.
##
## When called with an optional third argument the order of colors in the new
## colormap is defined by @var{index}.
##
## @strong{Caution:} @code{index} should not have repeated elements or the
## function will fail.
##
## @end deftypefn
    
    ## Author:  Josep Mones i Teixidor <jmones@puntbarra.com>
    
    
@function
def cmpermute(X=None,map=None,index=None,*args,**kwargs):
    varargin = cmpermute.varargin
    nargin = cmpermute.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    cls=class_(X)
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:46
    if (logical_not(any(strcmp(cls,cellarray(['uint8','uint16','single','double']))))):
        error('cmpermute: invalid data type \'%s\'',cls)
    
    if (logical_not(isreal(X)) or issparse(X) or (isfloat(X) and (any(ravel(X) < 1 or any(ravel(X) != fix(ravel(X))))))):
        error('cmpermute: X must be an indexed image')
    
    if (logical_not(iscolormap(map))):
        error('cmpermute: MAP must be a valid colormap')
    
    if (nargin < 3):
        index=randperm(rows(map))
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:61
    else:
        if (logical_not(isvector(index)) or length(index) != rows(map)):
            error('cmpermute: invalid parameter INDEX')
    
    ## new colormap
    newmap=map[index,:]
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:67
    
    rindex=zeros(size(index))
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:70
    rindex[index]=arange(1,length(index))
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:71
    
    if (strcmp(cls,'double')):
        Y=rindex[X]
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:75
    else:
        if (strcmp(cls,'single')):
            rindex=single(rindex)
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:77
            Y=rindex[X]
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:78
        else:
            ## adapt indices
            rindex=feval(cls,rindex - 1)
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:81
            Y=rindex[single(X) + 1]
# /home/lei/octave-4.0.2/scripts/image/cmpermute.m:83
    
    return Y,newmap
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map_out} =} brighten (@var{beta})
## @deftypefnx {Function File} {@var{map_out} =} brighten (@var{map}, @var{beta})
## @deftypefnx {Function File} {@var{map_out} =} brighten (@var{h}, @var{beta})
## @deftypefnx {Function File} {} brighten (@dots{})
## Brighten or darken a colormap.
##
## The argument @var{beta} must be a scalar between -1 and 1, where a negative
## value darkens and a positive value brightens the colormap.
##
## If the @var{map} argument is omitted, the function is applied to the current
## colormap.
##
## The first argument can also be a valid graphics handle @var{h}, in which
## case @code{brighten} is applied to the colormap associated with this handle.
##
## If no output is specified then the result is written to the current colormap.
## @seealso{colormap, contrast}
## @end deftypefn
    
    
@function
def brighten(arg1=None,beta=None,*args,**kwargs):
    varargin = brighten.varargin
    nargin = brighten.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    h=- 1
# /home/lei/octave-4.0.2/scripts/image/brighten.m:45
    if (nargin == 1):
        beta=copy(arg1)
# /home/lei/octave-4.0.2/scripts/image/brighten.m:47
        m=colormap()
# /home/lei/octave-4.0.2/scripts/image/brighten.m:48
        h=gcf()
# /home/lei/octave-4.0.2/scripts/image/brighten.m:49
    else:
        if (ishandle(arg1)):
            h=copy(arg1)
# /home/lei/octave-4.0.2/scripts/image/brighten.m:52
            m=get(h,'colormap')
# /home/lei/octave-4.0.2/scripts/image/brighten.m:53
        else:
            if (iscolormap(arg1)):
                m=copy(arg1)
# /home/lei/octave-4.0.2/scripts/image/brighten.m:55
            else:
                error('brighten: first argument must be a colormap or a graphics handle')
    
    if (logical_not(isscalar(beta)) or beta <= - 1 or beta >= 1):
        error('brighten: BETA must be a scalar in the range (-1,1)')
    
    if (beta > 0):
        gamma=1 - beta
# /home/lei/octave-4.0.2/scripts/image/brighten.m:66
    else:
        gamma=1 / (1 + beta)
# /home/lei/octave-4.0.2/scripts/image/brighten.m:68
    
    if (nargout == 0):
        if (ishandle(h)):
            set(h,'colormap',m ** gamma)
        else:
            colormap(m ** gamma)
    else:
        rmap=m ** gamma
# /home/lei/octave-4.0.2/scripts/image/brighten.m:78
    
    return rmap
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} iscolormap (@var{cmap})
## Return true if @var{cmap} is a colormap.
##
## A colormap is a real matrix with @var{n} rows and 3 columns.  Each row
## represents a single color.  The columns contain red, green, and blue
## intensities respectively.  All entries must be between 0 and 1 inclusive.
## @seealso{colormap, rgbplot}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug+dev@gmail.com>
    
    
@function
def iscolormap(cmap=None,*args,**kwargs):
    varargin = iscolormap.varargin
    nargin = iscolormap.nargin

    if (nargin != 1):
        print_usage
    
    retval=(isnumeric(cmap) and isreal(cmap) and ndims(cmap) == 2 and columns(cmap) == 3 and isa(cmap,'double') and min(ravel(cmap)) >= 0 and max(ravel(cmap)) <= 1)
# /home/lei/octave-4.0.2/scripts/image/iscolormap.m:37
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} cubehelix ()
## @deftypefnx {Function File} {@var{map} =} cubehelix (@var{n})
## Create cubehelix colormap.
##
## This colormap varies from black to white going though blue, green, and red
## tones while maintaining a monotonically increasing perception of intensity.
## This is achieved by transversing a color cube from black to white through
## a helix, hence the name cubehelix, while taking into account the perceived
## brightness of each channel according to the NTSC specifications from 1953.
##
## @example
## rgbplot (cubehelix (256))
## @end example
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
##
## Reference: Green, D. A., 2011,
## @cite{"A @nospell{colour} scheme for the display of astronomical intensity
## images"}, Bulletin of the Astronomical Society of India, 39, 289.
##
## @seealso{colormap}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug@octave.org>
    
    ## PKG_ADD: colormap ("register", "cubehelix");
## PKG_DEL: colormap ("unregister", "cubehelix");
    
    
@function
def cubehelix(n=rows(colormap()),start=0.5,rots=- 1.5,hue=1,gamma=1,*args,**kwargs):
    varargin = cubehelix.varargin
    nargin = cubehelix.nargin

    if (nargin > 5):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('cubehelix: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:57
    if (n > 1):
        coeff=matlabarray(cat(- 0.14861,- 0.29227,1.97294,1.78277,- 0.90649,0.0))
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:60
        fract=((arange(0,n - 1)) / (n - 1)).T
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:63
        angle=dot(dot(2,pi),(start / 3 + 1 + dot(rots,fract)))
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:64
        fract=fract ** gamma
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:65
        amp=multiply(dot(hue,fract),(1 - fract)) / 2
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:66
        map=fract + multiply(amp,(dot(cat(cos(angle),sin(angle)),coeff)))
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:67
        map[map < 0]=0
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:70
        map[map > 1]=1
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:71
    else:
        if (n > 0):
            map=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:74
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/cubehelix.m:76
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2012 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{cmap} =} colormap ()
## @deftypefnx {Function File} {@var{cmap} =} colormap (@var{map})
## @deftypefnx {Function File} {@var{cmap} =} colormap ("default")
## @deftypefnx {Function File} {@var{cmap} =} colormap ("@var{map_name}")
## @deftypefnx {Function File} {@var{cmap} =} colormap (@var{hax}, @dots{})
## @deftypefnx {Command} {} colormap @var{map_name}
## @deftypefnx {Function File} {@var{cmaps} =} colormap ("list")
## @deftypefnx {Function File} {} colormap ("register", "@var{name}")
## @deftypefnx {Function File} {} colormap ("unregister", "@var{name}")
## Query or set the current colormap.
##
## With no input arguments, @code{colormap} returns the current color map.
##
## @code{colormap (@var{map})} sets the current colormap to @var{map}.  The
## colormap should be an @var{n} row by 3 column matrix.  The columns
## contain red, green, and blue intensities respectively.  All entries
## must be between 0 and 1 inclusive.  The new colormap is returned.
##
## @code{colormap ("default")} restores the default colormap (the
## @code{jet} map with 64 entries).  The default colormap is returned.
##
## The map may also be specified by a string, @qcode{"@var{map_name}"}, where
## @var{map_name} is the name of a function that returns a colormap.
##
## If the first argument @var{hax} is an axes handle, then the colormap for
## the parent figure of @var{hax} is queried or set.
##
## For convenience, it is also possible to use this function with the
## command form, @code{colormap @var{map_name}}.
##
## @code{colormap ("list")} returns a cell array with all of the available
## colormaps.  The options @qcode{"register"} and @qcode{"unregister"}
## add or remove the colormap @var{name} from this list.
##
## @seealso{jet}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def colormap(varargin=None,*args,**kwargs):
    varargin = colormap.varargin
    nargin = colormap.nargin

    mlock
    
    
    hax,varargin,nargin=__plt_get_axis_arg__('colormap',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/image/colormap.m:66
    if (nargin > 2):
        print_usage()
    
    if (logical_not(isempty(hax))):
        cf=ancestor(hax,'figure')
# /home/lei/octave-4.0.2/scripts/image/colormap.m:73
    else:
        cf=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/image/colormap.m:75
    
    if (nargin == 1):
        map=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/colormap.m:79
        if (ischar(map)):
            if (strcmp(map,'default')):
                map=jet(64)
# /home/lei/octave-4.0.2/scripts/image/colormap.m:82
            else:
                if (strcmp(map,'list')):
                    cmap=copy(map_list)
# /home/lei/octave-4.0.2/scripts/image/colormap.m:84
                    return cmap
                else:
                    map=feval(map)
# /home/lei/octave-4.0.2/scripts/image/colormap.m:87
        if (logical_not(isempty(map))):
            if (logical_not((isnumeric(map) and isreal(map) and ndims(map) == 2 and columns(map) == 3))):
                error('colormap: MAP must be a real-valued N x 3 ([R,G,B]) matrix')
            if (any(ravel(map) < 0) or any(ravel(map) > 1)):
                error('colormap: all MAP values must be in the range [0,1]')
            if (isempty(cf)):
                cf=gcf()
# /home/lei/octave-4.0.2/scripts/image/colormap.m:100
            ## Set the new color map
            set(cf,'colormap',map)
    else:
        if (nargin == 2):
            opt=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/colormap.m:107
            name=varargin[2]
# /home/lei/octave-4.0.2/scripts/image/colormap.m:108
            if (logical_not(ischar(opt)) or logical_not(any(strcmp(opt,cellarray(['register','unregister']))))):
                print_usage()
            else:
                if (logical_not(ischar(name))):
                    error('colormap: to register/unregister a colormap, NAME must be a string')
                else:
                    if (strcmp(opt,'register')):
                        map_list[end() + 1]=name
# /home/lei/octave-4.0.2/scripts/image/colormap.m:114
                    else:
                        if (strcmp(opt,'unregister')):
                            map_list[strcmp(name,map_list)]=[]
# /home/lei/octave-4.0.2/scripts/image/colormap.m:116
    
    ## Return current color map.
    if (nargout > 0 or (nargout == 0 and nargin == 0)):
        if (isempty(cf)):
            cf=gcf()
# /home/lei/octave-4.0.2/scripts/image/colormap.m:123
        cmap=get(cf,'colormap')
# /home/lei/octave-4.0.2/scripts/image/colormap.m:125
    
    return cmap
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2012 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{map}] =} rgb2ind (@var{rgb})
## @deftypefnx {Function File} {[@var{x}, @var{map}] =} rgb2ind (@var{R}, @var{G}, @var{B})
## Convert an image in red-green-blue (RGB) color space to an indexed image.
##
## The input image @var{rgb} can be specified as a single matrix of size
## @nospell{MxNx3}, or as three separate variables, @var{R}, @var{G}, and
## @var{B}, its three color channels, red, green, and blue.
##
## It outputs an indexed image @var{x} and a colormap @var{map} to interpret
## an image exactly the same as the input.  No dithering or other form of color
## quantization is performed.  The output class of the indexed image @var{x}
## can be uint8, uint16 or double, whichever is required to specify the
## number of unique colors in the image (which will be equal to the number
## of rows in @var{map}) in order
##
## Multi-dimensional indexed images (of size @nospell{MxNx3xK}) are also
## supported, both via a single input (@var{rgb}) or its three color channels
## as separate variables.
##
## @seealso{ind2rgb, rgb2hsv, rgb2ntsc}
## @end deftypefn
    
    ## FIXME: This function has a very different syntax than the Matlab
##        one of the same name.
##        Octave function does not support N, MAP, DITHER, or TOL arguments.
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def rgb2ind(R=None,G=None,B=None,*args,**kwargs):
    varargin = rgb2ind.varargin
    nargin = rgb2ind.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (nargin == 1):
        rgb=copy(R)
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:58
        if (ndims(rgb) > 4 or size(rgb,3) != 3):
            error('rgb2ind: argument is not an RGB image')
        else:
            R=rgb[:,:,1,:]
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:62
            G=rgb[:,:,2,:]
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:63
            B=rgb[:,:,3,:]
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:64
    else:
        if (logical_not(size_equal(R,G,B))):
            error('rgb2ind: R, G, and B must have the same size')
    
    x=reshape(arange(1,numel(R)),size(R))
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:70
    map=unique(cat(ravel(R),ravel(G),ravel(B)),'rows')
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:72
    __,x=ismember(cat(ravel(R),ravel(G),ravel(B)),map,'rows',nargout=2)
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:73
    x=reshape(x,size(R))
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:74
    
    if cellarray(['single','double','logical']) == (class_(R)):
        ## do nothing, return the same
        pass
    else:
        if cellarray(['uint8','uint16']) == (class_(R)):
            map=double(map) / double(intmax(class_(R)))
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:81
        else:
            if 'int16' == (class_(R)):
                map=(double(im) + 32768) / 65535
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:83
            else:
                error('unsupported image class %s',im_class)
    
    ## we convert to the smallest class necessary to encode the image. Matlab
  ## documentation does not mention what it does when uint16 is not enough...
  ## When an indexed image is of integer class, there's a -1 offset to the
  ## colormap, hence the adjustment
    if (rows(map) < 256):
        x=uint8(x - 1)
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:93
    else:
        if (rows(map) < 65536):
            x=uint16(x - 1)
# /home/lei/octave-4.0.2/scripts/image/rgb2ind.m:95
        else:
            ## leave it as double
            pass
    
    return x,map
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## FIXME: the following tests simply make sure that rgb2ind and ind2rgb
##        reverse each other. We should have better tests for this.
    
    ## Typical usage
    
    
    
    
    
    
    
    ## Test N-dimensional images
    
    
    
    
    
    ## Test output class
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Carn Draug
## Copyright (C) 2008-2015 Thomas L. Scofield
## Copyright (C) 2008 Kristian Rumberg
## Copyright (C) 2006 Thomas Weber
## Copyright (C) 2005 Stefan van der Walt
## Copyright (C) 2002 Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{img}, @var{map}, @var{alpha}] =} imread (@var{filename})
## @deftypefnx {Function File} {[@dots{}] =} imread (@var{url})
## @deftypefnx {Function File} {[@dots{}] =} imread (@dots{}, @var{ext})
## @deftypefnx {Function File} {[@dots{}] =} imread (@dots{}, @var{idx})
## @deftypefnx {Function File} {[@dots{}] =} imread (@dots{}, @var{param1}, @var{val1}, @dots{})
## Read images from various file formats.
##
## Read an image as a matrix from the file @var{filename}.  If there is no file
## @var{filename}, and @var{ext} was specified, it will look for a file with
## the extension @var{ext}.  Finally, it will attempt to download and read an
## image from @var{url}.
##
## The size and class of the output depends on the format of the image.  A
## color image is returned as an @nospell{MxNx3} matrix.  Gray-level and
## black-and-white images are of size @nospell{MxN}.  Multipage images will
## have an additional 4th dimension.
##
## The bit depth of the image determines the class of the output:
## @qcode{"uint8"}, @qcode{"uint16"} or @qcode{"single"} for gray and color,
## and @qcode{"logical"} for black and white.  Note that indexed images always
## return the indexes for a colormap, independent if @var{map} is a requested
## output.  To obtain the actual RGB image, use @code{ind2rgb}.  When more
## than one indexed image is being read, @var{map} is obtained from the
## first.  In some rare cases this may be incorrect and @code{imfinfo} can be
## used to obtain the colormap of each image.
##
## See the Octave manual for more information in representing images.
##
## Some file formats, such as TIFF and GIF, are able to store multiple images
## in a single file.  @var{idx} can be a scalar or vector specifying the
## index of the images to read.  By default, Octave will only read the first
## page.
##
## Depending on the file format, it is possible to configure the reading of
## images with @var{param}, @var{val} pairs.  The following options are
## supported:
##
## @table @samp
## @item @qcode{"Frames"} or @qcode{"Index"}
## This is an alternative method to specify @var{idx}.  When specifying it
## in this way, its value can also be the string @qcode{"all"}.
##
## @item @qcode{"Info"}
## This option exists for @sc{matlab} compatibility and has no effect.  For
## maximum performance while reading multiple images from a single file, use
## the Index option.
##
## @item @qcode{"PixelRegion"}
## Controls the image region that is read.  Takes as value a cell array with
## two arrays of 3 elements @code{@{@var{rows} @var{cols}@}}.  The elements
## in the array are the start, increment and end pixel to be read.  If the
## increment value is omitted, defaults to 1.  For example, the following are
## all equivalent:
##
## @example
## @group
## imread (filename, "PixelRegion", @{[200 600] [300 700]@});
## imread (filename, "PixelRegion", @{[200 1 600] [300 1 700]@});
## imread (filename)(200:600, 300:700);
## @end group
## @end example
##
## @end table
##
## @seealso{imwrite, imfinfo, imformats}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug@octave.org>
## Author: Thomas L. Scofield <scofield@calvin.edu>
## Author: Kristian Rumberg <kristianrumberg@gmail.com>
## Author: Thomas Weber <thomas.weber.mail@gmail.com>
## Author: Stefan van der Walt <stefan@sun.ac.za>
## Author: Andy Adler
    
    
@function
def imread(filename=None,varargin=None,*args,**kwargs):
    varargin = imread.varargin
    nargin = imread.nargin

    if (nargin < 1):
        print_usage()
    else:
        if (logical_not(ischar(filename))):
            error('imread: FILENAME must be a string')
    
    img,varargout[1:nargout - 1]=imageIO('imread',__imread__,'read',filename,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/image/imread.m:106
    return img,varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test PixelRegion option
    
    
    
    
    
    ## If a file does not exist, it's the job of imread to check the file
## exists before sending it over to __imread__ or whatever function
## is defined in imformats to handle that specific format.  This is the
## same in imfinfo.  So in this test we replace one format in imformats
## with something that will not give an error if the file is missing
## and make sure we do get an error.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## make one of the formats read, return what it received as input to
## confirm that the input parsing is working correcly
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 John W. Eaton
## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## This function does all the work of imwrite. It exists here as private
## function so that imwrite can use other functions if imformats is
## configured to. It is also needed so that imformats can create a
## function handle for it.
    
    
@function
def __imwrite__(img=None,varargin=None,*args,**kwargs):
    varargin = __imwrite__.varargin
    nargin = __imwrite__.nargin

    if (nargin < 2 or logical_not((isnumeric(img) or islogical(img)))):
        print_usage('imwrite')
    
    filename,ext,map,param_list=imwrite_filename(varargin[:],nargout=4)
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:31
    if (isempty(img)):
        error('imwrite: invalid empty image')
    else:
        if (issparse(img) or issparse(map)):
            error('imwrite: sparse images are not supported')
    
    if (rem(numel(param_list),2) != 0):
        error('imwrite: no pair for all arguments (odd number left)')
    
    ## set default for options
    options=struct('writemode','overwrite','disposalmethod',cellarray([repmat(cellarray(['doNotSpecify']),1,size(img,4))]),'quality',75,'delaytime',dot(ones(1,size(img,4)),500),'loopcount',0,'alpha',cast([],class_(img)))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:44
    for idx in arange(1,numel(param_list),2).reshape(-1):
        if 'alpha' == (tolower(param_list[idx])):
            options.alpha = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:56
            if (logical_not(isnumeric(options.alpha))):
                error('imwrite: value for %s option must be a numeric matrix',param_list[idx])
            else:
                if (size(options.alpha,3) != 1):
                    error('imwrite: 3rd dimension of matrix for %s must be singleton',param_list[idx])
                else:
                    if (ndims(options.alpha) > 4 or any(size(options.alpha)(cat(1,2)) != size(img)(cat(1,2))) or size(options.alpha,4) != size(img,4)):
                        error('imwrite: matrix for %s must have same dimension as image',param_list[idx])
        else:
            if 'delaytime' == (tolower(param_list[idx])):
                options.delaytime = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:71
                if (logical_not(isnumeric(options.delaytime))):
                    error('imwrite: value for %s option must be numeric',param_list[idx])
                options.delaytime *= 100
                if (isscalar(options.delaytime)):
                    options.delaytime[1:size(img,4)]=options.delaytime
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:78
                else:
                    if (size(img,4) != numel(options.delaytime)):
                        error('imwrite: value for %s must either be a scalar or the number of frames',param_list[idx])
                if (any(ravel(options.delaytime) < 0) or any(ravel(options.delaytime) > 65535)):
                    error('imwrite: value for %s must be between 0 and 655.35 seconds',param_list[idx])
            else:
                if 'disposalmethod' == (tolower(param_list[idx])):
                    options.disposalmethod = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:90
                    if (logical_not(ischar(options.disposalmethod)) and logical_not(iscellstr(options.disposalmethod))):
                        error('imwrite: value for %s must be a string or cell array of strings',param_list[idx])
                    else:
                        if (logical_not(iscell(options.disposalmethod))):
                            options.disposalmethod = copy(cellarray([options.disposalmethod]))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:96
                    options.disposalmethod = copy(tolower(options.disposalmethod))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:98
                    matches=ismember(options.disposalmethod,cellarray(['donotspecify','leaveinplace','restorebg','restoreprevious']))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:99
                    if (any(logical_not(matches))):
                        error('imwrite: unknown method %s for option %s',options.disposalmethod[find(logical_not(matches),1)],param_list[idx])
                    if (isscalar(options.disposalmethod)):
                        options.disposalmethod = copy(repmat(options.disposalmethod,1,size(img,4)))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:108
                    else:
                        if (numel(options.disposalmethod) != size(img,4)):
                            error('imwrite: if value %s is a cell array must have same length as number of frames',param_list[idx])
                else:
                    if 'loopcount' == (tolower(param_list[idx])):
                        options.loopcount = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:116
                        if (logical_not(isscalar(options.loopcount)) or logical_not(isnumeric(options.loopcount)) or (logical_not(isinf(options.loopcount)) and (options.loopcount < 0 or options.loopcount > 65535))):
                            error('imwrite: value for %s must be Inf or between 0 and 65535',param_list[idx])
                        ## Graphics Magick is a bit weird here. A value of 0 will be an
        ## infinite loop, a value of 1, will really be no loop, while a
        ## value of 2 or more will be that number of loops (checked
        ## with GNOME image viewer). This means that there is no way
        ## to make it loop only once. See
        ## https://sourceforge.net/p/graphicsmagick/bugs/249/
        ## There is also the problem of setting this when there is only
        ## a single frame. See
        ## https://sourceforge.net/p/graphicsmagick/bugs/248/
                        if (isinf(options.loopcount)):
                            options.loopcount = copy(0)
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:133
                        else:
                            if (options.loopcount == 0 or options.loopcount == 1):
                                options.loopcount
                        options.loopcount = copy(floor(options.loopcount))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:137
                    else:
                        if 'quality' == (tolower(param_list[idx])):
                            options.quality = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:140
                            if (logical_not(isnumeric(options.quality)) or logical_not(isscalar(options.quality)) or options.quality < 0 or options.quality > 100):
                                error('imwrite: value for %s option must be a scalar between 0 and 100',param_list[idx])
                            options.quality = copy(round(options.quality))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:146
                        else:
                            if 'writemode' == (tolower(param_list[idx])):
                                options.writemode = copy(param_list[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:149
                                if (logical_not(ischar(options.writemode)) or logical_not(any(strcmpi(options.writemode,cellarray(['append','overwrite']))))):
                                    error('imwrite: value for %s option must be "append" or "overwrite"',param_list[idx])
                                options.writemode = copy(tolower(options.writemode))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:155
                            else:
                                error('imwrite: invalid PARAMETER `%s\'',param_list[idx])
    
    if (logical_not(isempty(map))):
        if (logical_not(iscolormap(map))):
            error('imwrite: invalid MAP for indexed image')
        else:
            if (ndims(img) != 2 and ndims(img) != 4):
                error('imwrite: indexed image must have 2 or 4 dimensions (found %i)',ndims(img))
        ## Fill in the colormap as required with rgb (0, 0, 0) (bug #33615)
        nColors=rows(map)
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:171
        if (any(strcmp(class_(img),cellarray(['uint8','uint16','logical'])))):
            required_colors=max(ravel(img)) + 1
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:173
        else:
            required_colors=max(ravel(img))
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:175
        if (nColors < required_colors):
            warning('imwrite: MAP has not enough colors. Filling with black')
            map[nColors + 1:required_colors,:]=0
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:179
        ## If the image is floating point, then we convert it to integer (makes
    ## it easier in __magick_write__ since it only handles integers. Also,
    ## if it's floating point, it has an offset of 1
        if (isfloat(img)):
            if (rows(map) <= 256):
                img=uint8(img - 1)
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:187
            else:
                img=uint16(img - 1)
# /home/lei/octave-4.0.2/scripts/image/private/__imwrite__.m:189
    
    if (ndims(img) > 4):
        error('imwrite: invalid %d-dimensional image data',ndims(img))
    else:
        if (all(size(img,3) != cat(1,3,4))):
            ## 1, 3, or 4 for grayscle, RGB, and CMYK respectively
            error('imwrite: IMG 3rd dimension must be 1, 3, or 4')
    
    __magick_write__(filename,ext,img,map,options)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Carn Draug
## Copyright (C) 2008-2015 Thomas L. Scofield
## Copyright (C) 2008 Kristian Rumberg
## Copyright (C) 2006 Thomas Weber
## Copyright (C) 2005 Stefan van der Walt
## Copyright (C) 2002 Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## This function does all the work of imread. It exists here as private
## function so that imread can use other functions if imformats is
## configured to. It is also needed so that imformats can create a
## function handle for it.
    
    ## Author: Carn Draug <carandraug@octave.org>
## Author: Thomas L. Scofield <scofield@calvin.edu>
## Author: Kristian Rumberg <kristianrumberg@gmail.com>
## Author: Thomas Weber <thomas.weber.mail@gmail.com>
## Author: Stefan van der Walt <stefan@sun.ac.za>
## Author: Andy Adler
    
    
@function
def __imread__(filename=None,varargin=None,*args,**kwargs):
    varargin = __imread__.varargin
    nargin = __imread__.nargin

    if (nargin < 1):
        print_usage('imread')
    else:
        if (logical_not(ischar(filename))):
            error('imread: FILENAME must be a string')
    
    ## keep track of the varargin offset we're looking at each moment
    offset=1
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:45
    
    ## images on each page. Specifically, they may have different sizes. Because
  ## of this, we need to first find out the index of the images to read so
  ## we can set up defaults for things such as PixelRegion later on.
    options=struct('index',1)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:51
    
    ## Index is the only option that can be defined without the parameter/value
  ## pair style. When defining it here, the string "all" is invalid though.
  ## Also, for matlab compatibility, if index is defined both as an option here
  ## and parameter/value pair, silently ignore the first.
    if (nargin >= offset + 1 and logical_not(ischar(varargin[offset]))):
        if (logical_not(is_valid_index_option(options.index))):
            error('imread: IDX must be a numeric vector')
        options.index = copy(varargin[offset])
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:61
        offset
    
    if (rem(numel(varargin) - offset + 1,2) != 0):
        error('imread: no pair for all arguments (odd number left over)')
    
    ## Check key/value options.
    indexes=cellfun('isclass',varargin,'char')
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:70
    indexes[indexes] &= ismember(tolower(varargin[indexes]),cellarray(['frames','index']))
    indexes=find(indexes)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:73
    if (indexes):
        options.index = copy(varargin[indexes + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:75
        if (logical_not(is_valid_index_option(options.index)) and logical_not((ischar(options.index) and strcmpi(options.index,'all')))):
            error('imread: value for %s must be a vector or the string `all\'')
    
    ## Use information from the first image to be read to set defaults.
    if (ischar(options.index) and strcmpi(options.index,'all')):
        info=__magick_ping__(filename,1)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:84
    else:
        info=__magick_ping__(filename,options.index(1))
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:86
    
    ## Set default for options.
    options.region = copy(cellarray([arange(1,info.rows,1),arange(1,info.columns,1)]))
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:90
    for idx in arange(offset,(numel(varargin) - offset + 1),2).reshape(-1):
        if cellarray(['frames','index']) == (tolower(varargin[idx])):
            ## Do nothing. This options were already processed before the loop.
            pass
        else:
            if 'pixelregion' == (tolower(varargin[idx])):
                options.region = copy(varargin[idx + 1])
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:99
                if (logical_not(iscell(options.region)) or numel(options.region) != 2):
                    error('imread: value for %s must be a 2 element cell array',varargin[idx])
                for reg_idx in arange(1,2).reshape(-1):
                    if (numel(options.region[reg_idx]) == 3):
                        ## do nothing
                        pass
                    else:
                        if (numel(options.region[reg_idx]) == 2):
                            options.region[reg_idx][3]=options.region[reg_idx](2)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:108
                            options.region[reg_idx][2]=1
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:109
                        else:
                            error('imread: range for %s must be a 2 or 3 element vector',varargin[idx])
                    options.region[reg_idx]=arange(floor(options.region[reg_idx](1)),floor(options.region[reg_idx](3)),floor(options.region[reg_idx](2)))
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:114
                if (options.region[1](end()) > info.rows):
                    error('imread: end ROWS for PixelRegions option is larger than image height')
                else:
                    if (options.region[2](end()) > info.columns):
                        error('imread: end COLS for PixelRegions option is larger than image width')
            else:
                if 'info' == (tolower(varargin[idx])):
                    ## speed up the reading of multipage TIFF by passing a structure
        ## that contains information about the start on the file of each
        ## page.  We can't control it through GraphicsMagic but at least
        ## we allow to load multiple pages with one command.
                    pass
                else:
                    error('imread: invalid PARAMETER `%s\'',varargin[idx])
    
    varargout[1:nargout]=__magick_read__(filename,options)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:137
    return varargout
    
if __name__ == '__main__':
    pass
    
    ## Tests if the value passed to the Index or Frames is valid. This option
## can be defined in two places, but only in one place can it also be the
## string "all"
    
@function
def is_valid_index_option(arg=None,*args,**kwargs):
    varargin = is_valid_index_option.varargin
    nargin = is_valid_index_option.nargin

    bool=isvector(arg) and isnumeric(arg) and isreal(arg)
# /home/lei/octave-4.0.2/scripts/image/private/__imread__.m:145
    return bool
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## The input check for imwrite needs to be done twice, once when imwrite
## is called the first time to find where the filename is, and a second
## time by __imwrite__ after imformats decides what function to use.
## Because a user can, and is encouraged to, get a function handle to
## __imwrite__, the input check is also done there.
## In addition, the input check for imwrite is not that straightforward
## in order to support the multiple ways the function can be called,
## and interpretations of Matlab documentation.
##
## Anyway, this will only do the input check until it finds the filename
## to be used, the only part that imwrite actually needs.
    
    
@function
def imwrite_filename(varargin=None,*args,**kwargs):
    varargin = imwrite_filename.varargin
    nargin = imwrite_filename.nargin

    ## First, we check if the first argument is a colormap or a filename.
    cmap=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:34
    if (ischar(varargin[1])):
        filename_idx=1
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:36
    else:
        if (numel(varargin) >= 2 and iscolormap(varargin[1]) and ischar(varargin[2])):
            filename_idx=2
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:39
            cmap=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:40
        else:
            error('imwrite: no FILENAME specified')
    
    filename=tilde_expand(varargin[filename_idx])
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:44
    
    ## if we have an odd number of leftover arguments, and the next argument
  ## is a string, we consider it the file extension. Otherwise we will
  ## extract what we can from the previously found filename.
    options_idx=filename_idx + 1
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:50
    if (numel(varargin) > filename_idx and rem(length(varargin) - filename_idx,2) != 0 and ischar(varargin[filename_idx + 1])):
        ext=varargin[filename_idx + 1]
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:54
        options_idx
    else:
        __,__,ext=fileparts(filename,nargout=3)
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:57
        if (logical_not(isempty(ext))):
            ## remove dot from extension
            ext=ext[2:end()]
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:60
    
    ## After all the work finding where the filename was, we might as well
  ## send the leftovers list (they should be in key value pairs)
    options=varargin[options_idx:end()]
# /home/lei/octave-4.0.2/scripts/image/private/imwrite_filename.m:66
    return filename,ext,cmap,options
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2012 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## private function for the ind2XXX functions which have a lot of code in common
    
    
@function
def ind2x(caller=None,x=None,map=None,*args,**kwargs):
    varargin = ind2x.varargin
    nargin = ind2x.nargin

    ## Check if X is an indexed image.
  ## An indexed image is defined has having only 2D, and that's how Matlab
  ## behaves.  But we want to support ND images, so we will allow up to 4D
  ## and check that the 3rd dimension is a singleton.
    if (all(ndims(x) != cat(2,4)) or size(x,3) != 1 or iscomplex(x) or issparse(x) or (isfloat(x) and x != fix(x)) or logical_not(any(strcmp(class_(x),cellarray(['uint8','uint16','single','double']))))):
        error('%s: X must be an indexed image',caller)
    
    ## Check if map is a valid colormap.
    if (logical_not(iscolormap(map))):
        error('%s: MAP must be a valid colormap',caller)
    
    ## Any color indices below the lower bound of the color map are modified
  ## to point to the first color in the map (see bug #41851).
    if (isfloat(x)):
        invalid_idx=x < 1
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:43
        if (any(ravel(invalid_idx))):
            warning(cat('Octave:',caller,':invalid-idx-img'),cat(caller,': indexed image contains colors outside of colormap'))
            x[invalid_idx]=1
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:47
    
    ## Switch to using 1-based indexing.
  ## It is possible that an integer storage class may not have enough room
  ## to make the switch, in which case we convert the data to single.
    maxidx=max(ravel(x))
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:54
    if (isinteger(x)):
        if (maxidx == intmax(class_(x))):
            x=single(x)
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:57
        x += 1
        maxidx += 1
    
    ## When there are more colors in the image, than there are in the map,
  ## pad the colormap with the last color in the map for Matlab compatibility.
    num_colors=rows(map)
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:65
    if (num_colors < maxidx):
        warning(cat('Octave:',caller,':invalid-idx-img'),cat(caller,': indexed image contains colors outside of colormap'))
        pad=repmat(map[end(),:],maxidx - num_colors,1)
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:69
        map[end() + 1:maxidx,:]=pad
# /home/lei/octave-4.0.2/scripts/image/private/ind2x.m:70
    
    return x,map
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## This function the image input functions imread() and imfinfo() to the
## functions that will actually be used, based on their format.  See below
## on the details on how it identifies the format, and to what it defaults.
##
## It will change the input arguments that were passed to imread() and
## imfinfo().  It will change the filename to provide the absolute filepath
## for the file, it will extract the possible format name from the rest of
## the input arguments (in case there was one), and will give an error if
## the file can't be found.
##
## Usage:
##
## func      - Function name to use on error message.
## core_func - Function handle for the default function to use if we can't
##             find the format in imformats.
## fieldname - Name of the field in the struct returned by imformats that
##             has the function to use.
## filename  - Most likely the first input argument from the function that
##             called this. May be missing the file extension which can be
##             on varargin.
## varargin  - Followed by all the OTHER arguments passed to imread and
##             imfinfo.
    
    
@function
def imageIO(func=None,core_func=None,fieldname=None,filename=None,varargin=None,*args,**kwargs):
    varargin = imageIO.varargin
    nargin = imageIO.nargin

    ## First thing: figure out the filename and possibly download it.
  ## The first attempt is to try the filename and see if it exists.  If it
  ## does not, we try to add the next argument since the file extension can
  ## be given as a separate argument.  If we still can't find the file, it
  ## can be a URL.  Lastly, if we still didn't found a file, try adding the
  ## extension to the URL
    
    file_2_delete=copy(false)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:51
    
    
    
    fn=abs_path(filename)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:55
    if (isempty(fn) and logical_not(isempty(varargin))):
        ## Maybe if we add a file extension
        fn=abs_path(cat(filename,'.',varargin[1]))
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:58
    
    ## Maybe we have an URL
    if (isempty(fn)):
        file_2_delete=copy(true)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:63
        fn,__=urlwrite(filename,tempname(),nargout=2)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:64
        if (isempty(fn) and logical_not(isempty(varargin))):
            fn,__=urlwrite(cat(filename,'.',varargin[1]),tempname(),nargout=2)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:67
        if (isempty(fn)):
            error('%s: unable to find file %s',func,filename)
    
    ## unwind_protect block because we may have a file to remove in the end
    try:
        ## When guessing the format to use, we first check if the second
    ## argument is a format defined in imformats.  If so, we remove it
    ## from the rest of arguments before passing them on.  If not, we
    ## try to guess the format from the file extension.  Finally, if
    ## we still don't know the format, we use the Octave core functions
    ## which is the same for all formats.
        foo=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:84
        ## We check if the call to imformats (ext) worked using
    ## "numfields (fmt) > 0 because when it fails, the returned
    ## struct is not considered empty.
        ## try the second input argument
        if (logical_not(isempty(varargin)) and ischar(varargin[1])):
            fmt=imformats(varargin[1])
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:92
            if (numfields(fmt) > 0):
                foo=getattr(fmt,(fieldname))
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:94
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:95
        ## try extension from file name
        if (isempty(foo)):
            __,__,ext=fileparts(fn,nargout=3)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:101
            if (logical_not(isempty(ext))):
                ## remove dot from extension
                ext=ext[2:end()]
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:104
            fmt=imformats(ext)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:106
            if (numfields(fmt) > 0):
                foo=getattr(fmt,(fieldname))
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:108
        ## use the core function
        if (isempty(foo)):
            foo=copy(core_func)
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:114
        varargout[1:nargout]=foo[fn,varargin[:]]
# /home/lei/octave-4.0.2/scripts/image/private/imageIO.m:117
    finally:
        if (file_2_delete):
            unlink(fn)
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 Soren Hauberg
## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## This function does all the work of imfinfo. It exists here as private
## function so that imfinfo can use other functions if imformats is
## configured to. It is also needed so that imformats can create a
## function handle for it.
    
    ## Author: Soren Hauberg <hauberg@gmail.com>
    
    
@function
def __imfinfo__(filename=None,*args,**kwargs):
    varargin = __imfinfo__.varargin
    nargin = __imfinfo__.nargin

    if (nargin != 1):
        print_usage('imfinfo')
    else:
        if (logical_not(ischar(filename))):
            error('imfinfo: FILENAME must be a string')
    
    info=__magick_finfo__(filename)
# /home/lei/octave-4.0.2/scripts/image/private/__imfinfo__.m:35
    return info
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{rgb} =} ind2rgb (@var{x}, @var{map})
## @deftypefnx {Function File} {[@var{R}, @var{G}, @var{B}] =} ind2rgb (@var{x}, @var{map})
## Convert an indexed image to red, green, and blue color components.
##
## The image @var{x} must be an indexed image which will be converted using the
## colormap @var{map}.  If @var{map} does not contain enough colors for the
## image, pixels in @var{x} outside the range are mapped to the last color in
## the map.
##
## The output may be a single RGB image (@nospell{MxNx3} matrix where M and N
## are the original image @var{x} dimensions, one for each of the red, green
## and blue channels).  Alternatively, the individual red, green, and blue
## color matrices of size @nospell{MxN} may be returned.
##
## Multi-dimensional indexed images (of size @nospell{MxNx1xK}) are also
## supported.
##
## @seealso{rgb2ind, ind2gray, hsv2rgb, ntsc2rgb}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def ind2rgb(x=None,map=None,*args,**kwargs):
    varargin = ind2rgb.varargin
    nargin = ind2rgb.nargin

    if (nargin != 2):
        print_usage()
    
    x,map=ind2x('ind2rgb',x,map,nargout=2)
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:49
    
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:52
    R=reshape(map[ravel(x),1],sz)
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:53
    G=reshape(map[ravel(x),2],sz)
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:54
    B=reshape(map[ravel(x),3],sz)
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:55
    
    if (nargout <= 1):
        if (ndims(x) == 2):
            R=reshape(cat([ravel(R)],[ravel(G)],[ravel(B)]),cat(sz,3))
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:60
        else:
            if (ndims(x) == 4):
                R=permute(reshape(cat([ravel(R)],[ravel(G)],[ravel(B)]),cat(sz[1],sz[2],sz[4],3)),cat(1,2,4,3))
# /home/lei/octave-4.0.2/scripts/image/ind2rgb.m:62
            else:
                ## we should never reach here since ind2x() should filter them out
                error('ind2rgb: an indexed image must have 2 or 4 dimensions.')
    
    return R,G,B
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} lines ()
## @deftypefnx {Function File} {@var{map} =} lines (@var{n})
## Create color colormap.  This colormap is composed of the list of colors
## in the current axes @qcode{"ColorOrder"} property.  The default is blue,
## green, red, cyan, pink, yellow, and gray.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## PKG_ADD: colormap ("register", "lines");
## PKG_DEL: colormap ("unregister", "lines");
    
    
@function
def lines(n=rows(colormap()),*args,**kwargs):
    varargin = lines.varargin
    nargin = lines.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('lines: N must be a scalar')
    
    if (n == 1):
        map=matlabarray(cat(0,0,1))
# /home/lei/octave-4.0.2/scripts/image/lines.m:43
    else:
        if (n > 1):
            C=get(gca,'colororder')
# /home/lei/octave-4.0.2/scripts/image/lines.m:45
            nr=rows(C)
# /home/lei/octave-4.0.2/scripts/image/lines.m:46
            map=C[rem(arange(0,(n - 1)),nr) + 1,:]
# /home/lei/octave-4.0.2/scripts/image/lines.m:47
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/lines.m:49
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2004 Josep Mones i Teixidor
## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{Y}, @var{newmap}] =} cmunique (@var{X}, @var{map})
## @deftypefnx {Function File} {[@var{Y}, @var{newmap}] =} cmunique (@var{RGB})
## @deftypefnx {Function File} {[@var{Y}, @var{newmap}] =} cmunique (@var{I})
## Convert an input image @var{X} to an ouput indexed image @var{Y} which uses
## the smallest colormap possible @var{newmap}.
##
## When the input is an indexed image (@var{X} with colormap @var{map}) the
## output is a colormap @var{newmap} from which any repeated rows have been
## eliminated.  The output image, @var{Y}, is the original input image with
## the indices adjusted to match the new, possibly smaller, colormap.
##
## When the input is an RGB image (an @nospell{MxNx3} array), the output
## colormap will contain one entry for every unique color in the original image.
## In the worst case the new map could have as many rows as the number of
## pixels in the original image.
##
## When the input is a grayscale image @var{I}, the output colormap will
## contain one entry for every unique intensity value in the original image.
## In the worst case the new map could have as many rows as the number of
## pixels in the original image.
##
## Implementation Details:
##
## @var{newmap} is always an Mx3 matrix, even if the input image is
## an intensity grayscale image @var{I} (all three RGB planes are
## assigned the same value).
##
## The output image is of class uint8 if the size of the new colormap is
## less than or equal to 256.  Otherwise, the output image is of class double.
##
## @seealso{rgb2ind, gray2ind}
## @end deftypefn
    
    ## Author:  Josep Mones i Teixidor <jmones@puntbarra.com>
    
    
@function
def cmunique(X=None,map=None,*args,**kwargs):
    varargin = cmunique.varargin
    nargin = cmunique.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    cls=class_(X)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:63
    if (logical_not(any(strcmp(cls,cellarray(['uint8','uint16','single','double']))))):
        error('cmunique: X is of invalid data type \'%s\'',cls)
    
    if (nargin == 2):
        ## (X, map) case
        if (logical_not(iscolormap(map))):
            error('cmunique: MAP must be a valid colormap')
        newmap,i,j=unique(map,'rows',nargout=3)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:73
        if (isfloat(X)):
            Y=j[X]
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:75
        else:
            Y=j[double(X) + 1]
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:77
    else:
        if 1 == (size(X,3)):
            ## I case
            newmap,i,j=unique(X,nargout=3)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:83
            newmap=repmat(newmap,1,3)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:84
            Y=reshape(j,rows(X),columns(X))
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:85
        else:
            if 3 == (size(X,3)):
                ## RGB case
        ## build a map with all values
                map=matlabarray(cat(ravel(X[:,:,1]),ravel(X[:,:,2]),ravel(X[:,:,3])))
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:89
                newmap,i,j=unique(map,'rows',nargout=3)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:90
                Y=reshape(j,rows(X),columns(X))
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:91
            else:
                error('cmunique: X is not a valid image')
        ## if image was uint8 or uint16 we have to convert newmap to [0,1] range
        if (isinteger(X)):
            newmap=double(newmap) / double(intmax(cls))
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:98
    
    if (rows(newmap) <= 256):
        ## convert Y to uint8 and 0-based indexing
        Y=uint8(Y - 1)
# /home/lei/octave-4.0.2/scripts/image/cmunique.m:104
    
    return Y,newmap
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Check that output is uint8 in short colormaps
    
    
    
    ## Check that output is double in bigger
    
    
    
    ## Check boundary case 256
    
    
    
    ## Check boundary case 257
    
    
    
    ## Random RGB image
    
    
    
    
    
    ## Random uint8 RGB image
    
    
    
    
    
    
    ## Random uint16 RGB image
    
    
    
    
    
    
    ## Random I image
    
    
    
    
    
    ## Random uint8 I image
    
    
    
    
    
    
    ## Random uint16 I image
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} prism ()
## @deftypefnx {Function File} {@var{map} =} prism (@var{n})
## Create color colormap.  This colormap cycles through red, orange, yellow,
## green, blue and violet with each index change.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "prism");
## PKG_DEL: colormap ("unregister", "prism");
    
    
@function
def prism(n=rows(colormap()),*args,**kwargs):
    varargin = prism.varargin
    nargin = prism.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('prism: N must be a scalar')
    
    if (n == 1):
        map=matlabarray(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/image/prism.m:44
    else:
        if (n > 1):
            C=matlabarray(cat([1,0,0],[1,1 / 2,0],[1,1,0],[0,1,0],[0,0,1],[2 / 3,0,1]))
# /home/lei/octave-4.0.2/scripts/image/prism.m:46
            map=C[rem(arange(0,(n - 1)),6) + 1,:]
# /home/lei/octave-4.0.2/scripts/image/prism.m:47
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/prism.m:49
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} winter ()
## @deftypefnx {Function File} {@var{map} =} winter (@var{n})
## Create color colormap.  This colormap varies from blue to green.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "winter");
## PKG_DEL: colormap ("unregister", "winter");
    
    
@function
def winter(n=rows(colormap()),*args,**kwargs):
    varargin = winter.varargin
    nargin = winter.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('winter: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/winter.m:41
    if (n == 1):
        map=matlabarray(cat(0,0,1))
# /home/lei/octave-4.0.2/scripts/image/winter.m:44
    else:
        if (n > 1):
            r=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/image/winter.m:46
            g=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/winter.m:47
            b=1 - g / 2
# /home/lei/octave-4.0.2/scripts/image/winter.m:48
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/winter.m:49
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/winter.m:51
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} spinmap ()
## @deftypefnx {Function File} {} spinmap (@var{t})
## @deftypefnx {Function File} {} spinmap (@var{t}, @var{inc})
## @deftypefnx {Function File} {} spinmap ("inf")
## Cycle the colormap for @var{t} seconds with a color increment of @var{inc}.
##
## Both parameters are optional.  The default cycle time is 5 seconds and the
## default increment is 2.  If the option @qcode{"inf"} is given then cycle
## continuously until @kbd{Control-C} is pressed.
##
## When rotating, the original color 1 becomes color 2, color 2 becomes
## color 3, etc.  A positive or negative increment is allowed and a higher
## value of @var{inc} will cause faster cycling through the colormap.
## @seealso{colormap}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel at gmx.de>
    
    
@function
def spinmap(t=5,inc=2,*args,**kwargs):
    varargin = spinmap.varargin
    nargin = spinmap.nargin

    if (nargin > 2):
        print_usage()
    else:
        if (ischar(t)):
            if (strcmpi(t,'inf')):
                t=copy(Inf)
# /home/lei/octave-4.0.2/scripts/image/spinmap.m:44
            else:
                error('spinmap: time T must be a real scalar or "inf"')
        else:
            if (logical_not(isscalar(t)) or logical_not(isreal(t))):
                error('spinmap: time T must be a real scalar')
    
    cmap=cmap_orig=get(gcf(),'colormap')
# /home/lei/octave-4.0.2/scripts/image/spinmap.m:52
# /home/lei/octave-4.0.2/scripts/image/spinmap.m:52
    t0=copy(clock)
# /home/lei/octave-4.0.2/scripts/image/spinmap.m:54
    while (etime(clock,t0) < t):

        cmap=shift(cmap,inc,1)
# /home/lei/octave-4.0.2/scripts/image/spinmap.m:56
        set(gcf(),'colormap',cmap)
        drawnow()

    
    set(gcf(),'colormap',cmap_orig)
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} ocean ()
## @deftypefnx {Function File} {@var{map} =} ocean (@var{n})
## Create color colormap.  This colormap varies from black to white with shades
## of blue.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    ## PKG_ADD: colormap ("register", "ocean");
## PKG_DEL: colormap ("unregister", "ocean");
    
    
@function
def ocean(n=rows(colormap()),*args,**kwargs):
    varargin = ocean.varargin
    nargin = ocean.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('ocean: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/ocean.m:44
    if (n == 1):
        map=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/image/ocean.m:47
    else:
        if (n > 1):
            cutin=fix(n / 3)
# /home/lei/octave-4.0.2/scripts/image/ocean.m:49
            dr=(n - 1) / cutin
# /home/lei/octave-4.0.2/scripts/image/ocean.m:51
            r=prepad(cat(arange(0,(n - 1),dr)),n).T
# /home/lei/octave-4.0.2/scripts/image/ocean.m:52
            dg=(n - 1) / (dot(2,cutin))
# /home/lei/octave-4.0.2/scripts/image/ocean.m:54
            g=prepad(cat(arange(0,(n - 1),dg)),n).T
# /home/lei/octave-4.0.2/scripts/image/ocean.m:55
            b=cat(arange(0,(n - 1))).T
# /home/lei/octave-4.0.2/scripts/image/ocean.m:57
            map=cat(r,g,b) / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/ocean.m:59
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/ocean.m:61
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} bone ()
## @deftypefnx {Function File} {@var{map} =} bone (@var{n})
## Create color colormap.  This colormap varies from black to white with
## gray-blue shades.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "bone");
## PKG_DEL: colormap ("unregister", "bone");
    
    
@function
def bone(n=rows(colormap()),*args,**kwargs):
    varargin = bone.varargin
    nargin = bone.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('bone: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/bone.m:42
    if (n == 1):
        map=matlabarray(cat(1 / 8,1 / 8,1 / 8))
# /home/lei/octave-4.0.2/scripts/image/bone.m:45
    else:
        if (n == 2):
            map=matlabarray(cat(1 / 16,1 / 8,1 / 8,1,1,1))
# /home/lei/octave-4.0.2/scripts/image/bone.m:47
        else:
            if (n > 2):
                x=cat(arange(0,n - 1)).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/bone.m:50
                idx=floor(dot(3 / 4,n))
# /home/lei/octave-4.0.2/scripts/image/bone.m:52
                nel=n - idx + 1
# /home/lei/octave-4.0.2/scripts/image/bone.m:53
                rem=mod(n,8)
# /home/lei/octave-4.0.2/scripts/image/bone.m:54
                if cellarray([2,4]) == (rem):
                    base=1 / (16 + dot(2,(n - rem)))
# /home/lei/octave-4.0.2/scripts/image/bone.m:57
                else:
                    if cellarray([5,7]) == (rem):
                        base=1 / (24 + dot(2,(n - rem)))
# /home/lei/octave-4.0.2/scripts/image/bone.m:59
                    else:
                        base=0
# /home/lei/octave-4.0.2/scripts/image/bone.m:61
                r[1:idx,1]=dot(7 / 8,x[1:idx])
# /home/lei/octave-4.0.2/scripts/image/bone.m:63
                r[idx:n,1]=linspace(dot(7 / 8,x[idx]) + base,1,nel)
# /home/lei/octave-4.0.2/scripts/image/bone.m:64
                idx=floor(dot(3 / 8,n))
# /home/lei/octave-4.0.2/scripts/image/bone.m:66
                nel=idx + 1
# /home/lei/octave-4.0.2/scripts/image/bone.m:67
                g[1:idx,1]=dot(7 / 8,x[1:idx])
# /home/lei/octave-4.0.2/scripts/image/bone.m:68
                g[idx:dot(2,idx),1]=linspace(dot(7 / 8,x[idx]),dot(7 / 8,x[dot(2,idx)]) + 1 / 8,nel)
# /home/lei/octave-4.0.2/scripts/image/bone.m:69
                g[dot(2,idx) + 1:n,1]=dot(7 / 8,x[dot(2,idx) + 1:n]) + 1 / 8
# /home/lei/octave-4.0.2/scripts/image/bone.m:70
                base=1 / (dot(8,idx))
# /home/lei/octave-4.0.2/scripts/image/bone.m:72
                nel=copy(idx)
# /home/lei/octave-4.0.2/scripts/image/bone.m:73
                b[1:idx,1]=linspace(base,dot(7 / 8,x[idx]) + 1 / 8,nel)
# /home/lei/octave-4.0.2/scripts/image/bone.m:74
                b[idx:n,1]=dot(7 / 8,x[idx:n]) + 1 / 8
# /home/lei/octave-4.0.2/scripts/image/bone.m:75
                map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/bone.m:77
            else:
                map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/bone.m:79
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
## Copyright (C) 2012-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rgbplot (@var{cmap})
## @deftypefnx {Function File} {} rgbplot (@var{cmap}, @var{style})
## @deftypefnx {Function File} {@var{h} =} rgbplot (@dots{})
## Plot the components of a colormap.
##
## Two different @var{style}s are available for displaying the @var{cmap}:
##
## @table @asis
## @item profile (default)
## Plot the RGB line profile of the colormap for each of the channels (red,
## green and blue) with the plot lines colored appropriately.  Each line
## represents the intensity of each RGB components across the colormap.
##
## @item composite
## Draw the colormap across the X-axis so that the actual index colors are
## visible rather than the individual color components.
##
## @end table
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Run @code{demo rgbplot} to see an example of @code{rgbplot} and each style
## option.
## @seealso{colormap}
## @end deftypefn
    
    
@function
def rgbplot(cmap=None,style='profile',*args,**kwargs):
    varargin = rgbplot.varargin
    nargin = rgbplot.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(iscolormap(cmap))):
        error('rgbplot: CMAP must be a valid colormap')
    else:
        if (logical_not(ischar(style))):
            error('rgbplot: STYLE must be a string')
    
    if 'profile' == (tolower(style)):
        htmp=plot(cmap[:,1],'r',cmap[:,2],'g',cmap[:,3],'b')
# /home/lei/octave-4.0.2/scripts/image/rgbplot.m:61
        set(gca,'ytick',arange(0,1,0.1))
    else:
        if 'composite' == (tolower(style)):
            htmp=image(arange(1,rows(cmap)))
# /home/lei/octave-4.0.2/scripts/image/rgbplot.m:64
            set(gca,'ytick',[])
            colormap(cmap)
        else:
            error('rgbplot: unknown style \'%s\'',style)
    
    xlabel('color index')
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/image/rgbplot.m:73
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} white ()
## @deftypefnx {Function File} {@var{map} =} white (@var{n})
## Create color colormap.  This colormap is completely white.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "white");
## PKG_DEL: colormap ("unregister", "white");
    
    
@function
def white(n=rows(colormap()),*args,**kwargs):
    varargin = white.varargin
    nargin = white.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('white: N must be a scalar')
    
    map=ones(n,3)
# /home/lei/octave-4.0.2/scripts/image/white.m:42
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} gray ()
## @deftypefnx {Function File} {@var{map} =} gray (@var{n})
## Create gray colormap.  This colormap varies from black to white with shades
## of gray.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    ## PKG_ADD: colormap ("register", "gray");
## PKG_DEL: colormap ("unregister", "gray");
    
    
@function
def gray(n=rows(colormap()),*args,**kwargs):
    varargin = gray.varargin
    nargin = gray.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('gray: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/gray.m:44
    if (n == 1):
        map=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/image/gray.m:47
    else:
        if (n > 1):
            gr=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/gray.m:49
            map=matlabarray(cat(gr,gr,gr))
# /home/lei/octave-4.0.2/scripts/image/gray.m:50
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/gray.m:52
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} image (@var{img})
## @deftypefnx {Function File} {} image (@var{x}, @var{y}, @var{img})
## @deftypefnx {Function File} {} image (@dots{}, "@var{prop}", @var{val}, @dots{})
## @deftypefnx {Function File} {} image ("@var{prop1}", @var{val1}, @dots{})
## @deftypefnx {Function File} {@var{h} =} image (@dots{})
## Display a matrix as an indexed color image.
##
## The elements of @var{img} are indices into the current colormap.
##
## @var{x} and @var{y} are optional 2-element vectors, @w{@code{[min, max]}},
## which specify the range for the axis labels.  If a range is specified as
## @w{@code{[max, min]}} then the image will be reversed along that axis.  For
## convenience, @var{x} and @var{y} may be specified as N-element vectors
## matching the length of the data in @var{img}.  However, only the first and
## last elements will be used to determine the axis limits.
## @strong{Warning:} @var{x} and @var{y} are ignored when using gnuplot 4.0
## or earlier.
##
## Multiple property/value pairs may be specified for the image object, but
## they must appear in pairs.
##
## The optional return value @var{h} is a graphics handle to the image.
##
## Implementation Note: The origin (0, 0) for images is located in the
## upper left.  For ordinary plots, the origin is located in the lower
## left.  Octave handles this inversion by plotting the data normally,
## and then reversing the direction of the y-axis by setting the
## @code{ydir} property to @qcode{"reverse"}.  This has implications whenever
## an image and an ordinary plot need to be overlaid.  The recommended
## solution is to display the image and then plot the reversed ydata
## using, for example, @code{flipud (ydata)}.
##
## Calling Forms: The @code{image} function can be called in two forms:
## High-Level and Low-Level.  When invoked with normal options, the High-Level
## form is used which first calls @code{newplot} to prepare the graphic figure
## and axes.  When the only inputs to @code{image} are property/value pairs
## the Low-Level form is used which creates a new instance of an image object
## and inserts it in the current axes.
## @seealso{imshow, imagesc, colormap}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def image(varargin=None,*args,**kwargs):
    varargin = image.varargin
    nargin = image.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('image',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/image/image.m:67
    chararg=find(cellfun('isclass',varargin,'char'),1,'first')
# /home/lei/octave-4.0.2/scripts/image/image.m:69
    do_new=copy(true)
# /home/lei/octave-4.0.2/scripts/image/image.m:71
    if (nargin == 0):
        img=get(0,'defaultimagecdata')
# /home/lei/octave-4.0.2/scripts/image/image.m:73
        x=y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:74
# /home/lei/octave-4.0.2/scripts/image/image.m:74
    else:
        if (chararg == 1):
            ## Low-Level syntax
            do_new=copy(false)
# /home/lei/octave-4.0.2/scripts/image/image.m:77
            x=y=img=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:78
# /home/lei/octave-4.0.2/scripts/image/image.m:78
# /home/lei/octave-4.0.2/scripts/image/image.m:78
            idx=find(strcmpi(varargin,'cdata'),1)
# /home/lei/octave-4.0.2/scripts/image/image.m:79
            if (idx):
                img=varargin[idx + 1]
# /home/lei/octave-4.0.2/scripts/image/image.m:81
                varargin[idx:idx + 1]=[]
# /home/lei/octave-4.0.2/scripts/image/image.m:82
            idx=find(strcmpi(varargin,'xdata'),1)
# /home/lei/octave-4.0.2/scripts/image/image.m:84
            if (idx):
                x=varargin[idx + 1]
# /home/lei/octave-4.0.2/scripts/image/image.m:86
                varargin[idx:idx + 1]=[]
# /home/lei/octave-4.0.2/scripts/image/image.m:87
            idx=find(strcmpi(varargin,'ydata'),1)
# /home/lei/octave-4.0.2/scripts/image/image.m:89
            if (idx):
                y=varargin[idx + 1]
# /home/lei/octave-4.0.2/scripts/image/image.m:91
                varargin[idx:idx + 1]=[]
# /home/lei/octave-4.0.2/scripts/image/image.m:92
        else:
            if (nargin == 1 or chararg == 2):
                img=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/image.m:95
                x=y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:96
# /home/lei/octave-4.0.2/scripts/image/image.m:96
            else:
                if (nargin == 2 or chararg == 3):
                    print_usage()
                else:
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/image/image.m:100
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/image/image.m:101
                    img=varargin[3]
# /home/lei/octave-4.0.2/scripts/image/image.m:102
                    chararg=4
# /home/lei/octave-4.0.2/scripts/image/image.m:103
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:106
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/image/image.m:108
    
    try:
        if (do_new):
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/image/image.m:112
        else:
            if (isempty(hax)):
                hax=gca()
# /home/lei/octave-4.0.2/scripts/image/image.m:114
            else:
                hax=hax[1]
# /home/lei/octave-4.0.2/scripts/image/image.m:116
        htmp=__img__(hax,do_new,x,y,img,varargin[chararg:end()])
# /home/lei/octave-4.0.2/scripts/image/image.m:119
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/image/image.m:128
    
    return h
    
if __name__ == '__main__':
    pass
    
    ## Generic image creation.
##
## The axis values corresponding to the matrix elements are specified in
## @var{x} and @var{y}.  If you're not using gnuplot 4.2 or later, these
## variables are ignored.
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def __img__(hax=None,do_new=None,x=None,y=None,img=None,varargin=None,*args,**kwargs):
    varargin = __img__.varargin
    nargin = __img__.nargin

    if (logical_not(isempty(img))):
        if (isempty(x)):
            xdata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:148
        else:
            xdata=ravel(x[cat(1,end())]).T
# /home/lei/octave-4.0.2/scripts/image/image.m:150
        if (isempty(y)):
            ydata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/image/image.m:154
        else:
            ydata=ravel(y[cat(1,end())]).T
# /home/lei/octave-4.0.2/scripts/image/image.m:156
        if (numel(x) > 2 and numel(y) > 2):
            ## Test data for non-linear spacing which is unsupported
            tol=0.01
# /home/lei/octave-4.0.2/scripts/image/image.m:161
            dx=diff(x)
# /home/lei/octave-4.0.2/scripts/image/image.m:162
            dxmean=(max(x) - min(x)) / (numel(x) - 1)
# /home/lei/octave-4.0.2/scripts/image/image.m:163
            dx=abs((abs(dx) - dxmean) / dxmean)
# /home/lei/octave-4.0.2/scripts/image/image.m:164
            dy=diff(y)
# /home/lei/octave-4.0.2/scripts/image/image.m:165
            dymean=(max(y) - min(y)) / (numel(y) - 1)
# /home/lei/octave-4.0.2/scripts/image/image.m:166
            dy=abs((abs(dy) - dymean) / dymean)
# /home/lei/octave-4.0.2/scripts/image/image.m:167
            if (any(dx > tol) or any(dy > tol)):
                warning(cat('image: non-linear X, Y data is ignored.  ','IMG will be shown with linear mapping'))
    
    if (do_new and logical_not(ishold(hax))):
        ## Set axis properties for new images
    ## NOTE: Do this before calling __go_image__ so that image is not drawn
    ##       once with default auto-scale axis limits and then a second time
    ##       with tight axis limits.
        if (logical_not(isempty(img))):
            if (isempty(get(hax,'children'))):
                axis(hax,'tight')
            if (ndims(img) == 3):
                if (isinteger(img)):
                    cls=class_(img)
# /home/lei/octave-4.0.2/scripts/image/image.m:188
                    mn=intmin(cls)
# /home/lei/octave-4.0.2/scripts/image/image.m:189
                    mx=intmax(cls)
# /home/lei/octave-4.0.2/scripts/image/image.m:190
                    set(hax,'clim',double(cat(mn,mx)))
        set(hax,'view',cat(0,90),'ydir','reverse','layer','top')
    
    h=__go_image__(hax,'cdata',img,'xdata',xdata,'ydata',ydata,'cdatamapping','direct',varargin[:])
# /home/lei/octave-4.0.2/scripts/image/image.m:201
    if (do_new and logical_not(ishold(hax)) and logical_not(isempty(img)) and isscalar(get(hax,'children'))):
        ## Re-scale axis limits for an image in a new figure or axis.
        axis(hax,'tight')
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: Need #!tests for linear
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} spring ()
## @deftypefnx {Function File} {@var{map} =} spring (@var{n})
## Create color colormap.  This colormap varies from magenta to yellow.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "spring");
## PKG_DEL: colormap ("unregister", "spring");
    
    
@function
def spring(n=rows(colormap()),*args,**kwargs):
    varargin = spring.varargin
    nargin = spring.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('spring: N must be a scalar')
    
    n=double(n)
# /home/lei/octave-4.0.2/scripts/image/spring.m:41
    if (n == 1):
        map=matlabarray(cat(1,0,1))
# /home/lei/octave-4.0.2/scripts/image/spring.m:44
    else:
        if (n > 1):
            r=ones(n,1)
# /home/lei/octave-4.0.2/scripts/image/spring.m:46
            g=cat(arange(0,(n - 1))).T / (n - 1)
# /home/lei/octave-4.0.2/scripts/image/spring.m:47
            b=1 - g
# /home/lei/octave-4.0.2/scripts/image/spring.m:48
            map=matlabarray(cat(r,g,b))
# /home/lei/octave-4.0.2/scripts/image/spring.m:49
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/spring.m:51
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{rgb_map} =} ntsc2rgb (@var{yiq_map})
## @deftypefnx {Function File} {@var{rgb_img} =} ntsc2rgb (@var{yiq_img})
## Transform a colormap or image from luminance-chrominance (NTSC) space to
## red-green-blue (RGB) color space.
##
## Implementation Note:
## The conversion matrix is chosen to be the inverse of the matrix used for
## rgb2ntsc such that
##
## @example
## x == ntsc2rgb (rgb2ntsc (x))
## @end example
##
## @sc{matlab} uses a slightly different matrix where rounding means the
## equality above does not hold.
## @seealso{rgb2ntsc, hsv2rgb, ind2rgb}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: July 1994
## Adapted-By: jwe
    
    
@function
def ntsc2rgb(yiq=None,*args,**kwargs):
    varargin = ntsc2rgb.varargin
    nargin = ntsc2rgb.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isa(yiq,'double'))):
        error('ntsc2rgb: YIQ must be of type double')
    
    ## If we have an image convert it into a color map.
    if (isnumeric(yiq) and ndims(yiq) == 3):
        is_image=copy(true)
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:54
        sz=size(yiq)
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:55
        yiq=matlabarray(cat(ravel(yiq[:,:,1]),ravel(yiq[:,:,2]),ravel(yiq[:,:,3])))
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:56
    else:
        is_image=copy(false)
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:58
    
    if (logical_not(isreal(yiq)) or columns(yiq) != 3 or issparse(yiq)):
        error('ntsc2rgb: input must be a matrix of size Nx3 or NxMx3')
    
    ## Conversion matrix constructed from 'inv (rgb2ntsc matrix)'.
  ## See programming notes in rgb2ntsc.m.  Note: Matlab matrix for inverse
  ## is slightly different.  We prefer this matrix so that
  ## x == ntsc2rgb (rgb2ntsc (x)) rather than maintaining strict compatibility
  ## with Matlab.
    trans=matlabarray(cat([1.0,1.0,1.0],[0.95617,- 0.27269,- 1.10374],[0.62143,- 0.64681,1.70062]))
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:70
    rgb=dot(yiq,trans)
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:74
    
    if (is_image):
        rgb=reshape(rgb,sz)
# /home/lei/octave-4.0.2/scripts/image/ntsc2rgb.m:78
    
    return rgb
    
if __name__ == '__main__':
    pass
    
    ## Test pure R, G, B colors
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} flag ()
## @deftypefnx {Function File} {@var{map} =} flag (@var{n})
## Create color colormap.  This colormap cycles through red, white, blue, and
## black with each index change.
##
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    ## PKG_ADD: colormap ("register", "flag");
## PKG_DEL: colormap ("unregister", "flag");
    
    
@function
def flag(n=rows(colormap()),*args,**kwargs):
    varargin = flag.varargin
    nargin = flag.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('flag: N must be a scalar')
    
    if (n == 1):
        map=matlabarray(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/image/flag.m:44
    else:
        if (n > 1):
            C=matlabarray(cat([1,0,0],[1,1,1],[0,0,1],[0,0,0]))
# /home/lei/octave-4.0.2/scripts/image/flag.m:46
            map=C[rem(arange(0,(n - 1)),4) + 1,:]
# /home/lei/octave-4.0.2/scripts/image/flag.m:47
        else:
            map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/image/flag.m:49
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{files} =} unpack (@var{file})
## @deftypefnx {Function File} {@var{files} =} unpack (@var{file}, @var{dir})
## @deftypefnx {Function File} {@var{files} =} unpack (@var{file}, @var{dir}, @var{filetype})
## Unpack the archive @var{file} based on its extension to the directory
## @var{dir}.
##
## If @var{file} is a list of strings, then each file is unpacked
## individually.  Shell wildcards in the filename such as @samp{*} or
## @samp{?} are accepted and expanded.
##
## If @var{dir} is not specified or is empty (@code{[]}), it defaults to the
## current directory.  If a directory is in the file list, then @var{filetype}
## must also be specified.
##
## The specific archive filetype is inferred from the extension of the file.
## The @var{filetype} may also be specified directly using a string which
## corresponds to a known extension.
##
## Valid filetype extensions:
##
## @table @code
## @item  bz
## @itemx bz2
## bzip archive
##
## @item gz
## gzip archive
##
## @item tar
## tar archive
##
## @item  tarbz
## @itemx tarbz2
## @itemx tbz
## @itemx tbz2
## tar + bzip archive
##
## @item  targz
## @itemx tgz
## tar + gzip archive
##
## @item z
## compress archive
##
## @item zip
## zip archive
## @end table
##
## The optional return value is a list of @var{files} unpacked.
## @seealso{bunzip2, gunzip, unzip, untar, bzip2, gzip, zip, tar}
## @end deftypefn
    
    ## Author: Bill Denney <denney@seas.upenn.edu>
    
    
@function
def unpack(file=None,dir='.',filetype='',*args,**kwargs):
    varargin = unpack.varargin
    nargin = unpack.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(file)) and logical_not(iscellstr(file))):
        error('unpack: FILE must be a string or cell array of strings')
    
    ## Convert char arrays to cell strings to simplify further processing
    if (ischar(file)):
        file=cellstr(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:86
    
    if (numel(file) == 1):
        gfile=glob(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:89
        if (isempty(gfile)):
            error('unpack: file "%s" not found',file[1])
        else:
            file=copy(gfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:93
    
    ## Recursively unpack cellstr arrays one file at a time
    if (numel(file) > 1):
        files=cellarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:99
        for i in arange(1,numel(file)).reshape(-1):
            tmpfiles=unpack(file[i],dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:101
            files=cellarray([files[:],tmpfiles[:]])
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:102
        ## Return output if requested.
        if (nargout > 0):
            filelist=copy(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:107
        return filelist
    else:
        file=file[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:112
    
    if (isdir(file)):
        if (isempty(filetype)):
            error('unpack: FILETYPE must be given for a directory')
        else:
            if (logical_not(any(strcmpi(filetype,'gunzip')))):
                error('unpack: FILETYPE must be "gunzip" for a directory')
        ext='.gz'
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:121
    else:
        pathstr,name,ext=fileparts(file,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:123
        if (any(strcmpi(cellarray(['.gz','.Z','.bz2','.bz']),ext))):
            __,tmpname,tmpext=fileparts(name,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:127
            if (strcmpi(tmpext,'.tar')):
                name=copy(tmpname)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:129
                ext=matlabarray(cat(tmpext,ext))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:130
        ## If the file is a URL, download it and then work with that file.
        if (logical_not(isempty(strfind(file,'://')))):
            ## FIXME: The above code is not a perfect test for a URL
            urlfile=copy(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:137
            tmpfile=matlabarray(cat(tempname,ext))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:138
            file,success,msg=urlwrite(urlfile,tmpfile,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:139
            if (logical_not(success)):
                error('unpack: could not fetch "%s": %s',urlfile,msg)
    
    file=make_absolute_filename(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:147
    if (isempty(dir)):
        dir='.'
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:150
    else:
        dir=tilde_expand(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:152
    
    ## Instructions on what to do for any extension.
  ##
  ## The field names are the file extension without periods.
  ## The first cell is what is executed to unpack an archive verbosely.
  ## The second cell is what is executed to unpack an archive quietly.
  ## The third cell is the function to execute on output to get the files list.
  ## The fourth cell indicates if the files may need to be manually moved
  ##   (i.e., tar and unzip decompress into the current directory while
  ##    bzip2 and gzip decompress the file at its location).
    
    if (isempty(commandlist)):
        commandlist.gz = copy(cellarray(['gzip -d -v -f -r "%s"','gzip -d -f -r "%s"',__parse_gzip__,true]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:166
        commandlist.z = copy(commandlist.gz)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:169
        commandlist.bz2 = copy(cellarray(['bzip2 -d -v -f "%s"','bzip2 -d -f "%s"',__parse_bzip2__,true]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:170
        commandlist.bz = copy(commandlist.bz2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:173
        commandlist.tar = copy(cellarray(['tar xvf "%s"','tar xf "%s"',__parse_tar__,false]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:174
        commandlist.targz = copy(cellarray(['gzip -d -c "%s" | tar xvf -','gzip -d -c "%s" | tar xf -',__parse_tar__,false]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:177
        commandlist.tgz = copy(commandlist.targz)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:180
        commandlist.tarbz2 = copy(cellarray(['bzip2 -d -c "%s" | tar xvf -','bzip2 -d -c "%s" | tar xf -',__parse_tar__,false]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:181
        commandlist.tarbz = copy(commandlist.tarbz2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:184
        commandlist.tbz2 = copy(commandlist.tarbz2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:185
        commandlist.tbz = copy(commandlist.tarbz2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:186
        commandlist.zip = copy(cellarray(['unzip -n "%s"','unzip -nq "%s"',__parse_zip__,false]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:187
    
    ## Unzip doesn't actually care about the extension
    if (strcmpi(filetype,'unzip')):
        nodotext='zip'
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:194
    else:
        nodotext=ext[ext != '.']
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:196
    
    if (ispc and strcmp(nodotext,'tar')):
        ## Change file pathname into a mingw style acceptable for tar
        file=__w2mpth__(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:201
    
    if (isfield(commandlist,tolower(nodotext))):
        commandv,commandq,parsefcn,move=deal(getattr(commandlist,(nodotext))[:],nargout=4)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:205
        origdir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:206
        if (move):
            startdir=fileparts(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:208
        else:
            startdir=copy(origdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:210
        cstartdir=make_absolute_filename(startdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:212
        cenddir=make_absolute_filename(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:213
        if (cenddir[end()] == filesep):
            cenddir[end()]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:215
        needmove=move and logical_not(strcmp(cstartdir,cenddir))
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:217
        if (nargout > 0 or needmove):
            command=copy(commandv)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:219
        else:
            command=copy(commandq)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:221
    else:
        warning('unpack: unrecognized FILETYPE <%s>',ext)
        files=copy(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:225
        return filelist
    
    ## Create the directory if necessary.
    s=stat(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:230
    if (isempty(s)):
        status,msg=mkdir(dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:232
        if (logical_not(status)):
            error('unpack: mkdir failed to create %s: %s',dir,msg)
    else:
        if (logical_not(S_ISDIR(s.mode))):
            error('unpack: %s: not a directory',dir)
    
    try:
        cd(dir)
        status,output=system(sprintf(cat(command,' 2>&1'),file),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:242
    finally:
        cd(origdir)
    
    if (status):
        error('unpack: unarchiving program exited with status: %d\n%s',status,output)
    
    if (nargout > 0 or needmove):
        ## Trim the last CR or NL if needed.
        files=parsefcn[ostrsplit(output,'\r\n',true)].T
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:254
        if (needmove):
            st,msg=movefile(files,cenddir,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:258
            if (logical_not(st)):
                error('unpack: unable to move files to "%s": %s',dir,msg)
            ## Fix the names of the files since they were moved.
            files=strrep(files,cstartdir,cenddir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:264
        ## Return output if requested.
        if (nargout > 0):
            filelist=copy(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:269
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
@function
def __parse_zip__(output=None,*args,**kwargs):
    varargin = __parse_zip__.varargin
    nargin = __parse_zip__.nargin

    ## Parse the output from zip and unzip.
    
    ## Skip first line which is Archive header.
    files=char(output[2:end()])
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:279
    
    files=cellstr(files[:,14:end()])
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:281
    return files
    
if __name__ == '__main__':
    pass
    
    
@function
def __parse_tar__(output=None,*args,**kwargs):
    varargin = __parse_tar__.varargin
    nargin = __parse_tar__.nargin

    ## This is a no-op, but it makes things simpler for other cases.
    return output
    
if __name__ == '__main__':
    pass
    
    
@function
def __parse_gzip__(output=None,*args,**kwargs):
    varargin = __parse_gzip__.varargin
    nargin = __parse_gzip__.nargin

    ## Parse the output from gzip and gunzip returning the files
  ## commpressed (or decompressed).
    
    files=regexprep(output,'^.+ with (.*)$','$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:292
    return files
    
if __name__ == '__main__':
    pass
    
    
@function
def __parse_bzip2__(output=None,*args,**kwargs):
    varargin = __parse_bzip2__.varargin
    nargin = __parse_bzip2__.nargin

    ## Parse the output from bzip2 and bunzip2 returning the files
  ## commpressed (or decompressed).
    
    ## Strip leading blanks and .bz2 extension from file name
    files=regexprep(output,'^\\s+(.*)\\.bz2: .*','$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/unpack.m:300
    return files
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} run @var{script}
## @deftypefnx {Function File} {} run ("@var{script}")
## Run @var{script} in the current workspace.
##
## Scripts which reside in directories specified in Octave's load path, and
## which end with the extension @file{".m"}, can be run simply by typing
## their name.  For scripts not located on the load path, use @code{run}.
##
## The file name @var{script} can be a bare, fully qualified, or relative
## filename and with or without a file extension.  If no extension is specified,
## Octave will first search for a script with the @file{".m"} extension before
## falling back to the script name without an extension.
##
## Implementation Note: If @var{script} includes a path component, then
## @code{run} first changes the working directory to the directory where
## @var{script} is found.  Next, the script is executed.  Finally, @code{run}
## returns to the original working directory unless @code{script} has
## specifically changed directories.
## @seealso{path, addpath, source}
## @end deftypefn
    
    
@function
def run(script=None,*args,**kwargs):
    varargin = run.varargin
    nargin = run.nargin

    if (nargin != 1):
        print_usage()
    
    d,f,ext=fileparts(script,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:47
    if (logical_not(strcmp(ext,'.m'))):
        ## prefer files with .m extension for compatibility with Matlab
        if (exist(cat(script,'.m'),'file')):
            f=matlabarray(cat(f,ext))
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:51
            ext='.m'
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:52
            script=matlabarray(cat(script,'.m'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:53
    
    if (logical_not(exist(script,'file'))):
        error('run: file SCRIPT must exist and be a valid Octave scriptfile')
    
    if (logical_not(isempty(d))):
        if (exist(d,'dir')):
            startdir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:63
            d=make_absolute_filename(d)
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:64
            try:
                cd(d)
                evalin('caller',sprintf('source (\'%s%s\');',f,ext),'rethrow (lasterror ())')
            finally:
                if (strcmp(d,pwd())):
                    cd(startdir)
        else:
            error('run: the path %s doesn\'t exist',d)
    else:
        if (logical_not(isempty(ext))):
            script=which(script)
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:79
        else:
            ## Search PATH with null extension ('.' will be stripped and ext = "")
            script=which(cat(script,'.'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/run.m:82
        evalin('caller',sprintf('source (\'%s\');',script),'rethrow (lasterror ())')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} what
## @deftypefnx {Command} {} what @var{dir}
## @deftypefnx {Function File} {w =} what (@var{dir})
## List the Octave specific files in directory @var{dir}.
##
## If @var{dir} is not specified then the current directory is used.
##
## If a return argument is requested, the files found are returned in the
## structure @var{w}.  The structure contains the following fields:
##
## @table @asis
## @item path
## Full path to directory @var{dir}
##
## @item m
## Cell array of m-files
##
## @item mat
## Cell array of mat files
##
## @item mex
## Cell array of mex files
##
## @item oct
## Cell array of oct files
##
## @item mdl
## Cell array of mdl files
##
## @item slx
## Cell array of slx files
##
## @item p
## Cell array of p-files
##
## @item classes
## Cell array of class directories (@file{@@@var{classname}/})
##
## @item packages
## Cell array of package directories (@file{+@var{pkgname}/})
## @end table
##
## Compatibility Note: Octave does not support mdl, slx, and p files; nor does
## it support package directories.  @code{what} will always return an empty
## list for these categories.
## @seealso{which, ls, exist}
## @end deftypefn
    
    
@function
def what(dir=None,*args,**kwargs):
    varargin = what.varargin
    nargin = what.nargin

    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        dir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:75
    else:
        dtmp=canonicalize_file_name(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:77
        if (isempty(dtmp)):
            ## Search for directory name in path
            if (dir[end()] == '/' or dir[end()] == '\\'):
                dir[end()]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:81
            dtmp=dir_in_loadpath(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:83
            if (isempty(dtmp)):
                error('what: could not find the directory %s',dir)
        dir=copy(dtmp)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:88
    
    files=readdir(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:91
    w.path = copy(dir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:92
    w.m = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:93
    w.mat = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:94
    w.mex = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:95
    w.oct = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:96
    w.mdl = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:97
    w.slx = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:98
    w.p = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:99
    w.classes = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:100
    w.packages = copy(cell(0,1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:101
    for i in arange(1,length(files)).reshape(-1):
        n=files[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:104
        if (strcmp(n,'.') or strcmp(n,'..')):
            continue
        else:
            ## Ignore mdl, slx, p, and packages since they are not
            __,f,e=fileparts(n,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:110
            if (strcmp(e,'.m')):
                w.m[end() + 1]=n
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:112
            else:
                if (strcmp(e,'.mat')):
                    w.mat[end() + 1]=n
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:114
                else:
                    if (strcmp(e,'.oct')):
                        w.oct[end() + 1]=n
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:116
                    else:
                        if (strcmp(e,mexext())):
                            w.mex[end() + 1]=n
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:118
                        else:
                            if (n[1] == '@' and isdir(n)):
                                w.classes[end() + 1]=n
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:120
    
    if (nargout == 0):
        __display_filenames__('M-files in directory',w.path,w.m)
        __display_filenames__('\nMAT-files in directory',w.path,w.mat)
        __display_filenames__('\nMEX-files in directory',w.path,w.mex)
        __display_filenames__('\nOCT-files in directory',w.path,w.oct)
        __display_filenames__('\nClasses in directory',w.path,w.classes)
    else:
        retval=copy(w)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:132
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __display_filenames__(msg=None,p=None,f=None,*args,**kwargs):
    varargin = __display_filenames__.varargin
    nargin = __display_filenames__.nargin

    if (length(f) > 0):
        printf('%s %s:\n\n',msg,p)
        maxlen=max(cellfun('length',f))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:142
        ncols=max(1,floor(terminal_size()(2) / (maxlen + 3)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:143
        fmt=sprintf('   %%-%ds',maxlen)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:144
        fmt=repmat(fmt,cat(1,ncols))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:145
        fmt=matlabarray(cat(fmt,'\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:146
        nrows=ceil(length(f) / ncols)
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:148
        for i in arange(1,nrows).reshape(-1):
            args=f[i:nrows:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:150
            if (length(args) < ncols):
                args[end() + 1:ncols]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/miscellaneous/what.m:152
            printf(fmt,args[:])
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{current_state} =} recycle ()
## @deftypefnx {Function File} {@var{old_state} =} recycle (@var{new_state})
## Query or set the preference for recycling deleted files.
##
## When recycling is enabled, commands which would permanently erase files
## instead move them to a temporary location (such as the directory labeled
## Trash).
##
## Programming Note: This function is provided for @sc{matlab} compatibility,
## but recycling is not implemented in Octave.  To help avoid accidental data
## loss an error will be raised if an attempt is made to enable file recycling.
## @seealso{delete, rmdir}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def recycle(state=None,*args,**kwargs):
    varargin = recycle.varargin
    nargin = recycle.nargin

    
    if (nargin > 1):
        print_usage()
    
    if (nargin == 0 or nargout > 0):
        retval=copy(current_state)
# /home/lei/octave-4.0.2/scripts/miscellaneous/recycle.m:45
    
    if (nargin == 1):
        if (logical_not(ischar(state))):
            error('recycle: STATE must be a character string')
        if (strcmpi(state,'on')):
            error('recycle: recycling files is not implemented')
        else:
            if (strcmpi(state,'off')):
                current_state='off'
# /home/lei/octave-4.0.2/scripts/miscellaneous/recycle.m:56
            else:
                error('recycle: invalid value of STATE = \'%s\'',state)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rmappdata (@var{h}, @var{name})
## @deftypefnx {Function File} {} rmappdata (@var{h}, @var{name1}, @var{name2}, @dots{})
## Delete the application data @var{name} from the graphics object with handle
## @var{h}.
##
## @var{h} may also be a vector of graphics handles.  Multiple application data
## names may be supplied to delete several properties at once.
##
## @seealso{setappdata, getappdata, isappdata}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-15
    
    
@function
def rmappdata(h=None,varargin=None,*args,**kwargs):
    varargin = rmappdata.varargin
    nargin = rmappdata.nargin

    if (nargin < 2):
        print_usage()
    
    h=ravel(h).T
# /home/lei/octave-4.0.2/scripts/miscellaneous/rmappdata.m:40
    if (logical_not(all(ishandle(h)))):
        error('rmappdata: H must be a scalar or vector of graphic handles')
    else:
        if (logical_not(iscellstr(varargin))):
            error('rmappdata: NAME must be a string')
    
    for hg in h.reshape(-1):
        if (isprop(hg,'__appdata__')):
            appdata=get(hg,'__appdata__')
# /home/lei/octave-4.0.2/scripts/miscellaneous/rmappdata.m:49
            vld=isfield(appdata,varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/rmappdata.m:50
            if (logical_not(all(vld))):
                ## FIXME: Should we bother to error out?  Or just silently continue?
                missing=varargin[find(logical_not(vld),1)]
# /home/lei/octave-4.0.2/scripts/miscellaneous/rmappdata.m:53
                error('rmappdata: appdata \'%s\' is not present',missing)
            appdata=rmfield(appdata,varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/rmappdata.m:56
            set(hg,'__appdata__',appdata)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} delete (@var{file})
## @deftypefnx {Function File} {} delete (@var{file1}, @var{file2}, @dots{})
## @deftypefnx {Function File} {} delete (@var{handle})
## Delete the named file or graphics handle.
##
## @var{file} may contain globbing patterns such as @samp{*}.  Multiple files
## to be deleted may be specified in the same function call.
##
## @var{handle} may be a scalar or vector of graphic handles to delete.
##
## Programming Note: Deleting graphics objects is the proper way to remove
## features from a plot without clearing the entire figure.
## @seealso{clf, cla, unlink, rmdir}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def delete(varargin=None,*args,**kwargs):
    varargin = delete.varargin
    nargin = delete.nargin

    if (nargin == 0):
        print_usage()
    
    if (iscellstr(varargin)):
        for arg in varargin.reshape(-1):
            files=glob(arg[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/delete.m:45
            if (isempty(files)):
                warning('delete: no such file: %s',arg[1])
            for i in arange(1,length(files)).reshape(-1):
                file=files[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/delete.m:50
                err,msg=unlink(file,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/delete.m:51
                if (err):
                    warning('delete: %s: %s',file,msg)
    else:
        if (isscalar(varargin) and all(ishandle(ravel(varargin[1])))):
            ## Delete a graphics object.
            __go_delete__(varargin[1])
        else:
            error('delete: first argument must be a filename or graphics handle')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2006-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} ls
## @deftypefnx {Command} {} ls @var{filenames}
## @deftypefnx {Command} {} ls @var{options}
## @deftypefnx {Command} {} ls @var{options} @var{filenames}
## @deftypefnx {Function File} {@var{list} =} ls (@dots{})
##
## List directory contents.
##
## The @code{ls} command is implemented by calling the native operating
## system's directory listing command---available @var{options} will vary from
## system to system.
##
## Filenames are subject to shell expansion if they contain any wildcard
## characters @samp{*}, @samp{?}, @samp{[]}.  To find a literal example of a
## wildcard character the wildcard must be escaped using the backslash operator
## @samp{\}.
##
## If the optional output @var{list} is requested then @code{ls} returns a
## character array with one row for each file/directory name.
##
## Example usage on a UNIX-like system:
##
## @example
## @group
## ls -l
##      @print{} total 12
##      @print{} -rw-r--r--   1 jwe  users  4488 Aug 19 04:02 foo.m
##      @print{} -rw-r--r--   1 jwe  users  1315 Aug 17 23:14 bar.m
## @end group
## @end example
##
## @seealso{dir, readdir, glob, what, stat, filesep, ls_command}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def ls(varargin=None,*args,**kwargs):
    varargin = ls.varargin
    nargin = ls.nargin

    global __ls_command__
    if (isempty(__ls_command__) or logical_not(ischar(__ls_command__))):
        ls_command()
    
    if (logical_not(iscellstr(varargin))):
        error('ls: all arguments must be character strings')
    
    if (nargin > 0):
        args=tilde_expand(varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:69
        if (ispc() and logical_not(isunix())):
            idx=logical_not(strncmp(args,'/',1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:71
            args[idx]=strcat('"',args[idx],'"')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:73
            args=regexprep(args,'([^\\w.*?])','^$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:75
        else:
            ## Escape any special characters in filename
            args=regexprep(args,'([^][\\w.*?-])','\\\\$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:78
            ## Only used for command form where single str contains many args.
      ## Example: list = ls ("-l /usr/bin")
            args=regexprep(args,'(-\\w+)(?:\\\\ )+','$1 ')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:82
        args=sprintf('%s ',args[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:84
    else:
        args=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:86
    
    cmd=matlabarray(cat(__ls_command__,' ',args))
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:89
    if (page_screen_output() or nargout > 0):
        status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:92
        if (status != 0):
            error('ls: command exited abnormally with status %d\n',status)
        else:
            if (nargout == 0):
                puts(output)
            else:
                retval=strvcat(regexp(output,'[\r\n]+','split')[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls.m:99
    else:
        ## Just let the output flow if the pager is off.  That way the
    ## output from things like "ls -R /" will show up immediately and
    ## we won't have to buffer all the output.
        system(cmd)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test below is valid, but produces confusing output on screen
    
    ## Copyright (C) 2006-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} bunzip2 (@var{bzfile})
## @deftypefnx {Function File} {@var{filelist} =} bunzip2 (@var{bzfile}, @var{dir})
## Unpack the bzip2 archive @var{bzfile}.
##
## If @var{dir} is specified the files are unpacked in this directory rather
## than the one where @var{bzfile} is located.
##
## The optional output @var{filelist} is a list of the uncompressed files.
## @seealso{bzip2, unpack, gunzip, unzip, untar}
## @end deftypefn
    
    ## Author: Bill Denney <denney@seas.upenn.edu>
    
    
@function
def bunzip2(bzfile=None,dir=[],*args,**kwargs):
    varargin = bunzip2.varargin
    nargin = bunzip2.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (isempty(dir)):
        dir=fileparts(bzfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/bunzip2.m:40
    
    if (nargout > 0):
        filelist=unpack(bzfile,dir,'bunzip2')
# /home/lei/octave-4.0.2/scripts/miscellaneous/bunzip2.m:44
    else:
        unpack(bzfile,dir,'bunzip2')
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    ## Tests for this m-file are located in bzip2.m
## Remove from test statistics
    
    ## Copyright (C) 2006-2015 Keith Goodman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} mkoctfile [-options] file @dots{}
## @deftypefnx {Function File} {[@var{output}, @var{status}] =} mkoctfile (@dots{})
##
## The @code{mkoctfile} function compiles source code written in C, C++, or
## Fortran.  Depending on the options used with @code{mkoctfile}, the
## compiled code can be called within Octave or can be used as a stand-alone
## application.
##
## @code{mkoctfile} can be called from the shell prompt or from the Octave
## prompt.  Calling it from the Octave prompt simply delegates the call to
## the shell prompt.  The output is stored in the @var{output} variable and
## the exit status in the @var{status} variable.
##
## @code{mkoctfile} accepts the following options, all of which are optional
## except for the file name of the code you wish to compile:
##
## @table @samp
## @item -I DIR
## Add the include directory DIR to compile commands.
##
## @item -D DEF
## Add the definition DEF to the compiler call.
##
## @item -l LIB
## Add the library LIB to the link command.
##
## @item -L DIR
## Add the library directory DIR to the link command.
##
## @item  -M
## @itemx --depend
## Generate dependency files (.d) for C and C++ source files.
##
## @item -R DIR
## Add the run-time path to the link command.
##
## @item @nospell{-Wl,@dots{}}
## Pass flags though the linker like @nospell{"-Wl,-rpath=@dots{}"}.
## The quotes are needed since commas are interpreted as command
## separators.
##
## @item -W@dots{}
## Pass flags though the compiler like @nospell{"-Wa,OPTION"}.
##
## @item -c
## Compile but do not link.
##
## @item -g
## Enable debugging options for compilers.
##
## @item  -o FILE
## @itemx --output FILE
## Output file name.  Default extension is .oct (or .mex if @samp{--mex} is
## specified) unless linking a stand-alone executable.
##
## @item  -p VAR
## @itemx --print VAR
## Print the configuration variable VAR@.  Recognized variables are:
##
## @example
##    ALL_CFLAGS                  INCFLAGS
##    ALL_CXXFLAGS                INCLUDEDIR
##    ALL_FFLAGS                  LAPACK_LIBS
##    ALL_LDFLAGS                 LD_CXX
##    AR                          LDFLAGS
##    BLAS_LIBS                   LD_STATIC_FLAG
##    CC                          LFLAGS
##    CFLAGS                      LIBDIR
##    CPICFLAG                    LIBOCTAVE
##    CPPFLAGS                    LIBOCTINTERP
##    CXX                         LIBS
##    CXXFLAGS                    OCTAVE_HOME
##    CXXPICFLAG                  OCTAVE_LIBS
##    DEPEND_EXTRA_SED_PATTERN    OCTAVE_LINK_DEPS
##    DEPEND_FLAGS                OCTAVE_LINK_OPTS
##    DL_LD                       OCTAVE_PREFIX
##    DL_LDFLAGS                  OCTINCLUDEDIR
##    F77                         OCTLIBDIR
##    F77_INTEGER8_FLAG           OCT_LINK_DEPS
##    FFLAGS                      OCT_LINK_OPTS
##    FFTW3F_LDFLAGS              RANLIB
##    FFTW3F_LIBS                 RDYNAMIC_FLAG
##    FFTW3_LDFLAGS               READLINE_LIBS
##    FFTW3_LIBS                  SED
##    FFTW_LIBS                   SPECIAL_MATH_LIB
##    FLIBS                       XTRA_CFLAGS
##    FPICFLAG                    XTRA_CXXFLAGS
## @end example
##
## @item --link-stand-alone
## Link a stand-alone executable file.
##
## @item --mex
## Assume we are creating a MEX file.  Set the default output extension to
## ".mex".
##
## @item  -s
## @itemx --strip
## Strip the output file.
##
## @item  -v
## @itemx --verbose
## Echo commands as they are executed.
##
## @item file
## The file to compile or link.  Recognized file types are
##
## @example
## @group
##    .c    C source
##    .cc   C++ source
##    .C    C++ source
##    .cpp  C++ source
##    .f    Fortran source (fixed form)
##    .F    Fortran source (fixed form)
##    .f90  Fortran source (free form)
##    .F90  Fortran source (free form)
##    .o    object file
##    .a    library file
## @end group
## @end example
##
## @end table
## @end deftypefn
    
    
@function
def mkoctfile(varargin=None,*args,**kwargs):
    varargin = mkoctfile.varargin
    nargin = mkoctfile.nargin

    bindir=octave_config_info('bindir')
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:147
    ext=octave_config_info('EXEEXT')
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:148
    shell_script=fullfile(bindir,sprintf('mkoctfile-%s%s',OCTAVE_VERSION,ext))
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:150
    if (logical_not(exist(shell_script,'file'))):
        __gripe_missing_component__('mkoctfile','mkoctfile')
    
    cmd=matlabarray(cat('"',shell_script,'"'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:157
    for i in arange(1,nargin).reshape(-1):
        cmd=matlabarray(cat(cmd,' "',varargin[i],'"'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:159
    
    sys,out=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:162
    if (nargout > 0):
        output,status=deal(out,sys,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/mkoctfile.m:165
    else:
        printf('%s',out)
    
    if (sys != 0):
        warning('mkoctfile exited with failure status')
    
    return output,status
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{value} =} getappdata (@var{h}, @var{name})
## @deftypefnx {Function File} {@var{appdata} =} getappdata (@var{h})
## Return the @var{value} of the application data @var{name} for the graphics
## object with handle @var{h}.
##
## @var{h} may also be a vector of graphics handles.  If no second argument
## @var{name} is given then @code{getappdata} returns a structure,
## @var{appdata}, whose fields correspond to the appdata properties.
##
## @seealso{setappdata, isappdata, rmappdata, guidata, get, set, getpref, setpref}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-15
    
    
@function
def getappdata(h=None,name=None,*args,**kwargs):
    varargin = getappdata.varargin
    nargin = getappdata.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(all(ishandle(ravel(h))))):
        error('getappdata: H must be a scalar or vector of graphic handles')
    
    if (nargin == 2):
        if (logical_not(ischar(name))):
            error('getappdata: NAME must be a string')
        value=cell(numel(h),1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:50
        appdata=struct()
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:51
        for i in arange(1,numel(h)).reshape(-1):
            value[i]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:53
            pval=get(h[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:54
            if (isfield(pval,'__appdata__') and isfield(pval.__appdata__,name)):
                value[i]=getattr(pval.__appdata__,(name))
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:56
        if (i == 1):
            value=value[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:61
    else:
        if (numel(h) != 1):
            error('getappdata: Only one handle H may be used when fetching appdata')
        try:
            value=get(h,'__appdata__')
# /home/lei/octave-4.0.2/scripts/miscellaneous/getappdata.m:69
        finally:
            pass
    
    return value
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{status}, @var{msg}, @var{msgid}] =} copyfile (@var{f1}, @var{f2})
## @deftypefnx {Function File} {[@var{status}, @var{msg}, @var{msgid}] =} copyfile (@var{f1}, @var{f2}, 'f')
## Copy the source files or directories @var{f1} to the destination @var{f2}.
##
## The name @var{f1} may contain globbing patterns.  If @var{f1} expands to
## multiple file names, @var{f2} must be a directory.
##
## When the force flag @qcode{'f'} is given any existing files will be
## overwritten without prompting.
##
## If successful, @var{status} is 1, and @var{msg}, @var{msgid} are empty
## character strings ("").  Otherwise, @var{status} is 0, @var{msg} contains a
## system-dependent error message, and @var{msgid} contains a unique message
## identifier.  Note that the status code is exactly opposite that of the
## @code{system} command.
## @seealso{movefile, rename, unlink, delete, glob}
## @end deftypefn
    
    
@function
def copyfile(f1=None,f2=None,force=None,*args,**kwargs):
    varargin = copyfile.varargin
    nargin = copyfile.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    max_cmd_line=1024
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:44
    status=copy(true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:45
    msg=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:46
    msgid=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:47
    
    ##        over the command that is executed.
    
    if (ispc() and logical_not(isunix()) and isempty(file_in_path(getenv('PATH'),'cp.exe'))):
        ## Windows.
        cmd='cmd /C xcopy /E'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:55
        cmd_force_flag='/Y'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:56
    else:
        cmd='cp -r'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:58
        cmd_force_flag='-f'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:59
    
    ## Input type check.
    if (ischar(f1)):
        f1=cellstr(f1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:64
    else:
        if (logical_not(iscellstr(f1))):
            error('copyfile: F1 must be a string or a cell array of strings')
    
    if (logical_not(ischar(f2))):
        error('copyfile: F2 must be a string')
    
    if (nargin == 3 and strcmp(force,'f')):
        cmd=matlabarray(cat(cmd,' ',cmd_force_flag))
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:73
    
    ## If f1 has more than 1 element then f2 must be a directory
    isdir=(exist(f2,'dir') != 0)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:77
    if (numel(f1) > 1 and logical_not(isdir)):
        error('copyfile: when copying multiple files, F2 must be a directory')
    
    ## Protect the file name(s).
    f1=glob(f1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:83
    if (isempty(f1)):
        error('copyfile: no files to move')
    
    p1=sprintf('"%s" ',f1[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:87
    p2=tilde_expand(f2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:88
    if (isdir and length(p1) > max_cmd_line):
        l2=length(p2) + length(cmd) + 6
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:91
        while (logical_not(isempty(f1))):

            p1=sprintf('"%s" ',f1[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:93
            f1[1]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:94
            while (logical_not(isempty(f1)) and (length(p1) + length(f1[1]) + l2 < max_cmd_line)):

                p1=sprintf('%s"%s" ',p1,f1[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:97
                f1[1]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:98

            if (ispc() and logical_not(isunix()) and logical_not(isempty(file_in_path(getenv('PATH'),'cp.exe')))):
                p1=strrep(p1,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:103
                p2=strrep(p2,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:104
            ## Copy the files.
            err,msg=system(sprintf('%s %s"%s"',cmd,p1,p2),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:108
            if (err != 0):
                status=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:110
                msgid='copyfile'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:111
                break

    else:
        if (ispc() and logical_not(isunix()) and logical_not(isempty(file_in_path(getenv('PATH'),'cp.exe')))):
            p1=strrep(p1,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:118
            p2=strrep(p2,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:119
        ## Copy the files.
        err,msg=system(sprintf('%s %s"%s"',cmd,p1,p2),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:123
        if (err != 0):
            status=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:125
            msgid='copyfile'
# /home/lei/octave-4.0.2/scripts/miscellaneous/copyfile.m:126
    
    return status,msg,msgid
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} edit @var{name}
## @deftypefnx {Command} {} edit @var{field} @var{value}
## @deftypefnx {Command} {@var{value} =} edit get @var{field}
## Edit the named function, or change editor settings.
##
## If @code{edit} is called with the name of a file or function as its
## argument it will be opened in the text editor defined by @env{EDITOR}.
##
## @itemize @bullet
## @item
## If the function @var{name} is available in a file on your path and that
## file is modifiable, then it will be edited in place.  If it is a system
## function, then it will first be copied to the directory @env{HOME} (see
## below) and then edited.  If no file is found, then the m-file variant,
## ending with @qcode{".m"}, will be considered.  If still no file is found,
## then variants with a leading @qcode{"@@"} and then with both a leading
## @qcode{"@@"} and trailing @qcode{".m"} will be considered.
##
## @item
## If @var{name} is the name of a function defined in the interpreter but not
## in an m-file, then an m-file will be created in @env{HOME} to contain that
## function along with its current definition.
##
## @item
## If @code{@var{name}.cc} is specified, then it will search for
## @code{@var{name}.cc} in the path and try to modify it, otherwise it will
## create a new @file{.cc} file in the current directory.  If @var{name} happens
## to be an m-file or interpreter defined function, then the text of that
## function will be inserted into the .cc file as a comment.
##
## @item
## If @file{@var{name}.ext} is on your path then it will be edited, otherwise
## the editor will be started with @file{@var{name}.ext} in the current
## directory as the filename.  If @file{@var{name}.ext} is not modifiable,
## it will be copied to @env{HOME} before editing.
##
## @strong{Warning:} You may need to clear @var{name} before the new definition
## is available.  If you are editing a .cc file, you will need to execute
## @code{mkoctfile @file{@var{name}.cc}} before the definition will be
## available.
## @end itemize
##
## If @code{edit} is called with @var{field} and @var{value} variables, the
## value of the control field @var{field} will be set to @var{value}.  If an
## output argument is requested and the first input argument is @code{get}
## then @code{edit} will return the value of the control field @var{field}.
## If the control field does not exist, edit will return a structure
## containing all fields and values.  Thus, @code{edit get all} returns a
## complete control structure.
##
## The following control fields are used:
##
## @table @samp
## @item home
## This is the location of user local m-files.  Be sure it is in your path.
## The default is @file{~/octave}.
##
## @item author
## This is the name to put after the "## Author:" field of new functions.  By
## default it guesses from the @code{gecos} field of the password database.
##
## @item email
## This is the e-mail address to list after the name in the author field.  By
## default it guesses @code{<$LOGNAME@@$HOSTNAME>}, and if @code{$HOSTNAME}
## is not defined it uses @code{uname -n}.  You probably want to override
## this.  Be sure to use the format @code{@email{user@@host}}.
##
## @item license
##
## @table @samp
## @item gpl
## GNU General Public License (default).
##
## @item bsd
## BSD-style license without advertising clause.
##
## @item pd
## Public domain.
##
## @item "text"
## Your own default copyright and license.
## @end table
##
## Unless you specify @samp{pd}, edit will prepend the copyright statement
## with "Copyright (C) yyyy Function Author".
##
## @item mode
## This value determines whether the editor should be started in async mode
## (editor is started in the background and Octave continues) or sync mode
## (Octave waits until the editor exits).  Set it to @qcode{"sync"} to start
## the editor in sync mode.  The default is @qcode{"async"}
## (@pxref{XREFsystem,,system}).
##
## @item editinplace
## Determines whether files should be edited in place, without regard to
## whether they are modifiable or not.  The default is @code{false}.
## @end table
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
    
    ## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    
@function
def edit(varargin=None,*args,**kwargs):
    varargin = edit.varargin
    nargin = edit.nargin

    ## Pick up globals or default them.
    
    
    
    mlock
    
    FUNCTION.EDITOR = copy(cat(EDITOR(),' %s'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:139
    if (nargin == 1):
        ## User has supplied one arg, this can be a single file name
    ## or a cell array of strings containing multiple files to be opened
        if (iscellstr(varargin[1])):
            ## If first arg is a cell array of strings,
      ## it becomes the list of files to be edited
            editfilelist=varargin[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:147
        else:
            if (ischar(varargin[1])):
                ## If first arg is a string, create a cell array of strings
      ## of length 1 (by copying the input cell array)
                editfilelist=varargin[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:151
            else:
                error('edit: expected file to be a string or cell array of strings')
    else:
        if (nargin == 2):
            ## User has supplied two arguments, these could be two file names,
    ## or a combination of editor state name and new value for that state,
    ## so first check for the various states
            statevar=varargin[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:159
            stateval=varargin[2]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:160
            if 'EDITOR' == (toupper(statevar)):
                error('Octave:deprecated-function','The EDITOR option of edit has been removed.  Use EDITOR() directly.')
                return ret
            else:
                if 'HOME' == (toupper(statevar)):
                    if (logical_not(isempty(stateval)) and stateval[1] == '~'):
                        stateval=matlabarray(cat(get_home_directory,stateval[2:end()]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:168
                    FUNCTION.HOME = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:170
                    return ret
                else:
                    if 'AUTHOR' == (toupper(statevar)):
                        FUNCTION.AUTHOR = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:173
                        return ret
                    else:
                        if 'EMAIL' == (toupper(statevar)):
                            FUNCTION.EMAIL = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:176
                            return ret
                        else:
                            if 'LICENSE' == (toupper(statevar)):
                                FUNCTION.LICENSE = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:179
                                return ret
                            else:
                                if 'MODE' == (toupper(statevar)):
                                    if (strcmp(stateval,'sync') or strcmp(stateval,'async')):
                                        FUNCTION.MODE = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:183
                                    else:
                                        error('edit: expected "edit MODE sync|async"')
                                    return ret
                                else:
                                    if 'EDITINPLACE' == (toupper(statevar)):
                                        if (ischar(stateval)):
                                            if (strcmpi(stateval,'true')):
                                                stateval=copy(true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:191
                                            else:
                                                if (strcmpi(stateval,'false')):
                                                    stateval=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:193
                                                else:
                                                    stateval=eval(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:195
                                        FUNCTION.EDITINPLACE = copy(stateval)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:198
                                        return ret
                                    else:
                                        if 'GET' == (toupper(statevar)):
                                            if (isfield(FUNCTION,toupper(stateval))):
                                                ret=getattr(FUNCTION,(toupper(stateval)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:202
                                            else:
                                                ret=copy(FUNCTION)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:204
                                            return ret
                                        else:
                                            ## If none of the states match, assume both inputs are actually
        ## file names to be opened.
                                            editfilelist=copy(varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:210
        else:
            if (nargin > 2):
                if (iscellstr(varargin)):
                    editfilelist=copy(varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:214
                else:
                    error('edit: if supplying more than one input all inputs must be strings containing field names to open.')
    
    ## Start the editor without a file if no file is given.
    if (nargin == 0):
        if (exist(FUNCTION.HOME,'dir') == 7):
            curr_dir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:223
            try:
                cd(FUNCTION.HOME)
                do_edit(FUNCTION.EDITOR,'',FUNCTION.MODE)
            finally:
                cd(curr_dir)
        else:
            do_edit(FUNCTION.EDITOR,'',FUNCTION.MODE)
        return ret
    
    if (numel(editfilelist) > 1):
        ## Call edit on each of the files in the list if there are more than 1
        for i in arange(1,numel(editfilelist)).reshape(-1):
            edit(editfilelist[i])
    else:
        ## Only one file name was supplied, get it from the cell array
        file=tilde_expand(editfilelist[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:246
        if cellarray([3,5]) == (exist(file)):
            error('edit: unable to edit a built-in or compiled function')
        ## Checks for whether the file is
    ## absolute or relative should be handled inside file_in_loadpath.
    ## That way, it will be possible to look up files correctly given
    ## partial path information.  For example, you should be able to
    ## edit a particular overloaded function by doing any one of
    ##
    ##   edit classname/foo
    ##   edit classname/foo.m
    ##   edit @classname/foo
    ##   edit @classname/foo.m
    ##
    ## This functionality is needed for other functions as well (at least
    ## help and type; there may be more).  So the place to fix that is in
    ## file_in_loadpath, possibly with some help from the load_path class.
        ## The code below includes a portion that serves as a place-holder for
    ## the changes suggested above.
        ## Create list of explicit and implicit file names.
        filelist=cellarray([file])
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:273
        idx=rindex(file,'.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:275
        if (idx == 0):
            if (isempty(regexp(file,'\\.m$'))):
                ## No ".m" at the end of the file, add to the list.
                filelist[end() + 1]=cat(file,'.m')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:279
            if (isempty(regexp(file,'\\.cc$'))):
                ## No ".cc" at the end of the file, add to the list.
                filelist[end() + 1]=cat(file,'.cc')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:283
        ## If the file includes a path, it may be an overloaded function.
        if (logical_not(index(file,'@')) and strchr(file,'/\\')):
            ## No "@" at the beginning of the file, add to the list.
            numfiles=numel(filelist)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:290
            for n in arange(1,numfiles).reshape(-1):
                filelist[n + numfiles]=cat('@',filelist[n])
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:292
        ## Search the entire path for the 1st instance of a file in the list.
        fileandpath=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:297
        for n in arange(1,numel(filelist)).reshape(-1):
            filetoedit=file_in_path(path,filelist[n])
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:299
            if (logical_not(isempty(filetoedit))):
                ## The path is explicitly included.
                fileandpath=copy(filetoedit)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:302
                break
        if (logical_not(isempty(fileandpath))):
            ## If the file exists, then edit it.
            if (FUNCTION.EDITINPLACE):
                ## Edit in place even if it is protected.
                do_edit(FUNCTION.EDITOR,fileandpath,FUNCTION.MODE)
                return ret
            else:
                ## If the file is modifiable in place then edit it,
        ## otherwise make a copy in HOME and then edit it.
                fid=fopen(fileandpath,'r+t')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:316
                if (fid < 0):
                    from_=copy(fileandpath)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:318
                    fileandpath=matlabarray(cat(FUNCTION.HOME,from_[rindex(from_,filesep):end()]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:319
                    status,msg=copyfile(from_,fileandpath,1,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:320
                    if (status == 0):
                        error(msg)
                else:
                    fclose(fid)
                do_edit(FUNCTION.EDITOR,fileandpath,FUNCTION.MODE)
                return ret
        ## If editing a new file, prompt for creation if gui is running
        if (isguirunning()):
            if (logical_not(__octave_link_edit_file__(file,'prompt'))):
                return ret
        ## If editing a new file that is neither an m-file nor an oct-file,
    ## just edit it.
    ## If in gui-mode, create it before or editor would prompt again.
        fileandpath=copy(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:342
        idx=rindex(file,'.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:343
        if (idx):
            name=file[1:idx - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:345
            ext=file[idx + 1:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:346
        else:
            name=copy(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:348
            ext=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:349
        if (logical_not(any(strcmp(ext,cellarray(['cc','m']))))):
            ## Some unknown file.  Create and open it or just open it.
            if (isempty(ext)):
                fileandpath=matlabarray(cat(fileandpath,'.m'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:354
            if (isguirunning()):
                ## Write the initial file (if there is anything to write)
        ## Give user the opportunity to change the file extension
                fileandpath=uiputfile(fileandpath)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:359
                fid=fopen(fileandpath,'wt')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:360
                if (fid < 0):
                    error('edit: could not create %s',fileandpath)
                fclose(fid)
            do_edit(FUNCTION.EDITOR,fileandpath,FUNCTION.MODE)
            return ret
        ## The file doesn't exist in path so
    ## create it, put in the function template, and edit it.
        ## Guess the email name if it was not given.
        if (isempty(FUNCTION.EMAIL)):
            host=getenv('HOSTNAME')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:375
            if (isempty(host) and ispc()):
                host=getenv('COMPUTERNAME')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:377
            if (isempty(host)):
                __,host=system('uname -n',nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:380
                if (logical_not(isempty(host))):
                    host=host[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:383
            if (isempty(host)):
                FUNCTION.EMAIL = copy(' ')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:387
            else:
                FUNCTION.EMAIL = copy(cat('<',default_user(0),'@',host,'>'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:389
        ## Fill in the revision string.
        now=localtime(time)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:394
        revs=matlabarray(cat('Created: ',strftime('%Y-%m-%d',now)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:395
        copyright=matlabarray(cat(strftime('Copyright (C) %Y ',now),FUNCTION.AUTHOR))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:398
        author=matlabarray(cat('Author: ',FUNCTION.AUTHOR,' ',FUNCTION.EMAIL))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:401
        uclicense=toupper(FUNCTION.LICENSE)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:404
        if 'GPL' == (uclicense):
            head=cstrcat(copyright,'\n\n','This program is free software; you can redistribute it and/or modify it\nunder the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 3 of the License, or\n(at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program.  If not, see <http://www.gnu.org/licenses/>.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:407
            tail=matlabarray(cat(author,'\n',revs))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:408
        else:
            if 'BSD' == (uclicense):
                head=cstrcat(copyright,'\n\n','This program is free software; redistribution and use in source and\nbinary forms, with or without modification, are permitted provided that\nthe following conditions are met:\n\n   1.Redistributions of source code must retain the above copyright\n     notice, this list of conditions and the following disclaimer.\n   2.Redistributions in binary form must reproduce the above copyright\n     notice, this list of conditions and the following disclaimer in the\n     documentation and/or other materials provided with the distribution.\n\nTHIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS\'\' AND\nANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE\nARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE\nFOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\nDAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS\nOR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)\nHOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT\nLIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY\nOUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF\nSUCH DAMAGE.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:411
                tail=matlabarray(cat(author,'\n',revs))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:412
            else:
                if 'PD' == (uclicense):
                    head=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:415
                    tail=matlabarray(cat(author,'\n',revs,'\n\n','This program is granted to the public domain.'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:416
                else:
                    head=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:420
                    tail=matlabarray(cat(copyright,'\n\n',FUNCTION.LICENSE,'\n',author,'\n',revs))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:421
        ## Generate the function template.
        exists=exist(name)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:425
        if cellarray(['cc','C','cpp']) == (ext):
            if (isempty(head)):
                comment=matlabarray(cat('/*\n\n',tail,'\n\n*/\n\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:429
            else:
                comment=matlabarray(cat('/*\n\n',head,'\n\n',tail,'\n\n*/\n\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:431
            ## If we are shadowing an m-file, paste the code for the m-file.
            if (any(exists == cat(2,103))):
                code=matlabarray(cat('\\ ',strrep(type_(name)[1],'\n','\n// ')))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:435
            else:
                code=' '
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:437
            body=matlabarray(cat('#include <octave/oct.h>\n\n','DEFUN_DLD(',name,', args, nargout, "\\\n',name,'\\n\\\n")\n{\n','  octave_value_list retval;\n','  int nargin = args.length ();\n\n',code,'\n  return retval;\n}\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:439
            text=matlabarray(cat(comment,body))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:446
        else:
            if 'm' == (ext):
                ## If we are editing a function defined on the fly, paste the code.
                if (any(exists == cat(2,103))):
                    body=type_(name)[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:450
                else:
                    body=matlabarray(cat('function [retval] = ',name,' (input1, input2)\n\n','endfunction\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:452
                if (isempty(head)):
                    comment=matlabarray(cat('## -*- texinfo -*- \n## @deftypefn {Function File} ','{@var{retval} =} ',name,' (@var{input1}, @var{input2})\n##\n','## @seealso{}\n## @end deftypefn\n\n','## ',strrep(tail,'\n','\n## '),'\n\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:456
                else:
                    comment=matlabarray(cat('## ',strrep(head,'\n','\n## '),'\n\n','## -*- texinfo -*- \n## @deftypefn {Function File} ','{@var{retval} =} ',name,' (@var{input1}, @var{input2})\n##\n','## @seealso{}\n## @end deftypefn\n\n','## ',strrep(tail,'\n','\n## '),'\n\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:462
                text=matlabarray(cat(comment,body))
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:469
        ## Write the initial file (if there is anything to write)
        fid=fopen(fileandpath,'wt')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:473
        if (fid < 0):
            error('edit: could not create %s',fileandpath)
        fputs(fid,text)
        fclose(fid)
        do_edit(FUNCTION.EDITOR,fileandpath,FUNCTION.MODE)
    
    return ret
    
if __name__ == '__main__':
    pass
    
    ## Return the name associated with the current user ID.
##
## If LONG_FORM is 1, return the full name.  This will be the
## default author.  Otherwise return the login name.
## login@host will be the default email address.
    
    
@function
def default_user(long_form=None,*args,**kwargs):
    varargin = default_user.varargin
    nargin = default_user.nargin

    ent=getpwuid(getuid)
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:494
    if (logical_not(isstruct(ent))):
        retval=getenv('USER')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:496
        if (isempty(retval)):
            retval=getenv('USERNAME')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:498
    else:
        if (long_form):
            retval=ent.gecos
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:501
            pos=strfind(retval,',')
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:502
            if (logical_not(isempty(pos))):
                retval=retval[1:pos - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:504
        else:
            retval=ent.name
# /home/lei/octave-4.0.2/scripts/miscellaneous/edit.m:507
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def do_edit(editor=None,file=None,mode=None,*args,**kwargs):
    varargin = do_edit.varargin
    nargin = do_edit.nargin

    if (isguirunning()):
        __octave_link_edit_file__(file)
    else:
        system(sprintf(undo_string_escapes(editor),cat('"',file,'"')),[],mode)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{status}, @var{result}, @var{msgid}] =} fileattrib (@var{file})
## Return information about @var{file}.
##
## If successful, @var{status} is 1, with @var{result} containing a structure
## with the following fields:
##
## @table @code
## @item Name
## Full name of @var{file}.
##
## @item archive
## True if @var{file} is an archive (Windows).
##
## @item system
## True if @var{file} is a system file (Windows).
##
## @item hidden
## True if @var{file} is a hidden file (Windows).
##
## @item directory
## True if @var{file} is a directory.
##
## @item  UserRead
## @itemx GroupRead
## @itemx OtherRead
## True if the user (group; other users) has read permission for @var{file}.
##
## @item  UserWrite
## @itemx GroupWrite
## @itemx OtherWrite
## True if the user (group; other users) has write permission for @var{file}.
##
## @item  UserExecute
## @itemx GroupExecute
## @itemx OtherExecute
## True if the user (group; other users) has execute permission for @var{file}.
## @end table
##
## If an attribute does not apply (i.e., archive on a Unix system) then the
## field is set to NaN.
##
## With no input arguments, return information about the current directory.
##
## If @var{file} contains globbing characters, return information about all
## the matching files.
## @seealso{glob}
## @end deftypefn
    
    
@function
def fileattrib(file=None,*args,**kwargs):
    varargin = fileattrib.varargin
    nargin = fileattrib.nargin

    status=copy(true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:70
    msg=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:71
    msgid=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:72
    if (nargin == 0):
        file='.'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:75
    
    if (ischar(file)):
        files=glob(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:79
        if (isempty(files)):
            files=cellarray([file])
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:81
            nfiles=1
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:82
        else:
            nfiles=length(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:84
    else:
        error('fileattrib: expecting first argument to be a character string')
    
    if (nargin == 0 or nargin == 1):
        r_n=r_a=r_s=r_h=r_d=r_u_r=r_u_w=r_u_x=r_g_r=r_g_w=r_g_x=r_o_r=r_o_w=r_o_x=cell(nfiles,1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:95
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:95
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:95
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:95
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:94
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:94
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:94
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:93
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:93
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:93
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:92
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:92
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:92
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:92
        curr_dir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:97
        for i in arange(1,nfiles).reshape(-1):
            info,err,msg=stat(files[i],nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:100
            if (logical_not(err)):
                r_n[i]=canonicalize_file_name(files[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:102
                r_a[i]=NaN
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:103
                r_s[i]=NaN
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:104
                r_h[i]=NaN
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:105
                r_d[i]=S_ISDIR(info.mode)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:106
                modestr=info.modestr
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:108
                r_u_r[i]=modestr[2] == 'r'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:109
                r_u_w[i]=modestr[3] == 'w'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:110
                r_u_x[i]=modestr[4] == 'x'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:111
                r_g_r[i]=modestr[5] == 'r'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:112
                r_g_w[i]=modestr[6] == 'w'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:113
                r_g_x[i]=modestr[7] == 'x'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:114
                r_o_r[i]=modestr[8] == 'r'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:115
                r_o_w[i]=modestr[9] == 'w'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:116
                r_o_x[i]=modestr[10] == 'x'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:117
            else:
                status=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:119
                msgid='fileattrib'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:120
                break
        if (status):
            r=struct('Name',r_n,'archive',r_a,'system',r_s,'hidden',r_s,'directory',r_d,'UserRead',r_u_r,'UserWrite',r_u_w,'UserExecute',r_u_x,'GroupRead',r_g_r,'GroupWrite',r_g_w,'GroupExecute',r_g_x,'OtherRead',r_o_r,'OtherWrite',r_o_w,'OtherExecute',r_o_x)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:125
            if (nargout == 0):
                status=copy(r)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:132
            else:
                msg=copy(r)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileattrib.m:134
    else:
        print_usage()
    
    return status,msg,msgid
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} setappdata (@var{h}, @var{name}, @var{value})
## @deftypefnx {Function File} {} setappdata (@var{h}, @var{name1}, @var{value1}, @var{name2}, @var{value3}, @dots{})
## Set the application data @var{name} to @var{value} for the graphics object
## with handle @var{h}.
##
## @var{h} may also be a vector of graphics handles.  If the application data
## with the specified @var{name} does not exist, it is created.  Multiple
## @var{name}/@var{value} pairs can be specified at a time.
##
## @seealso{getappdata, isappdata, rmappdata, guidata, get, set, getpref, setpref}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-15
    
    
@function
def setappdata(h=None,varargin=None,*args,**kwargs):
    varargin = setappdata.varargin
    nargin = setappdata.nargin

    h=ravel(h).T
# /home/lei/octave-4.0.2/scripts/miscellaneous/setappdata.m:37
    if (logical_not(all(ishandle(h)))):
        error('setappdata: H must be a scalar or vector of graphic handles')
    else:
        if (mod(numel(varargin),2) != 0):
            error('setappdata: NAME/VALUE arguments must occur in pairs')
    
    for hg in h.reshape(-1):
        try:
            appdata=get(hg,'__appdata__')
# /home/lei/octave-4.0.2/scripts/miscellaneous/setappdata.m:46
        finally:
            pass
        for narg in arange(1,numel(varargin),2).reshape(-1):
            if (ischar(varargin[narg])):
                setattr(appdata,varargin[narg],varargin[narg + 1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/setappdata.m:54
            else:
                if (iscellstr(varargin[narg])):
                    ## Handle cell arrays like set() does.
                    set(hg,'__appdata__',appdata)
                    setappdata(hg,vertcat(varargin[narg].T,varargin[narg + 1].T)[:])
                    appdata=get(hg,'__appdata__')
# /home/lei/octave-4.0.2/scripts/miscellaneous/setappdata.m:59
                else:
                    error('setappdata: NAME must be a string or cellstr')
        set(hg,'__appdata__',appdata)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{z} =} xor (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{z} =} xor (@var{x1}, @var{x2}, @dots{})
## Return the @dfn{exclusive or} of @var{x} and @var{y}.
##
## For boolean expressions @var{x} and @var{y},
## @code{xor (@var{x}, @var{y})} is true if and only if one of @var{x} or
## @var{y} is true.  Otherwise, if @var{x} and @var{y} are both true or both
## false, @code{xor} returns false.
##
## The truth table for the xor operation is
##
## @multitable @columnfractions 0.44 .03 .05 .03 0.44
## @item @tab @var{x} @tab @var{y} @tab @var{z} @tab
## @item @tab - @tab - @tab - @tab
## @item @tab 0 @tab 0 @tab 0 @tab
## @item @tab 1 @tab 0 @tab 1 @tab
## @item @tab 0 @tab 1 @tab 1 @tab
## @item @tab 1 @tab 1 @tab 0 @tab
## @end multitable
##
## If more than two arguments are given the xor operation is applied
## cumulatively from left to right:
##
## @example
## (@dots{}((x1 XOR x2) XOR x3) XOR @dots{})
## @end example
##
## @seealso{and, or, not}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 16 September 1994
## Adapted-By: jwe
    
    
@function
def xor(x=None,y=None,varargin=None,*args,**kwargs):
    varargin = xor.varargin
    nargin = xor.nargin

    if (nargin < 2):
        print_usage()
    
    z=__xor__(x,y)
# /home/lei/octave-4.0.2/scripts/miscellaneous/xor.m:60
    
    ## Probably okay number of elements ## will be small.
    if (logical_not(isempty(varargin))):
        for i in arange(1,numel(varargin)).reshape(-1):
            z=__xor__(z,varargin[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/xor.m:66
    
    return z
    
if __name__ == '__main__':
    pass
    
    
@function
def __xor__(x=None,y=None,*args,**kwargs):
    varargin = __xor__.varargin
    nargin = __xor__.nargin

    if (isscalar(x) or isscalar(y) or size_equal(x,y)):
        ## Typecast to logicals is necessary for other numeric types.
        z=logical(x) != logical(y)
# /home/lei/octave-4.0.2/scripts/miscellaneous/xor.m:76
    else:
        try:
            z=bsxfun(xor,x,y)
# /home/lei/octave-4.0.2/scripts/miscellaneous/xor.m:79
        finally:
            pass
    
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test XOR reduction
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{vars} =} symvar (@var{str})
## Identify the symbolic variable names in the string @var{str}.
##
## Common constant names such as @code{i}, @code{j}, @code{pi}, @code{Inf} and
## Octave functions such as @code{sin} or @code{plot} are ignored.
##
## Any names identified are returned in a cell array of strings.  The array is
## empty if no variables were found.
##
## Example:
##
## @example
## @group
## symvar ("x^2 + y^2 == 4")
## @result{} @{
##      [1,1] = x
##      [2,1] = y
##    @}
## @end group
## @end example
## @end deftypefn
    
    
@function
def symvar(str=None,*args,**kwargs):
    varargin = symvar.varargin
    nargin = symvar.nargin

    vars=argnames(inline(str))
# /home/lei/octave-4.0.2/scripts/miscellaneous/symvar.m:43
    
    if (numel(vars) == 1 and strcmp(vars[1],'x') and logical_not(any(str == 'x'))):
        vars=cellarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/symvar.m:46
    
    return vars
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2005-2015 William Poetra Yoga Hadisoeseno
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ver
## @deftypefnx {Function File} {} ver Octave
## @deftypefnx {Function File} {} ver @var{package}
## @deftypefnx {Function File} {v =} ver (@dots{})
##
## Display a header containing the current Octave version number, license
## string, and operating system.  The header is followed by a list of installed
## packages, versions, and installation directories.
##
## Use the package name @var{package} or Octave to limit the listing to a
## desired component.
##
## When called with an output argument, return a vector of structures
## describing Octave and each installed package.  The structure includes the
## following fields.
##
## @table @code
## @item Name
## Package name.
##
## @item Version
## Version of the package.
##
## @item Revision
## Revision of the package.
##
## @item Date
## Date of the version/revision.
## @end table
##
## @seealso{version, octave_config_info, usejava, pkg}
## @end deftypefn
    
    ## Author: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def ver(package='',*args,**kwargs):
    varargin = ver.varargin
    nargin = ver.nargin

    if (nargin > 1):
        print_usage()
    
    if (nargout == 0):
        unm,err=uname(nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:62
        if (err):
            os_string='unknown'
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:65
        else:
            os_string=sprintf('%s %s %s %s',unm.sysname,unm.release,unm.version,unm.machine)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:67
        hbar[1:70]='-'
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:71
        desc=cellarray([hbar,cat('GNU Octave Version: ',OCTAVE_VERSION),cat('GNU Octave License: ',license),cat('Operating System: ',os_string),hbar])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:72
        printf('%s\n',desc[:])
        if (isempty(package)):
            pkg('list')
        else:
            if (strcmpi(package,'Octave')):
                ## Nothing to do, Octave version was already reported
                pass
            else:
                pkg('list',package)
    else:
        ## Get the installed packages
        if (isempty(package)):
            lst=pkg('list')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:90
            retval=struct('Name','Octave','Version',version,'Release',[],'Date',[])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:92
            for i in arange(1,numel(lst)).reshape(-1):
                retval[end() + 1]=struct('Name',lst[i].name,'Version',lst[i].version,'Release',[],'Date',lst[i].date)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:95
        else:
            if (strcmpi(package,'Octave')):
                retval=struct('Name','Octave','Version',version,'Release',[],'Date',[])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:99
            else:
                lst=pkg('list',package)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:102
                if (isempty(lst)):
                    retval=struct('Name','','Version',[],'Release',[],'Date',[])
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:104
                else:
                    retval=struct('Name',lst[1].name,'Version',lst[1].version,'Release',[],'Date',lst[1].date)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ver.m:107
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{valid} =} isappdata (@var{h}, @var{name})
## Return true if the named application data, @var{name}, exists for the
## graphics object with handle @var{h}.
##
## @var{h} may also be a vector of graphics handles.
## @seealso{getappdata, setappdata, rmappdata, guidata, get, set, getpref, setpref}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-15
    
    
@function
def isappdata(h=None,name=None,*args,**kwargs):
    varargin = isappdata.varargin
    nargin = isappdata.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(all(ishandle(ravel(h))))):
        error('isappdata: H must be a scalar or vector of graphic handles')
    else:
        if (logical_not(ischar(name))):
            error('isappdata: NAME must be a string')
    
    valid=false(size(h))
# /home/lei/octave-4.0.2/scripts/miscellaneous/isappdata.m:43
    for i in arange(1,numel(h)).reshape(-1):
        try:
            appdata=get(h[i],'__appdata__')
# /home/lei/octave-4.0.2/scripts/miscellaneous/isappdata.m:46
            if (isfield(appdata,name)):
                valid[i]=true
# /home/lei/octave-4.0.2/scripts/miscellaneous/isappdata.m:48
        finally:
            pass
    
    return valid
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} gzip (@var{files})
## @deftypefnx {Function File} {@var{filelist} =} gzip (@var{files}, @var{dir})
## Compress the list of files and directories specified in @var{files}.
##
## @var{files} is a character array or cell array of strings.  Shell wildcards
## in the filename such as @samp{*} or @samp{?} are accepted and expanded.
## Each file is compressed separately and a new file with a @file{".gz"}
## extension is created.  The original files are not modified, but existing
## compressed files will be silently overwritten.  If a directory is
## specified then @code{gzip} recursively compresses all files in the
## directory.
##
## If @var{dir} is defined the compressed files are placed in this directory,
## rather than the original directory where the uncompressed file resides.
## If @var{dir} does not exist it is created.
##
## The optional output @var{filelist} is a list of the compressed files.
## @seealso{gunzip, unpack, bzip2, zip, tar}
## @end deftypefn
    
    
@function
def gzip(varargin=None,*args,**kwargs):
    varargin = gzip.varargin
    nargin = gzip.nargin

    if (nargin < 1 or nargin > 2 or nargout > 1):
        print_usage()
    
    if (nargout == 0):
        __xzip__('gzip','gz','gzip -r %s',varargin[:])
    else:
        filelist=__xzip__('gzip','gz','gzip -r %s',varargin[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/gzip.m:49
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} list_primes ()
## @deftypefnx {Function File} {} list_primes (@var{n})
## List the first @var{n} primes.
##
## If @var{n} is unspecified, the first 25 primes are listed.
## @seealso{primes, isprime}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def list_primes(n=25,*args,**kwargs):
    varargin = list_primes.varargin
    nargin = list_primes.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isreal(n)) or logical_not(isscalar(n))):
            error('list_primes: N must be a real scalar')
    
    n=floor(n)
# /home/lei/octave-4.0.2/scripts/miscellaneous/list_primes.m:38
    if (n < 1):
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/list_primes.m:41
        return retval
    else:
        if (n == 1):
            retval=2
# /home/lei/octave-4.0.2/scripts/miscellaneous/list_primes.m:44
            return retval
    
    list=primes(dot(n,log(dot(5,n))))
# /home/lei/octave-4.0.2/scripts/miscellaneous/list_primes.m:48
    if (numel(list) < n):
        ## Algorithm tested up to n=10,000 without failure.
        error('list_primes: Algorithm failed.  Try primes (n*log (6*n))(1:n)')
    
    retval=list[1:n]
# /home/lei/octave-4.0.2/scripts/miscellaneous/list_primes.m:54
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2013-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{used} =} desktop ("-inuse")
## Return true if the desktop (GUI) is currently in use.
## @seealso{isguirunning}
## @end deftypefn
    
    
@function
def desktop(arg=None,*args,**kwargs):
    varargin = desktop.varargin
    nargin = desktop.nargin

    if (nargin == 0):
        if (isguirunning()):
            return retval
        else:
            print_usage()
    else:
        if (nargin > 1):
            error('desktop: only one argument, "-inuse", is allowed')
    
    if '-inuse' == (tolower(arg)):
        retval=isguirunning()
# /home/lei/octave-4.0.2/scripts/miscellaneous/desktop.m:39
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Julian Schnidder
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} info ()
## Display contact information for the GNU Octave community.
## @end deftypefn
    
    
@function
def info(*args,**kwargs):
    varargin = info.varargin
    nargin = info.nargin

    printf('\n  Additional information about GNU Octave is available at\n  http://www.octave.org\n\n  Links to the mailing list and other resources for getting help with\n  Octave are available at\n  http://www.octave.org/support.html\n\n  The Octave Wiki has user-generated content on a variety of subjects\n  including installation and is available at\n  http://wiki.octave.org\n\n  Additional functionality can be enabled by using packages from\n  the Octave Forge project, which may be found at\n  http://octave.sourceforge.net\n\n  Report bugs to the bug tracker at\n  http://bugs.octave.org\n  But first, please read the guidelines to writing a helpful report at\n  http://www.octave.org/bugs.html\n')
    return
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for a documentation .m file
    
    ## Copyright (C) 2006-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} gunzip (@var{gzfile})
## @deftypefnx {Function File} {@var{filelist} =} gunzip (@var{gzfile}, @var{dir})
## Unpack the gzip archive @var{gzfile}.
##
## If @var{gzfile} is a directory, all gzfiles in the directory will be
## recursively unpacked.
##
## If @var{dir} is specified the files are unpacked in this directory rather
## than the one where @var{gzfile} is located.
##
## The optional output @var{filelist} is a list of the uncompressed files.
## @seealso{gzip, unpack, bunzip2, unzip, untar}
## @end deftypefn
    
    ## Author: Bill Denney <denney@seas.upenn.edu>
    
    
@function
def gunzip(gzfile=None,dir=[],*args,**kwargs):
    varargin = gunzip.varargin
    nargin = gunzip.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (isempty(dir)):
        dir=fileparts(gzfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/gunzip.m:43
    
    if (nargout > 0):
        filelist=unpack(gzfile,dir,'gunzip')
# /home/lei/octave-4.0.2/scripts/miscellaneous/gunzip.m:47
    else:
        unpack(gzfile,dir,'gunzip')
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    ## Tests for this m-file are located in gzip.m
## Remove from test statistics
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dir
## @deftypefnx {Function File} {} dir (@var{directory})
## @deftypefnx {Function File} {[@var{list}] =} dir (@var{directory})
## Display file listing for directory @var{directory}.
##
## If @var{directory} is not specified then list the present working directory.
##
## If a return value is requested, return a structure array with the fields
##
## @table @asis
## @item name
## File or directory name.
##
## @item date
## Timestamp of file modification (string value).
##
## @item bytes
## File size in bytes.
##
## @item isdir
## True if name is a directory.
##
## @item datenum
## Timestamp of file modification as serial date number (double).
##
## @item statinfo
## Information structure returned from @code{stat}.
## @end table
##
## If @var{directory} is a filename, rather than a directory, then return
## information about the named file.  @var{directory} may also be a list rather
## than a single directory or file.
##
## @var{directory} is subject to shell expansion if it contains any wildcard
## characters @samp{*}, @samp{?}, @samp{[]}.  To find a literal example of a
## wildcard character the wildcard must be escaped using the backslash operator
## @samp{\}.
##
## Note that for symbolic links, @code{dir} returns information about the
## file that the symbolic link points to rather than the link itself.
## However, if the link points to a nonexistent file, @code{dir} returns
## information about the link.
## @seealso{ls, readdir, glob, what, stat, lstat}
## @end deftypefn
    
    ## Author: jwe
    
    ## FIXME: This is quite slow for large directories.
##        Perhaps it should be converted to C++?
    
    
@function
def dir(directory=None,*args,**kwargs):
    varargin = dir.varargin
    nargin = dir.nargin

    if (nargin == 0):
        directory='.'
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:73
    else:
        if (nargin > 1):
            print_usage()
    
    if (logical_not(ischar(directory))):
        error('dir: DIRECTORY argument must be a string')
    
    ## Prep the retval.
    info=struct(zeros(0,1),cellarray(['name','date','bytes','isdir','datenum','statinfo']))
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:83
    if (strcmp(directory,'*')):
        directory='.'
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:88
    
    if (strcmp(directory,'.')):
        flst=cellarray(['.'])
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:91
        nf=1
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:92
    else:
        flst=glob(directory)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:94
        nf=numel(flst)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:95
    
    ## Determine the file list for the case where a single directory is specified.
    if (nf == 1):
        fn=flst[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:100
        st,err,msg=stat(fn,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:101
        if (err < 0):
            warning('dir: \'stat (%s)\' failed: %s',fn,msg)
            nf=0
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:104
        else:
            if (S_ISDIR(st.mode)):
                flst=readdir(flst[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:106
                nf=numel(flst)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:107
                for i in arange(1,nf).reshape(-1):
                    flst[i]=fullfile(fn,flst[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:109
    
    if (numel(flst) > 0):
        ## Collect results.
        for i in arange(nf,1,- 1).reshape(-1):
            fn=flst[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:117
            st,err,msg=lstat(fn,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:118
            if (err < 0):
                warning('dir: \'lstat (%s)\' failed: %s',fn,msg)
            else:
                ## If we are looking at a link that points to something,
        ## return info about the target of the link, otherwise, return
        ## info about the link itself.
                if (S_ISLNK(st.mode)):
                    xst,err,msg=stat(fn,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:126
                    if (logical_not(err)):
                        st=copy(xst)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:128
                dummy,fn,ext=fileparts(fn,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:131
                fn=matlabarray(cat(fn,ext))
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:132
                info[i,1].name = copy(fn)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:133
                lt=localtime(st.mtime)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:134
                info[i,1].date = copy(strftime('%d-%b-%Y %T',lt))
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:135
                info[i,1].bytes = copy(st.size)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:136
                info[i,1].isdir = copy(S_ISDIR(st.mode))
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:137
                info[i,1].datenum = copy(datenum(lt.year + 1900,lt.mon + 1,lt.mday,lt.hour,lt.min,lt.sec))
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:138
                info[i,1].statinfo = copy(st)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:140
    
    ## Return the output arguments.
    if (nargout > 0):
        ## Return the requested structure.
        retval=copy(info)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dir.m:148
    else:
        if (numel(info) > 0):
            ## Print the structure to the screen.
            printf('%s',list_in_columns(cellarray([info.name])))
        else:
            warning('dir: nonexistent directory \'%s\'',directory)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Bill Denney, Robert Platt
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{varname} =} genvarname (@var{str})
## @deftypefnx {Function File} {@var{varname} =} genvarname (@var{str}, @var{exclusions})
## Create valid unique variable name(s) from @var{str}.
##
## If @var{str} is a cellstr, then a unique variable is created for each cell
## in @var{str}.
##
## @example
## @group
## genvarname (@{"foo", "foo"@})
##   @result{}
##      @{
##        [1,1] = foo
##        [1,2] = foo1
##      @}
## @end group
## @end example
##
## If @var{exclusions} is given, then the variable(s) will be unique to each
## other and to @var{exclusions} (@var{exclusions} may be either a string or a
## cellstr).
##
## @example
## @group
## x = 3.141;
## genvarname ("x", who ())
##   @result{} x1
## @end group
## @end example
##
## Note that the result is a char array or cell array of strings, not the
## variables themselves.  To define a variable, @code{eval()} can be used.
## The following trivial example sets @code{x} to @code{42}.
##
## @example
## @group
## name = genvarname ("x");
## eval ([name " = 42"]);
##   @result{} x =  42
## @end group
## @end example
##
## This can be useful for creating unique struct field names.
##
## @example
## @group
## x = struct ();
## for i = 1:3
##   x.(genvarname ("a", fieldnames (x))) = i;
## endfor
##   @result{} x =
##      @{
##        a =  1
##        a1 =  2
##        a2 =  3
##      @}
## @end group
## @end example
##
## Since variable names may only contain letters, digits, and underscores,
## @code{genvarname} will replace any sequence of disallowed characters with
## an underscore.  Also, variables may not begin with a digit; in this case
## an @samp{x} is added before the variable name.
##
## Variable names beginning and ending with two underscores @qcode{"__"} are
## valid, but they are used internally by Octave and should generally be
## avoided; therefore, @code{genvarname} will not generate such names.
##
## @code{genvarname} will also ensure that returned names do not clash with
## keywords such as @qcode{"for"} and @qcode{"if"}.  A number will be
## appended if necessary.  Note, however, that this does @strong{not} include
## function names such as @qcode{"sin"}.  Such names should be included in
## @var{exclusions} if necessary.
## @seealso{isvarname, iskeyword, exist, who, tempname, eval}
## @end deftypefn
    
    ## Authors: Rob Platt <robert.platt@postgrad.manchester.ac.uk>
##          Bill Denney <bill@denney.ws>
    
    
@function
def genvarname(str=None,exclusions=cellarray([]),*args,**kwargs):
    varargin = genvarname.varargin
    nargin = genvarname.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    strinput=ischar(str)
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:105
    
    if (strinput):
        if (rows(str) != 1):
            error('genvarname: if more than one STR is given, it must be a cellstr')
        str=cellarray([str])
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:111
    else:
        if (logical_not(iscellstr(str))):
            error('genvarname: STR must be a string or cellstr')
    
    if (ischar(exclusions)):
        if (rows(exclusions) != 1):
            error('genvarname: if more than one exclusion is given, it must be a cellstr')
        exclusions=cellarray([exclusions])
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:120
    else:
        if (logical_not(iscellstr(exclusions))):
            error('genvarname: EXCLUSIONS must be a string or cellstr')
        else:
            exclusions=ravel(exclusions)
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:124
    
    varname=cell(size(str))
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:127
    for i in arange(1,numel(str)).reshape(-1):
        ## Perform any modifications to the varname to make sure that it is
    ## a valid variable name.
        ## remove invalid characters
        str[i][logical_not((logical_or(isalnum(str[i]),str[i]) == '_'))]='_'
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:133
        if (iskeyword(str[i])):
            firstcharacter=toupper(str[i](1))
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:136
            str[i]=cat('x',firstcharacter,str[i](arange(2,end())))
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:137
        ## The variable cannot be empty
        if (isempty(str[i])):
            str[i]='x'
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:141
        ## Leading underscores are not Matlab compatible
        if (str[i](1) == '_'):
            str[i]=cat('x',str[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:145
        ## it cannot start with a number
        if (isdigit(str[i](1))):
            str[i]=cat('x',str[i])
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:149
        ## make sure that the variable is unique relative to other variables
    ## and the exclusions list
        excluded=any(strcmp(str[i],exclusions))
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:154
        if (excluded and isdigit(str[i](end()))):
            ## if it is not unique and ends with a digit, add an underscore to
      ## make the variable name more readable ("x1_1" instead of "x11")
            str[i]=cat(str[i],'_')
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:158
        varname[i]=str[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:160
        idx=0
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:161
        while (excluded):

            idx
            varname[i]=sprintf('%s%d',str[i],idx)
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:164
            excluded=any(strcmp(varname[i],exclusions))
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:165

        exclusions[end() + 1]=varname[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:167
    
    if (strinput):
        varname=varname[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/genvarname.m:171
    
    return varname
    
if __name__ == '__main__':
    pass
    
    ## a single argument
    
    ## a single argument with a non-conflicting exception
    
    ## a single argument with a conflicting exception
    
    ## a single argument as a cell
    
    
    
    
    
    ## Test different arguments
## orientation
    
    
    
    
    
    ## more than one repetition
    
    
    ## more than one repetition not in order
    
    ## Variable name munging
    
    
    
    
    
    
    
    
    ## Exclusions in odd format
    
    ## Test input validation
    
    ## Copyright (C) 2006-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} mexext ()
## Return the filename extension used for MEX files.
## @seealso{mex}
## @end deftypefn
    
    
@function
def mexext(*args,**kwargs):
    varargin = mexext.varargin
    nargin = mexext.nargin

    retval='mex'
# /home/lei/octave-4.0.2/scripts/miscellaneous/mexext.m:26
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2005-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} unzip (@var{zipfile})
## @deftypefnx {Function File} {@var{filelist} =} unzip (@var{zipfile}, @var{dir})
## Unpack the ZIP archive @var{zipfile}.
##
## If @var{dir} is specified the files are unpacked in this directory rather
## than the one where @var{zipfile} is located.
##
## The optional output @var{filelist} is a list of the uncompressed files.
## @seealso{zip, unpack, bunzip2, gunzip, untar}
## @end deftypefn
    
    ## Author: Sren Hauberg <hauberg@gmail.com>
## Adapted-By: jwe, Bill Denney
    
    
@function
def unzip(zipfile=None,dir=[],*args,**kwargs):
    varargin = unzip.varargin
    nargin = unzip.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (isempty(dir)):
        dir=fileparts(zipfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unzip.m:41
    
    if (nargout > 0):
        filelist=unpack(zipfile,dir,'unzip')
# /home/lei/octave-4.0.2/scripts/miscellaneous/unzip.m:45
    else:
        unpack(zipfile,dir,'unzip')
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    ## Tests for this m-file are located in zip.m
## Remove from test statistics
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{choice} =} menu (@var{title}, @var{opt1}, @dots{})
## @deftypefnx {Function File} {@var{choice} =} menu (@var{title}, @{@var{opt1}, @dots{}@})
## Display a menu with heading @var{title} and options @var{opt1}, @dots{},
## and wait for user input.
##
## If the GUI is running, or Java is available, the menu is displayed
## graphically using @code{listdlg}.  Otherwise, the title and menu options
## are printed on the console.
##
## @var{title} is a string and the options may be input as individual strings
## or as a cell array of strings.
##
## The return value @var{choice} is the number of the option selected by the
## user counting from 1.
##
## This function is useful for interactive programs.  There is no limit to the
## number of options that may be passed in, but it may be confusing to present
## more than will fit easily on one screen.
## @seealso{input, listdlg}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def menu(title=None,varargin=None,*args,**kwargs):
    varargin = menu.varargin
    nargin = menu.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(ischar(title))):
        error('menu: TITLE must be a string')
    else:
        if (nargin > 2 and logical_not(iscellstr(varargin))):
            error('menu: All OPTIONS must be strings')
        else:
            if (logical_not(ischar(varargin[1])) and logical_not(iscellstr(varargin[1]))):
                error('menu: OPTIONS must be string or cell array of strings')
    
    if (isguirunning() or usejava('awt')):
        choice,ok=listdlg('Name','menu','PromptString',title,'ListString',varargin,'SelectionMode','Single',nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/menu.m:58
        if (logical_not(ok)):
            choice=1
# /home/lei/octave-4.0.2/scripts/miscellaneous/menu.m:61
    else:
        ## Force pending output to appear before the menu.
        fflush(stdout)
        ## major confusion.
        page_screen_output(0,'local')
        if (logical_not(isempty(title))):
            printf('%s\n',title)
        nopt=numel(varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/menu.m:75
        while (1):

            for i in arange(1,nopt).reshape(-1):
                printf('  [%2d] %s\n',i,varargin[i])
            printf('\n')
            s=input_('Select a number: ','s')
# /home/lei/octave-4.0.2/scripts/miscellaneous/menu.m:81
            choice=sscanf(s,'%d')
# /home/lei/octave-4.0.2/scripts/miscellaneous/menu.m:82
            if (logical_not(isscalar(choice)) or choice < 1 or choice > nopt):
                printf('\nerror: input invalid or out of range\n\n')
            else:
                break

    
    return choice
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} namelengthmax ()
## Return the @sc{matlab} compatible maximum variable name length.
##
## Octave is capable of storing strings up to @math{2^{31} - 1} in length.
## However for @sc{matlab} compatibility all variable, function, and structure
## field names should be shorter than the length returned by
## @code{namelengthmax}.  In particular, variables stored to a @sc{matlab} file
## format (@file{*.mat}) will have their names truncated to this length.
## @end deftypefn
    
    
@function
def namelengthmax(*args,**kwargs):
    varargin = namelengthmax.varargin
    nargin = namelengthmax.nargin

    n=63
# /home/lei/octave-4.0.2/scripts/miscellaneous/namelengthmax.m:31
    return n
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} version ()
## Return the version number of Octave as a string.
##
## This is an alias for the function @w{@env{OCTAVE_VERSION}} provided for
## compatibility.
## @seealso{OCTAVE_VERSION, ver}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def version(*args,**kwargs):
    varargin = version.varargin
    nargin = version.nargin

    if (nargin != 0):
        warning('version: ignoring extra arguments')
    
    vs=copy(OCTAVE_VERSION)
# /home/lei/octave-4.0.2/scripts/miscellaneous/version.m:36
    return vs
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2008-2015 Julian Schnidder
## Copyright (C) 2012 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{output} =} python (@var{scriptfile})
## @deftypefnx {Function File} {@var{output} =} python (@var{scriptfile}, @var{argument1}, @var{argument2}, @dots{})
## @deftypefnx {Function File} {[@var{output}, @var{status}] =} python (@dots{})
## Invoke Python script @var{scriptfile}, possibly with a list of command line
## arguments.
##
## Return output in @var{output} and optional status in @var{status}.  If
## @var{scriptfile} is not an absolute file name it is searched for in the
## current directory and then in the Octave loadpath.
## @seealso{system, perl}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug+dev@gmail.com>
    
    
@function
def python(scriptfile='-c \'\'',varargin=None,*args,**kwargs):
    varargin = python.varargin
    nargin = python.nargin

    if (ischar(scriptfile) and ((nargin == 1 and logical_not(isempty(scriptfile))) or (nargin != 1 and iscellstr(varargin)))):
        if (logical_not(strcmp(scriptfile[1:2],'-c'))):
            ## Attempt to find file in loadpath.  No effect for absolute filenames.
            scriptfile=file_in_loadpath(scriptfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/python.m:42
        status,output=system(cat('python ',scriptfile,sprintf(' %s',varargin[:])),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/python.m:45
    else:
        error('python: invalid arguments')
    
    return output,status
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2003-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{dir}, @var{name}, @var{ext}] =} fileparts (@var{filename})
## Return the directory, name, and extension components of @var{filename}.
##
## The input @var{filename} is a string which is parsed.  There is no attempt
## to check whether the filename or directory specified actually exists.
## @seealso{fullfile, filesep}
## @end deftypefn
    
    
@function
def fileparts(filename=None,*args,**kwargs):
    varargin = fileparts.varargin
    nargin = fileparts.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(ischar(filename)) or rows(filename) > 1):
        error('fileparts: FILENAME must be a single string')
    
    ds=strchr(filename,filesep('all'),1,'last')
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:38
    if (isempty(ds)):
        ds=0
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:40
    
    es=rindex(filename,'.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:42
    
    if (es <= ds):
        es=length(filename) + 1
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:45
    
    if (ds == 0):
        dir=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:49
    else:
        if (ds == 1):
            dir=filename[1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:51
        else:
            dir=filename[1:ds - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:53
    
    name=filename[ds + 1:es - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:56
    if (isempty(name)):
        name=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:58
    
    if (es > 0 and es <= length(filename)):
        ext=filename[es:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:62
    else:
        ext=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fileparts.m:64
    
    return dir,name,ext
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2003-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{dir} =} tempdir ()
## Return the name of the host system's directory for temporary files.
##
## The directory name is taken first from the environment variable
## @env{TMPDIR}.  If that does not exist the system default returned by
## @code{P_tmpdir} is used.
## @seealso{P_tmpdir, tempname, mkstemp, tmpfile}
## @end deftypefn
    
    
@function
def tempdir(*args,**kwargs):
    varargin = tempdir.varargin
    nargin = tempdir.nargin

    dirname=getenv('TMPDIR')
# /home/lei/octave-4.0.2/scripts/miscellaneous/tempdir.m:31
    if (isempty(dirname)):
        dirname=copy(P_tmpdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tempdir.m:33
    
    if (logical_not(strcmp(dirname[end()],filesep))):
        dirname=matlabarray(cat(dirname,filesep))
# /home/lei/octave-4.0.2/scripts/miscellaneous/tempdir.m:37
    
    if (logical_not(isdir(dirname))):
        warning('tempdir: \'%s\' does not exist or is not a directory',dirname)
    
    return dirname
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} pack ()
## Consolidate workspace memory in @sc{matlab}.
##
## This function is provided for compatibility, but does nothing in Octave.
## @seealso{clear}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def pack(*args,**kwargs):
    varargin = pack.varargin
    nargin = pack.nargin

    return
    
if __name__ == '__main__':
    pass
    
    ## No test needed for empty function
    
    ## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} news
## @deftypefnx {Command} {} news @var{package}
## Display the current NEWS file for Octave or an installed package.
##
## When called without an argument, display the NEWS file for Octave.
##
## When given a package name @var{package}, display the current NEWS file for
## that package.
## @seealso{ver, pkg}
## @end deftypefn
    
    
@function
def news(package='octave',*args,**kwargs):
    varargin = news.varargin
    nargin = news.nargin

    if (nargin > 1):
        print_usage()
    else:
        display_info_file('news',package,'NEWS')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2006-2015 John W. Eaton
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} substruct (@var{type}, @var{subs}, @dots{})
## Create a subscript structure for use with @code{subsref} or @code{subsasgn}.
##
## For example:
##
## @example
## @group
## idx = substruct ("()", @{3, ":"@})
##      @result{}
##        idx =
##        @{
##          type = ()
##          subs =
##          @{
##            [1,1] =  3
##            [1,2] = :
##          @}
##        @}
## x = [1, 2, 3;
##      4, 5, 6;
##      7, 8, 9];
## subsref (x, idx)
##    @result{} 7  8  9
## @end group
## @end example
## @seealso{subsref, subsasgn}
## @end deftypefn
    
    ## Author:  jwe
    
    
@function
def substruct(varargin=None,*args,**kwargs):
    varargin = substruct.varargin
    nargin = substruct.nargin

    if (nargin < 2 or mod(nargin,2) != 0):
        print_usage()
    
    typ=varargin[1:2:nargin]
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:57
    sub=varargin[2:2:nargin]
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:58
    braces=logical_or(strcmp(typ,'()'),strcmp(typ,'{}'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:59
    dots=strcmp(typ,'.')
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:60
    if (all(logical_or(braces,dots))):
        cells=cellfun('isclass',sub,'cell')
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:62
        chars=cellfun('isclass',sub,'char')
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:63
        if (any(logical_and(braces,logical_not(cells)))):
            error('substruct: for TYPE == () or {}, SUBS must be a cell array')
        else:
            if (any(logical_and(dots,logical_not(chars)))):
                error('substruct: for TYPE == ., SUBS must be a character string')
    else:
        error('substruct: expecting TYPE to be one of "()", "{}", or "."')
    
    retval=struct('type',typ,'subs',sub)
# /home/lei/octave-4.0.2/scripts/miscellaneous/substruct.m:73
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{val} =} ls_command ()
## @deftypefnx {Function File} {@var{old_val} =} ls_command (@var{new_val})
## Query or set the shell command used by Octave's @code{ls} command.
## @seealso{ls}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def ls_command(cmd=None,*args,**kwargs):
    varargin = ls_command.varargin
    nargin = ls_command.nargin

    global __ls_command__
    if (isempty(__ls_command__)):
        ## MinGW uses different ls_command
        if (ispc() and logical_not(isunix()) and isempty(file_in_path(getenv('PATH'),'ls'))):
            __ls_command__='dir /D'
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls_command.m:36
        else:
            __ls_command__='ls -C'
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls_command.m:38
    
    if (nargin == 0 or nargin == 1):
        old_cmd=copy(__ls_command__)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls_command.m:44
        if (nargin == 1):
            if (ischar(cmd)):
                __ls_command__=copy(cmd)
# /home/lei/octave-4.0.2/scripts/miscellaneous/ls_command.m:48
            else:
                error('ls_command: argument must be a character string')
    
    return old_cmd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} inputname (@var{n})
## Return the name of the @var{n}-th argument to the calling function.
##
## If the argument is not a simple variable name, return an empty string.
## @code{inputname} may only be used within a function body, not at the
## command line.
## @seealso{nargin, nthargout}
## @end deftypefn
    
    
@function
def inputname(n=None,*args,**kwargs):
    varargin = inputname.varargin
    nargin = inputname.nargin

    if (nargin != 1):
        print_usage()
    
    s=evalin('caller',sprintf('__varval__ (".argn."){%d};',fix(n)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/inputname.m:38
    
    ## return empty string if argument name is not a valid identifier.
    if (logical_not(isvarname(s))):
        s=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/inputname.m:42
    
    return s
    
if __name__ == '__main__':
    pass
    
    ## Warning: heap big magic in the following tests!!!
## The test function builds a private context for each
## test, with only the specified values shared between
## them.  It does this using the following template:
##
##     function [<shared>] = testfn(<shared>)
##        <test>
##
## To test inputname, I need a function context invoked
## with known parameter names.  So define a couple of
## shared parameters, et voila!, the test is trivial.
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} citation
## @deftypefnx {Command} {} citation @var{package}
## Display instructions for citing GNU Octave or its packages in publications.
##
## When called without an argument, display information on how to cite the core
## GNU Octave system.
##
## When given a package name @var{package}, display information on citing the
## specific named package.  Note that some packages may not yet have
## instructions on how to cite them.
##
## The GNU Octave developers and its active community of package authors have
## invested a lot of time and effort in creating GNU Octave as it is today.
## Please give credit where credit is due and cite GNU Octave and its packages
## when you use them.
##
## @end deftypefn
    
    ## Author: Carn Draug <carandraug+dev@gmail.com>
## Idea and documentation from R's citation() (also under GPL)
    
    
@function
def citation(package='octave',*args,**kwargs):
    varargin = citation.varargin
    nargin = citation.nargin

    if (nargin > 1):
        print_usage()
    else:
        display_info_file('citation',package,'CITATION')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{output} =} open @var{file}
## @deftypefnx {Function File} {@var{output} =} open (@var{file})
## Open the file @var{file} in Octave or in an external application based on
## the file type as determined by the file name extension.
##
## Recognized file types are
##
## @table @code
## @item .m
## Open file in the editor.
##
## @item .mat
## Load the file in the base workspace.
##
## @item .exe
## Execute the program (on Windows systems only).
## @end table
##
## Other file types are opened in the appropriate external application.
## @end deftypefn
    
    
@function
def open_(file=None,*args,**kwargs):
    varargin = open_.varargin
    nargin = open_.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(ischar(file))):
        error('expecting argument to be a file name')
    
    __,__,ext=fileparts(file,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/open.m:51
    if (strcmpi(ext,'.m')):
        edit(file)
    else:
        if (strcmpi(ext,'.mat')):
            if (nargout > 0):
                output=load(file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/open.m:57
            else:
                evalin('base',sprintf('load (\'%s\');',file))
        else:
            if (any(strcmpi(ext,cellarray(['.fig','.mdl','.slx','.prj'])))):
                error('opening file type \'%s\' is not supported',ext)
            else:
                if (strcmpi(ext,'.exe')):
                    if (ispc()):
                        dos(file)
                    else:
                        error('executing .exe files is only supported on Windows systems')
                else:
                    __open_with_system_app__(file)
    
    return output
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Command} {} mex [options] file @dots{}
## Compile source code written in C, C++, or Fortran, to a MEX file.
##
## This is equivalent to @code{mkoctfile --mex [options] file}.
## @seealso{mkoctfile, mexext}
## @end deftypefn
    
    
@function
def mex(varargin=None,*args,**kwargs):
    varargin = mex.varargin
    nargin = mex.nargin

    output,status=mkoctfile('--mex',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/mex.m:29
    if (logical_not(isempty(output))):
        disp(output)
    
    if (nargout > 0):
        retval=copy(status)
# /home/lei/octave-4.0.2/scripts/miscellaneous/mex.m:35
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Remove from test statistics.  All real tests are in mkoctfile.
    
    ## Copyright (C) 2006-2015 Alexander Barth
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{reg}, @var{prop}] =} parseparams (@var{params})
## @deftypefnx {Function File} {[@var{reg}, @var{var1}, @dots{}] =} parseparams (@var{params}, @var{name1}, @var{default1}, @dots{})
## Return in @var{reg} the cell elements of @var{param} up to the first
## string element and in @var{prop} all remaining elements beginning with the
## first string element.
##
## For example:
##
## @example
## @group
## [reg, prop] = parseparams (@{1, 2, "linewidth", 10@})
## reg =
## @{
##   [1,1] = 1
##   [1,2] = 2
## @}
## prop =
## @{
##   [1,1] = linewidth
##   [1,2] = 10
## @}
## @end group
## @end example
##
## The parseparams function may be used to separate regular numeric arguments
## from additional arguments given as property/value pairs of the
## @var{varargin} cell array.
##
## In the second form of the call, available options are specified directly
## with their default values given as name-value pairs.  If @var{params} do
## not form name-value pairs, or if an option occurs that does not match any
## of the available options, an error occurs.
##
## When called from an m-file function, the error is prefixed with the name
## of the caller function.
##
## The matching of options is case-insensitive.
##
## @seealso{varargin, inputParser}
## @end deftypefn
    
    ## Author: Alexander Barth <abarth93@users.sourceforge.net>
## Author: Aida Alvera Azcarate <aida@netecho.info>
    
    
@function
def parseparams(params=None,varargin=None,*args,**kwargs):
    varargin = parseparams.varargin
    nargin = parseparams.nargin

    strs=cellfun('isclass',params,'char')
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:67
    i=find(strs,1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:68
    if (i):
        reg=params[1:i - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:70
        prop=params[i:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:71
    else:
        reg=copy(params)
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:73
        prop=cellarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:74
    
    if (nargin == 1):
        varargout=cellarray([prop])
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:78
    else:
        names=varargin[1:2:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:80
        defaults=varargin[2:2:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:81
        if (logical_not(size_equal(names,defaults))):
            error('parseparams: needs odd number of arguments')
        names,sidx=sort(names,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:85
        varargout=copy(defaults)
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:87
        if (i):
            ## Let's parse the properties.
            pnames=prop[1:2:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:90
            values=prop[2:2:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:91
            if (logical_not(size_equal(pnames,values)) or logical_not(all(strs[i:2:end()]))):
                error_as_caller('options must be given as name-value pairs')
            idx=lookup(toupper(names),toupper(pnames),'m')
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:95
            if (logical_not(all(idx))):
                error_as_caller('unrecognized option: %s',pnames[find(idx == 0,1)])
            else:
                varargout[sidx[idx]]=values
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:99
    
    return reg,varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def error_as_caller(msg=None,varargin=None,*args,**kwargs):
    varargin = error_as_caller.varargin
    nargin = error_as_caller.nargin

    stack=dbstack(1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:107
    
    fname=stack[min(2,end())].name
# /home/lei/octave-4.0.2/scripts/miscellaneous/parseparams.m:108
    error(cat(fname,': ',msg),varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filename} =} fullfile (@var{dir1}, @var{dir2}, @dots{}, @var{file})
## @deftypefnx {Function File} {@var{filenames} =} fullfile (@dots{}, @var{files})
## Build complete filename from separate parts.
##
## Joins any number of path components intelligently.  The return value is
## the concatenation of each component with exactly one file separator
## between each non empty part and at most one leading and/or trailing file
## separator.
##
## If the last component part is a cell array, returns a cell array of
## filepaths, one for each element in the last component, e.g.:
##
## @example
## @group
## fullfile ("/home/username", "data", @{"f1.csv", "f2.csv", "f3.csv"@})
## @result{}  /home/username/data/f1.csv
##     /home/username/data/f2.csv
##     /home/username/data/f3.csv
## @end group
## @end example
##
## On Windows systems, while forward slash file separators do work, they are
## replaced by backslashes; in addition drive letters are stripped of leading
## file separators to obtain a valid file path.
##
## @seealso{fileparts, filesep}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug@octave.org>
    
    
@function
def fullfile(varargin=None,*args,**kwargs):
    varargin = fullfile.varargin
    nargin = fullfile.nargin

    if (nargin and iscell(varargin[end()])):
        filename=cellfun(lambda x=None: fullfile(varargin[1:end() - 1],x),varargin[end()],'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:53
    else:
        non_empty=cellfun('isempty',varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:56
        if (ispc and logical_not(isempty(varargin))):
            varargin=strrep(varargin,'/',filesep)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:58
            varargin[1]=regexprep(varargin[1],'[\\\\/]*([a-zA-Z]:[\\\\/]*)','$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:59
        filename=strjoin(varargin[logical_not(non_empty)],filesep)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:61
        filename[strfind(filename,cat(filesep,filesep))]=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/fullfile.m:62
    
    return filename
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## different on purpose so that "fullfile (c{:})" works for empty c
    
    
    ## Windows specific - drive letters and file sep type
    
    
    
    
    ## Windows specific - drive letters and file sep type, cell array
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Julian Schnidder
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{output} =} perl (@var{scriptfile})
## @deftypefnx {Function File} {@var{output} =} perl (@var{scriptfile}, @var{argument1}, @var{argument2}, @dots{})
## @deftypefnx {Function File} {[@var{output}, @var{status}] =} perl (@dots{})
## Invoke Perl script @var{scriptfile}, possibly with a list of command line
## arguments.
##
## Return output in @var{output} and optional status in @var{status}.  If
## @var{scriptfile} is not an absolute file name it is searched for in the
## current directory and then in the Octave loadpath.
## @seealso{system, python}
## @end deftypefn
    
    
@function
def perl(scriptfile='-e \'\'',varargin=None,*args,**kwargs):
    varargin = perl.varargin
    nargin = perl.nargin

    ## VARARGIN is intialized to {}(1x0) if no additional arguments are
  ## supplied, so there is no need to check for it, or provide an
  ## initial value in the argument list of the function definition.
    
    if (ischar(scriptfile) and ((nargin == 1 and logical_not(isempty(scriptfile))) or (nargin != 1 and iscellstr(varargin)))):
        if (logical_not(strcmp(scriptfile[1:2],'-e'))):
            ## Attempt to find file in loadpath.  No effect for absolute filenames.
            scriptfile=file_in_loadpath(scriptfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/perl.m:43
        status,output=system(cat('perl ',scriptfile,sprintf(' %s',varargin[:])),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/perl.m:46
    else:
        error('perl: invalid arguments')
    
    return output,status
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dos ("@var{command}")
## @deftypefnx {Function File} {@var{status} =} dos ("@var{command}")
## @deftypefnx {Function File} {[@var{status}, @var{text}] =} dos ("@var{command"})
## @deftypefnx {Function File} {[@dots{}] =} dos ("@var{command}", "-echo")
## Execute a system command if running under a Windows-like operating system,
## otherwise do nothing.
##
## Octave waits for the external command to finish before returning the exit
## status of the program in @var{status} and any output in @var{text}.
##
## When called with no output argument, or the @qcode{"-echo"} argument is
## given, then @var{text} is also sent to standard output.
## @seealso{unix, system, isunix, ismac, ispc}
## @end deftypefn
    
    ## Author: octave-forge ???
## Adapted by: jwe
    
    
@function
def dos(command=None,echo_arg=None,*args,**kwargs):
    varargin = dos.varargin
    nargin = dos.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not(isunix())):
            status,text=system(command,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/dos.m:43
            if (nargin > 1 or nargout == 0):
                printf('%s\n',text)
    
    return status,text
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} debug ()
## Summary of debugging commands.
##
## For more information on each command and available options use
## @code{help CMD}.
##
## The debugging commands available in Octave are
##
## @table @code
## @item dbstop
## Add a breakpoint.
##
## @item dbclear
## Remove a breakpoint.
##
## @item dbstatus
## List all breakpoints.
##
## @item dbwhere
## Report the current file and line number where execution is stopped.
##
## @item dbtype
## Display the code of the function being debugged, enumerating
## the line numbers.
##
## @item dblist
## List 10 lines of code centered around the line number where execution is
## stopped.
##
## @item  dbstep
## @itemx dbnext
## Execute (step) one or more lines, follow execution into (step into) a
## function call, or execute until the end of a function (step out), and
## re-enter debug mode.
##
## @item dbcont
## Continue normal code execution from the debug prompt.
##
## @item dbquit
## Quit debugging mode immediately and return to the main prompt.
##
## @item dbstack
## Print a backtrace of the execution stack.
##
## @item dbup
## Move up the execution stack.
##
## @item dbdown
## Move down the execution stack.
##
## @item keyboard
## Force entry into debug mode from an m-file.
##
## @item debug_on_error
## Configure whether Octave enters debug mode when it encounters an error.
##
## @item debug_on_warning
## Configure whether Octave enters debug mode when it encounters a warning.
##
## @item debug_on_interrupt
## Configure whether Octave enters debug mode when it encounters an interrupt.
##
## @item isdebugmode
## Return true if in debug mode.
## @end table
##
## @noindent
## When Octave encounters a breakpoint, or other reason to enter debug mode,
## the prompt changes to @qcode{"debug>"}.  The workspace of the function
## where the breakpoint was encountered becomes available and any Octave
## command that is valid in that workspace context may be executed.
##
## @seealso{dbstop, dbclear, dbstatus, dbwhere, dbtype, dbcont, dbquit,
## dbstack, dbup, dbdown, keyboard, debug_on_error, debug_on_warning,
## debug_on_interrupt, isdebugmode}
## @end deftypefn
    
    
@function
def debug(*args,**kwargs):
    varargin = debug.varargin
    nargin = debug.nargin

    help('debug')
    return
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for a documentation .m file
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} swapbytes (@var{x})
## Swap the byte order on values, converting from little endian to big endian
## and vice versa.
##
## For example:
##
## @example
## @group
## swapbytes (uint16 (1:4))
## @result{} [   256   512   768  1024]
## @end group
## @end example
##
## @seealso{typecast, cast}
## @end deftypefn
    
    
@function
def swapbytes(x=None,*args,**kwargs):
    varargin = swapbytes.varargin
    nargin = swapbytes.nargin

    if (nargin != 1):
        print_usage()
    
    cls=class_(x)
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:42
    if (strcmp(cls,'int8') or strcmp(cls,'uint8') or isempty(x)):
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:44
    else:
        if (strcmp(cls,'int16') or strcmp(cls,'uint16')):
            nb=2
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:47
        else:
            if (strcmp(cls,'single') or strcmp(cls,'int32') or strcmp(cls,'uint32')):
                nb=4
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:50
            else:
                if (strcmp(cls,'double') or strcmp(cls,'int64') or strcmp(cls,'uint64')):
                    nb=8
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:53
                else:
                    error('swapbytes: invalid object of class \'%s\'',cls)
        y=reshape(typecast(ravel(reshape(typecast(ravel(x),'uint8'),nb,numel(x))(cat(arange(nb,1,- 1)),arange())),cls),size(x))
# /home/lei/octave-4.0.2/scripts/miscellaneous/swapbytes.m:57
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Thorsten Meyer
## based on the original gzip function by David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{filelist} =} __xzip__ (@var{commandname}, @var{extension}, @var{commandtemplate}, @var{files}, @var{outdir})
## Undocumented internal function.
## @end deftypefn
    
    ## Compress the list of files and/or directories specified in @var{files}
## with the external compression command @var{commandname}. The template
## @var{commandtemplate} is used to actually start the command. Each file
## is compressed separately and a new file with the extension @var{extension}
## is created and placed into the directory @var{outdir}. The original files
## are not touched. Existing compressed files are silently overwritten.
## This is an internal function. Do not use directly.
    
    
@function
def __xzip__(commandname=None,extension=None,commandtemplate=None,files=None,outdir=None,*args,**kwargs):
    varargin = __xzip__.varargin
    nargin = __xzip__.nargin

    if (nargin == 5 and logical_not(exist(outdir,'dir'))):
        r=mkdir(outdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:37
        if (logical_not(r)):
            error('%s: Failed to create output directory DIR',commandname)
    
    if (ischar(files)):
        files=cellstr(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:44
    else:
        if (logical_not(iscellstr(files))):
            error('%s: FILES must be a character array or cellstr',commandname)
    
    if (nargin == 4):
        outdir=tempname()
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:50
        r=mkdir(outdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:51
        if (logical_not(r)):
            error('%s: Failed to create temporary output directory',commandname)
    
    cwd=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:57
    try:
        files=glob(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:59
        files[cellfun(lambda x=None: (length(x) > length(extension) and strcmp(x[(end() - length(extension) + 1):end()],extension)),files)]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:65
        copyfile(files,outdir)
        fnames=fname_only(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:69
        cd(outdir)
        cmd=sprintf(commandtemplate,sprintf(' %s',fnames[:]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:73
        status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:75
        if (status):
            fcn=evalin('caller','mfilename ()')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:77
            error('%s: %s command failed with exit status = %d',fcn,commandname,status)
        if (nargin == 5):
            if (nargout > 0):
                ## FIXME: This doesn't work if a directory is compressed
                filelist=cellfun(lambda x=None: fullfile(outdir,sprintf('%s.%s',x,extension)),fnames,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:85
        else:
            ## FIXME: This does not work when you try to compress directories
      ##        The resulting name is dir/.gz which is totally wrong.
      ##        See bug #43431.
            movefile(cellfun(lambda x=None: sprintf('%s.%s',x,extension),fnames,'uniformoutput',false),cwd)
            if (nargout > 0):
                filelist=cellfun(lambda x=None: sprintf('%s.%s',x,extension),files,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:96
    finally:
        cd(cwd)
        if (nargin == 4):
            confirm_recursive_rmdir(false,'local')
            rmdir(outdir,'s')
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
@function
def fname_only(files=None,*args,**kwargs):
    varargin = fname_only.varargin
    nargin = fname_only.nargin

    __,f,ext=cellfun('fileparts',files,'uniformoutput',false,nargout=3)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:112
    f=cellfun(lambda x=None,y=None: sprintf('%s%s',x,y),f,ext,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:113
    idx=cellfun('isdir',files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:114
    f[idx]=files[idx]
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__xzip__.m:115
    return f
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## news() and citation() are very much alike. They both do the same thing, just
## for different files. This function does all the work.
    
    
@function
def display_info_file(func=None,package=None,file=None,*args,**kwargs):
    varargin = display_info_file.varargin
    nargin = display_info_file.nargin

    if (logical_not(ischar(package))):
        error('%s: PACKAGE must be a string',func)
    
    if (strcmpi(package,'octave')):
        octetcdir=octave_config_info('octetcdir')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:29
        filepath=fullfile(octetcdir,file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:30
    else:
        installed=pkg('list')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:32
        names=cellfun(lambda x=None: x.name,installed,'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:33
        pos=strcmpi(names,package)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:34
        if (logical_not(any(pos))):
            error('%s: package \'%s\' is not installed.',func,package)
        filepath=fullfile(installed[pos].dir,'packinfo',file)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:38
    
    if (logical_not(exist(filepath,'file'))):
        if (strcmpi(package,'octave')):
            error('%s: broken installation -- unable to locate %s file',func,file)
        else:
            error('%s: unable to locate %s file for package %s',func,file,package)
    
    fid=fopen(filepath,'r')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:49
    while (ischar(line=fgets(fid)
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/display_info_file.m:50)):

        puts(line)

    
    fclose(fid)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2015 Philip Nienhuis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{mingwpath} =} __w2mpth__ (@var{winpath})
## Convert a Windows-style relative or full path name to MinGW style.
##
## @strong{Caution:} __w2mpth__ does not check the validity of the path.
##
## Examples:
##
## @example
## @group
##   mpth = __w2mpth__ ('D:\full\path\to\file.dat')
##   @result{} '/D/full/path/to/file.dat'
## @end group
## @end example
##
## @example
## @group
##   mpth = __w2mpth__ ('relative\path\to\file.dat')
##   @result{} 'relative/path/to/file.dat'
## @end group
## @end example
##
## @end deftypefn
    
    ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
## Created: 2015-01-16
    
    
@function
def __w2mpth__(winpath=None,*args,**kwargs):
    varargin = __w2mpth__.varargin
    nargin = __w2mpth__.nargin

    ## Check for platform
    if (logical_not(ispc)):
        error('__w2mpth__ should only be called on Windows platforms\n')
    
    ## Replace backslash file separators by forward slashes
    mingwpath=strrep(winpath,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__w2mpth__.m:54
    
    mingwpath=regexprep(mingwpath,'^([a-zA-Z]):','/$1')
# /home/lei/octave-4.0.2/scripts/miscellaneous/private/__w2mpth__.m:56
    return mingwpath
    
if __name__ == '__main__':
    pass
    
    ## Use single quote strings for winpaths to cope with backslashes.
## These tests are commented out until a better place is found (bug #44581)
###!test
###! if (ispc)
###!   assert (__w2mpth__ ('file.fil'), 'file.fil');
###!   assert (__w2mpth__ ('\file.fil'), '/file.fil');
###!   assert (__w2mpth__ ('G:\file.fil'), '/G/file.fil');
###!   assert (__w2mpth__ ('r:\subdir\file.fil'), '/r/subdir/file.fil');
###!   assert (__w2mpth__ ('relative\path\to\file.dat'),
###!                       'relative/path/to/file.dat')
###! endif
    
    ## Copyright (C) 2005-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} tar (@var{tarfile}, @var{files})
## @deftypefnx {Function File} {@var{filelist} =} tar (@var{tarfile}, @var{files}, @var{rootdir})
## Pack the list of files and directories specified in @var{files} into the
## TAR archive @var{tarfile}.
##
## @var{files} is a character array or cell array of strings.  Shell wildcards
## in the filename such as @samp{*} or @samp{?} are accepted and expanded.
## Directories are recursively traversed and all files are added to the
## archive.
##
## If @var{rootdir} is defined then any files without absolute pathnames are
## located relative to @var{rootdir} rather than the current directory.
##
## The optional output @var{filelist} is a list of the files that were included
## in the archive.
## @seealso{untar, unpack, bzip2, gzip, zip}
## @end deftypefn
    
    ## Author: Sren Hauberg <hauberg@gmail.com>
    
    
@function
def tar(tarfile=None,files=None,rootdir='.',*args,**kwargs):
    varargin = tar.varargin
    nargin = tar.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(tarfile))):
        error('tar: TARFILE must be a string')
    else:
        if (ischar(files)):
            files=cellstr(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:49
        else:
            if (logical_not(iscellstr(files))):
                error('tar: FILES must be a character array or cellstr')
    
    rootdir=tilde_expand(rootdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:54
    tarfile=make_absolute_filename(tarfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:56
    if (ispc):
        ## Change tarfile into a mingw style acceptable for tar
        tarfile=__w2mpth__(tarfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:60
    
    cmd=sprintf('tar cvf %s -C %s %s',tarfile,rootdir,sprintf(' %s',files[:]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:63
    status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:66
    if (status):
        error('tar: tar exited with status = %d',status)
    
    if (nargout > 0):
        filelist=ostrsplit(output,'\r\n',true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:73
        filelist=filelist.T
# /home/lei/octave-4.0.2/scripts/miscellaneous/tar.m:74
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} movefile (@var{f1})
## @deftypefnx {Function File} {} movefile (@var{f1}, @var{f2})
## @deftypefnx {Function File} {} movefile (@var{f1}, @var{f2}, 'f')
## @deftypefnx {Function File} {[@var{status}, @var{msg}, @var{msgid}] =} movefile (@dots{})
## Move the source files or directories @var{f1} to the destination @var{f2}.
##
## The name @var{f1} may contain globbing patterns.  If @var{f1} expands to
## multiple file names, @var{f2} must be a directory.  If no destination
## @var{f2} is specified then the destination is the present working directory.
## If @var{f2} is a file name then @var{f1} is renamed to @var{f2}.
##
## When the force flag @qcode{'f'} is given any existing files will be
## overwritten without prompting.
##
## If successful, @var{status} is 1, and @var{msg}, @var{msgid} are empty
## character strings ("").  Otherwise, @var{status} is 0, @var{msg} contains a
## system-dependent error message, and @var{msgid} contains a unique message
## identifier.  Note that the status code is exactly opposite that of the
## @code{system} command.
## @seealso{rename, copyfile, unlink, delete, glob}
## @end deftypefn
    
    
@function
def movefile(f1=None,f2=None,force=None,*args,**kwargs):
    varargin = movefile.varargin
    nargin = movefile.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    max_cmd_line=1024
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:48
    status=copy(true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:49
    msg=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:50
    msgid=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:51
    
    ##        over the command that is executed.
    
    if (ispc() and logical_not(isunix()) and isempty(file_in_path(getenv('PATH'),'mv.exe'))):
        ## Windows.
        cmd='cmd /C move'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:59
        cmd_force_flag='/Y'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:60
    else:
        cmd='mv'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:62
        cmd_force_flag='-f'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:63
    
    ## Input type check.
    if (ischar(f1)):
        f1=cellstr(f1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:68
    else:
        if (logical_not(iscellstr(f1))):
            error('copyfile: F1 must be a string or a cell array of strings')
    
    if (nargin == 1):
        f2=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:74
    else:
        if (logical_not(ischar(f2))):
            error('movefile: F2 must be a string')
    
    if (nargin == 3 and strcmp(force,'f')):
        cmd=matlabarray(cat(cmd,' ',cmd_force_flag))
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:80
    
    ## If f1 has more than 1 element f2 must be a directory
    isdir=(exist(f2,'dir') != 0)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:84
    if (numel(f1) > 1 and logical_not(isdir)):
        error('movefile: when moving multiple files, F2 must be a directory')
    
    ## Protect the file name(s).
    f1=glob(f1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:90
    if (isempty(f1)):
        error('movefile: no files to move')
    
    p1=sprintf('"%s" ',f1[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:94
    p2=tilde_expand(f2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:95
    if (isdir and length(p1) > max_cmd_line):
        l2=length(p2) + length(cmd) + 6
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:98
        while (logical_not(isempty(f1))):

            p1=sprintf('"%s" ',f1[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:100
            f1[1]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:101
            while (logical_not(isempty(f1)) and (length(p1) + length(f1[1]) + l2 < max_cmd_line)):

                p1=sprintf('%s"%s" ',p1,f1[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:104
                f1[1]=[]
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:105

            if (ispc() and logical_not(isunix()) and logical_not(isempty(file_in_path(getenv('PATH'),'cp.exe')))):
                p1=strrep(p1,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:110
                p2=strrep(p2,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:111
            ## Move the file(s).
            err,msg=system(sprintf('%s %s "%s"',cmd,p1,p2),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:115
            if (err != 0):
                status=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:117
                msgid='movefile'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:118

    else:
        if (ispc() and logical_not(isunix()) and logical_not(isempty(file_in_path(getenv('PATH'),'cp.exe')))):
            p1=strrep(p1,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:124
            p2=strrep(p2,'\\','/')
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:125
        ## Move the file(s).
        err,msg=system(sprintf('%s %s "%s"',cmd,p1,p2),nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:129
        if (err != 0):
            status=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:131
            msgid='movefile'
# /home/lei/octave-4.0.2/scripts/miscellaneous/movefile.m:132
    
    return status,msg,msgid
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} computer ()
## @deftypefnx {Function File} {@var{c} =} computer ()
## @deftypefnx {Function File} {[@var{c}, @var{maxsize}] =} computer ()
## @deftypefnx {Function File} {[@var{c}, @var{maxsize}, @var{endian}] =} computer ()
## @deftypefnx {Function File} {@var{arch} =} computer ("arch")
## Print or return a string of the form @var{cpu}-@var{vendor}-@var{os} that
## identifies the type of computer that Octave is running on.
##
## If invoked with an output argument, the value is returned instead of
## printed.  For example:
##
## @example
## @group
## computer ()
##    @print{} i586-pc-linux-gnu
##
## mycomp = computer ()
##    @result{} mycomp = "i586-pc-linux-gnu"
## @end group
## @end example
##
## If two output arguments are requested, also return the maximum number of
## elements for an array.  This will depend on whether Octave has been
## compiled with 32-bit or 64-bit index vectors.
##
## If three output arguments are requested, also return the byte order of the
## current system as a character (@qcode{"B"} for big-endian or @qcode{"L"}
## for little-endian).
##
## If the argument @qcode{"arch"} is specified, return a string indicating the
## architecture of the computer on which Octave is running.
## @seealso{isunix, ismac, ispc}
## @end deftypefn
    
    
@function
def computer(a=None,*args,**kwargs):
    varargin = computer.varargin
    nargin = computer.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (nargin == 1 and logical_not(strcmpi(a,'arch'))):
            error('computer: "arch" is only valid argument')
    
    if (nargin == 0):
        msg=octave_config_info('canonical_host_type')
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:63
        if (strcmp(msg,'unknown')):
            msg='Hi Dave, I\'m a HAL-9000'
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:66
        if (nargout == 0):
            disp(msg)
        else:
            c=copy(msg)
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:72
            if (isargout(2)):
                if (strcmp(octave_config_info('USE_64_BIT_IDX_T'),'true')):
                    maxsize=2 ** 63 - 1
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:75
                else:
                    maxsize=2 ** 31 - 1
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:77
            if (isargout(3)):
                if (octave_config_info('words_big_endian')):
                    endian='B'
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:82
                else:
                    if (octave_config_info('words_little_endian')):
                        endian='L'
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:84
                    else:
                        endian='?'
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:86
    else:
        ## "arch" argument asked for
        tmp=ostrsplit(octave_config_info('canonical_host_type'),'-')
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:92
        if (numel(tmp) == 4):
            c=sprintf('%s-%s-%s',tmp[4],tmp[3],tmp[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:94
        else:
            c=sprintf('%s-%s',tmp[3],tmp[1])
# /home/lei/octave-4.0.2/scripts/miscellaneous/computer.m:96
    
    return c,maxsize,endian
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2000-2015 Etienne Grossmann
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{val} =} getfield (@var{s}, @var{field})
## @deftypefnx {Function File} {@var{val} =} getfield (@var{s}, @var{sidx1}, @var{field1}, @var{fidx1}, @dots{})
## Get the value of the field named @var{field} from a structure or nested
## structure @var{s}.
##
## If @var{s} is a structure array then @var{sidx} selects an element of the
## structure array, @var{field} specifies the field name of the selected
## element, and @var{fidx} selects which element of the field (in the case of
## an array or cell array).  See @code{setfield} for a more complete
## description of the syntax.
##
## @seealso{setfield, rmfield, orderfields, isfield, fieldnames, isstruct, struct}
## @end deftypefn
    
    ## Author: Etienne Grossmann <etienne@cs.uky.edu>
    
    
@function
def getfield(s=None,varargin=None,*args,**kwargs):
    varargin = getfield.varargin
    nargin = getfield.nargin

    if (nargin < 2):
        print_usage()
    
    subs=copy(varargin)
# /home/lei/octave-4.0.2/scripts/miscellaneous/getfield.m:43
    flds=cellfun('isclass',subs,'char')
# /home/lei/octave-4.0.2/scripts/miscellaneous/getfield.m:44
    idxs=cellfun('isclass',subs,'cell')
# /home/lei/octave-4.0.2/scripts/miscellaneous/getfield.m:45
    if (logical_not(all(logical_or(flds,idxs)))):
        error('getfield: invalid index')
    
    typs=merge(flds,cellarray(['.']),cellarray(['()']))
# /home/lei/octave-4.0.2/scripts/miscellaneous/getfield.m:50
    val=subsref(s,struct('type',typs,'subs',subs))
# /home/lei/octave-4.0.2/scripts/miscellaneous/getfield.m:51
    return val
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 Jordi Gutirrez Hermoso
## Copyright (C) 2007 Stallmanfacts.com
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} fact
## @deftypefnx {Function File} {@var{truth} =} fact ()
## Display an amazing and random fact about the world's greatest hacker.
## @end deftypefn
    
    
@function
def fact(*args,**kwargs):
    varargin = fact.varargin
    nargin = fact.nargin

    
    w=wisdom[randi(numel(wisdom))]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:260
    if (nargout > 0):
        truth=copy(w)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:262
    else:
        w=wordwrap(w)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:264
        printf('%s',w)
    
    return truth
    
if __name__ == '__main__':
    pass
    
    
@function
def wordwrap(w=None,*args,**kwargs):
    varargin = wordwrap.varargin
    nargin = wordwrap.nargin

    ncol=terminal_size()(2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:271
    wc=ostrsplit(w,' ')
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:272
    out='\n'
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:273
    i=1
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:274
    numwords=numel(wc)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:275
    while (i <= numwords):

        line=wc[i]
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:277
        while (i < numwords and length(newline=matlabarray(cat(line,' ',wc[i + 1]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:279) < ncol):

            line=copy(newline)
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:280
            i

        out=matlabarray(cat(out,line,'\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:283
        i

    
    out=matlabarray(cat(out,'\n'))
# /home/lei/octave-4.0.2/scripts/miscellaneous/fact.m:286
    return out
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for a documentation .m file
    
    ## Copyright (C) 2008-2015 Thorsten Meyer
## (based on gzip.m by David Bateman)
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} bzip2 (@var{files})
## @deftypefnx {Function File} {@var{filelist} =} bzip2 (@var{files}, @var{dir})
## Compress the list of files specified in @var{files}.
##
## @var{files} is a character array or cell array of strings.  Shell wildcards
## in the filename such as @samp{*} or @samp{?} are accepted and expanded.
## Each file is compressed separately and a new file with a @file{".bz2"}
## extension is created.  The original files are not modified, but existing
## compressed files will be silently overwritten.
##
## If @var{dir} is defined the compressed files are placed in this directory,
## rather than the original directory where the uncompressed file resides.
## If @var{dir} does not exist it is created.
##
## The optional output @var{filelist} is a list of the compressed files.
## @seealso{bunzip2, unpack, gzip, zip, tar}
## @end deftypefn
    
    
@function
def bzip2(varargin=None,*args,**kwargs):
    varargin = bzip2.varargin
    nargin = bzip2.nargin

    if (nargin < 1 or nargin > 2 or nargout > 1):
        print_usage()
    
    if (nargout == 0):
        __xzip__('bzip2','bz2','bzip2 %s',varargin[:])
    else:
        filelist=__xzip__('bzip2','bz2','bzip2 %s',varargin[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/bzip2.m:48
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} compare_versions (@var{v1}, @var{v2}, @var{operator})
## Compare two version strings using the given @var{operator}.
##
## This function assumes that versions @var{v1} and @var{v2} are arbitrarily
## long strings made of numeric and period characters possibly followed by an
## arbitrary string (e.g., @qcode{"1.2.3"}, @qcode{"0.3"}, @qcode{"0.1.2+"},
## or @qcode{"1.2.3.4-test1"}).
##
## The version is first split into numeric and character portions and then
## the parts are padded to be the same length (i.e., @qcode{"1.1"} would be
## padded to be @qcode{"1.1.0"} when being compared with @qcode{"1.1.1"}, and
## separately, the character parts of the strings are padded with nulls).
##
## The operator can be any logical operator from the set
##
## @itemize @bullet
## @item
## @qcode{"=="}
## equal
##
## @item
## @qcode{"<"}
## less than
##
## @item
## @qcode{"<="}
## less than or equal to
##
## @item
## @qcode{">"}
## greater than
##
## @item
## @qcode{">="}
## greater than or equal to
##
## @item
## @qcode{"!="}
## not equal
##
## @item
## @qcode{"~="}
## not equal
## @end itemize
##
## Note that version @qcode{"1.1-test2"} will compare as greater than
## @qcode{"1.1-test10"}.  Also, since the numeric part is compared first,
## @qcode{"a"} compares less than @qcode{"1a"} because the second string
## starts with a numeric part even though @code{double ("a")} is greater than
## @code{double ("1").}
## @end deftypefn
    
    ## Author: Bill Denney <denney@seas.upenn.edu>
    
    
@function
def compare_versions(v1=None,v2=None,operator=None,*args,**kwargs):
    varargin = compare_versions.varargin
    nargin = compare_versions.nargin

    if (nargin != 3):
        print_usage()
    
    ## Make sure that the version numbers are valid.
    if (logical_not((ischar(v1) and ischar(v2)))):
        error('compare_versions: version numbers V1 and V2 must be strings')
    else:
        if (rows(v1) != 1 or rows(v2) != 1):
            error('compare_versions: version numbers V1 and V2 must be a single row')
    
    ## check and make sure that the operator is valid
    if (logical_not(ischar(operator))):
        error('compare_versions: OPERATOR must be a string')
    else:
        if (numel(operator) > 2):
            error('compare_versions: OPERATOR must be 1 or 2 characters long')
    
    ## trim off any character data that is not part of a normal version number
    v1firstchar=find(logical_not((logical_or(isdigit(v1),v1) == '.')),1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:95
    v2firstchar=find(logical_not((logical_or(isdigit(v2),v2) == '.')),1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:96
    if (isempty(v1firstchar)):
        v1c=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:99
        v1nochar=copy(v1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:100
    else:
        v1c=v1[v1firstchar:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:102
        v1nochar=v1[1:v1firstchar - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:103
    
    if (isempty(v2firstchar)):
        v2c=''
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:106
        v2nochar=copy(v2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:107
    else:
        v2c=v2[v2firstchar:end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:109
        v2nochar=v2[1:v2firstchar - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:110
    
    v1n=str2double(ostrsplit(v1nochar,'.').T)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:113
    if (isnan(v1n)):
        v1n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:115
    
    v2n=str2double(ostrsplit(v2nochar,'.').T)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:117
    if (isnan(v2n)):
        v2n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:119
    
    if (isempty(v1n) and isempty(v1c)):
        error('compare_versions: version string V1 is not valid: %s',v1)
    else:
        if (isempty(v2n) and isempty(v2c)):
            error('compare_versions: version string V2 is not valid: %s',v2)
    
    ## Assume any additional elements would be 0 if one is longer than the other.
    maxnumlen=max(cat(length(v1n),length(v2n)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:129
    v1n[end() + 1:maxnumlen]=0
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:130
    v2n[end() + 1:maxnumlen]=0
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:131
    
    ## if one is longer than the other.
    maxcharlen=max(cat(length(v1c),length(v2c)))
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:135
    v1c[end() + 1:maxcharlen]='\x00'
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:136
    v2c[end() + 1:maxcharlen]='\x00'
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:137
    
    equal_op=any(operator == '=')
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:140
    not_op=any(operator == logical_or('!',operator) == '~')
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:141
    lt_op=any(operator == '<')
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:142
    gt_op=any(operator == '>')
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:143
    
    if (gt_op and lt_op):
        error('compare_versions: OPERATOR cannot contain both greater and less than symbols')
    else:
        if ((gt_op or lt_op) and not_op):
            error('compare_versions: OPERATOR cannot contain not and greater than or less than symbols')
        else:
            if (strcmp(operator,'=')):
                error('compare_versions: equality OPERATOR is "==", not "="')
            else:
                if (logical_not((equal_op or not_op or lt_op or gt_op))):
                    error('compare_versions: no valid OPERATOR specified')
    
    ## Compare the versions (making sure that they're the same shape)
    vcmp=ravel(v1n) - ravel(v2n)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:157
    vcmp=matlabarray(cat([vcmp],[ravel((v1c - v2c))]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:158
    if (lt_op):
        ## so that we only need to check for the output being greater than 1
        vcmp=- vcmp
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:161
    
    firstdiff=find(vcmp,1)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:163
    if (isempty(firstdiff)):
        ## They're equal.
        out=copy(equal_op)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:167
    else:
        if (lt_op or gt_op):
            ## They're correctly less than or greater than.
            out=(vcmp[firstdiff] > 0)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:170
        else:
            ## They're not correctly less than or greater than, and they're not equal.
            out=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:173
    
    ## Reverse the output if not is given.
    if (not_op):
        out=logical_not(out)
# /home/lei/octave-4.0.2/scripts/miscellaneous/compare_versions.m:178
    
    return out
    
if __name__ == '__main__':
    pass
    
    ## tests
## test both equality symbols
## test arbitrarily long equality
    
    
    
    
    
    ## test different length numbers
    
    
    
    
    
    ## test alphanumeric strings
    
    
    
    
    
    
    
    
    ## make sure that it won't just give true output
    
    ## test arbitrarily long equality
    
    
    
    
    
    ## test different length numbers
    
    
    
    
    
    ## Test input validation
    
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ispc ()
## Return true if Octave is running on a Windows system and false otherwise.
## @seealso{isunix, ismac}
## @end deftypefn
    
    
@function
def ispc(*args,**kwargs):
    varargin = ispc.varargin
    nargin = ispc.nargin

    if (nargin == 0):
        retval=octave_config_info('windows')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ispc.m:28
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2005-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} untar (@var{tarfile})
## @deftypefnx {Function File} {} untar (@var{tarfile}, @var{dir})
## Unpack the TAR archive @var{tarfile}.
##
## If @var{dir} is specified the files are unpacked in this directory rather
## than the one where @var{tarfile} is located.
##
## The optional output @var{filelist} is a list of the uncompressed files.
## @seealso{tar, unpack, bunzip2, gunzip, unzip}
## @end deftypefn
    
    ## Author: Sren Hauberg <hauberg@gmail.com>
## Adapted-By: jwe, Bill Denney
    
    
@function
def untar(tarfile=None,dir=[],*args,**kwargs):
    varargin = untar.varargin
    nargin = untar.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (isempty(dir)):
        dir=fileparts(tarfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/untar.m:41
    
    if (nargout > 0):
        filelist=unpack(tarfile,dir,'untar')
# /home/lei/octave-4.0.2/scripts/miscellaneous/untar.m:45
    else:
        unpack(tarfile,dir,'untar')
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    ## Tests for this m-file are located in tar.m
## Remove from test statistics
    
    ## Copyright (C) 2000-2015 Etienne Grossmann
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{sout} =} setfield (@var{s}, @var{field}, @var{val})
## @deftypefnx {Function File} {@var{sout} =} setfield (@var{s}, @var{sidx1}, @var{field1}, @var{fidx1}, @var{sidx2}, @var{field2}, @var{fidx2}, @dots{}, @var{val})
##
## Return a @emph{copy} of the structure @var{s} with the field member
## @var{field} set to the value @var{val}.
##
## For example:
##
## @example
## @group
## @var{s} = struct ();
## @var{s} = setfield (@var{s}, "foo bar", 42);
## @end group
## @end example
##
## @noindent
## This is equivalent to
##
## @example
## @var{s}.("foo bar") = 42;
## @end example
##
## @noindent
## Note that ordinary structure syntax @code{@var{s}.foo bar = 42} cannot be
## used here, as the field name is not a valid Octave identifier because of
## the space character.  Using arbitrary strings for field names is
## incompatible with @sc{matlab}, and this usage will emit a warning if the
## warning ID @code{Octave:language-extension} is enabled.
## @xref{XREFwarning_ids}.
##
## With the second calling form, set a field of a structure array.  The
## input @var{sidx} selects an element of the structure array, @var{field}
## specifies the field name of the selected element, and @var{fidx} selects
## which element of the field (in the case of an array or cell array).
## The @var{sidx}, @var{field}, and @var{fidx} inputs can be repeated to
## address nested structure array elements.  The structure array index and
## field element index must be cell arrays while the field name must be a
## string.
##
## For example:
##
## @example
## @group
## @var{s} = struct ("baz", 42);
## setfield (@var{s}, @{1@}, "foo", @{1@}, "bar", 54)
## @result{}
##   ans =
##     scalar structure containing the fields:
##       baz =  42
##       foo =
##         scalar structure containing the fields:
##           bar =  54
## @end group
## @end example
##
## The example begins with an ordinary scalar structure to which a nested
## scalar structure is added.  In all cases, if the structure index @var{sidx}
## is not specified it defaults to 1 (scalar structure).  Thus, the example
## above could be written more concisely as
## @code{setfield (@var{s}, "foo", "bar", 54)}
##
## Finally, an example with nested structure arrays:
##
## @example
## @group
## @var{sa}.foo = 1;
## @var{sa} = setfield (@var{sa}, @{2@}, "bar", @{3@}, "baz", @{1, 4@}, 5);
## @var{sa}(2).bar(3)
## @result{}
##   ans =
##     scalar structure containing the fields:
##       baz =  0   0   0   5
## @end group
## @end example
##
## Here @var{sa} is a structure array whose field at elements 1 and 2 is in
## turn another structure array whose third element is a simple scalar
## structure.  The terminal scalar structure has a field which contains a
## matrix value.
##
## Note that the same result as in the above example could be achieved by:
##
## @example
## @group
## @var{sa}.foo = 1;
## @var{sa}(2).bar(3).baz(1,4) = 5
## @end group
## @end example
## @seealso{getfield, rmfield, orderfields, isfield, fieldnames, isstruct, struct}
## @end deftypefn
    
    ## Author:  Etienne Grossmann <etienne@cs.uky.edu>
    
    
@function
def setfield(s=None,varargin=None,*args,**kwargs):
    varargin = setfield.varargin
    nargin = setfield.nargin

    if (nargin < 3):
        print_usage()
    
    subs=varargin[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:120
    val=varargin[end()]
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:121
    flds=cellfun('isclass',subs,'char')
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:122
    idxs=cellfun('isclass',subs,'cell')
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:123
    if (logical_not(all(logical_or(flds,idxs)))):
        error('setfield: invalid index')
    
    typs=ifelse(flds,cellarray(['.']),cellarray(['()']))
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:128
    sout=subsasgn(s,struct('type',typs,'subs',subs),val)
# /home/lei/octave-4.0.2/scripts/miscellaneous/setfield.m:129
    return sout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isunix ()
## Return true if Octave is running on a Unix-like system and false otherwise.
## @seealso{ismac, ispc}
## @end deftypefn
    
    
@function
def isunix(*args,**kwargs):
    varargin = isunix.varargin
    nargin = isunix.nargin

    if (nargin == 0):
        retval=octave_config_info('unix')
# /home/lei/octave-4.0.2/scripts/miscellaneous/isunix.m:28
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2003-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{fname} =} tmpnam ()
## @deftypefnx {Function File} {@var{fname} =} tmpnam (@var{dir})
## @deftypefnx {Function File} {@var{fname} =} tmpnam (@var{dir}, @var{prefix})
## Return a unique temporary file name as a string.
##
## If @var{prefix} is omitted, a value of @qcode{"oct-"} is used.
##
## If @var{dir} is also omitted, the default directory for temporary files
## (@code{P_tmpdir} is used.  If @var{dir} is provided, it must exist,
## otherwise the default directory for temporary files is used.
##
## Programming Note: Because the named file is not opened by @code{tmpnam},
## it is possible, though relatively unlikely, that it will not be available
## by the time your program attempts to open it.  If this is a concern,
## see @code{tmpfile}.  The functions @code{tmpnam} and @code{tempname} are
## equivalent with the latter provided for @sc{matlab} compatibility.
##
## @strong{Caution}: @code{tmpnam} will be removed in a future version of
## Octave.  Use the equivalent @code{tempname} in all new code.
## @seealso{tempname, mkstemp, tempdir, P_tmpdir, tmpfile}
## @end deftypefn
    
    
@function
def tmpnam(varargin=None,*args,**kwargs):
    varargin = tmpnam.varargin
    nargin = tmpnam.nargin

    filename=tempname(varargin[:])
# /home/lei/octave-4.0.2/scripts/miscellaneous/tmpnam.m:44
    return filename
    
if __name__ == '__main__':
    pass
    
    ## No tests needed for alias.
    
    ## Copyright (C) 2012-2015 Juan Pablo Carbajal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @cindex error ids
##
## @table @code
## @item Octave:invalid-context
## Indicates the error was generated by an operation that cannot be executed in
## the scope from which it was called.  For example, the function
## @code{print_usage ()} when called from the Octave prompt raises this error.
##
## @item Octave:invalid-input-arg
## Indicates that a function was called with invalid input arguments.
##
## @item Octave:invalid-fun-call
## Indicates that a function was called in an incorrect way, e.g., wrong number
## of input arguments.
##
## @item Octave:invalid-indexing
## Indicates that a data-type was indexed incorrectly, e.g., real-value index
## for arrays, nonexistent field of a structure.
##
## @item Octave:bad-alloc
## Indicates that memory couldn't be allocated.
##
## @item Octave:undefined-function
## Indicates a call to a function that is not defined.  The function may exist
## but Octave is unable to find it in the search path.
##
## @end table
##
    
    
@function
def error_ids(*args,**kwargs):
    varargin = error_ids.varargin
    nargin = error_ids.nargin

    help('error_ids')
    return
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for a documentation .m file
    
    ## Copyright (C) 2007-2015 Thomas Treichl
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ismac ()
## Return true if Octave is running on a Mac OS X system and false otherwise.
## @seealso{isunix, ispc}
## @end deftypefn
    
    
@function
def ismac(*args,**kwargs):
    varargin = ismac.varargin
    nargin = ismac.nargin

    if (nargin == 0):
        retval=octave_config_info('mac')
# /home/lei/octave-4.0.2/scripts/miscellaneous/ismac.m:28
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cast (@var{val}, "@var{type}")
## Convert @var{val} to data type @var{type}.
##
## @var{val} must be one of the numeric classes:
##
## @example
## @group
## "double"
## "single"
## "logical"
## "char"
## "int8"
## "int16"
## "int32"
## "int64"
## "uint8"
## "uint16"
## "uint32"
## "uint64"
## @end group
## @end example
##
## The value @var{val} may be modified to fit within the range of the new type.
##
## Examples:
##
## @example
## @group
## cast (-5, "uint8")
##    @result{} 0
## cast (300, "int8")
##    @result{} 127
## @end group
## @end example
##
## @seealso{typecast, int8, uint8, int16, uint16, int32, uint32, int64, uint64, double, single, logical, char, class, typeinfo}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def cast(val=None,type_=None,*args,**kwargs):
    varargin = cast.varargin
    nargin = cast.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(ischar(type_))):
        error('cast: TYPE must be a string')
    else:
        if (logical_not(any(strcmp(type_,cellarray([['int8'],['uint8'],['int16'],['uint16'],['int32'],['uint32'],['int64'],['uint64'],['double'],['single'],['logical'],['char']]))))):
            error('cast: TYPE \'%s\' is not a built-in type',type_)
    
    retval=feval(type_,val)
# /home/lei/octave-4.0.2/scripts/miscellaneous/cast.m:74
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unix ("@var{command}")
## @deftypefnx {Function File} {@var{status} =} unix ("@var{command}")
## @deftypefnx {Function File} {[@var{status}, @var{text}] =} unix ("@var{command}")
## @deftypefnx {Function File} {[@dots{}] =} unix ("@var{command}", "-echo")
## Execute a system command if running under a Unix-like operating system,
## otherwise do nothing.
##
## Octave waits for the external command to finish before returning the exit
## status of the program in @var{status} and any output in @var{text}.
##
## When called with no output argument, or the @qcode{"-echo"} argument is
## given, then @var{text} is also sent to standard output.
## @seealso{dos, system, isunix, ismac, ispc}
## @end deftypefn
    
    ## Author: octave-forge ???
## Adapted by: jwe
    
    
@function
def unix(command=None,echo_arg=None,*args,**kwargs):
    varargin = unix.varargin
    nargin = unix.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (isunix()):
            status,text=system(command,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/unix.m:43
            if (nargin > 1 or nargout == 0):
                printf('%s\n',text)
    
    return status,text
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} bug_report ()
## Display information about how to submit bug reports for Octave.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def bug_report(*args,**kwargs):
    varargin = bug_report.varargin
    nargin = bug_report.nargin

    disp(' ')
    disp('  Bug reports play an essential role in making Octave')
    disp('  reliable.  Please use the Octave bug tracker at')
    disp(' ')
    disp('    http://bugs.octave.org')
    disp(' ')
    disp('  to report problems.')
    disp(' ')
    disp('  Please also read the bug reporting guidelines at')
    disp(' ')
    disp('    http://www.octave.org/bugs.html')
    disp(' ')
    disp('  to learn how to submit useful bug reports that will')
    disp('  help the Octave community diagnose and fix the problem')
    disp('  quickly and efficiently.')
    disp(' ')
    return
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for this function.
    
    ## Copyright (C) 2006-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @cindex warning ids
##
## @table @code
## @item Octave:abbreviated-property-match
## By default, the @code{Octave:abbreviated-property-match} warning is enabled.
##
## @item Octave:array-to-scalar
## If the @code{Octave:array-to-scalar} warning is enabled, Octave will
## warn when an implicit conversion from an array to a scalar value is
## attempted.
## By default, the @code{Octave:array-to-scalar} warning is disabled.
##
## @item Octave:array-to-vector
## If the @code{Octave:array-to-vector} warning is enabled, Octave will
## warn when an implicit conversion from an array to a vector value is
## attempted.
## By default, the @code{Octave:array-to-vector} warning is disabled.
##
## @item Octave:assign-as-truth-value
## If the @code{Octave:assign-as-truth-value} warning is
## enabled, a warning is issued for statements like
##
## @example
## @group
## if (s = t)
##   @dots{}
## @end group
## @end example
##
## @noindent
## since such statements are not common, and it is likely that the intent
## was to write
##
## @example
## @group
## if (s == t)
##   @dots{}
## @end group
## @end example
##
## @noindent
## instead.
##
## There are times when it is useful to write code that contains
## assignments within the condition of a @code{while} or @code{if}
## statement.  For example, statements like
##
## @example
## @group
## while (c = getc ())
##   @dots{}
## @end group
## @end example
##
## @noindent
## are common in C programming.
##
## It is possible to avoid all warnings about such statements by
## disabling the @code{Octave:assign-as-truth-value} warning,
## but that may also let real errors like
##
## @example
## @group
## if (x = 1)  # intended to test (x == 1)!
##   @dots{}
## @end group
## @end example
##
## @noindent
## slip by.
##
## In such cases, it is possible suppress errors for specific statements by
## writing them with an extra set of parentheses.  For example, writing the
## previous example as
##
## @example
## @group
## while ((c = getc ()))
##   @dots{}
## @end group
## @end example
##
## @noindent
## will prevent the warning from being printed for this statement, while
## allowing Octave to warn about other assignments used in conditional
## contexts.
##
## By default, the @code{Octave:assign-as-truth-value} warning is enabled.
##
## @item Octave:associativity-change
## If the @code{Octave:associativity-change} warning is
## enabled, Octave will warn about possible changes in the meaning of
## some code due to changes in associativity for some operators.
## Associativity changes have typically been made for @sc{matlab}
## compatibility.
## By default, the @code{Octave:associativity-change} warning is enabled.
##
## @item Octave:autoload-relative-file-name
## If the @code{Octave:autoload-relative-file-name} is enabled,
## Octave will warn when parsing autoload() function calls with relative
## paths to function files.  This usually happens when using autoload()
## calls in PKG_ADD files, when the PKG_ADD file is not in the same
## directory as the .oct file referred to by the autoload() command.
## By default, the @code{Octave:autoload-relative-file-name} warning is enabled.
##
## @item Octave:built-in-variable-assignment
## By default, the @code{Octave:built-in-variable-assignment} warning is
## enabled.
##
## @item Octave:deprecated-keyword
## If the @code{Octave:deprecated-keyword} warning is enabled, a
## warning is issued when Octave encounters a keyword that is obsolete and
## scheduled for removal from Octave.
## By default, the @code{Octave:deprecated-keyword} warning is enabled.
##
## @item Octave:divide-by-zero
## If the @code{Octave:divide-by-zero} warning is enabled, a
## warning is issued when Octave encounters a division by zero.
## By default, the @code{Octave:divide-by-zero} warning is enabled.
##
## @item Octave:fopen-file-in-path
## By default, the @code{Octave:fopen-file-in-path} warning is enabled.
##
## @item Octave:function-name-clash
## If the @code{Octave:function-name-clash} warning is enabled, a
## warning is issued when Octave finds that the name of a function
## defined in a function file differs from the name of the file.  (If
## the names disagree, the name declared inside the file is ignored.)
## By default, the @code{Octave:function-name-clash} warning is enabled.
##
## @item Octave:future-time-stamp
## If the @code{Octave:future-time-stamp} warning is enabled, Octave
## will print a warning if it finds a function file with a time stamp
## that is in the future.
## By default, the @code{Octave:future-time-stamp} warning is enabled.
##
## @item Octave:glyph-render
## By default, the @code{Octave:glyph-render} warning is enabled.
##
## @item Octave:imag-to-real
## If the @code{Octave:imag-to-real} warning is enabled, a warning is
## printed for implicit conversions of complex numbers to real numbers.
## By default, the @code{Octave:imag-to-real} warning is disabled.
##
## @item Octave:language-extension
## Print warnings when using features that are unique to the Octave
## language and that may still be missing in @sc{matlab}.
## By default, the @code{Octave:language-extension} warning is disabled.
## The @option{--traditional} or @option{--braindead} startup options for
## Octave may also be of use, @pxref{Command Line Options}.
##
## @item Octave:load-file-in-path
## By default, the @code{Octave:load-file-in-path} warning is enabled.
##
## @item Octave:logical-conversion
## By default, the @code{Octave:logical-conversion} warning is enabled.
##
## @item Octave:md5sum-file-in-path
## By default, the @code{Octave:md5sum-file-in-path} warning is enabled.
##
## @item Octave:missing-glyph
## By default, the @code{Octave:missing-glyph} warning is enabled.
##
## @item Octave:missing-semicolon
## If the @code{Octave:missing-semicolon} warning is enabled, Octave
## will warn when statements in function definitions don't end in
## semicolons.
## By default the @code{Octave:missing-semicolon} warning is disabled.
##
## @item Octave:mixed-string-concat
## If the @code{Octave:mixed-string-concat} warning is enabled, print a
## warning when concatenating a mixture of double and single quoted strings.
## By default, the @code{Octave:mixed-string-concat} warning is disabled.
##
## @item Octave:neg-dim-as-zero
## If the @code{Octave:neg-dim-as-zero} warning is enabled, print a warning
## for expressions like
##
## @example
## eye (-1)
## @end example
##
## @noindent
## By default, the @code{Octave:neg-dim-as-zero} warning is disabled.
##
## @item Octave:nested-functions-coerced
## By default, the @code{Octave:nested-functions-coerced} warning is enabled.
##
## @item Octave:noninteger-range-as-index
## By default, the @code{Octave:noninteger-range-as-index} warning is enabled.
##
## @item Octave:num-to-str
## If the @code{Octave:num-to-str} warning is enable, a warning is
## printed for implicit conversions of numbers to their ASCII character
## equivalents when strings are constructed using a mixture of strings and
## numbers in matrix notation.  For example,
##
## @example
## @group
## [ "f", 111, 111 ]
## @result{} "foo"
## @end group
## @end example
##
## @noindent
## elicits a warning if the @code{Octave:num-to-str} warning is
## enabled.  By default, the @code{Octave:num-to-str} warning is enabled.
##
## @item Octave:possible-matlab-short-circuit-operator
## If the @code{Octave:possible-matlab-short-circuit-operator} warning
## is enabled, Octave will warn about using the not short circuiting
## operators @code{&} and @code{|} inside @code{if} or @code{while}
## conditions.  They normally never short circuit, but @sc{matlab} always
## short circuits if any logical operators are used in a condition.  You
## can turn on the option
##
## @example
## @group
## do_braindead_shortcircuit_evaluation (1)
## @end group
## @end example
##
## @noindent
## if you would like to enable this short-circuit evaluation in
## Octave.  Note that the @code{&&} and @code{||} operators always short
## circuit in both Octave and @sc{matlab}, so it's only necessary to
## enable @sc{matlab}-style short-circuiting if it's too arduous to modify
## existing code that relies on this behavior.
## By default, the @code{Octave:possible-matlab-short-circuit-operator} warning
## is enabled.
##
## @item Octave:precedence-change
## If the @code{Octave:precedence-change} warning is enabled, Octave
## will warn about possible changes in the meaning of some code due to
## changes in precedence for some operators.  Precedence changes have
## typically been made for @sc{matlab} compatibility.
## By default, the @code{Octave:precedence-change} warning is enabled.
##
## @item Octave:recursive-path-search
## By default, the @code{Octave:recursive-path-search} warning is enabled.
##
## @item Octave:remove-init-dir
## The @code{path} function changes the search path that Octave uses
## to find functions.  It is possible to set the path to a value which
## excludes Octave's own built-in functions.  If the
## @code{Octave:remove-init-dir} warning is enabled then Octave will warn
## when the @code{path} function has been used in a way that may render
## Octave unworkable.
## By default, the @code{Octave:remove-init-dir} warning is enabled.
##
## @item Octave:reload-forces-clear
## If several functions have been loaded from the same file, Octave must
## clear all the functions before any one of them can be reloaded.  If
## the @code{Octave:reload-forces-clear} warning is enabled, Octave will
## warn you when this happens, and print a list of the additional
## functions that it is forced to clear.
## By default, the @code{Octave:reload-forces-clear} warning is enabled.
##
## @item Octave:resize-on-range-error
## If the @code{Octave:resize-on-range-error} warning is enabled, print a
## warning when a matrix is resized by an indexed assignment with
## indices outside the current bounds.
## By default, the ## @code{Octave:resize-on-range-error} warning is disabled.
##
## @item Octave:separator-insert
## Print warning if commas or semicolons might be inserted
## automatically in literal matrices.
## By default, the @code{Octave:separator-insert} warning is disabled.
##
## @item Octave:shadowed-function
## By default, the @code{Octave:shadowed-function} warning is enabled.
##
## @item Octave:single-quote-string
## Print warning if a single quote character is used to introduce a
## string constant.
## By default, the @code{Octave:single-quote-string} warning is disabled.
##
## @item  Octave:nearly-singular-matrix
## @itemx Octave:singular-matrix
## By default, the @code{Octave:nearly-singular-matrix} and
## @code{Octave:singular-matrix} warnings are enabled.
##
## @item Octave:sqrtm:SingularMatrix
## By default, the @code{Octave:sqrtm:SingularMatrix} warning is enabled.
##
## @item Octave:str-to-num
## If the @code{Octave:str-to-num} warning is enabled, a warning is printed
## for implicit conversions of strings to their numeric ASCII equivalents.
## For example,
##
## @example
## @group
## "abc" + 0
## @result{} 97 98 99
## @end group
## @end example
##
## @noindent
## elicits a warning if the @code{Octave:str-to-num} warning is enabled.
## By default, the @code{Octave:str-to-num} warning is disabled.
##
## @item Octave:undefined-return-values
## If the @code{Octave:undefined-return-values} warning is disabled,
## print a warning if a function does not define all the values in
## the return list which are expected.
## By default, the @code{Octave:undefined-return-values} warning is enabled.
##
## @item Octave:variable-switch-label
## If the @code{Octave:variable-switch-label} warning is enabled, Octave
## will print a warning if a switch label is not a constant or constant
## expression.
## By default, the @code{Octave:variable-switch-label} warning is disabled.
## @end table
##
    
    
@function
def warning_ids(*args,**kwargs):
    varargin = warning_ids.varargin
    nargin = warning_ids.nargin

    help('warning_ids')
    return
    
if __name__ == '__main__':
    pass
    
    ## Mark file as being tested.  No real test needed for a documentation .m file
    
    ## Copyright (C) 2006-2015 Sylvain Pelissier
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{filelist} =} zip (@var{zipfile}, @var{files})
## @deftypefnx {Function File} {@var{filelist} =} zip (@var{zipfile}, @var{files}, @var{rootdir})
## Compress the list of files and directories specified in @var{files} into the
## ZIP archive @var{zipfile}.
##
## @var{files} is a character array or cell array of strings.  Shell
## wildcards in the filename such as @samp{*} or @samp{?} are accepted and
## expanded.  Directories are recursively traversed and all files are
## compressed and added to the archive.
##
## If @var{rootdir} is defined then any files without absolute pathnames are
## located relative to @var{rootdir} rather than the current directory.
##
## The optional output @var{filelist} is a list of the files that were included
## in the archive.
## @seealso{unzip, unpack, bzip2, gzip, tar}
## @end deftypefn
    
    ## Author: Sylvain Pelissier <sylvain.pelissier@gmail.com>
    
    
@function
def zip(zipfile=None,files=None,rootdir='.',*args,**kwargs):
    varargin = zip.varargin
    nargin = zip.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(zipfile))):
        error('zip: ZIPFILE must be a string')
    else:
        if (ischar(files)):
            files=cellstr(files)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:49
        else:
            if (logical_not(iscellstr(files))):
                error('zip: FILES must be a character array or cellstr')
    
    rootdir=tilde_expand(rootdir)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:54
    zipfile=make_absolute_filename(zipfile)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:56
    cmd=sprintf('zip -r %s %s',zipfile,sprintf(' %s',files[:]))
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:58
    origdir=pwd()
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:60
    cd(rootdir)
    status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:62
    cd(origdir)
    if (status):
        error('zip: zip failed with exit status = %d',status)
    
    if (nargout > 0):
        cmd=matlabarray(cat('unzip -Z -1 ',zipfile))
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:70
        status,filelist=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:71
        if (status):
            error('zip: zipinfo failed with exit status = %d',status)
        filelist=ostrsplit(filelist,'\r\n',true)
# /home/lei/octave-4.0.2/scripts/miscellaneous/zip.m:75
    
    return filelist
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isdeployed ()
## Return true if the current program has been compiled and is running
## separately from the Octave interpreter and false if it is running in
## the Octave interpreter.
##
## Currently, this function always returns false in Octave.
## @end deftypefn
    
    
@function
def isdeployed(*args,**kwargs):
    varargin = isdeployed.varargin
    nargin = isdeployed.nargin

    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/miscellaneous/isdeployed.m:29
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} stairs (@var{y})
## @deftypefnx {Function File} {} stairs (@var{x}, @var{y})
## @deftypefnx {Function File} {} stairs (@dots{}, @var{style})
## @deftypefnx {Function File} {} stairs (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} stairs (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} stairs (@dots{})
## @deftypefnx {Function File} {[@var{xstep}, @var{ystep}] =} stairs (@dots{})
## Produce a stairstep plot.
##
## The arguments @var{x} and @var{y} may be vectors or matrices.
## If only one argument is given, it is taken as a vector of Y values
## and the X coordinates are taken to be the indices of the elements.
##
## The style to use for the plot can be defined with a line style @var{style}
## of the same format as the @code{plot} command.
##
## Multiple property/value pairs may be specified, but they must appear in
## pairs.
##
## If the first argument @var{hax} is an axis handle, then plot into this axis,
## rather than the current axis handle returned by @code{gca}.
##
## If one output argument is requested, return a graphics handle to the
## created plot.  If two output arguments are specified, the data are generated
## but not plotted.  For example,
##
## @example
## stairs (x, y);
## @end example
##
## @noindent
## and
##
## @example
## @group
## [xs, ys] = stairs (x, y);
## plot (xs, ys);
## @end group
## @end example
##
## @noindent
## are equivalent.
## @seealso{bar, hist, plot, stem}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def stairs(varargin=None,*args,**kwargs):
    varargin = stairs.varargin
    nargin = stairs.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('stairs',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:69
    if (nargin < 1):
        print_usage()
    
    if (nargout < 2):
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:76
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:78
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:81
            htmp,xxs,yys=__stairs__(true,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:82
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
        if (nargout == 1):
            xs=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:89
    else:
        __,xs,ys=__stairs__(false,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:92
    
    return xs,ys
    
if __name__ == '__main__':
    pass
    
    
@function
def __stairs__(doplot=None,varargin=None,*args,**kwargs):
    varargin = __stairs__.varargin
    nargin = __stairs__.nargin

    if (nargin == 2 or ischar(varargin[2])):
        y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:100
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:101
        if (logical_not(isnumeric(y)) or ndims(y) > 2):
            error('stairs: Y must be a numeric 2-D vector or matrix')
        if (isvector(y)):
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:106
        x=arange(1,rows(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:108
    else:
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:110
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:111
        varargin[1:2]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:112
        if (logical_not(isnumeric(x)) or logical_not(isnumeric(y)) or ndims(x) > 2 or ndims(y) > 2):
            error('stairs: X and Y must be numeric 2-D vectors or matrices')
    
    vec_x=isvector(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:118
    if (vec_x):
        x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:120
    
    if (isvector(y)):
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:124
    else:
        if (isnumeric(y) and vec_x):
            x=repmat(x,cat(1,columns(y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:126
    
    if (logical_not(size_equal(x,y))):
        error('stairs: X and Y sizes must match')
    
    nr,nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:133
    len_=dot(2,nr) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:135
    xs=ys=zeros(len_,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:137
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:137
    xs[1,:]=x[1,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:139
    ys[1,:]=y[1,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:140
    xtmp=x[2:nr,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:142
    ridx=arange(2,len_ - 1,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:143
    xs[ridx,:]=xtmp
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:144
    ys[ridx,:]=y[1:nr - 1,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:145
    ridx=arange(3,len_,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:147
    xs[ridx,:]=xtmp
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:148
    ys[ridx,:]=y[2:nr,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:149
    have_line_spec=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:151
    for i in arange(1,numel(varargin),2).reshape(-1):
        arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:153
        if (ischar(arg) or iscellstr(arg)):
            linespec,valid=__pltopt__('stairs',arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:155
            if (valid):
                have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:157
                varargin[i]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:158
                break
    
    if (doplot):
        h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:165
        hold_state=get(gca(),'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:166
        try:
            for i in arange(1,columns(y)).reshape(-1):
                if (have_line_spec):
                    lc=linespec.color
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:171
                    if (isempty(lc)):
                        lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:173
                    ls=linespec.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:175
                    if (isempty(ls)):
                        ls='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:177
                    mk=linespec.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:179
                    if (isempty(mk)):
                        mk='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:181
                else:
                    lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:184
                    ls='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:185
                    mk='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:186
                ## Must occur after __next_line_color__ in order to work correctly.
                hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:190
                h=matlabarray(cat([h],[hg]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:191
                args=__add_datasource__('stairs',hg,cellarray(['x','y']),varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:192
                addproperty('xdata',hg,'data',x[:,i].T)
                addproperty('ydata',hg,'data',y[:,i].T)
                addlistener(hg,'xdata',update_data)
                addlistener(hg,'ydata',update_data)
                htmp=line(xs[:,i].T,ys[:,i].T,'color',lc,'linestyle',ls,'marker',mk,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:200
                addproperty('color',hg,'linecolor',get(htmp,'color'))
                addproperty('linestyle',hg,'linelinestyle',get(htmp,'linestyle'))
                addproperty('linewidth',hg,'linelinewidth',get(htmp,'linewidth'))
                addproperty('marker',hg,'linemarker',get(htmp,'marker'))
                addproperty('markeredgecolor',hg,'linemarkeredgecolor',get(htmp,'markeredgecolor'))
                addproperty('markerfacecolor',hg,'linemarkerfacecolor',get(htmp,'markerfacecolor'))
                addproperty('markersize',hg,'linemarkersize',get(htmp,'markersize'))
                addlistener(hg,'color',update_props)
                addlistener(hg,'linestyle',update_props)
                addlistener(hg,'linewidth',update_props)
                addlistener(hg,'marker',update_props)
                addlistener(hg,'markeredgecolor',update_props)
                addlistener(hg,'markerfacecolor',update_props)
                addlistener(hg,'markersize',update_props)
                addproperty('hittestarea',hg,'radio','on|{off}','off')
                if (logical_not(isempty(args))):
                    set(hg,args[:])
        finally:
            set(gca(),'nextplot',hold_state)
    else:
        h=0
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:234
    
    return h,xs,ys
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,__=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    set(get(h,'children'),cellarray(['color','linestyle','linewidth','marker','markeredgecolor','markerfacecolor','markersize']),get(h,cellarray(['color','linestyle','linewidth','marker','markeredgecolor','markerfacecolor','markersize'])))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    x=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:248
    y=get(h,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:249
    sz=min(cat([size(x)],[size(y)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:251
    x=x[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:252
    y=y[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:253
    nr=length(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:255
    len_=dot(2,nr) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:256
    xs=ys=zeros(1,len_)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:257
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:257
    xs[1]=x[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:259
    ys[1]=y[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:260
    xtmp=x[2:nr]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:262
    ridx=arange(2,len_ - 1,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:263
    xs[ridx]=xtmp
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:264
    ys[ridx]=y[1:nr - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:265
    ridx=arange(3,len_,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:267
    xs[ridx]=xtmp
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:268
    ys[ridx]=y[2:nr]
# /home/lei/octave-4.0.2/scripts/plot/draw/stairs.m:269
    set(get(h,'children'),'xdata',xs,'ydata',ys)
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Invisible figure used for tests
    
    
    
    
    ## Close figure used for testing
    
    ## Copyright (C) 1993-2015 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} contour (@var{z})
## @deftypefnx {Function File} {} contour (@var{z}, @var{vn})
## @deftypefnx {Function File} {} contour (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} contour (@var{x}, @var{y}, @var{z}, @var{vn})
## @deftypefnx {Function File} {} contour (@dots{}, @var{style})
## @deftypefnx {Function File} {} contour (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{c}, @var{h}] =} contour (@dots{})
## Create a 2-D contour plot.
##
## Plot level curves (contour lines) of the matrix @var{z}, using the
## contour matrix @var{c} computed by @code{contourc} from the same
## arguments; see the latter for their interpretation.
##
## The appearance of contour lines can be defined with a line style @var{style}
## in the same manner as @code{plot}.  Only line style and color are used;
## Any markers defined by @var{style} are ignored.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional output @var{c} contains the contour levels in @code{contourc}
## format.
##
## The optional return value @var{h} is a graphics handle to the hggroup
## comprising the contour lines.
##
## Example:
##
## @example
## @group
## x = 0:2;
## y = x;
## z = x' * y;
## contour (x, y, z, 2:3)
## @end group
## @end example
##
## @seealso{ezcontour, contourc, contourf, contour3, clabel, meshc, surfc, caxis, colormap, plot}
##
## @end deftypefn
    
    ## Author: Shai Ayal <shaiay@users.sourceforge.net>
    
    
@function
def contour(varargin=None,*args,**kwargs):
    varargin = contour.varargin
    nargin = contour.nargin

    hax,varargin=__plt_get_axis_arg__('contour',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:65
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:67
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:69
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:72
        ctmp,htmp=__contour__(hax,'none',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:74
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        c=copy(ctmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:82
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour.m:83
    
    return c,h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} comet (@var{y})
## @deftypefnx {Function File} {} comet (@var{x}, @var{y})
## @deftypefnx {Function File} {} comet (@var{x}, @var{y}, @var{p})
## @deftypefnx {Function File} {} comet (@var{hax}, @dots{})
## Produce a simple comet style animation along the trajectory provided by
## the input coordinate vectors (@var{x}, @var{y}).
##
## If @var{x} is not specified it defaults to the indices of @var{y}.
##
## The speed of the comet may be controlled by @var{p}, which represents the
## time each point is displayed before moving to the next one.  The default for
## @var{p} is 0.1 seconds.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
## @seealso{comet3}
## @end deftypefn
    
    ## Author: Ben Abbott bpabbott@mac.com
## Created: 2008-09-21
    
    
@function
def comet(varargin=None,*args,**kwargs):
    varargin = comet.varargin
    nargin = comet.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('comet',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:43
    if (nargin == 0):
        print_usage()
    else:
        if (nargin == 1):
            y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:48
            x=arange(1,numel(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:49
            p=0.1
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:50
        else:
            if (nargin == 2):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:52
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:53
                p=0.1
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:54
            else:
                if (nargin == 3):
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:56
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:57
                    p=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:58
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:61
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:63
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:66
        limits=matlabarray(cat(min(x),max(x),min(y),max(y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:67
        num=numel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:68
        dn=round(num / 10)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:69
        hl=plot(x[1],y[1],'color','r','marker','none',x[1],y[1],'color','g','marker','none',x[1],y[1],'color','b','marker','o')
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:71
        axis(limits)
        for n in arange(2,(num + dn)).reshape(-1):
            m=n - dn
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:77
            m=max(cat(m,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:78
            k=min(cat(n,num))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet.m:79
            set(hl[1],'xdata',x[1:m],'ydata',y[1:m])
            set(hl[2],'xdata',x[m:k],'ydata',y[m:k])
            set(hl[3],'xdata',x[k],'ydata',y[k])
            drawnow()
            pause(p)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sombrero ()
## @deftypefnx {Function File} {} sombrero (@var{n})
## @deftypefnx {Function File} {@var{z} =} sombrero (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} sombrero (@dots{})
## Plot the familiar 3-D sombrero function.
##
## The function plotted is
## @tex
## $$z = { \rm{sin} (\sqrt {(x^2 + y^2)}) \over \sqrt {(x^2 + y^2)} }$$
## @end tex
## @ifnottex
##
## @example
## z = sin (sqrt (x^2 + y^2)) / (sqrt (x^2 + y^2))
## @end example
##
## @end ifnottex
## Called without a return argument, @code{sombrero} plots the surface of the
## above function over the meshgrid [-8,8] using @code{surf}.
##
## If @var{n} is a scalar the plot is made with @var{n} grid lines.
## The default value for @var{n} is 41.
##
## When called with output arguments, return the data for the function
## evaluated over the meshgrid.  This can subsequently be plotted with
## @code{surf (@var{x}, @var{y}, @var{z})}.
##
## @seealso{peaks, meshgrid, mesh, surf}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def sombrero(n=41,*args,**kwargs):
    varargin = sombrero.varargin
    nargin = sombrero.nargin

    if (nargin > 2):
        print_usage()
    else:
        if (n <= 1):
            error('sombrero: number of grid lines N must be greater than 1')
    
    xx,yy=meshgrid(linspace(- 8,8,n),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:60
    r=sqrt(xx ** 2 + yy ** 2) + eps
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:61
    
    zz=sin(r) / r
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:62
    if (nargout == 0):
        surf(xx,yy,zz)
    else:
        if (nargout == 1):
            x=copy(zz)
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:67
        else:
            x=copy(xx)
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:69
            y=copy(yy)
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:70
            z=copy(zz)
# /home/lei/octave-4.0.2/scripts/plot/draw/sombrero.m:71
    
    return x,y,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} surfnorm (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} surfnorm (@var{z})
## @deftypefnx {Function File} {} surfnorm (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} surfnorm (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{nx}, @var{ny}, @var{nz}] =} surfnorm (@dots{})
## Find the vectors normal to a meshgridded surface.
##
## If @var{x} and @var{y} are vectors, then a typical vertex is
## (@var{x}(j), @var{y}(i), @var{z}(i,j)).  Thus, columns of @var{z} correspond
## to different @var{x} values and rows of @var{z} correspond to different
## @var{y} values.  If only a single input @var{z} is given then @var{x} is
## taken to be @code{1:rows (@var{z})} and @var{y} is
## @code{1:columns (@var{z})}.
##
## If no return arguments are requested, a surface plot with the normal
## vectors to the surface is plotted.
##
## Any property/value input pairs are assigned to the surface object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## If output arguments are requested then the components of the normal
## vectors are returned in @var{nx}, @var{ny}, and @var{nz} and no plot is
## made.
##
## An example of the use of @code{surfnorm} is
##
## @example
## surfnorm (peaks (25));
## @end example
##
## Algorithm: The normal vectors are calculated by taking the cross product
## of the diagonals of each of the quadrilaterals in the meshgrid to find the
## normal vectors of the centers of these quadrilaterals.  The four nearest
## normal vectors to the meshgrid points are then averaged to obtain the
## normal to the surface at the meshgridded points.
##
## @seealso{isonormals, quiver3, surf, meshgrid}
## @end deftypefn
    
    
@function
def surfnorm(varargin=None,*args,**kwargs):
    varargin = surfnorm.varargin
    nargin = surfnorm.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('surfnorm',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:63
    if (nargin == 0 or nargin == 2):
        print_usage()
    
    if (nargin == 1):
        z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:70
        x,y=meshgrid(arange(1,columns(z)),arange(1,rows(z)),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:71
        ioff=2
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:72
    else:
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:74
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:75
        z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:76
        ioff=4
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:77
    
    if (iscomplex(z) or iscomplex(x) or iscomplex(y)):
        error('surfnorm: X, Y, and Z must be 2-D real matrices')
    
    if (logical_not(size_equal(x,y,z))):
        error('surfnorm: X, Y, and Z must have the same dimensions')
    
    ## Do a linear extrapolation for mesh points on the boundary so that the mesh
  ## is increased by 1 on each side.  This allows each original meshgrid point
  ## to be surrounded by four quadrilaterals and the same calculation can be
  ## used for interior and boundary points.  The extrapolation works badly for
  ## closed surfaces like spheres.
    xx=matlabarray(cat(dot(2,x[:,1]) - x[:,2],x,dot(2,x[:,end()]) - x[:,end() - 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:92
    xx=matlabarray(cat([dot(2,xx[1,:]) - xx[2,:]],[xx],[dot(2,xx[end(),:]) - xx[end() - 1,:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:93
    yy=matlabarray(cat(dot(2,y[:,1]) - y[:,2],y,dot(2,y[:,end()]) - y[:,end() - 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:94
    yy=matlabarray(cat([dot(2,yy[1,:]) - yy[2,:]],[yy],[dot(2,yy[end(),:]) - yy[end() - 1,:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:95
    zz=matlabarray(cat(dot(2,z[:,1]) - z[:,2],z,dot(2,z[:,end()]) - z[:,end() - 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:96
    zz=matlabarray(cat([dot(2,zz[1,:]) - zz[2,:]],[zz],[dot(2,zz[end(),:]) - zz[end() - 1,:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:97
    u.x = copy(xx[1:end() - 1,1:end() - 1] - xx[2:end(),2:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:99
    u.y = copy(yy[1:end() - 1,1:end() - 1] - yy[2:end(),2:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:100
    u.z = copy(zz[1:end() - 1,1:end() - 1] - zz[2:end(),2:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:101
    v.x = copy(xx[1:end() - 1,2:end()] - xx[2:end(),1:end() - 1])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:102
    v.y = copy(yy[1:end() - 1,2:end()] - yy[2:end(),1:end() - 1])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:103
    v.z = copy(zz[1:end() - 1,2:end()] - zz[2:end(),1:end() - 1])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:104
    c=cross(cat(ravel(u.x),ravel(u.y),ravel(u.z)),cat(ravel(v.x),ravel(v.y),ravel(v.z)))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:106
    w.x = copy(reshape(c[:,1],size(u.x)))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:107
    w.y = copy(reshape(c[:,2],size(u.y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:108
    w.z = copy(reshape(c[:,3],size(u.z)))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:109
    
    nx=(w.x(arange(1,end() - 1),arange(1,end() - 1)) + w.x(arange(1,end() - 1),arange(2,end())) + w.x(arange(2,end()),arange(1,end() - 1)) + w.x(arange(2,end()),arange(2,end()))) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:112
    ny=(w.y(arange(1,end() - 1),arange(1,end() - 1)) + w.y(arange(1,end() - 1),arange(2,end())) + w.y(arange(2,end()),arange(1,end() - 1)) + w.y(arange(2,end()),arange(2,end()))) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:114
    nz=(w.z(arange(1,end() - 1),arange(1,end() - 1)) + w.z(arange(1,end() - 1),arange(2,end())) + w.z(arange(2,end()),arange(1,end() - 1)) + w.z(arange(2,end()),arange(2,end()))) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:116
    
    ##        returned are not normalized.
  ## Normalize the normal vectors
    len_=sqrt(nx ** 2 + ny ** 2 + nz ** 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:122
    nx / len_
    ny / len_
    nz / len_
    if (nargout == 0):
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:128
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:130
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:133
            surf(x,y,z,varargin[ioff:end()])
            old_hold_state=get(hax,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:136
            try:
                set(hax,'nextplot','add')
                ##        normals to appear correct.
        ##daratio = daspect (hax);
        ##daspect ("manual");
        ##len = norm (daratio);
        ## This assumes an even meshgrid which isn't a great assumption
        ##dx = x(1,2) - x(1,1);
        ##dy = y(2,1) - y(1,1);
        ##nx *= daratio(1);
        ##ny *= daratio(2);
        ##nz *= daratio(3);
        ##len = sqrt (nx.^2 + ny.^2 + nz.^2);
        ##nx ./= len;
        ##ny ./= len;
        ##nz ./= len;
                plot3(ravel(cat([ravel(x).T],[ravel(x).T + ravel(nx).T],[NaN(size(ravel(x).T))])),ravel(cat([ravel(y).T],[ravel(y).T + ravel(ny).T],[NaN(size(ravel(y).T))])),ravel(cat([ravel(z).T],[ravel(z).T + ravel(nz).T],[NaN(size(ravel(z).T))])),'r')
            finally:
                set(hax,'nextplot',old_hold_state)
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
    else:
        Nx=copy(nx)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:169
        Ny=copy(ny)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:170
        Nz=copy(nz)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfnorm.m:171
    
    return Nx,Ny,Nz
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezplot (@var{f})
## @deftypefnx {Function File} {} ezplot (@var{f2v})
## @deftypefnx {Function File} {} ezplot (@var{fx}, @var{fy})
## @deftypefnx {Function File} {} ezplot (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezplot (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezplot (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezplot (@dots{})
##
## Plot the 2-D curve defined by the function @var{f}.
##
## The function @var{f} may be a string, inline function, or function handle
## and can have either one or two variables.  If @var{f} has one variable, then
## the function is plotted over the domain @code{-2*pi < @var{x} < 2*pi}
## with 500 points.
##
## If @var{f2v} is a function of two variables then the implicit function
## @code{@var{f}(@var{x},@var{y}) = 0} is calculated over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## For example:
##
## @example
## ezplot (@@(@var{x}, @var{y}) @var{x}.^2 - @var{y}.^2 - 1)
## @end example
##
## If two functions are passed as inputs then the parametric function
##
## @example
## @group
## @var{x} = @var{fx} (@var{t})
## @var{y} = @var{fy} (@var{t})
## @end group
## @end example
##
## @noindent
## is plotted over the domain @code{-2*pi <= @var{t} <= 2*pi} with 500 points.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}, or @var{t} for a parametric plot.  If
## @var{dom} is a four element vector, then the minimum and maximum values are
## @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in plotting
## the function.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to
## the created line objects.
##
## @seealso{plot, ezplot3, ezpolar, ezcontour, ezcontourf, ezmesh, ezmeshc, ezsurf, ezsurfc}
## @end deftypefn
    
    
@function
def ezplot(varargin=None,*args,**kwargs):
    varargin = ezplot.varargin
    nargin = ezplot.nargin

    htmp,needusage=__ezplot__('plot',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezplot.m:76
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezplot.m:83
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezsurf (@var{f})
## @deftypefnx {Function File} {} ezsurf (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {} ezsurf (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezsurf (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezsurf (@dots{}, "circ")
## @deftypefnx {Function File} {} ezsurf (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezsurf (@dots{})
##
## Plot the surface defined by a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If three functions are passed, then plot the parametrically defined
## function @code{[@var{fx} (@var{s}, @var{t}), @var{fy} (@var{s}, @var{t}),
## @var{fz} (@var{s}, @var{t})]}.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the argument @qcode{"circ"} is given, then the function is plotted over
## a disk centered on the middle of the domain @var{dom}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Example 1: 2-argument function
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezsurf (f, [-3, 3]);
## @end group
## @end example
##
## Example 2: parametrically defined function
##
## @example
## @group
## fx = @@(s,t) cos (s) .* cos (t);
## fy = @@(s,t) sin (s) .* cos (t);
## fz = @@(s,t) sin (t);
## ezsurf (fx, fy, fz, [-pi, pi, -pi/2, pi/2], 20);
## @end group
## @end example
##
## @seealso{surf, ezsurfc, ezplot, ezmesh, ezmeshc, shading}
## @end deftypefn
    
    
@function
def ezsurf(varargin=None,*args,**kwargs):
    varargin = ezsurf.varargin
    nargin = ezsurf.nargin

    htmp,needusage=__ezplot__('surf',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezsurf.m:78
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezsurf.m:85
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} polar (@var{theta}, @var{rho})
## @deftypefnx {Function File} {} polar (@var{theta}, @var{rho}, @var{fmt})
## @deftypefnx {Function File} {} polar (@var{cplx})
## @deftypefnx {Function File} {} polar (@var{cplx}, @var{fmt})
## @deftypefnx {Function File} {} polar (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} polar (@dots{})
## Create a 2-D plot from polar coordinates @var{theta} and @var{rho}.
##
## If a single complex input @var{cplx} is given then the real part is used
## for @var{theta} and the imaginary part is used for @var{rho}.
##
## The optional argument @var{fmt} specifies the line format in the same way
## as @code{plot}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Implementation Note: The polar axis is drawn using line and text objects
## encapsulated in an hggroup.  The hggroup properties are linked to the
## original axes object such that altering an appearance property, for example
## @code{fontname}, will update the polar axis.  Two new properties are
## added to the original axes--@code{rtick}, @code{ttick}--which replace
## @code{xtick}, @code{ytick}.  The first is a list of tick locations in the
## radial (rho) direction; The second is a list of tick locations in the
## angular (theta) direction specified in degrees, i.e., in the range 0--359.
## @seealso{rose, compass, plot}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def polar(varargin=None,*args,**kwargs):
    varargin = polar.varargin
    nargin = polar.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('polar',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:54
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:60
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:62
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:65
        if (nargs == 3):
            if (logical_not(ischar(varargin[3]))):
                error('polar: FMT argument must be a string')
            htmp=__plr2__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:71
            maxr=max(ravel(varargin[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:72
        else:
            if (nargs == 2):
                if (ischar(varargin[2])):
                    htmp=__plr1__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:75
                    if (iscomplex(varargin[1])):
                        maxr=max(ravel(imag(varargin[1])))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:77
                    else:
                        maxr=max(ravel(varargin[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:79
                else:
                    fmt=''
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:82
                    htmp=__plr2__(hax,varargin[:],fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:83
                    maxr=max(ravel(varargin[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:84
            else:
                if (nargs == 1):
                    fmt=''
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:87
                    htmp=__plr1__(hax,varargin[:],fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:88
                    if (iscomplex(varargin[1])):
                        maxr=max(ravel(imag(varargin[1])))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:90
                    else:
                        maxr=max(ravel(varargin[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:92
                else:
                    print_usage()
        if (logical_not(ishold(hax))):
            hg=hggroup(hax,'tag','polar_grid','handlevisibility','off')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:99
            set(hax,'visible','off','plotboxaspectratio',cat(1,1,1),'zlim',cat(- 1,1))
            if (logical_not(isprop(hax,'rtick'))):
                addproperty('rtick',hax,'data')
            set(hax,'rtick',__calc_rtick__(hax,maxr))
            if (logical_not(isprop(hax,'ttick'))):
                addproperty('ttick',hax,'data')
            ## theta(angular) ticks in degrees
            set(hax,'ttick',arange(0,330,30))
            __update_polar_grid__(hax,[],hg)
            set(hg,'deletefcn',cellarray([resetaxis,hax]))
            addlistener(hax,'rtick',cellarray([__update_polar_grid__,hg]))
            addlistener(hax,'ttick',cellarray([__update_polar_grid__,hg]))
            addlistener(hax,'color',cellarray([__update_patch__,hg]))
            addlistener(hax,'fontangle',cellarray([__update_text__,hg,'fontangle']))
            addlistener(hax,'fontname',cellarray([__update_text__,hg,'fontname']))
            addlistener(hax,'fontsize',cellarray([__update_text__,hg,'fontsize']))
            addlistener(hax,'fontunits',cellarray([__update_text__,hg,'fontunits']))
            addlistener(hax,'fontweight',cellarray([__update_text__,hg,'fontweight']))
            addlistener(hax,'interpreter',cellarray([__update_text__,hg,'interpreter']))
            addlistener(hax,'layer',cellarray([__update_layer__,hg]))
            addlistener(hax,'gridlinestyle',cellarray([__update_lines__,hg,'gridlinestyle']))
            addlistener(hax,'linewidth',cellarray([__update_lines__,hg,'linewidth']))
        else:
            hg=findall(hax,'tag','polar_grid')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:135
            if (logical_not(isempty(hg))):
                oldrtick=max(get(hax,'rtick'))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:137
                if (maxr > oldrtick):
                    set(hax,'rtick',__calc_rtick__(hax,maxr))
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:151
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __calc_rtick__(hax=None,maxr=None,*args,**kwargs):
    varargin = __calc_rtick__.varargin
    nargin = __calc_rtick__.nargin

    ## FIXME: workaround: calculate r(ho)tick from xtick
    savexlim=get(hax,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:158
    saveylim=get(hax,'ylim')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:159
    set(hax,'xlim',cat(- maxr,maxr),'ylim',cat(- maxr,maxr))
    xtick=get(hax,'xtick')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:161
    rtick=xtick[find(xtick > 0,1):find(xtick >= maxr,1)]
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:162
    if (isempty(rtick)):
        rtick=matlabarray(cat(0.5,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:164
    
    set(hax,'xlim',savexlim,'ylim',saveylim)
    return rtick
    
if __name__ == '__main__':
    pass
    
    
@function
def __plr1__(h=None,theta=None,fmt=None,*args,**kwargs):
    varargin = __plr1__.varargin
    nargin = __plr1__.nargin

    theta=ravel(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:171
    if (iscomplex(theta)):
        rho=imag(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:173
        theta=real(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:174
    else:
        rho=copy(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:176
        theta=(arange(1,rows(rho))).T
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:177
    
    retval=__plr2__(h,theta,rho,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:180
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plr2__(h=None,theta=None,rho=None,fmt=None,*args,**kwargs):
    varargin = __plr2__.varargin
    nargin = __plr2__.nargin

    if (ndims(theta) > 2 or ndims(rho) > 2):
        error('polar: THETA and RHO must be 2-D objects')
    
    theta=real(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:189
    rho=real(rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:190
    if (isscalar(theta)):
        if (isscalar(rho)):
            x=dot(rho,cos(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:194
            y=dot(rho,sin(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:195
            retval=__plt__('polar',h,x,y,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:196
        else:
            error('polar: Can\'t plot constant THETA with varying RHO')
    else:
        if (isvector(theta)):
            if (isvector(rho)):
                if (length(theta) != length(rho)):
                    error('polar: THETA and RHO vector lengths must match')
                rho=ravel(rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:205
                theta=ravel(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:206
                x=multiply(rho,cos(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:207
                y=multiply(rho,sin(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:208
                retval=__plt__('polar',h,x,y,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:209
            else:
                if (ismatrix(rho)):
                    theta=ravel(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:211
                    t_nr=rows(theta)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:212
                    r_nr,r_nc=size(rho,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:213
                    if (t_nr != r_nr):
                        rho=rho.T
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:215
                        r_nr=copy(r_nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:216
                    if (t_nr != r_nr):
                        error('polar: THETA vector and RHO matrix sizes must match')
                    x=dot(diag(cos(theta)),rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:221
                    y=dot(diag(sin(theta)),rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:222
                    retval=__plt__('polar',h,x,y,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:223
                else:
                    error('polar: invalid data for plotting')
        else:
            if (ismatrix(theta)):
                if (isvector(rho)):
                    rho=ravel(rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:229
                    r_nr=rows(rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:230
                    t_nr,t_nc=size(theta,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:231
                    if (r_nr != t_nr):
                        theta=theta.T
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:233
                        t_nr=copy(t_nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:234
                    if (r_nr != t_nr):
                        error('polar: THETA matrix and RHO vector sizes must match')
                    diag_r=diag(rho)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:239
                    x=dot(diag_r,cos(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:240
                    y=dot(diag_r,sin(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:241
                    retval=__plt__('polar',h,x,y,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:242
                else:
                    if (ismatrix(rho)):
                        if (logical_not(size_equal(rho,theta))):
                            error('polar: THETA and RHO matrix dimensions must match')
                        x=multiply(rho,cos(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:247
                        y=multiply(rho,sin(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:248
                        retval=__plt__('polar',h,x,y,fmt)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:249
                    else:
                        error('polar: invalid data for plotting')
            else:
                error('polar: invalid data for plotting')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Callback functions for listeners
    
    
@function
def __update_text__(hax=None,__=None,hg=None,prop=None,*args,**kwargs):
    varargin = __update_text__.varargin
    nargin = __update_text__.nargin

    kids=get(hg,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:263
    idx=strcmp(get(kids,'type'),'text')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:264
    set(kids[idx].T,prop,get(hax,prop))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __update_lines__(hax=None,__=None,hg=None,prop=None,*args,**kwargs):
    varargin = __update_lines__.varargin
    nargin = __update_lines__.nargin

    kids=get(hg,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:271
    idx=strcmp(get(kids,'type'),'line')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:272
    lprop=copy(prop)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:273
    if (strcmp(prop,'gridlinestyle')):
        lprop='linestyle'
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:275
    
    set(kids[idx].T,lprop,get(hax,prop))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __update_patch__(hax=None,__=None,hg=None,*args,**kwargs):
    varargin = __update_patch__.varargin
    nargin = __update_patch__.nargin

    kids=get(hg,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:283
    idx=strcmp(get(kids,'type'),'patch')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:284
    set(kids[idx].T,'facecolor',get(hax,'color'))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __update_layer__(hax=None,__=None,hg=None,*args,**kwargs):
    varargin = __update_layer__.varargin
    nargin = __update_layer__.nargin

    ## FIXME: This re-implements allchild() because setting the "children"
  ##        property needs to preserve all children (titles, xlabels, etc.).
    shh=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:293
    try:
        set(0,'showhiddenhandles','on')
        kids=get(hax,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:296
        if (strcmp(get(hax,'layer'),'bottom')):
            set(hax,'children',cat([kids[kids != hg]],[hg]))
        else:
            set(hax,'children',cat([hg],[kids[kids != hg]]))
    finally:
        set(0,'showhiddenhandles',shh)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __update_polar_grid__(hax=None,__=None,hg=None,*args,**kwargs):
    varargin = __update_polar_grid__.varargin
    nargin = __update_polar_grid__.nargin

    ## Delete existing polar grid
    delete(get(hg,'children'))
    rtick=unique(ravel(get(hax,'rtick')).T)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:312
    rtick=rtick[rtick > 0]
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:313
    if (isempty(rtick)):
        rtick=matlabarray(cat(0.5,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:315
    
    ttick=unique(ravel(get(hax,'ttick')).T)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:318
    ttick=ttick[ttick >= 0]
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:319
    if (isempty(ttick)):
        ttick=arange(0,330,30)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:321
    
    lprops=cellarray(['linestyle',get(hax,'gridlinestyle'),'linewidth',get(hax,'linewidth')])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:324
    
    tprops[1:2:12]=cellarray(['fontunits','fontangle','fontname','fontsize','fontweight','interpreter'])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:327
    tprops[2:2:12]=get(hax,tprops[1:2:12])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:329
    
    circle_points=50
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:332
    t=linspace(0,dot(2,pi),circle_points).T
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:333
    x=kron(cos(t),rtick)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:334
    y=kron(sin(t),rtick)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:335
    
    patch(x[:,end()],y[:,end()],- ones(circle_points,1),get(hax,'color'),'parent',hg)
    
    line(x[:,1:end() - 1],y[:,1:end() - 1],lprops[:],'parent',hg)
    
    line(x[:,end()],y[:,end()],lprops[:],'linestyle','-','parent',hg)
    
    x,y=pol2cart(dot(0.42,pi),rtick,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:348
    text(x,y,num2cell(rtick),'verticalalignment','bottom',tprops[:],'parent',hg)
    
    s=dot(rtick[end()],sin(dot(ttick,pi) / 180))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:353
    c=dot(rtick[end()],cos(dot(ttick,pi) / 180))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:354
    x=matlabarray(cat([zeros(1,numel(ttick))],[c]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:355
    y=matlabarray(cat([zeros(1,numel(ttick))],[s]))
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:356
    line(x,y,'linestyle',':',lprops[:],'parent',hg)
    
    tticklabel=num2cell(ttick)
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:360
    
    tm=1.08
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:362
    text(dot(tm,c),dot(tm,s),tticklabel,'horizontalalignment','center',tprops[:],'parent',hg)
    lim=dot(1.1,rtick[end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/polar.m:366
    set(hax,'xlim',cat(- lim,lim),'ylim',cat(- lim,lim))
    
    __update_layer__(hax,[],hg)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def resetaxis(__=None,__=None,hax=None,*args,**kwargs):
    varargin = resetaxis.varargin
    nargin = resetaxis.nargin

    if (isaxes(hax)):
        dellistener(hax,'rtick')
        dellistener(hax,'ttick')
        dellistener(hax,'color')
        dellistener(hax,'fontangle')
        dellistener(hax,'fontname')
        dellistener(hax,'fontsize')
        dellistener(hax,'fontunits')
        dellistener(hax,'fontweight')
        dellistener(hax,'interpreter')
        dellistener(hax,'layer')
        dellistener(hax,'gridlinestyle')
        dellistener(hax,'linewidth')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} triplot (@var{tri}, @var{x}, @var{y})
## @deftypefnx {Function File} {} triplot (@var{tri}, @var{x}, @var{y}, @var{linespec})
## @deftypefnx {Function File} {@var{h} =} triplot (@dots{})
## Plot a 2-D triangular mesh.
##
## @var{tri} is typically the output of a Delaunay triangulation over the
## grid of @var{x}, @var{y}.  Every row of @var{tri} represents one triangle
## and contains three indices into [@var{x}, @var{y}] which are the
## vertices of the triangles in the x-y plane.
##
## The linestyle to use for the plot can be defined with the argument
## @var{linespec} of the same format as the @code{plot} command.
##
## The optional return value @var{h} is a graphics handle to the created
## patch object.
## @seealso{plot, trimesh, trisurf, delaunay}
## @end deftypefn
    
    
@function
def triplot(tri=None,x=None,y=None,varargin=None,*args,**kwargs):
    varargin = triplot.varargin
    nargin = triplot.nargin

    if (nargin < 3):
        print_usage()
    
    idx=tri[:,cat(1,2,3,1)].T
# /home/lei/octave-4.0.2/scripts/plot/draw/triplot.m:44
    nt=rows(tri)
# /home/lei/octave-4.0.2/scripts/plot/draw/triplot.m:45
    handle=plot(ravel(cat([x[idx]],[NaN(1,nt)])),ravel(cat([y[idx]],[NaN(1,nt)])),varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/triplot.m:46
    if (nargout > 0):
        h=copy(handle)
# /home/lei/octave-4.0.2/scripts/plot/draw/triplot.m:50
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott and John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} comet3 (@var{z})
## @deftypefnx {Function File} {} comet3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} comet3 (@var{x}, @var{y}, @var{z}, @var{p})
## @deftypefnx {Function File} {} comet3 (@var{hax}, @dots{})
## Produce a simple comet style animation along the trajectory provided by
## the input coordinate vectors (@var{x}, @var{y}, @var{z}).
##
## If only @var{z} is specified then @var{x}, @var{y} default to the indices
## of @var{z}.
##
## The speed of the comet may be controlled by @var{p}, which represents the
## time each point is displayed before moving to the next one.  The default for
## @var{p} is 0.1 seconds.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
## @seealso{comet}
## @end deftypefn
    
    ## Author: jwe
## Created: 2010-12-17
    
    
@function
def comet3(varargin=None,*args,**kwargs):
    varargin = comet3.varargin
    nargin = comet3.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('comet3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:44
    if (nargin == 0 or nargin == 2 or nargin > 4):
        print_usage()
    else:
        if (nargin == 1):
            z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:49
            x=y=arange(1,numel(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:50
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:50
            p=0.1
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:51
        else:
            if (nargin == 3):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:53
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:54
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:55
                p=0.1
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:56
            else:
                if (nargin == 4):
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:58
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:59
                    z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:60
                    p=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:61
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:64
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:66
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:69
        limits=matlabarray(cat(min(x),max(x),min(y),max(y),min(z),max(z)))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:70
        num=numel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:71
        dn=round(num / 10)
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:72
        hl=plot3(x[1],y[1],z[1],'color','r','marker','none',x[1],y[1],z[1],'color','g','marker','none',x[1],y[1],z[1],'color','b','marker','o')
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:74
        axis(limits)
        for n in arange(2,(num + dn)).reshape(-1):
            m=n - dn
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:80
            m=max(cat(m,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:81
            k=min(cat(n,num))
# /home/lei/octave-4.0.2/scripts/plot/draw/comet3.m:82
            set(hl[1],'xdata',x[1:m],'ydata',y[1:m],'zdata',z[1:m])
            set(hl[2],'xdata',x[m:k],'ydata',y[m:k],'zdata',z[m:k])
            set(hl[3],'xdata',x[k],'ydata',y[k],'zdata',z[k])
            drawnow()
            pause(p)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} trimesh (@var{tri}, @var{x}, @var{y}, @var{z}, @var{c})
## @deftypefnx {Function File} {} trimesh (@var{tri}, @var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} trimesh (@var{tri}, @var{x}, @var{y})
## @deftypefnx {Function File} {} trimesh (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} trimesh (@dots{})
## Plot a 3-D triangular wireframe mesh.
##
## In contrast to @code{mesh}, which plots a mesh using rectangles,
## @code{trimesh} plots the mesh using triangles.
##
## @var{tri} is typically the output of a Delaunay triangulation over the
## grid of @var{x}, @var{y}.  Every row of @var{tri} represents one triangle
## and contains three indices into [@var{x}, @var{y}] which are the
## vertices of the triangles in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If no @var{z} input is given then
## the triangles are plotted as a 2-D figure.
##
## The color of the trimesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally, the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.  If @var{z} has N elements, then
## @var{c} should be an Nx1 vector for colormap data or an Nx3 matrix for
## RGB data.
##
## Any property/value pairs are passed directly to the underlying patch object.
##
## The optional return value @var{h} is a graphics handle to the created patch
## object.
## @seealso{mesh, tetramesh, triplot, trisurf, delaunay, patch, hidden}
## @end deftypefn
    
    
@function
def trimesh(tri=None,x=None,y=None,z=None,varargin=None,*args,**kwargs):
    varargin = trimesh.varargin
    nargin = trimesh.nargin

    if (nargin < 3):
        print_usage()
    
    if (nargin == 3):
        htmp=triplot(tri,x,y)
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:60
    else:
        if (ischar(z)):
            htmp=triplot(tri,x,y,z,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:62
        else:
            ## Process color argument
            if (nargin > 4 and isnumeric(varargin[1])):
                c=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:66
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:67
                if (isvector(c)):
                    if (numel(c) != numel(z)):
                        error('trimesh: C must have \'numel (Z)\' elements')
                    c=ravel(c)
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:72
                else:
                    if (rows(c) != numel(z) or columns(c) != 3):
                        error('trimesh: TrueColor C matrix must be \'numel (Z)\' rows by 3 columns')
            else:
                c=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:77
            hax=newplot()
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:80
            htmp=patch('Vertices',cat(ravel(x),ravel(y),ravel(z)),'Faces',tri,'FaceVertexCdata',c,'EdgeColor','flat','FaceColor','w','Tag','trimesh',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:83
            if (logical_not(ishold())):
                set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/trimesh.m:93
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{cd}] =} isocolors (@var{c}, @var{v})
## @deftypefnx {Function File} {[@var{cd}] =} isocolors (@var{x}, @var{y}, @var{z}, @var{c}, @var{v})
## @deftypefnx {Function File} {[@var{cd}] =} isocolors (@var{x}, @var{y}, @var{z}, @var{r}, @var{g}, @var{b}, @var{v})
## @deftypefnx {Function File} {[@var{cd}] =} isocolors (@var{r}, @var{g}, @var{b}, @var{v})
## @deftypefnx {Function File} {[@var{cd}] =} isocolors (@dots{}, @var{p})
## @deftypefnx {Function File} {} isocolors (@dots{})
##
## Compute isosurface colors.
##
## If called with one output argument and the first input argument
## @var{c} is a three-dimensional array that contains color values and
## the second input argument @var{v} keeps the vertices of a geometry
## then return a matrix @var{cd} with color data information for the
## geometry at computed points
## @command{[x, y, z] = meshgrid (1:l, 1:m, 1:n)}.  The output argument
## @var{cd} can be taken to manually set FaceVertexCData of a patch.
##
## If called with further input arguments @var{x}, @var{y} and @var{z}
## which are three--dimensional arrays of the same size than @var{c}
## then the color data is taken at those given points.  Instead of the
## color data @var{c} this function can also be called with RGB values
## @var{r}, @var{g}, @var{b}.  If input argumnets @var{x}, @var{y},
## @var{z} are not given then again @command{meshgrid} computed values
## are taken.
##
## Optionally, the patch handle @var{p} can be given as the last input
## argument to all variations of function calls instead of the vertices
## data @var{v}.  Finally, if no output argument is given then directly
## change the colors of a patch that is given by the patch handle
## @var{p}.
##
## For example:
##
## @example
## function [] = isofinish (p)
##   set (gca, "PlotBoxAspectRatioMode", "manual", ...
##             "PlotBoxAspectRatio", [1 1 1]);
##   set (p, "FaceColor", "interp");
##   ## set (p, "FaceLighting", "flat");
##   ## light ("Position", [1 1 5]);  # Available with JHandles
## endfunction
##
## N = 15;    # Increase number of vertices in each direction
## iso = .4;  # Change isovalue to .1 to display a sphere
## lin = linspace (0, 2, N);
## [x, y, z] = meshgrid (lin, lin, lin);
## c = abs ((x-.5).^2 + (y-.5).^2 + (z-.5).^2);
## figure (); # Open another figure window
##
## subplot (2,2,1); view (-38, 20);
## [f, v] = isosurface (x, y, z, c, iso);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "none");
## cdat = rand (size (c));       # Compute random patch color data
## isocolors (x, y, z, cdat, p); # Directly set colors of patch
## isofinish (p);                # Call user function isofinish
##
## subplot (2,2,2); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "none");
## [r, g, b] = meshgrid (lin, 2-lin, 2-lin);
## cdat = isocolors (x, y, z, c, v); # Compute color data vertices
## set (p, "FaceVertexCData", cdat); # Set color data manually
## isofinish (p);
##
## subplot (2,2,3); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "none");
## cdat = isocolors (r, g, b, c, p); # Compute color data patch
## set (p, "FaceVertexCData", cdat); # Set color data manually
## isofinish (p);
##
## subplot (2,2,4); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "none");
## r = g = b = repmat ([1:N] / N, [N, 1, N]); # Black to white
## cdat = isocolors (x, y, z, r, g, b, v);
## set (p, "FaceVertexCData", cdat);
## isofinish (p);
## @end example
##
## @seealso{isosurface, isonormals}
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def isocolors(varargin=None,*args,**kwargs):
    varargin = isocolors.varargin
    nargin = isocolors.nargin

    calc_rgb=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:103
    if 2 == (nargin):
        c=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:106
        vp=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:107
        x=arange(1,size(c,2))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:108
        y=arange(1,size(c,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:109
        z=arange(1,size(c,3))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:110
    else:
        if 4 == (nargin):
            calc_rgb=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:112
            R=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:113
            G=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:114
            B=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:115
            vp=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:116
            x=arange(1,size(R,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:117
            y=arange(1,size(R,2))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:118
            z=arange(1,size(R,3))
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:119
        else:
            if 5 == (nargin):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:121
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:122
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:123
                c=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:124
                vp=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:125
            else:
                if 7 == (nargin):
                    calc_rgb=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:127
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:128
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:129
                    z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:130
                    R=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:131
                    G=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:132
                    B=varargin[6]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:133
                    vp=varargin[7]
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:134
                else:
                    print_usage()
    
    if (isnumeric(vp) and columns(vp) == 3):
        pa=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:139
        v=copy(vp)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:140
    else:
        if (ishandle(vp)):
            pa=copy(vp)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:142
            v=get(pa,'Vertices')
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:143
        else:
            error('isocolors: last argument is not a vertex list or patch handle')
    
    if (calc_rgb):
        new_col=zeros(rows(v),3)
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:148
        new_col[:,1]=__interp_cube__(x,y,z,R,v,'values')
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:149
        new_col[:,2]=__interp_cube__(x,y,z,G,v,'values')
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:150
        new_col[:,3]=__interp_cube__(x,y,z,B,v,'values')
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:151
    else:
        new_col=__interp_cube__(x,y,z,c,v,'values')
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:153
    
    if 0 == (nargout):
        if (logical_not(isempty(pa))):
            set(pa,'FaceVertexCData',new_col)
    else:
        if 1 == (nargout):
            varargout=cellarray([new_col])
# /home/lei/octave-4.0.2/scripts/plot/draw/isocolors.m:161
        else:
            print_usage()
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Can't create a patch handle for tests without a figure
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} patch ()
## @deftypefnx {Function File} {} patch (@var{x}, @var{y}, @var{c})
## @deftypefnx {Function File} {} patch (@var{x}, @var{y}, @var{z}, @var{c})
## @deftypefnx {Function File} {} patch (@var{fv})
## @deftypefnx {Function File} {} patch ("Faces", @var{faces}, "Vertices", @var{verts}, @dots{})
## @deftypefnx {Function File} {} patch (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} patch (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} patch (@dots{})
## Create patch object in the current axes with vertices at locations
## (@var{x}, @var{y}) and of color @var{c}.
##
## If the vertices are matrices of size @nospell{MxN} then each polygon patch
## has M vertices and a total of N polygons will be created.  If some polygons
## do not have M vertices use NaN to represent "no vertex".  If the @var{z}
## input is present then 3-D patches will be created.
##
## The color argument @var{c} can take many forms.  To create polygons
## which all share a single color use a string value (e.g., @qcode{"r"} for
## red), a scalar value which is scaled by @code{caxis} and indexed into the
## current colormap, or a 3-element RGB vector with the precise TrueColor.
##
## If @var{c} is a vector of length N then the ith polygon will have a color
## determined by scaling entry @var{c}(i) according to @code{caxis} and then
## indexing into the current colormap.  More complicated coloring situations
## require directly manipulating patch property/value pairs.
##
## Instead of specifying polygons by matrices @var{x} and @var{y}, it is
## possible to present a unique list of vertices and then a list of polygon
## faces created from those vertices.  In this case the
## @qcode{"Vertices"} matrix will be an @nospell{Nx2} (2-D patch) or
## @nospell{Nx3} (3-D patch).  The @nospell{MxN} @qcode{"Faces"} matrix
## describes M polygons having N vertices---each row describes a
## single polygon and each column entry is an index into the
## @qcode{"Vertices"} matrix to identify a vertex.  The patch object
## can be created by directly passing the property/value pairs
## @qcode{"Vertices"}/@var{verts}, @qcode{"Faces"}/@var{faces} as
## inputs.
##
## A third input form is to create a structure @var{fv} with the fields
## @qcode{"vertices"}, @qcode{"faces"}, and optionally
## @qcode{"facevertexcdata"}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created patch
## object.
##
## Implementation Note: Patches are highly configurable objects.  To truly
## customize them requires setting patch properties directly.  Useful patch
## properties are: @qcode{"cdata"}, @qcode{"edgecolor"},
## @qcode{"facecolor"}, @qcode{"faces"}, @qcode{"facevertexcdata"}.
## @seealso{fill, get, set}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def patch(varargin=None,*args,**kwargs):
    varargin = patch.varargin
    nargin = patch.nargin

    hax,varargin=__plt_get_axis_arg__('patch',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/patch.m:79
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/patch.m:82
    else:
        hax=hax[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/patch.m:84
    
    htmp,failed=__patch__(hax,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/patch.m:87
    if (failed):
        print_usage()
    
    ## FIXME: This is a hack to get 'layer' command to work for 2D patches
  ##        Alternative is much more complicated surgery in graphics.cc.
  ##        of get_children_limits() for 'z' axis and 'patch' object type.
    if (logical_not(ishold())):
        if (isempty(get(htmp,'zdata'))):
            set(hax,'zlim',cat(- 1,1))
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/patch.m:103
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} colorbar
## @deftypefnx {Function File} {} colorbar (@var{loc})
## @deftypefnx {Function File} {} colorbar (@var{delete_option})
## @deftypefnx {Function File} {} colorbar (@var{hcb}, @dots{})
## @deftypefnx {Function File} {} colorbar (@var{hax}, @dots{})
## @deftypefnx {Function File} {} colorbar (@dots{}, "peer", @var{hax}, @dots{})
## @deftypefnx {Function File} {} colorbar (@dots{}, "location", @var{loc}, @dots{})
## @deftypefnx {Function File} {} colorbar (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} colorbar (@dots{})
## Add a colorbar to the current axes.
##
## A colorbar displays the current colormap along with numerical rulings
## so that the color scale can be interpreted.
##
## The optional input @var{loc} determines the location of the colorbar.
## Valid values for @var{loc} are
##
## @table @asis
## @item @qcode{"EastOutside"}
## Place the colorbar outside the plot to the right.  This is the default.
##
## @item @qcode{"East"}
## Place the colorbar inside the plot to the right.
##
## @item @qcode{"WestOutside"}
## Place the colorbar outside the plot to the left.
##
## @item @qcode{"West"}
## Place the colorbar inside the plot to the left.
##
## @item @qcode{"NorthOutside"}
## Place the colorbar above the plot.
##
## @item @qcode{"North"}
## Place the colorbar at the top of the plot.
##
## @item @qcode{"SouthOutside"}
## Place the colorbar under the plot.
##
## @item @qcode{"South"}
## Place the colorbar at the bottom of the plot.
## @end table
##
## To remove a colorbar from a plot use any one of the following keywords for
## the @var{delete_option}: @qcode{"delete"}, @qcode{"hide"}, @qcode{"off"}.
##
## If the argument @qcode{"peer"} is given, then the following argument is
## treated as the axes handle in which to add the colorbar.  Alternatively,
## If the first argument @var{hax} is an axes handle, then the colorbar is
## added to this axis, rather than the current axes returned by @code{gca}.
##
## If the first argument @var{hcb} is a handle to a colorbar object, then
## operate on this colorbar directly.
##
## Additional property/value pairs are passed directly to the underlying axes
## object.
##
## The optional return value @var{h} is a graphics handle to the created
## colorbar object.
##
## Implementation Note: A colorbar is created as an additional axes to the
## current figure with the @qcode{"tag"} property set to @qcode{"colorbar"}.
## The created axes object has the extra property @qcode{"location"} which
## controls the positioning of the colorbar.
## @seealso{colormap}
## @end deftypefn
    
    
@function
def colorbar(varargin=None,*args,**kwargs):
    varargin = colorbar.varargin
    nargin = colorbar.nargin

    hcb,varargin,nargin=__plt_get_axis_arg__('colorbar',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:89
    if (hcb and logical_not(strcmp(get(hcb,'tag'),'colorbar'))):
        ax=copy(hcb)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:92
        hcb=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:93
    else:
        ax=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:95
    
    loc=''
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:97
    args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:98
    deleting=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:99
    i=1
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:101
    while (i <= nargin):

        arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:103
        if (ischar(arg)):
            if 'peer' == (tolower(arg)):
                if (i > nargin):
                    error('colorbar: missing axes handle after "peer"')
                else:
                    ax=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:110
                    if (logical_not(isscalar(ax)) and logical_not(isaxes(ax))):
                        error('colorbar: expecting an axes handle following "peer"')
            else:
                if cellarray(['north','south','east','west','northoutside','southoutside','eastoutside','westoutside']) == (tolower(arg)):
                    loc=tolower(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:117
                else:
                    if 'location' == (tolower(arg)):
                        if (i > nargin):
                            error('colorbar: missing value after "location"')
                        else:
                            loc=tolower(varargin[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:122
                    else:
                        if cellarray(['delete','hide','off','none']) == (tolower(arg)):
                            deleting=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:125
                        else:
                            args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:127
        else:
            args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:130

    
    ## Handle changes to existing colorbar
    if (logical_not(isempty(hcb))):
        if (deleting):
            delete(hcb)
            if (nargout > 0):
                h=copy(hcb)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:139
            return h
        else:
            ## FIXME: No listener on location property so have to re-create
      ##        colorbar whenever an option changes.
      ##        re-instate this code if listener is developed.
      ## if (! isempty (loc))
      ##   set (hcb, "location", loc);
      ## endif
      ## if (! isempty (args))
      ##   set (hcb, args{:});
      ## endif
            ax=get(ancestor(hcb,'figure'),'currrentaxes')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:152
    
    if (isempty(loc)):
        loc='eastoutside'
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:157
    
    if (isempty(ax)):
        ax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:160
    
    showhiddenhandles=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:163
    try:
        set(0,'showhiddenhandles','on')
        cax=findobj(ancestor(ax,'figure'),'tag','colorbar','type','axes','axes',ax)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:166
        if (logical_not(isempty(cax))):
            delete(cax)
    finally:
        set(0,'showhiddenhandles',showhiddenhandles)
    
    if (logical_not(deleting)):
        ## FIXME: Matlab does not require the "position" property to be active.
    ##        Is there a way to determine the plotbox position for the
    ##        gnuplot graphics toolkit with the outerposition is active?
        set(ax,'activepositionproperty','position')
        obj=get(ax)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:180
        obj.__cbar_hax__ = copy(ax)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:181
        position=obj.position
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:182
        hpar=ancestor(ax,'figure')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:184
        clen=rows(get(hpar,'colormap'))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:185
        cext=get(ax,'clim')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:186
        cdiff=(cext[2] - cext[1]) / clen / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:187
        cmin=cext[1] + cdiff
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:188
        cmax=cext[2] - cdiff
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:189
        pos,cpos,vertical,mirror=__position_colorbox__(loc,obj,ancestor(ax,'figure'),nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:191
        set(ax,'position',pos)
        cax=__go_axes__(hpar,'tag','colorbar','handlevisibility','on','activepositionproperty','position','position',cpos)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:195
        addproperty('location',cax,'radio','eastoutside|east|westoutside|west|northoutside|north|southoutside|south',loc)
        addproperty('axes',cax,'handle',ax)
        if (vertical):
            ## Use low-level form to avoid calling newplot which changes axes
            hi=image(cax,'xdata',cat(0,1),'ydata',cat(cmin,cmax),'cdata',cat(arange(1,clen)).T)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:206
            if (mirror):
                set(cax,'xtick',[],'xdir','normal','ydir','normal','ylim',cext,'ylimmode','manual','yaxislocation','right','layer','top',args[:])
            else:
                set(cax,'xtick',[],'xdir','normal','ydir','normal','ylim',cext,'ylimmode','manual','yaxislocation','left','layer','top',args[:])
        else:
            hi=image(cax,'xdata',cat(cmin,cmax),'ydata',cat(0,1),'cdata',cat(arange(1,clen)))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:218
            if (mirror):
                set(cax,'ytick',[],'xdir','normal','ydir','normal','xlim',cext,'xlimmode','manual','xaxislocation','top','layer','top',args[:])
            else:
                set(cax,'ytick',[],'xdir','normal','ydir','normal','xlim',cext,'xlimmode','manual','xaxislocation','bottom','layer','top',args[:])
        ## Dummy object placed in axis to delete colorbar when axis is deleted.
        ctext=text(0,0,'','tag','colorbar','visible','off','handlevisibility','off','xliminclude','off','yliminclude','off','zliminclude','off','deletefcn',cellarray([deletecolorbar,cax,obj]))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:232
        set(cax,'deletefcn',cellarray([resetaxis,ax,obj]))
        addlistener(hpar,'colormap',cellarray([update_colorbar_cmap,hi,vertical,clen]))
        addlistener(ax,'clim',cellarray([update_colorbar_clim,hi,vertical]))
        addlistener(ax,'dataaspectratio',cellarray([update_colorbar_axis,cax,obj]))
        addlistener(ax,'dataaspectratiomode',cellarray([update_colorbar_axis,cax,obj]))
        addlistener(ax,'plotboxaspectratio',cellarray([update_colorbar_axis,cax,obj]))
        addlistener(ax,'plotboxaspectratiomode',cellarray([update_colorbar_axis,cax,obj]))
        addlistener(ax,'position',cellarray([update_colorbar_axis,cax,obj]))
    
    if (nargout > 0):
        h=copy(cax)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:251
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def deletecolorbar(h=None,d=None,hc=None,orig_props=None,*args,**kwargs):
    varargin = deletecolorbar.varargin
    nargin = deletecolorbar.nargin

    ## Don't delete the colorbar and reset the axis size if the
  ## parent figure is being deleted.
    if (isaxes(hc) and (isempty(gcbf()) or strcmp(get(gcbf(),'beingdeleted'),'off'))):
        if (strcmp(get(hc,'beingdeleted'),'off')):
            delete(hc)
        if (logical_not(isempty(ancestor(h,'axes'))) and strcmp(get(ancestor(h,'axes'),'beingdeleted'),'off')):
            ax=ancestor(h,'axes')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:266
            units=get(ax,'units')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:267
            set(ax,'units',orig_props.units)
            set(ancestor(h,'axes'),'position',orig_props.position,'outerposition',orig_props.outerposition,'activepositionproperty',orig_props.activepositionproperty)
            set(ax,'units',units)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def resetaxis(cax=None,d=None,ax=None,orig_props=None,*args,**kwargs):
    varargin = resetaxis.varargin
    nargin = resetaxis.nargin

    if (isaxes(ax)):
        ## FIXME: Probably don't want to delete everyone's listeners on colormap.
        dellistener(ancestor(ax,'figure'),'colormap')
        dellistener(ax,'clim')
        dellistener(ax,'dataaspectratio')
        dellistener(ax,'dataaspectratiomode')
        dellistener(ax,'plotboxaspectratio')
        dellistener(ax,'plotboxaspectratiomode')
        dellistener(ax,'position')
        units=get(ax,'units')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:288
        set(ax,'units',orig_props.units)
        set(ax,'position',orig_props.position,'outerposition',orig_props.outerposition,'activepositionproperty',orig_props.activepositionproperty)
        set(ax,'units',units)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_colorbar_clim(hax=None,d=None,hi=None,vert=None,*args,**kwargs):
    varargin = update_colorbar_clim.varargin
    nargin = update_colorbar_clim.nargin

    if (isaxes(hax) and (isempty(gcbf()) or strcmp(get(gcbf(),'beingdeleted'),'off'))):
        clen=rows(get(ancestor(hax,'figure'),'colormap'))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:300
        cext=get(hax,'clim')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:301
        cdiff=(cext[2] - cext[1]) / clen / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:302
        cmin=cext[1] + cdiff
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:303
        cmax=cext[2] - cdiff
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:304
        hiax=get(hi,'parent')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:306
        if (vert):
            set(hi,'ydata',cat(cmin,cmax))
            set(hiax,'ylim',cext)
        else:
            set(hi,'xdata',cat(cmin,cmax))
            set(hiax,'xlim',cext)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_colorbar_cmap(hf=None,d=None,hi=None,vert=None,init_sz=None,*args,**kwargs):
    varargin = update_colorbar_cmap.varargin
    nargin = update_colorbar_cmap.nargin

    
    if (ishandle(hf) and strcmp(get(hf,'type'),'figure') and (isempty(gcbf()) or strcmp(get(gcbf(),'beingdeleted'),'off'))):
        clen=rows(get(hf,'colormap'))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:322
        if (clen != sz):
            if (vert):
                set(hi,'cdata',cat(arange(1,clen)).T)
            else:
                set(hi,'cdata',cat(arange(1,clen)))
            sz=copy(clen)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:329
            update_colorbar_clim(get(hi,'parent'),d,hi,vert)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_colorbar_axis(h=None,d=None,cax=None,orig_props=None,*args,**kwargs):
    varargin = update_colorbar_axis.varargin
    nargin = update_colorbar_axis.nargin

    if (isaxes(cax) and (isempty(gcbf()) or strcmp(get(gcbf(),'beingdeleted'),'off'))):
        loc=get(cax,'location')
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:339
        obj=get(h)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:340
        obj.__cbar_hax__ = copy(h)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:341
        obj.position = copy(orig_props.position)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:342
        obj.outerposition = copy(orig_props.outerposition)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:343
        pos,cpos,vertical,mirror=__position_colorbox__(loc,obj,ancestor(h,'figure'),nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:344
        if (vertical):
            if (mirror):
                set(cax,'xtick',[],'xdir','normal','ydir','normal','yaxislocation','right','position',cpos)
            else:
                set(cax,'xtick',[],'xdir','normal','ydir','normal','yaxislocation','left','position',cpos)
        else:
            if (mirror):
                set(cax,'ytick',[],'xdir','normal','ydir','normal','xaxislocation','top','position',cpos)
            else:
                set(cax,'ytick',[],'xdir','normal','ydir','normal','xaxislocation','bottom','position',cpos)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __position_colorbox__(cbox=None,obj=None,cf=None,*args,**kwargs):
    varargin = __position_colorbox__.varargin
    nargin = __position_colorbox__.nargin

    ## This will always represent the position prior to adding the colorbar.
    pos=obj.position
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:371
    sz=pos[3:4]
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:372
    if (strcmp(obj.plotboxaspectratiomode,'manual') or strcmp(obj.dataaspectratiomode,'manual')):
        if (isempty(strfind(cbox,'outside'))):
            scale=1.0
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:377
        else:
            scale=0.8
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:379
        if (isempty(strfind(cbox,'east')) and isempty(strfind(cbox,'west'))):
            scale=matlabarray(cat(1,scale))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:382
        else:
            scale=matlabarray(cat(scale,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:384
        if (strcmp(get(cf,'__graphics_toolkit__'),'gnuplot') and strcmp(obj.activepositionproperty,'outerposition')):
            obj.outerposition = copy(multiply(obj.outerposition,cat(1,1,scale)))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:388
            off=dot(0.5,(obj.outerposition(arange(3,4)) - __actual_axis_position__(obj)(arange(3,4))))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:389
        else:
            obj.position = copy(multiply(obj.position,cat(1,1,scale)))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:391
            off=dot(0.5,(obj.position(arange(3,4)) - __actual_axis_position__(obj)(arange(3,4))))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:392
    else:
        off=0.0
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:395
    
    if 'northoutside' == (cbox):
        origin=pos[1:2] + multiply(cat(0.0,0.9),sz) + multiply(cat(1,- 1),off)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:400
        sz=multiply(sz,cat(1.0,0.06))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:401
        pos[4]=dot(0.8,pos[4])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:402
        mirr=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:403
        vertical=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:404
    else:
        if 'north' == (cbox):
            origin=pos[1:2] + multiply(cat(0.05,0.9),sz) + multiply(cat(1,- 1),off)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:406
            sz=dot(multiply(sz,cat(1.0,0.06)),0.9)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:407
            mirr=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:408
            vertical=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:409
        else:
            if 'southoutside' == (cbox):
                origin=pos[1:2] + off
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:411
                sz=multiply(sz,cat(1.0,0.06))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:412
                pos[2]=pos[2] + dot(pos[4],0.2)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:413
                pos[4]=dot(0.8,pos[4])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:414
                mirr=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:415
                vertical=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:416
            else:
                if 'south' == (cbox):
                    origin=pos[1:2] + multiply(cat(0.05,0.05),sz) + off
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:418
                    sz=dot(multiply(sz,cat(1.0,0.06)),0.9)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:419
                    mirr=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:420
                    vertical=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:421
                else:
                    if 'eastoutside' == (cbox):
                        origin=pos[1:2] + multiply(cat(0.9,0),sz) + multiply(cat(- 1,1),off)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:423
                        sz=multiply(sz,cat(0.06,1.0))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:424
                        pos[3]=dot(0.8,pos[3])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:425
                        mirr=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:426
                        vertical=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:427
                    else:
                        if 'east' == (cbox):
                            origin=pos[1:2] + multiply(cat(0.9,0.05),sz) + multiply(cat(- 1,1),off)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:429
                            sz=dot(multiply(sz,cat(0.06,1.0)),0.9)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:430
                            mirr=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:431
                            vertical=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:432
                        else:
                            if 'westoutside' == (cbox):
                                origin=pos[1:2] + off
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:434
                                sz=multiply(sz,cat(0.06,1.0))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:435
                                pos[1]=pos[1] + dot(pos[3],0.2)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:436
                                pos[3]=dot(0.8,pos[3])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:437
                                mirr=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:438
                                vertical=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:439
                            else:
                                if 'west' == (cbox):
                                    origin=pos[1:2] + multiply(cat(0.05,0.05),sz) + off
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:441
                                    sz=multiply(multiply(sz,cat(0.06,1.0)),0.9)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:442
                                    mirr=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:443
                                    vertical=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:444
    
    cpos=matlabarray(cat(origin,sz))
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:447
    if (strcmp(obj.plotboxaspectratiomode,'manual') or strcmp(obj.dataaspectratiomode,'manual')):
        obj.position = copy(pos)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:451
        actual_pos=__actual_axis_position__(obj)
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:452
        if (strfind(cbox,'outside')):
            scale=1.0
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:454
        else:
            scale=0.9
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:456
        if (sz[1] > sz[2]):
            ## Ensure north or south colorbars are the proper length
            dx=dot((1 - scale),actual_pos[3])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:460
            cpos[1]=actual_pos[1] + dx / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:461
            cpos[3]=actual_pos[3] - dx
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:462
        else:
            ## Ensure east or west colorbars are the proper height
            dy=dot((1 - scale),actual_pos[4])
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:465
            cpos[2]=actual_pos[2] + dy / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:466
            cpos[4]=actual_pos[4] - dy
# /home/lei/octave-4.0.2/scripts/plot/draw/colorbar.m:467
    
    return pos,cpos,vertical,mirr
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## This requires that the axes position be properly determined for 'axis equal'
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##! axes ('color','none','box','on','activepositionproperty','position');
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pie (@var{x})
## @deftypefnx {Function File} {} pie (@dots{}, @var{explode})
## @deftypefnx {Function File} {} pie (@dots{}, @var{labels})
## @deftypefnx {Function File} {} pie (@var{hax}, @dots{});
## @deftypefnx {Function File} {@var{h} =} pie (@dots{});
## Plot a 2-D pie chart.
##
## When called with a single vector argument, produce a pie chart of the
## elements in @var{x}.  The size of the ith slice is the percentage that the
## element @var{x}i represents of the total sum of @var{x}:
## @code{pct = @var{x}(i) / sum (@var{x})}.
##
## The optional input @var{explode} is a vector of the same length as @var{x}
## that, if nonzero, "explodes" the slice from the pie chart.
##
## The optional input @var{labels} is a cell array of strings of the same
## length as @var{x} specifying the label for each slice.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a list of handles to the patch
## and text objects generating the plot.
##
## Note: If @code{sum (@var{x}) @leq{} 1} then the elements of @var{x} are
## interpreted as percentages directly and are not normalized by @code{sum (x)}.
## Furthermore, if the sum is less than 1 then there will be a missing slice
## in the pie plot to represent the missing, unspecified percentage.
##
## @seealso{pie3, bar, hist, rose}
## @end deftypefn
    
    ## Very roughly based on pie.m from octave-forge whose author was
## Daniel Heiserer <Daniel.heiserer@physik.tu-muenchen.de>
    
    
@function
def pie(varargin=None,*args,**kwargs):
    varargin = pie.varargin
    nargin = pie.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('pie',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:57
    if (nargin < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:63
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:65
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:68
        htmp=__pie__('pie',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:69
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie.m:77
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} peaks ()
## @deftypefnx {Function File} {} peaks (@var{n})
## @deftypefnx {Function File} {} peaks (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{z} =} peaks (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} peaks (@dots{})
## Plot a function with lots of local maxima and minima.
##
## The function has the form
##
## @tex
## $$f(x,y) = 3 (1 - x) ^ 2 e ^ {\left(-x^2 - (y+1)^2\right)} - 10 \left({x \over 5} - x^3 - y^5\right) - {1 \over 3} e^{\left(-(x+1)^2 - y^2\right)}$$
## @end tex
## @ifnottex
## @verbatim
## f(x,y) = 3*(1-x)^2*exp(-x^2 - (y+1)^2) ...
##          - 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2) ...
##          - 1/3*exp(-(x+1)^2 - y^2)
## @end verbatim
## @end ifnottex
##
## Called without a return argument, @code{peaks} plots the surface of the
## above function using @code{surf}.
##
## If @var{n} is a scalar, @code{peaks} plots the value of the above
## function on an @var{n}-by-@var{n} mesh over the range [-3,3].  The
## default value for @var{n} is 49.
##
## If @var{n} is a vector, then it represents the grid values over which
## to calculate the function.  If @var{x} and @var{y} are specified then
## the function value is calculated over the specified grid of vertices.
##
## When called with output arguments, return the data for the function
## evaluated over the meshgrid.  This can subsequently be plotted with
## @code{surf (@var{x}, @var{y}, @var{z})}.
##
## @seealso{sombrero, meshgrid, mesh, surf}
## @end deftypefn
    
    ## Expression for the peaks function was taken from the following paper:
## http://www.control.hut.fi/Kurssit/AS-74.115/Material/GENALGgoga.pdf
    
    
@function
def peaks(x=None,y=None,*args,**kwargs):
    varargin = peaks.varargin
    nargin = peaks.nargin

    if (nargin == 0):
        x=y=linspace(- 3,3,49)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:64
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:64
    else:
        if (nargin == 1):
            if (length(x) > 1):
                y=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:67
            else:
                x=y=linspace(- 3,3,x)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:69
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:69
    
    if (isvector(x) and isvector(y)):
        X,Y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:74
    else:
        X=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:76
        Y=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:77
    
    Z=multiply(dot(3,(1 - X) ** 2),exp(- X ** 2 - (Y + 1) ** 2)) - multiply(dot(10,(X / 5 - X ** 3 - Y ** 5)),exp(- X ** 2 - Y ** 2)) - dot(1 / 3,exp(- (X + 1) ** 2 - Y ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:80
    if (nargout == 0):
        surf(x,y,Z)
        Z_max=max(ravel(Z))
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:86
        Z_min=min(ravel(Z))
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:87
        axis(cat(- 3,3,- 3,3,Z_min,Z_max))
    else:
        if (nargout == 1):
            X_out=copy(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:90
        else:
            X_out=copy(X)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:92
            Y_out=copy(Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:93
            Z_out=copy(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/peaks.m:94
    
    return X_out,Y_out,Z_out
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2006-2015 Michel D. Schmid
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} stem (@var{y})
## @deftypefnx {Function File} {} stem (@var{x}, @var{y})
## @deftypefnx {Function File} {} stem (@dots{}, @var{linespec})
## @deftypefnx {Function File} {} stem (@dots{}, "filled")
## @deftypefnx {Function File} {} stem (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} stem (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} stem (@dots{})
## Plot a 2-D stem graph.
##
## If only one argument is given, it is taken as the y-values and the
## x-coordinates are taken from the indices of the elements.
##
## If @var{y} is a matrix, then each column of the matrix is plotted as
## a separate stem graph.  In this case @var{x} can either be a vector,
## the same length as the number of rows in @var{y}, or it can be a
## matrix of the same size as @var{y}.
##
## The default color is @qcode{"b"} (blue), the default line style is
## @qcode{"-"}, and the default marker is @qcode{"o"}.  The line style can
## be altered by the @code{linespec} argument in the same manner as the
## @code{plot} command.  If the @qcode{"filled"} argument is present the
## markers at the top of the stems will be filled in.  For example,
##
## @example
## @group
## x = 1:10;
## y = 2*x;
## stem (x, y, "r");
## @end group
## @end example
##
## @noindent
## plots 10 stems with heights from 2 to 20 in red;
##
## Optional property/value pairs may be specified to control the appearance
## of the plot.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a handle to a @nospell{"stem series"}
## hggroup.  The single hggroup handle has all of the graphical elements
## comprising the plot as its children; This allows the properties of
## multiple graphics objects to be changed by modifying just a single
## property of the @nospell{"stem series"} hggroup.
##
## For example,
##
## @example
## @group
## x = [0:10]';
## y = [sin(x), cos(x)]
## h = stem (x, y);
## set (h(2), "color", "g");
## set (h(1), "basevalue", -1)
## @end group
## @end example
##
## @noindent
## changes the color of the second @nospell{"stem series"} and moves the base
## line of the first.
##
## Stem Series Properties
##
## @table @asis
## @item linestyle
## The linestyle of the stem.  (Default: @qcode{"-"})
##
## @item linewidth
## The width of the stem.  (Default: 0.5)
##
## @item color
## The color of the stem, and if not separately specified, the marker.
## (Default: @qcode{"b"} [blue])
##
## @item marker
## The marker symbol to use at the top of each stem.  (Default: @qcode{"o"})
##
## @item markeredgecolor
## The edge color of the marker.  (Default: @qcode{"color"} property)
##
## @item markerfacecolor
## The color to use for @nospell{"filling"} the marker.
## (Default: @qcode{"none"} [unfilled])
##
## @item markersize
## The size of the marker.  (Default: 6)
##
## @item baseline
## The handle of the line object which implements the baseline.  Use @code{set}
## with the returned handle to change graphic properties of the baseline.
##
## @item basevalue
## The y-value where the baseline is drawn.  (Default: 0)
## @end table
## @seealso{stem3, bar, hist, plot, stairs}
## @end deftypefn
    
    ## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
## Adapted-by: jwe
    
    
@function
def stem(varargin=None,*args,**kwargs):
    varargin = stem.varargin
    nargin = stem.nargin

    if (nargin < 1):
        print_usage()
    
    htmp=__stem__(false,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/stem.m:127
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/stem.m:130
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} surfc (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} surfc (@var{z})
## @deftypefnx {Function File} {} surfc (@dots{}, @var{c})
## @deftypefnx {Function File} {} surfc (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} surfc (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} surfc (@dots{})
## Plot a 3-D surface mesh with underlying contour lines.
##
## The surface mesh is plotted using shaded rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the surface is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally, the color of the surface can be specified independently of
## @var{z} by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Note: The exact appearance of the surface can be controlled with the
## @code{shading} command or by using @code{set} to control surface object
## properties.
## @seealso{ezsurfc, surf, surfl, surfnorm, trisurf, contour, mesh, surface, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    
@function
def surfc(varargin=None,*args,**kwargs):
    varargin = surfc.varargin
    nargin = surfc.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('surfc',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:61
    if (nargin < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:67
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:69
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:72
        surfc_props=cellarray(['facecolor','flat'])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:74
        chararg=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:75
        if (isempty(chararg)):
            htmp=surface(varargin[:],surfc_props[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:77
        else:
            htmp=surface(varargin[1:chararg - 1],surfc_props[:],varargin[chararg:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:79
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on','xlimmode','manual','ylimmode','manual')
        drawnow()
        stop_idx=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:92
        if (isempty(stop_idx)):
            stop_idx=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:94
        else:
            stop_idx
        if (stop_idx - 1 == 1 or stop_idx - 1 == 3):
            ## Don't pass a color matrix c to __contour__
            stop_idx -= 1
        zmin=get(hax,'zlim')(1)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:104
        __,htmp2=__contour__(hax,zmin,varargin[1:stop_idx],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:105
        htmp=matlabarray(cat([htmp],[htmp2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:107
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfc.m:116
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
## Copyright (C) 2003 Alberto Terruzzi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pareto (@var{y})
## @deftypefnx {Function File} {} pareto (@var{y}, @var{x})
## @deftypefnx {Function File} {} pareto (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} pareto (@dots{})
## Draw a Pareto chart.
##
## A Pareto chart is a bar graph that arranges information in such a way
## that priorities for process improvement can be established; It organizes
## and displays information to show the relative importance of data.  The chart
## is similar to the histogram or bar chart, except that the bars are arranged
## in decreasing magnitude from left to right along the x-axis.
##
## The fundamental idea (Pareto principle) behind the use of Pareto
## diagrams is that the majority of an effect is due to a small subset of the
## causes.  For quality improvement, the first few contributing causes
## (leftmost bars as presented on the diagram) to a problem usually account for
## the majority of the result.  Thus, targeting these "major causes" for
## elimination results in the most cost-effective improvement scheme.
##
## Typically only the magnitude data @var{y} is present in which case
## @var{x} is taken to be the range @code{1 : length (@var{y})}.  If @var{x}
## is given it may be a string array, a cell array of strings, or a numerical
## vector.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a 2-element vector with a graphics
## handle for the created bar plot and a second handle for the created line
## plot.
##
## An example of the use of @code{pareto} is
##
## @example
## @group
## Cheese = @{"Cheddar", "Swiss", "Camembert", ...
##           "Munster", "Stilton", "Blue"@};
## Sold = [105, 30, 70, 10, 15, 20];
## pareto (Sold, Cheese);
## @end group
## @end example
## @seealso{bar, barh, hist, pie, plot}
## @end deftypefn
    
    
@function
def pareto(varargin=None,*args,**kwargs):
    varargin = pareto.varargin
    nargin = pareto.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('pareto',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:67
    if (nargin != 1 and nargin != 2):
        print_usage()
    
    y=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:73
    if (nargin == 2):
        x=ravel(varargin[2]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:75
        if (logical_not(iscell(x))):
            if (ischar(x)):
                x=cellstr(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:78
            else:
                x=cellstr(num2str(ravel(x)))
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:80
    else:
        x=cellstr(int2str(cat(arange(1,numel(y))).T))
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:84
    
    y,idx=sort(y,'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:87
    x=x[idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:88
    cdf=cumsum(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:89
    maxcdf=cdf[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:90
    cdf / maxcdf
    idx95=find(cdf < 0.95,1,'last') + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:92
    if (isempty(hax)):
        ax,hbar,hline=plotyy(arange(1,idx95),y[1:idx95],arange(1,length(cdf)),dot(100,cdf),bar,plot,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:95
    else:
        ax,hbar,hline=plotyy(hax,arange(1,idx95),y[1:idx95],arange(1,length(cdf)),dot(100,cdf),bar,plot,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:99
    
    axis(ax[1],cat(1 - 0.6,idx95 + 0.6,0,maxcdf))
    axis(ax[2],cat(1 - 0.6,idx95 + 0.6,0,100))
    set(ax[2],'ytick',cat(0,20,40,60,80,100),'yticklabel',cellarray(['0%','20%','40%','60%','80%','100%']),'ycolor',get(ax[1],'ycolor'))
    set(hline,'color',get(ax[1],'colororder')(1,arange()))
    set(ax[1:2],'xtick',arange(1,idx95),'xticklabel',x[1:idx95])
    if (nargout > 0):
        h=matlabarray(cat([hbar],[hline]))
# /home/lei/octave-4.0.2/scripts/plot/draw/pareto.m:113
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} errorbar (@var{y}, @var{ey})
## @deftypefnx {Function File} {} errorbar (@var{y}, @dots{}, @var{fmt})
## @deftypefnx {Function File} {} errorbar (@var{x}, @var{y}, @var{ey})
## @deftypefnx {Function File} {} errorbar (@var{x}, @var{y}, @var{err}, @var{fmt})
## @deftypefnx {Function File} {} errorbar (@var{x}, @var{y}, @var{lerr}, @var{uerr}, @var{fmt})
## @deftypefnx {Function File} {} errorbar (@var{x}, @var{y}, @var{ex}, @var{ey}, @var{fmt})
## @deftypefnx {Function File} {} errorbar (@var{x}, @var{y}, @var{lx}, @var{ux}, @var{ly}, @var{uy}, @var{fmt})
## @deftypefnx {Function File} {} errorbar (@var{x1}, @var{y1}, @dots{}, @var{fmt}, @var{xn}, @var{yn}, @dots{})
## @deftypefnx {Function File} {} errorbar (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} errorbar (@dots{})
## Create a 2-D plot with errorbars.
##
## Many different combinations of arguments are possible.  The simplest form is
##
## @example
## errorbar (@var{y}, @var{ey})
## @end example
##
## @noindent
## where the first argument is taken as the set of @var{y} coordinates, the
## second argument @var{ey} are the errors around the @var{y} values, and the
## @var{x} coordinates are taken to be the indices of the elements
## (@code{1:numel (@var{y})}).
##
## The general form of the function is
##
## @example
## errorbar (@var{x}, @var{y}, @var{err1}, @dots{}, @var{fmt}, @dots{})
## @end example
##
## @noindent
## After the @var{x} and @var{y} arguments there can be 1, 2, or 4
## parameters specifying the error values depending on the nature of the error
## values and the plot format @var{fmt}.
##
## @table @asis
## @item @var{err} (scalar)
## When the error is a scalar all points share the same error value.
## The errorbars are symmetric and are drawn from @var{data}-@var{err} to
## @var{data}+@var{err}.
## The @var{fmt} argument determines whether @var{err} is in the x-direction,
## y-direction (default), or both.
##
## @item @var{err} (vector or matrix)
## Each data point has a particular error value.
## The errorbars are symmetric and are drawn from @var{data}(n)-@var{err}(n) to
## @var{data}(n)+@var{err}(n).
##
## @item @var{lerr}, @var{uerr} (scalar)
## The errors have a single low-side value and a single upper-side value.
## The errorbars are not symmetric and are drawn from @var{data}-@var{lerr} to
## @var{data}+@var{uerr}.
##
## @item @var{lerr}, @var{uerr} (vector or matrix)
## Each data point has a low-side error and an upper-side error.
## The errorbars are not symmetric and are drawn from
## @var{data}(n)-@var{lerr}(n) to @var{data}(n)+@var{uerr}(n).
## @end table
##
## Any number of data sets (@var{x1},@var{y1}, @var{x2},@var{y2}, @dots{}) may
## appear as long as they are separated by a format string @var{fmt}.
##
## If @var{y} is a matrix, @var{x} and the error parameters must also be
## matrices having the same dimensions.  The columns of @var{y} are plotted
## versus the corresponding columns of @var{x} and errorbars are taken from
## the corresponding columns of the error parameters.
##
## If @var{fmt} is missing, the yerrorbars ("~") plot style is assumed.
##
## If the @var{fmt} argument is supplied then it is interpreted, as in normal
## plots, to specify the line style, marker, and color.  In addition,
## @var{fmt} may include an errorbar style which @strong{must precede} the
## ordinary format codes.  The following errorbar styles are supported:
##
## @table @samp
## @item ~
## Set yerrorbars plot style (default).
##
## @item >
## Set xerrorbars plot style.
##
## @item ~>
## Set xyerrorbars plot style.
##
## @item #~
## Set yboxes plot style.
##
## @item #
## Set xboxes plot style.
##
## @item #~>
## Set xyboxes plot style.
## @end table
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a handle to the hggroup object
## representing the data plot and errorbars.
##
## Note: For compatibility with @sc{matlab} a line is drawn through all data
## points.  However, most scientific errorbar plots are a scatter plot of
## points with errorbars.  To accomplish this, add a marker style to the
## @var{fmt} argument such as @qcode{"."}.  Alternatively, remove the line
## by modifying the returned graphic handle with
## @code{set (h, "linestyle", "none")}.
##
## Examples:
##
## @example
## errorbar (@var{x}, @var{y}, @var{ex}, ">.r")
## @end example
##
## @noindent
## produces an xerrorbar plot of @var{y} versus @var{x} with @var{x}
## errorbars drawn from @var{x}-@var{ex} to @var{x}+@var{ex}.  The marker
## @qcode{"."} is used so no connecting line is drawn and the errorbars
## appear in red.
##
## @example
## @group
## errorbar (@var{x}, @var{y1}, @var{ey}, "~",
##           @var{x}, @var{y2}, @var{ly}, @var{uy})
## @end group
## @end example
##
## @noindent
## produces yerrorbar plots with @var{y1} and @var{y2} versus @var{x}.
## Errorbars for @var{y1} are drawn from @var{y1}-@var{ey} to
## @var{y1}+@var{ey}, errorbars for @var{y2} from @var{y2}-@var{ly} to
## @var{y2}+@var{uy}.
##
## @example
## @group
## errorbar (@var{x}, @var{y}, @var{lx}, @var{ux},
##           @var{ly}, @var{uy}, "~>")
## @end group
## @end example
##
## @noindent
## produces an xyerrorbar plot of @var{y} versus @var{x} in which
## @var{x} errorbars are drawn from @var{x}-@var{lx} to @var{x}+@var{ux}
## and @var{y} errorbars from @var{y}-@var{ly} to @var{y}+@var{uy}.
## @seealso{semilogxerr, semilogyerr, loglogerr, plot}
## @end deftypefn
    
    ## Created: 18.7.2000
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def errorbar(varargin=None,*args,**kwargs):
    varargin = errorbar.varargin
    nargin = errorbar.nargin

    hax,varargin=__plt_get_axis_arg__('errorbar',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:172
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:174
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:176
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:179
        htmp=__errcomm__('errorbar',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:181
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/errorbar.m:189
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Invisible figure used for tests
    
    
    
    
    
    ## Close figure used for testing
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} mesh (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} mesh (@var{z})
## @deftypefnx {Function File} {} mesh (@dots{}, @var{c})
## @deftypefnx {Function File} {} mesh (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} mesh (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} mesh (@dots{})
## Plot a 3-D wireframe mesh.
##
## The wireframe mesh is plotted using rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the mesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally, the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## @seealso{ezmesh, meshc, meshz, trimesh, contour, surf, surface, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def mesh(varargin=None,*args,**kwargs):
    varargin = mesh.varargin
    nargin = mesh.nargin

    if (logical_not(all(cellfun('isreal',varargin)))):
        error('mesh: X, Y, Z, C arguments must be real')
    
    hax,varargin,nargin=__plt_get_axis_arg__('mesh',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:64
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:66
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:68
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:71
        mesh_props=cellarray(['facecolor','w','edgecolor','flat'])
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:73
        chararg=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:74
        if (isempty(chararg)):
            htmp=surface(varargin[:],mesh_props[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:76
        else:
            htmp=surface(varargin[1:chararg - 1],mesh_props[:],varargin[chararg:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:78
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/mesh.m:93
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezplot3 (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {} ezplot3 (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezplot3 (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezplot3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezplot3 (@dots{})
##
## Plot a parametrically defined curve in three dimensions.
##
## @var{fx}, @var{fy}, and @var{fz} are strings, inline functions,
## or function handles with one argument defining the function.  By
## default the plot is over the domain @code{0 <= @var{t} <= 2*pi}
## with 500 points.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of @var{t}.
##
## @var{n} is a scalar defining the number of points to use in plotting the
## function.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## @example
## @group
## fx = @@(t) cos (t);
## fy = @@(t) sin (t);
## fz = @@(t) t;
## ezplot3 (fx, fy, fz, [0, 10*pi], 100);
## @end group
## @end example
##
## @seealso{plot3, ezplot, ezmesh, ezsurf}
## @end deftypefn
    
    
@function
def ezplot3(varargin=None,*args,**kwargs):
    varargin = ezplot3.varargin
    nargin = ezplot3.nargin

    htmp,needusage=__ezplot__('plot3',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezplot3.m:58
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezplot3.m:65
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Mike Miller
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} waterfall (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} waterfall (@var{z})
## @deftypefnx {Function File} {} waterfall (@dots{}, @var{c})
## @deftypefnx {Function File} {} waterfall (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} waterfall (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} waterfall (@dots{})
## Plot a 3-D waterfall plot.
##
## A waterfall plot is similar to a @code{meshz} plot except only
## mesh lines for the rows of @var{z} (x-values) are shown.
##
## The wireframe mesh is plotted using rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the mesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## @seealso{meshz, mesh, meshc, contour, surf, surface, ribbon, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    ## Author: Mike Miller <mtmiller@ieee.org>
    
    
@function
def waterfall(varargin=None,*args,**kwargs):
    varargin = waterfall.varargin
    nargin = waterfall.nargin

    htmp=meshz(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/waterfall.m:63
    set(htmp,'meshstyle','row')
    
    toolkit=get(ancestor(htmp,'figure'),'__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/draw/waterfall.m:68
    if (strcmp(toolkit,'gnuplot')):
        warning('waterfall: may not render correctly using toolkit \'%s\'',toolkit)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/waterfall.m:74
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} surface (@var{x}, @var{y}, @var{z}, @var{c})
## @deftypefnx {Function File} {} surface (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} surface (@var{z}, @var{c})
## @deftypefnx {Function File} {} surface (@var{z})
## @deftypefnx {Function File} {} surface (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} surface (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} surface (@dots{})
## Create a surface graphic object given matrices @var{x} and @var{y} from
## @code{meshgrid} and a matrix of values @var{z} corresponding to the
## @var{x} and @var{y} coordinates of the surface.
##
## If @var{x} and @var{y} are vectors, then a typical vertex is
## (@var{x}(j), @var{y}(i), @var{z}(i,j)).  Thus, columns of @var{z} correspond
## to different @var{x} values and rows of @var{z} correspond to different
## @var{y} values.  If only a single input @var{z} is given then @var{x} is
## taken to be @code{1:rows (@var{z})} and @var{y} is
## @code{1:columns (@var{z})}.
##
## Any property/value input pairs are assigned to the surface object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
## @seealso{surf, mesh, patch, line}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def surface(varargin=None,*args,**kwargs):
    varargin = surface.varargin
    nargin = surface.nargin

    hax,varargin=__plt_get_axis_arg__('surface',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:52
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:55
    else:
        hax=hax[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:57
    
    htmp,bad_usage=__surface__(hax,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:60
    if (bad_usage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:67
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __surface__(ax=None,varargin=None,*args,**kwargs):
    varargin = __surface__.varargin
    nargin = __surface__.nargin

    h=0
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:74
    bad_usage=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:75
    firststring=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:76
    if (isempty(firststring)):
        firststring=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:78
    
    if 5 == (firststring):
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:83
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:84
        z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:85
        c=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:86
        if (iscomplex(x) or iscomplex(y) or iscomplex(z) or iscomplex(c)):
            error('mesh: X, Y, Z, C arguments must be real')
        z_nr,z_nc=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:92
        c_nr,c_nc,c_np=size(c,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:93
        if (logical_not((z_nr == c_nr and z_nc == c_nc and (c_np == 1 or c_np == 3)))):
            error('surface: Z and C must have the same size')
        if (isvector(x) and isvector(y) and ismatrix(z)):
            if (rows(z) == length(y) and columns(z) == length(x)):
                x=ravel(x).T
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:100
                y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:101
            else:
                error('surface: rows (Z) must be the same as length (Y) and columns (Z) must be the same as length (X)')
        else:
            if (ismatrix(x) and ismatrix(y) and ismatrix(z)):
                if (logical_not(size_equal(x,y,z))):
                    error('surface: X, Y, and Z must have the same dimensions')
            else:
                error('surface: X and Y must be vectors and Z must be a matrix')
    else:
        if 4 == (firststring):
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:114
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:115
            z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:116
            c=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:117
            if (iscomplex(x) or iscomplex(y) or iscomplex(z)):
                error('mesh: X, Y, Z arguments must be real')
            if (isvector(x) and isvector(y) and ismatrix(z)):
                if (rows(z) == length(y) and columns(z) == length(x)):
                    x=ravel(x).T
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:125
                    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:126
                else:
                    error('surface: rows (Z) must be the same as length (Y) and columns (Z) must be the same as length (X)')
            else:
                if (ismatrix(x) and ismatrix(y) and ismatrix(z)):
                    if (logical_not(size_equal(x,y,z))):
                        error('surface: X, Y, and Z must have the same dimensions')
                else:
                    error('surface: X and Y must be vectors and Z must be a matrix')
        else:
            if 3 == (firststring):
                z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:139
                c=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:140
                if (iscomplex(z) or iscomplex(c)):
                    error('mesh: X, C arguments must be real')
                if (ismatrix(z) and logical_not(isvector(z)) and logical_not(isscalar(z))):
                    nr,nc=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:147
                    x=arange(1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:148
                    y=(arange(1,nr)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:149
                else:
                    error('surface: Z argument must be a matrix')
            else:
                if 2 == (firststring):
                    z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:155
                    c=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:156
                    if (iscomplex(z)):
                        error('mesh: Z argument must be real')
                    if (ismatrix(z) and logical_not(isvector(z)) and logical_not(isscalar(z))):
                        nr,nc=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:163
                        x=arange(1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:164
                        y=(arange(1,nr)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:165
                    else:
                        error('surface: Z argument must be a matrix')
                else:
                    if 1 == (firststring):
                        x=arange(1,3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:171
                        y=x.T
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:172
                        c=z=eye(3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:173
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:173
                    else:
                        bad_usage=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:176
                        return h,bad_usage
    
    if (firststring < nargin):
        other_args=varargin[firststring:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:182
    else:
        other_args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:184
    
    h=__go_surface__(ax,'xdata',x,'ydata',y,'zdata',z,'cdata',c,other_args[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/surface.m:186
    if (logical_not(ishold())):
        set(ax,'view',cat(0,90),'box','off')
    
    return h,bad_usage
    
if __name__ == '__main__':
    pass
    
    ## Functional tests for surface() are in surf.m, surfc.m, surfl.m, and pcolor.m
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} bar (@var{y})
## @deftypefnx {Function File} {} bar (@var{x}, @var{y})
## @deftypefnx {Function File} {} bar (@dots{}, @var{w})
## @deftypefnx {Function File} {} bar (@dots{}, @var{style})
## @deftypefnx {Function File} {} bar (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} bar (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} bar (@dots{}, @var{prop}, @var{val}, @dots{})
## Produce a bar graph from two vectors of X-Y data.
##
## If only one argument is given, @var{y}, it is taken as a vector of Y values
## and the X coordinates are the range @code{1:numel (@var{y})}.
##
## The optional input @var{w} controls the width of the bars.  A value of
## 1.0 will cause each bar to exactly touch any adjacent bars.
## The default width is 0.8.
##
## If @var{y} is a matrix, then each column of @var{y} is taken to be a
## separate bar graph plotted on the same graph.  By default the columns
## are plotted side-by-side.  This behavior can be changed by the @var{style}
## argument which can take the following values:
##
## @table @asis
## @item @qcode{"grouped"} (default)
## Side-by-side bars with a gap between bars and centered over the X-coordinate.
##
## @item  @qcode{"stacked"}
## Bars are stacked so that each X value has a single bar composed of
## multiple segments.
##
## @item @qcode{"hist"}
## Side-by-side bars with no gap between bars and centered over the
## X-coordinate.
##
## @item @qcode{"histc"}
## Side-by-side bars with no gap between bars and left-aligned to the
## X-coordinate.
## @end table
##
## Optional property/value pairs are passed directly to the underlying patch
## objects.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of handles to the created
## "bar series" hggroups with one handle per column of the variable @var{y}.
## This series makes it possible to change a common element in one bar series
## object and have the change reflected in the other "bar series".
## For example,
##
## @example
## @group
## h = bar (rand (5, 10));
## set (h(1), "basevalue", 0.5);
## @end group
## @end example
##
## @noindent
## changes the position on the base of all of the bar series.
##
## The following example modifies the face and edge colors using
## property/value pairs.
##
## @example
## bar (randn (1, 100), "facecolor", "r", "edgecolor", "b");
## @end example
##
## @noindent
## The color of the bars is taken from the figure's colormap, such that
##
## @example
## @group
## bar (rand (10, 3));
## colormap (summer (64));
## @end group
## @end example
##
## @noindent
## will change the colors used for the bars.  The color of bars can also be set
## manually using the @qcode{"facecolor"} property as shown below.
##
## @example
## @group
## h = bar (rand (10, 3));
## set (h(1), "facecolor", "r")
## set (h(2), "facecolor", "g")
## set (h(3), "facecolor", "b")
## @end group
## @end example
##
## @seealso{barh, hist, pie, plot, patch}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def bar(varargin=None,*args,**kwargs):
    varargin = bar.varargin
    nargin = bar.nargin

    varargout=cell(nargout,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/bar.m:116
    varargout[:]=__bar__(true,'bar',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/bar.m:117
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} scatter3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} scatter3 (@var{x}, @var{y}, @var{z}, @var{s})
## @deftypefnx {Function File} {} scatter3 (@var{x}, @var{y}, @var{z}, @var{s}, @var{c})
## @deftypefnx {Function File} {} scatter3 (@dots{}, @var{style})
## @deftypefnx {Function File} {} scatter3 (@dots{}, "filled")
## @deftypefnx {Function File} {} scatter3 (@dots{}, @var{prop}, @var{val})
## @deftypefnx {Function File} {} scatter3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} scatter3 (@dots{})
## Draw a 3-D scatter plot.
##
## A marker is plotted at each point defined by the coordinates in the vectors
## @var{x}, @var{y}, and @var{z}.
##
## The size of the markers is determined by @var{s}, which can be a scalar
## or a vector of the same length as @var{x}, @var{y}, and @var{z}.  If @var{s}
## is not given, or is an empty matrix, then a default value of 8 points is
## used.
##
## The color of the markers is determined by @var{c}, which can be a string
## defining a fixed color; a 3-element vector giving the red, green, and blue
## components of the color; a vector of the same length as @var{x} that gives
## a scaled index into the current colormap; or an @nospell{Nx3} matrix defining
## the RGB color of each marker individually.
##
## The marker to use can be changed with the @var{style} argument, that is a
## string defining a marker in the same manner as the @code{plot} command.
## If no marker is specified it defaults to @qcode{"o"} or circles.
## If the argument @qcode{"filled"} is given then the markers are filled.
##
## Additional property/value pairs are passed directly to the underlying
## patch object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the hggroup
## object representing the points.
##
## @example
## @group
## [x, y, z] = peaks (20);
## scatter3 (x(:), y(:), z(:), [], z(:));
## @end group
## @end example
##
## @seealso{scatter, patch, plot}
## @end deftypefn
    
    
@function
def scatter3(varargin=None,*args,**kwargs):
    varargin = scatter3.varargin
    nargin = scatter3.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('scatter3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:70
    if (nargin < 2):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:76
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:78
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:81
        htmp=__scatter__(hax,3,'scatter3',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:83
        if (logical_not(ishold(hax))):
            set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        retval=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter3.m:96
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} surf (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} surf (@var{z})
## @deftypefnx {Function File} {} surf (@dots{}, @var{c})
## @deftypefnx {Function File} {} surf (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} surf (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} surf (@dots{})
## Plot a 3-D surface mesh.
##
## The surface mesh is plotted using shaded rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the surface is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally, the color of the surface can be specified independently of
## @var{z} by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Note: The exact appearance of the surface can be controlled with the
## @code{shading} command or by using @code{set} to control surface object
## properties.
## @seealso{ezsurf, surfc, surfl, surfnorm, trisurf, contour, mesh, surface, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def surf(varargin=None,*args,**kwargs):
    varargin = surf.varargin
    nargin = surf.nargin

    hax,varargin=__plt_get_axis_arg__('surf',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:63
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:65
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:67
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:70
        htmp=surface(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:72
        if (logical_not(ishold(hax))):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        retval=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/surf.m:86
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} surfl (@var{z})
## @deftypefnx {Function File} {} surfl (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} surfl (@dots{}, @var{lsrc})
## @deftypefnx {Function File} {} surfl (@var{x}, @var{y}, @var{z}, @var{lsrc}, @var{P})
## @deftypefnx {Function File} {} surfl (@dots{}, "cdata")
## @deftypefnx {Function File} {} surfl (@dots{}, "light")
## @deftypefnx {Function File} {} surfl (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} surfl (@dots{})
## Plot a 3-D surface using shading based on various lighting models.
##
## The surface mesh is plotted using shaded rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The default lighting mode @qcode{"cdata"}, changes the cdata property of the
## surface object to give the impression of a lighted surface.
## @strong{Warning:} The alternative mode @qcode{"light"} mode which creates a
## light object to illuminate the surface is not implemented (yet).
##
## The light source location can be specified using @var{lsrc}.  It can be given
## as a 2-element vector [azimuth, elevation] in degrees, or as a 3-element
## vector [lx, ly, lz].  The default value is rotated 45 degrees
## counterclockwise to the current view.
##
## The material properties of the surface can specified using a 4-element
## vector @var{P} = [@var{AM} @var{D} @var{SP} @var{exp}] which defaults to
## @var{p} = [0.55 0.6 0.4 10].
##
## @table @asis
## @item @qcode{"AM"} strength of ambient light
##
## @item @qcode{"D"} strength of diffuse reflection
##
## @item @qcode{"SP"} strength of specular reflection
##
## @item @qcode{"EXP"} specular exponent
## @end table
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Example:
##
## @example
## @group
## colormap (bone (64));
## surfl (peaks);
## shading interp;
## @end group
## @end example
## @seealso{diffuse, specular, surf, shading, colormap, caxis}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def surfl(varargin=None,*args,**kwargs):
    varargin = surfl.varargin
    nargin = surfl.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('surfl',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:85
    if (nargin == 0):
        print_usage()
    
    ## Check for lighting type.
    use_cdata=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:92
    if (ischar(varargin[end()])):
        if 'light' == (tolower(varargin[end()])):
            warning('surfl: light method not supported (yet), using cdata method instead')
            use_cdata=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:98
        else:
            if 'cdata' == (tolower(varargin[end()])):
                use_cdata=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:100
            else:
                error('surfl: unknown lighting method')
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:104
    
    ## Check for reflection properties argument.
  ##
  ## r = [ambient light strength,
  ##      diffuse reflection strength,
  ##      specular reflection strength,
  ##      specular shine]
    if (isnumeric(varargin[end()]) and length(varargin[end()]) == 4):
        r=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:114
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:115
    else:
        ## Default values.
        r=matlabarray(cat(0.55,0.6,0.4,10))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:118
    
    ## Check for light vector (lv) argument.
    have_lv=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:122
    if (isnumeric(varargin[end()])):
        len_=numel(varargin[end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:124
        lastarg=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:125
        if (len_ == 3):
            lv=copy(lastarg)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:127
            varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:128
            have_lv=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:129
        else:
            if (len_ == 2):
                lv(1),lv[2],lv[3]=sph2cart(dot((lastarg[1] - 90),pi) / 180,dot(lastarg[2],pi) / 180,1.0,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:131
                varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:134
                have_lv=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:135
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:139
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:141
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:144
        htmp=surface(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:146
        if (logical_not(ishold(hax))):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on','clim',cat(0,1))
        ## Get view vector (vv).
        az,el=view(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:153
        vv=sph2cart(dot((az - 90),pi) / 180.0,dot(el,pi) / 180.0,1.0)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:154
        if (logical_not(have_lv)):
            ## Calculate light vector (lv) from view vector.
            phi=pi / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:158
            R=matlabarray(cat([cos(phi),- sin(phi),0],[sin(phi),cos(phi),0],[0,0,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:159
            lv=(dot(R,vv.T)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:162
        vn=get(htmp,'vertexnormals')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:165
        dar=get(hax,'dataaspectratio')
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:166
        vn[:,:,1] *= dar[1]
        vn[:,:,2] *= dar[2]
        vn[:,:,3] *= dar[3]
        vn / repmat(sqrt(sumsq(vn,3)),cat(1,1,3))
        nr,nc=size(get(htmp,'zdata'),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:173
        cdata=(dot(r[1],ones(nr,nc)) + dot(r[2],diffuse(vn[:,:,1],vn[:,:,2],vn[:,:,3],lv)) + dot(r[3],specular(vn[:,:,1],vn[:,:,2],vn[:,:,3],lv,vv,r[4])))
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:176
        cdata / sum(r[1:3])
        set(htmp,'cdata',cdata)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/surfl.m:190
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} scatter (@var{x}, @var{y})
## @deftypefnx {Function File} {} scatter (@var{x}, @var{y}, @var{s})
## @deftypefnx {Function File} {} scatter (@var{x}, @var{y}, @var{s}, @var{c})
## @deftypefnx {Function File} {} scatter (@dots{}, @var{style})
## @deftypefnx {Function File} {} scatter (@dots{}, "filled")
## @deftypefnx {Function File} {} scatter (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} scatter (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} scatter (@dots{})
## Draw a 2-D scatter plot.
##
## A marker is plotted at each point defined by the coordinates in the vectors
## @var{x} and @var{y}.
##
## The size of the markers is determined by @var{s}, which can be a scalar
## or a vector of the same length as @var{x} and @var{y}.  If @var{s}
## is not given, or is an empty matrix, then a default value of 8 points is
## used.
##
## The color of the markers is determined by @var{c}, which can be a string
## defining a fixed color; a 3-element vector giving the red, green, and blue
## components of the color; a vector of the same length as @var{x} that gives
## a scaled index into the current colormap; or an @nospell{Nx3} matrix defining
## the RGB color of each marker individually.
##
## The marker to use can be changed with the @var{style} argument, that is a
## string defining a marker in the same manner as the @code{plot} command.
## If no marker is specified it defaults to @qcode{"o"} or circles.
## If the argument @qcode{"filled"} is given then the markers are filled.
##
## Additional property/value pairs are passed directly to the underlying
## patch object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created patch
## object.
##
## Example:
##
## @example
## @group
## x = randn (100, 1);
## y = randn (100, 1);
## scatter (x, y, [], sqrt (x.^2 + y.^2));
## @end group
## @end example
##
## @seealso{scatter3, patch, plot}
## @end deftypefn
    
    
@function
def scatter(varargin=None,*args,**kwargs):
    varargin = scatter.varargin
    nargin = scatter.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('scatter',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:73
    if (nargin < 2):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:79
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:81
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:84
        htmp=__scatter__(hax,2,'scatter',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:86
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        retval=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/scatter.m:94
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezpolar (@var{f})
## @deftypefnx {Function File} {} ezpolar (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezpolar (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezpolar (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezpolar (@dots{})
##
## Plot a 2-D function in polar coordinates.
##
## The function @var{f} is a string, inline function, or function handle with
## a single argument.  The expected form of the function is
## @code{@var{rho} = @var{f}(@var{theta})}.
## By default the plot is over the domain @code{0 <= @var{theta} <= 2*pi}
## with 500 points.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of @var{theta}.
##
## @var{n} is a scalar defining the number of points to use in plotting
## the function.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Example:
##
## @example
## ezpolar (@@(t) sin (5/4 * t), [0, 8*pi]);
## @end example
##
## @seealso{polar, ezplot}
## @end deftypefn
    
    
@function
def ezpolar(varargin=None,*args,**kwargs):
    varargin = ezpolar.varargin
    nargin = ezpolar.nargin

    htmp,needusage=__ezplot__('polar',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezpolar.m:56
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezpolar.m:63
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2007-2015 David BAteman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} contour3 (@var{z})
## @deftypefnx {Function File} {} contour3 (@var{z}, @var{vn})
## @deftypefnx {Function File} {} contour3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} contour3 (@var{x}, @var{y}, @var{z}, @var{vn})
## @deftypefnx {Function File} {} contour3 (@dots{}, @var{style})
## @deftypefnx {Function File} {} contour3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{c}, @var{h}] =} contour3 (@dots{})
## Create a 3-D contour plot.
##
## @code{contour3} plots level curves (contour lines) of the matrix @var{z}
## at a Z level corresponding to each contour.  This is in contrast to
## @code{contour} which plots all of the contour lines at the same Z level
## and produces a 2-D plot.
##
## The level curves are taken from the contour matrix @var{c} computed by
## @code{contourc} for the same arguments; see the latter for their
## interpretation.
##
## The appearance of contour lines can be defined with a line style @var{style}
## in the same manner as @code{plot}.  Only line style and color are used;
## Any markers defined by @var{style} are ignored.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional output @var{c} are the contour levels in @code{contourc} format.
##
## The optional return value @var{h} is a graphics handle to the hggroup
## comprising the contour lines.
##
## Example:
##
## @example
## @group
## contour3 (peaks (19));
## colormap cool;
## hold on;
## surf (peaks (19), "facecolor", "none", "edgecolor", "black");
## @end group
## @end example
##
## @seealso{contour, contourc, contourf, clabel, meshc, surfc, caxis, colormap, plot}
## @end deftypefn
    
    
@function
def contour3(varargin=None,*args,**kwargs):
    varargin = contour3.varargin
    nargin = contour3.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('contour3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:66
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:68
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:70
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:73
        ctmp,htmp=__contour__(hax,'auto',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:75
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (logical_not(ishold())):
        set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    
    if (nargout > 0):
        c=copy(ctmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:88
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contour3.m:89
    
    return c,h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} quiver (@var{u}, @var{v})
## @deftypefnx {Function File} {} quiver (@var{x}, @var{y}, @var{u}, @var{v})
## @deftypefnx {Function File} {} quiver (@dots{}, @var{s})
## @deftypefnx {Function File} {} quiver (@dots{}, @var{style})
## @deftypefnx {Function File} {} quiver (@dots{}, "filled")
## @deftypefnx {Function File} {} quiver (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} quiver (@dots{})
##
## Plot a 2-D vector field with arrows.
##
## Plot the (@var{u}, @var{v}) components of a vector field in
## an (@var{x}, @var{y}) meshgrid.  If the grid is uniform then @var{x} and
## @var{y} can be specified as vectors.
##
## If @var{x} and @var{y} are undefined they are assumed to be
## @code{(1:@var{m}, 1:@var{n})} where
## @code{[@var{m}, @var{n}] = size (@var{u})}.
##
## The variable @var{s} is a scalar defining a scaling factor to use for
## the arrows of the field relative to the mesh spacing.  A value of 0
## disables all scaling.  The default value is 0.9.
##
## The style to use for the plot can be defined with a line style @var{style}
## of the same format as the @code{plot} command.
## If a marker is specified then markers at the grid points of the vectors are
## drawn rather than arrows.  If the argument @qcode{"filled"} is given then
## the markers are filled.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to a quiver object.
## A quiver object regroups the components of the quiver plot (body, arrow,
## and marker), and allows them to be changed together.
##
## Example:
##
## @example
## @group
## [x, y] = meshgrid (1:2:20);
## h = quiver (x, y, sin (2*pi*x/10), sin (2*pi*y/10));
## set (h, "maxheadsize", 0.33);
## @end group
## @end example
##
## @seealso{quiver3, compass, feather, plot}
## @end deftypefn
    
    
@function
def quiver(varargin=None,*args,**kwargs):
    varargin = quiver.varargin
    nargin = quiver.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('quiver',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:70
    if (nargin < 2):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:76
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:78
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:81
        htmp=__quiver__(hax,false,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:82
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver.m:90
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} meshc (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} meshc (@var{z})
## @deftypefnx {Function File} {} meshc (@dots{}, @var{c})
## @deftypefnx {Function File} {} meshc (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} meshc (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} meshc (@dots{})
## Plot a 3-D wireframe mesh with underlying contour lines.
##
## The wireframe mesh is plotted using rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the mesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a 2-element vector with a graphics
## handle to the created surface object and to the created contour plot.
##
## @seealso{ezmeshc, mesh, meshz, contour, surfc, surface, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    
@function
def meshc(varargin=None,*args,**kwargs):
    varargin = meshc.varargin
    nargin = meshc.nargin

    if (logical_not(all(cellfun('isreal',varargin)))):
        error('meshc: X, Y, Z, C arguments must be real')
    
    hax,varargin,nargin=__plt_get_axis_arg__('meshc',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:62
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:64
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:66
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:69
        ##        non-filled contour.  3D filled patches are also not supported.
    ##        Thus, the facecolor will be transparent for the gnuplot backend.
        mesh_props=cellarray(['facecolor','w','edgecolor','flat'])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:74
        chararg=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:75
        if (isempty(chararg)):
            htmp=surface(varargin[:],mesh_props[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:77
        else:
            htmp=surface(varargin[1:chararg - 1],mesh_props[:],varargin[chararg:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:79
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on','xlimmode','manual','ylimmode','manual')
        drawnow()
        zmin=get(hax,'zlim')(1)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:91
        __,htmp2=__contour__(hax,zmin,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:92
        htmp=matlabarray(cat([htmp],[htmp2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:94
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshc.m:103
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} shrinkfaces (@var{p}, @var{sf})
## @deftypefnx {Function File} {@var{nfv} =} shrinkfaces (@var{p}, @var{sf})
## @deftypefnx {Function File} {@var{nfv} =} shrinkfaces (@var{fv}, @var{sf})
## @deftypefnx {Function File} {@var{nfv} =} shrinkfaces (@var{f}, @var{v}, @var{sf})
## @deftypefnx {Function File} {[@var{nf}, @var{nv}] =} shrinkfaces (@dots{})
##
## Reduce the size of faces in a patch by the shrink factor @var{sf}.
##
## The patch object can be specified by a graphics handle (@var{p}), a patch
## structure (@var{fv}) with the fields @qcode{"faces"} and @qcode{"vertices"},
## or as two separate matrices (@var{f}, @var{v}) of faces and vertices.
##
## The shrink factor @var{sf} is a positive number specifying the percentage
## of the original area the new face will occupy.  If no factor is given the
## default is 0.3 (a reduction to 30# of the original size).  A factor greater
## than 1.0 will result in the expansion of faces.
##
## Given a patch handle as the first input argument and no output parameters,
## perform the shrinking of the patch faces in place and redraw the patch.
##
## If called with one output argument, return a structure with fields
## @qcode{"faces"}, @qcode{"vertices"}, and @qcode{"facevertexcdata"}
## containing the data after shrinking.  This structure can be used directly
## as an input argument to the @code{patch} function.
##
## @strong{Caution:}: Performing the shrink operation on faces which are not
## convex can lead to undesirable results.
##
## Example: a triangulated 3/4 circle and the corresponding shrunken version.
##
## @example
## @group
## [phi r] = meshgrid (linspace (0, 1.5*pi, 16), linspace (1, 2, 4));
## tri = delaunay (phi(:), r(:));
## v = [r(:).*sin(phi(:)) r(:).*cos(phi(:))];
## clf ()
## p = patch ("Faces", tri, "Vertices", v, "FaceColor", "none");
## fv = shrinkfaces (p);
## patch (fv)
## axis equal
## grid on
## @end group
## @end example
##
## @seealso{patch}
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def shrinkfaces(varargin=None,*args,**kwargs):
    varargin = shrinkfaces.varargin
    nargin = shrinkfaces.nargin

    if (nargin < 1 or nargin > 3 or nargout > 2):
        print_usage()
    
    sf=0.3
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:75
    colors=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:76
    p=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:77
    if (isscalar(p) and ishandle(p) and nargin < 3 and strcmp(get(p,'type'),'patch')):
        faces=get(p,'Faces')
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:81
        vertices=get(p,'Vertices')
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:82
        colors=get(p,'FaceVertexCData')
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:83
        if (nargin == 2):
            sf=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:85
    else:
        if (isstruct(p) and nargin < 3):
            faces=p.faces
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:88
            vertices=p.vertices
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:89
            if (isfield(p,'facevertexcdata')):
                colors=p.facevertexcdata
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:91
            if (nargin == 2):
                sf=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:94
        else:
            if (ismatrix(p) and nargin >= 2 and ismatrix(varargin[2])):
                faces=copy(p)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:97
                vertices=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:98
                if (nargin == 3):
                    sf=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:100
            else:
                print_usage()
    
    if (logical_not(isscalar(sf)) or sf <= 0):
        error('shrinkfaces: scale factor must be a positive scalar')
    
    nc=columns(vertices)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:110
    if (nc < 2 or nc > 3):
        error('shrinkfaces: only 2-D and 3-D patches are supported')
    
    m=columns(faces)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:115
    if (m < 3):
        error('shrinkfaces: faces must consist of at least 3 vertices')
    
    v=vertices[ravel(faces.T),:]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:120
    if (isempty(colors) or rows(colors) == rows(faces)):
        c=copy(colors)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:122
    else:
        if (rows(colors) == rows(vertices)):
            c=colors[ravel(faces.T),:]
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:124
        else:
            c=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:126
    
    sv=rows(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:128
    
    ## sparse as midpoint (1/m, ..., 1/m) in generalized barycentric coordinates.
    midpoints=full(dot(kron(speye(sv / m),ones(m,m) / m),sparse(v)))
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:131
    v=dot(sqrt(sf),(v - midpoints)) + midpoints
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:132
    f=reshape(arange(1,sv),m,sv / m).T
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:133
    if 0 == (nargout):
        if (ishandle(p)):
            ## avoid exceptions
            set(p,'FaceVertexCData',[],'CData',[])
            set(p,'Vertices',v,'Faces',f,'FaceVertexCData',c)
        else:
            nf=struct('faces',f,'vertices',v,'facevertexcdata',c)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:142
    else:
        if 1 == (nargout):
            nf=struct('faces',f,'vertices',v,'facevertexcdata',c)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:145
        else:
            if 2 == (nargout):
                nf=copy(f)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:147
                nv=copy(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/shrinkfaces.m:148
    
    return nf,nv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hist (@var{y})
## @deftypefnx {Function File} {} hist (@var{y}, @var{x})
## @deftypefnx {Function File} {} hist (@var{y}, @var{nbins})
## @deftypefnx {Function File} {} hist (@var{y}, @var{x}, @var{norm})
## @deftypefnx {Function File} {} hist (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} hist (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{nn}, @var{xx}] =} hist (@dots{})
## Produce histogram counts or plots.
##
## With one vector input argument, @var{y}, plot a histogram of the values
## with 10 bins.  The range of the histogram bins is determined by the
## range of the data.  With one matrix input argument, @var{y}, plot a
## histogram where each bin contains a bar per input column.
##
## Given a second vector argument, @var{x}, use that as the centers of
## the bins, with the width of the bins determined from the adjacent
## values in the vector.
##
## If scalar, the second argument, @var{nbins}, defines the number of bins.
##
## If a third argument is provided, the histogram is normalized such that
## the sum of the bars is equal to @var{norm}.
##
## Extreme values are lumped into the first and last bins.
##
## The histogram's appearance may be modified by specifying property/value
## pairs.  For example the face and edge color may be modified.
##
## @example
## @group
## hist (randn (1, 100), 25, "facecolor", "r", "edgecolor", "b");
## @end group
## @end example
##
## @noindent
## The histogram's colors also depend upon the current colormap.
##
## @example
## @group
## hist (rand (10, 3));
## colormap (summer ());
## @end group
## @end example
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## With two output arguments, produce the values @var{nn} (numbers of elements)
## and @var{xx} (bin centers) such that @code{bar (@var{xx}, @var{nn})} will
## plot the histogram.
##
## @seealso{histc, bar, pie, rose}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def hist(varargin=None,*args,**kwargs):
    varargin = hist.varargin
    nargin = hist.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('hist',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:78
    if (nargin < 1):
        print_usage()
    
    y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:84
    varargin=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:85
    arg_is_vector=isvector(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:87
    if (arg_is_vector):
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:90
    
    if (logical_not(isreal(y))):
        error('hist: Y must be real valued')
    
    max_val=max(ravel(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:97
    min_val=min(ravel(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:98
    iarg=1
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:100
    if (nargin == 1 or ischar(varargin[iarg])):
        n=10
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:102
        x=cat(arange(0.5,n)).T / n
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:103
        x=dot(x,(max_val - min_val)) + dot(ones(size(x)),min_val)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:104
    else:
        ## nargin is either 2 or 3
        x=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:107
        if (isscalar(x)):
            n=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:109
            if (n <= 0):
                error('hist: number of bins NBINS must be positive')
            x=cat(arange(0.5,n)).T / n
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:113
            x=dot(x,(max_val - min_val)) + dot(ones(size(x)),min_val)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:114
        else:
            if (isreal(x)):
                if (isvector(x)):
                    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:117
                xsort=sort(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:119
                if (any(xsort != x)):
                    warning('hist: bin values not sorted on input')
                    x=copy(xsort)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:122
            else:
                error('hist: second argument must be a scalar or a vector')
    
    ## Avoid issues with integer types for x and y
    x=double(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:130
    y=double(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:131
    cutoff=(x[1:end() - 1,:] + x[2:end(),:]) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:133
    n=rows(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:134
    y_nc=columns(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:135
    if (n < 30 and columns(x) == 1):
        ## The following algorithm works fastest for n less than about 30.
        chist=zeros(n + 1,y_nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:138
        for i in arange(1,n - 1).reshape(-1):
            chist[i + 1,:]=sum(y <= cutoff[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:140
        chist[n + 1,:]=sum(logical_not(isnan(y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:142
    else:
        ## The following algorithm works fastest for n greater than about 30.
    ## Put cutoff elements between boundaries, integrate over all
    ## elements, keep totals at boundaries.
        s,idx=sort(cat([y],[repmat(cutoff,1,y_nc)]),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:147
        len_=rows(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:148
        chist=cumsum(idx <= len_)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:149
        chist=matlabarray(cat([(zeros(1,y_nc))],[(reshape(chist[idx > len_],rows(cutoff),y_nc))],[(chist[end(),:] - sum(isnan(y)))]))
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:150
    
    freq=diff(chist)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:155
    if (nargin > 2 and logical_not(ischar(varargin[iarg]))):
        ## Normalize the histogram.
        norm=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:159
        freq=bsxfun(times,freq,norm / sum(logical_not(isnan(y))))
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:160
    
    if (nargout > 0):
        if (arg_is_vector):
            ## Matlab compatibility requires a row vector return
            nn=freq.T
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:166
            xx=x.T
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:167
        else:
            nn=copy(freq)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:169
            xx=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:170
    else:
        if (isempty(hax)):
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/hist.m:174
        bar(hax,x,freq,'hist',varargin[iarg:end()])
    
    return nn,xx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test bug #42394
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} compass (@var{u}, @var{v})
## @deftypefnx {Function File} {} compass (@var{z})
## @deftypefnx {Function File} {} compass (@dots{}, @var{style})
## @deftypefnx {Function File} {} compass (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} compass (@dots{})
##
## Plot the @code{(@var{u}, @var{v})} components of a vector field emanating
## from the origin of a polar plot.
##
## The arrow representing each vector has one end at the origin and the tip at
## [@var{u}(i), @var{v}(i)].  If a single complex argument @var{z} is given,
## then @code{@var{u} = real (@var{z})} and @code{@var{v} = imag (@var{z})}.
##
## The style to use for the plot can be defined with a line style @var{style}
## of the same format as the @code{plot} command.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to the
## line objects representing the drawn vectors.
##
## @example
## @group
## a = toeplitz ([1;randn(9,1)], [1,randn(1,9)]);
## compass (eig (a));
## @end group
## @end example
##
## @seealso{polar, feather, quiver, rose, plot}
## @end deftypefn
    
    
@function
def compass(varargin=None,*args,**kwargs):
    varargin = compass.varargin
    nargin = compass.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('compass',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:54
    if (nargin == 0 or nargin > 3):
        print_usage()
    
    if (nargin == 1 or (nargin == 2 and logical_not(isnumeric(varargin[2])))):
        z=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:61
        u=real(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:62
        v=imag(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:63
        have_line_spec=(nargin == 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:64
    else:
        if (nargin >= 2 and isnumeric(varargin[2])):
            u=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:66
            v=ravel(varargin[2]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:67
            have_line_spec=(nargin == 3)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:68
        else:
            print_usage()
    
    arrowsize=0.2
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:73
    line_spec='-b'
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:74
    if (have_line_spec):
        arg=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:77
        if (ischar(arg) or iscellstr(arg)):
            __,valid=__pltopt__('compass',arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:79
            if (valid):
                line_spec=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:81
            else:
                error('compass: invalid linestyle STYLE')
        else:
            error('compass: invalid linestyle STYLE')
    
    ## Matlab draws compass plots with the arrow head as one continous line,
  ## and each arrow separately.  This is completely different from quiver
  ## and quite ugly.
    n=length(u)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:93
    xend=copy(u)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:94
    xtmp=multiply(u,(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:95
    yend=copy(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:96
    ytmp=multiply(v,(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:97
    x=matlabarray(cat([zeros(1,n)],[xend],[xtmp - dot(v,arrowsize) / 3],[xend],[xtmp + dot(v,arrowsize) / 3]))
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:98
    y=matlabarray(cat([zeros(1,n)],[yend],[ytmp + dot(u,arrowsize) / 3],[yend],[ytmp - dot(u,arrowsize) / 3]))
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:100
    r,p=cart2pol(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:102
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:104
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:106
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:109
        hlist=polar(r,p,line_spec)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:110
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(hlist)
# /home/lei/octave-4.0.2/scripts/plot/draw/compass.m:118
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{n}] =} isonormals (@var{val}, @var{v})
## @deftypefnx {Function File} {[@var{n}] =} isonormals (@var{val}, @var{p})
## @deftypefnx {Function File} {[@var{n}] =} isonormals (@var{x}, @var{y}, @var{z}, @var{val}, @var{v})
## @deftypefnx {Function File} {[@var{n}] =} isonormals (@var{x}, @var{y}, @var{z}, @var{val}, @var{p})
## @deftypefnx {Function File} {[@var{n}] =} isonormals (@dots{}, "negate")
## @deftypefnx {Function File} {} isonormals (@dots{}, @var{p})
##
## Calculate normals to an isosurface.
##
## If called with one output argument and the first input argument
## @var{val} is a three-dimensional array that contains the data for an
## isosurface geometry and the second input argument @var{v} keeps the
## vertices of an isosurface then return the normals @var{n} in form of
## a matrix with the same size than @var{v} at computed points
## @command{[x, y, z] = meshgrid (1:l, 1:m, 1:n)}.  The output argument
## @var{n} can be taken to manually set @var{VertexNormals} of a patch.
##
## If called with further input arguments @var{x}, @var{y} and @var{z}
## which are three--dimensional arrays with the same size than @var{val}
## then the volume data is taken at those given points.  Instead of the
## vertices data @var{v} a patch handle @var{p} can be passed to this
## function.
##
## If given the string input argument @qcode{"negate"} as last input argument
## then compute the reverse vector normals of an isosurface geometry.
##
## If no output argument is given then directly redraw the patch that is
## given by the patch handle @var{p}.
##
## For example:
## @c Set example in small font to prevent overfull line
##
## @smallexample
## function [] = isofinish (p)
##   set (gca, "PlotBoxAspectRatioMode", "manual", ...
##             "PlotBoxAspectRatio", [1 1 1]);
##   set (p, "VertexNormals", -get (p,"VertexNormals")); # Revert normals
##   set (p, "FaceColor", "interp");
##   ## set (p, "FaceLighting", "phong");
##   ## light ("Position", [1 1 5]); # Available with JHandles
## endfunction
##
## N = 15;    # Increase number of vertices in each direction
## iso = .4;  # Change isovalue to .1 to display a sphere
## lin = linspace (0, 2, N);
## [x, y, z] = meshgrid (lin, lin, lin);
## c = abs ((x-.5).^2 + (y-.5).^2 + (z-.5).^2);
## figure (); # Open another figure window
##
## subplot (2,2,1); view (-38, 20);
## [f, v, cdat] = isosurface (x, y, z, c, iso, y);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", cdat, ...
##            "FaceColor", "interp", "EdgeColor", "none");
## isofinish (p);  # Call user function isofinish
##
## subplot (2,2,2); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", cdat, ...
##            "FaceColor", "interp", "EdgeColor", "none");
## isonormals (x, y, z, c, p); # Directly modify patch
## isofinish (p);
##
## subplot (2,2,3); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", cdat, ...
##            "FaceColor", "interp", "EdgeColor", "none");
## n = isonormals (x, y, z, c, v); # Compute normals of isosurface
## set (p, "VertexNormals", n);    # Manually set vertex normals
## isofinish (p);
##
## subplot (2,2,4); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", cdat, ...
##            "FaceColor", "interp", "EdgeColor", "none");
## isonormals (x, y, z, c, v, "negate"); # Use reverse directly
## isofinish (p);
## @end smallexample
##
## @seealso{isosurface, isocolors}
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def isonormals(varargin=None,*args,**kwargs):
    varargin = isonormals.varargin
    nargin = isonormals.nargin

    na=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:101
    negate=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:102
    if (ischar(varargin[nargin])):
        na=nargin - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:104
        if (strcmp(lower(varargin[nargin]),'negate')):
            negate=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:106
        else:
            error('isonormals: Unknown option \'%s\'',varargin[nargin])
    
    if 2 == (na):
        c=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:113
        vp=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:114
        x=arange(1,size(c,2))
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:115
        y=arange(1,size(c,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:116
        z=arange(1,size(c,3))
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:117
    else:
        if 5 == (na):
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:119
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:120
            z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:121
            c=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:122
            vp=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:123
        else:
            print_usage()
    
    if (isnumeric(vp) and columns(vp) == 3):
        pa=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:128
        v=copy(vp)
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:129
    else:
        if (ishandle(vp)):
            pa=copy(vp)
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:131
            v=get(pa,'Vertices')
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:132
        else:
            error('isonormals: Last argument is not a vertex list or a patch handle')
    
    if (negate):
        normals=- __interp_cube__(x,y,z,c,v,'normals')
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:137
    else:
        normals=__interp_cube__(x,y,z,c,v,'normals')
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:139
    
    if 0 == (nargout):
        if (logical_not(isempty(pa))):
            set(pa,'VertexNormals',normals)
    else:
        if 1 == (nargout):
            varargout=cellarray([normals])
# /home/lei/octave-4.0.2/scripts/plot/draw/isonormals.m:147
        else:
            print_usage()
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fplot (@var{fn}, @var{limits})
## @deftypefnx {Function File} {} fplot (@dots{}, @var{tol})
## @deftypefnx {Function File} {} fplot (@dots{}, @var{n})
## @deftypefnx {Function File} {} fplot (@dots{}, @var{fmt})
## @deftypefnx {Function File} {[@var{x}, @var{y}] =} fplot (@dots{})
## Plot a function @var{fn} within the range defined by @var{limits}.
##
## @var{fn} is a function handle, inline function, or string containing the
## name of the function to evaluate.
##
## The limits of the plot are of the form @w{@code{[@var{xlo}, @var{xhi}]}} or
## @w{@code{[@var{xlo}, @var{xhi}, @var{ylo}, @var{yhi}]}}.
##
## The next three arguments are all optional and any number of them may be
## given in any order.
##
## @var{tol} is the relative tolerance to use for the plot and defaults
## to 2e-3 (.2#).
##
## @var{n} is the minimum number of points to use.  When @var{n} is specified,
## the maximum stepsize will be @code{@var{xhi} - @var{xlo} / @var{n}}.  More
## than @var{n} points may still be used in order to meet the relative
## tolerance requirement.
##
## The @var{fmt} argument specifies the linestyle to be used by the plot
## command.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## With no output arguments the results are immediately plotted.  With two
## output arguments the 2-D plot data is returned.  The data can subsequently
## be plotted manually with @code{plot (@var{x}, @var{y})}.
##
## Example:
##
## @example
## @group
## fplot (@@cos, [0, 2*pi])
## fplot ("[cos(x), sin(x)]", [0, 2*pi])
## @end group
## @end example
##
## Programming Notes:
##
## @code{fplot} works best with continuous functions.  Functions with
## discontinuities are unlikely to plot well.  This restriction may be removed
## in the future.
##
## @code{fplot} requires that the function accept and return a vector argument.
## Consider this when writing user-defined functions and use @code{.*},
## @code{./}, etc.  See the function @code{vectorize} for potentially
## converting inline or anonymous functions to vectorized versions.
##  
## @seealso{ezplot, plot, vectorize}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
    
    
@function
def fplot(varargin=None,*args,**kwargs):
    varargin = fplot.varargin
    nargin = fplot.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('fplot',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:81
    if (nargin < 2 or nargin > 5):
        print_usage()
    
    fn=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:87
    limits=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:88
    varargin=varargin[3:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:89
    if (strcmp(typeinfo(fn),'inline function')):
        fn=vectorize(fn)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:92
        nam=formula(fn)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:93
    else:
        if (isa(fn,'function_handle')):
            nam=func2str(fn)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:95
        else:
            if (all(isalnum(fn))):
                nam=copy(fn)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:97
            else:
                if (ischar(fn)):
                    fn=vectorize(inline(fn))
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:99
                    nam=formula(fn)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:100
                else:
                    error('fplot: FN must be a function handle, inline function, or string')
    
    if (iscomplex(limits) or (numel(limits) != 2 and numel(limits) != 4)):
        error('fplot: LIMITS must be a real vector with 2 or 4 elements')
    
    n=5
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:109
    tol=0.002
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:110
    fmt=''
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:111
    for i in arange(1,numel(varargin)).reshape(-1):
        arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:113
        if (ischar(arg)):
            fmt=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:115
        else:
            if (isnumeric(arg) and isscalar(arg) and arg > 0):
                if (arg == fix(arg)):
                    n=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:118
                else:
                    tol=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:120
            else:
                error('fplot: bad input in position %d',i + 2)
    
    if (n != 5):
        ## n was specified
        x0=linspace(limits[1],limits[2],n / 2 + 1).T
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:129
        y0=feval(fn,x0)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:130
        x=linspace(limits[1],limits[2],n).T
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:131
        y=feval(fn,x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:132
    else:
        x0=linspace(limits[1],limits[2],5).T
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:134
        y0=feval(fn,x0)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:135
        n=8
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:136
        x=linspace(limits[1],limits[2],n).T
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:137
        y=feval(fn,x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:138
    
    if (rows(x0) != rows(y0)):
        ## FN is a constant value function
        y0=repmat(y0,size(x0))
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:143
        y=repmat(y,size(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:144
    
    err0=copy(Inf)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:147
    
    ##        the numerical quadrature algorithms do so that extra points are
  ##        used where they are needed and not spread evenly over the entire
  ##        x-range.  Try any function with a discontinuity, such as
  ##        fplot (@tan, [-2, 2]) or fplot ("1./x", [-3, 2]), to see the
  ##        problems with the current solution.
    
    while (n < 2 ** 18):

        yi=interp1(x0,y0,x,'linear')
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:157
        ## since neither estimate is known a priori to be better than the other.
        err=dot(0.5,max(ravel(abs((yi - y) / (yi + y)))))
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:160
        if (err < tol or abs(err - err0) < tol / 2):
            ## Either relative tolerance has been met OR
      ## algorithm has stopped making any reasonable progress per iteration.
            break
        x0=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:166
        y0=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:167
        err0=copy(err)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:168
        n=dot(2,(n - 1)) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:169
        x=linspace(limits[1],limits[2],n).T
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:170
        y=feval(fn,x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:171

    
    if (nargout == 2):
        X=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:175
        Y=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:176
    else:
        if (isempty(hax)):
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:179
        plot(hax,x,y,fmt)
        axis(hax,limits)
        if (isvector(y)):
            legend(hax,nam)
        else:
            for i in arange(1,columns(y)).reshape(-1):
                nams[i]=sprintf('%s(:,%i)',nam,i)
# /home/lei/octave-4.0.2/scripts/plot/draw/fplot.m:187
            legend(hax,nams[:])
    
    return X,Y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} plot (@var{y})
## @deftypefnx {Function File} {} plot (@var{x}, @var{y})
## @deftypefnx {Function File} {} plot (@var{x}, @var{y}, @var{fmt})
## @deftypefnx {Function File} {} plot (@dots{}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} plot (@var{x1}, @var{y1}, @dots{}, @var{xn}, @var{yn})
## @deftypefnx {Function File} {} plot (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} plot (@dots{})
## Produce 2-D plots.
##
## Many different combinations of arguments are possible.  The simplest
## form is
##
## @example
## plot (@var{y})
## @end example
##
## @noindent
## where the argument is taken as the set of @var{y} coordinates and the
## @var{x} coordinates are taken to be the range @code{1:numel (@var{y})}.
##
## If more than one argument is given, they are interpreted as
##
## @example
## plot (@var{y}, @var{property}, @var{value}, @dots{})
## @end example
##
## @noindent
## or
##
## @example
## plot (@var{x}, @var{y}, @var{property}, @var{value}, @dots{})
## @end example
##
## @noindent
## or
##
## @example
## plot (@var{x}, @var{y}, @var{fmt}, @dots{})
## @end example
##
## @noindent
## and so on.  Any number of argument sets may appear.  The @var{x} and
## @var{y} values are interpreted as follows:
##
## @itemize @bullet
## @item
## If a single data argument is supplied, it is taken as the set of @var{y}
## coordinates and the @var{x} coordinates are taken to be the indices of
## the elements, starting with 1.
##
## @item
## If @var{x} and @var{y} are scalars, a single point is plotted.
##
## @item
## @code{squeeze()} is applied to arguments with more than two dimensions,
## but no more than two singleton dimensions.
##
## @item
## If both arguments are vectors, the elements of @var{y} are plotted versus
## the elements of @var{x}.
##
## @item
## If @var{x} is a vector and @var{y} is a matrix, then
## the columns (or rows) of @var{y} are plotted versus @var{x}.
## (using whichever combination matches, with columns tried first.)
##
## @item
## If the @var{x} is a matrix and @var{y} is a vector,
## @var{y} is plotted versus the columns (or rows) of @var{x}.
## (using whichever combination matches, with columns tried first.)
##
## @item
## If both arguments are matrices, the columns of @var{y} are plotted
## versus the columns of @var{x}.  In this case, both matrices must have
## the same number of rows and columns and no attempt is made to transpose
## the arguments to make the number of rows match.
## @end itemize
##
## Multiple property-value pairs may be specified, but they must appear
## in pairs.  These arguments are applied to the line objects drawn by
## @code{plot}.  Useful properties to modify are @qcode{"linestyle"},
## @qcode{"linewidth"}, @qcode{"color"}, @qcode{"marker"},
## @qcode{"markersize"}, @qcode{"markeredgecolor"}, @qcode{"markerfacecolor"}.  
## @xref{Line Properties}.  
##
## The @var{fmt} format argument can also be used to control the plot style.
## It is a string composed of four optional parts:
## "<linestyle><marker><color><;displayname;>".
## When a marker is specified, but no linestyle, only the markers are
## plotted.  Similarly, if a linestyle is specified, but no marker, then
## only lines are drawn.  If both are specified then lines and markers will
## be plotted.  If no @var{fmt} and no @var{property}/@var{value} pairs are
## given, then the default plot style is solid lines with no markers and the
## color determined by the @qcode{"colororder"} property of the current axes.
##
## Format arguments:
##
## @table @asis
## @item linestyle
##
## @multitable @columnfractions 0.06 0.94
## @item @samp{-}  @tab Use solid lines (default).
## @item @samp{--} @tab Use dashed lines.
## @item @samp{:}  @tab Use dotted lines.
## @item @samp{-.} @tab Use dash-dotted lines.
## @end multitable
##
## @item marker
##
## @multitable @columnfractions 0.06 0.94
## @item @samp{+} @tab crosshair
## @item @samp{o} @tab circle
## @item @samp{*} @tab star
## @item @samp{.} @tab point
## @item @samp{x} @tab cross
## @item @samp{s} @tab square
## @item @samp{d} @tab diamond
## @item @samp{^} @tab upward-facing triangle
## @item @samp{v} @tab downward-facing triangle
## @item @samp{>} @tab right-facing triangle
## @item @samp{<} @tab left-facing triangle
## @item @samp{p} @tab pentagram
## @item @samp{h} @tab hexagram
## @end multitable
##
## @item color
##
## @multitable @columnfractions 0.06 0.94
## @item @samp{k} @tab blacK
## @item @samp{r} @tab Red
## @item @samp{g} @tab Green
## @item @samp{b} @tab Blue
## @item @samp{m} @tab Magenta
## @item @samp{c} @tab Cyan
## @item @samp{w} @tab White
## @end multitable
##
## @item @qcode{";displayname;"}
## Here @qcode{"displayname"} is the label to use for the plot legend.
## @end table
##
## The @var{fmt} argument may also be used to assign legend labels.
## To do so, include the desired label between semicolons after the
## formatting sequence described above, e.g., @qcode{"+b;Key Title;"}.
## Note that the last semicolon is required and Octave will generate
## an error if it is left out.
##
## Here are some plot examples:
##
## @example
## plot (x, y, "or", x, y2, x, y3, "m", x, y4, "+")
## @end example
##
## This command will plot @code{y} with red circles, @code{y2} with solid
## lines, @code{y3} with solid magenta lines, and @code{y4} with points
## displayed as @samp{+}.
##
## @example
## plot (b, "*", "markersize", 10)
## @end example
##
## This command will plot the data in the variable @code{b},
## with points displayed as @samp{*} and a marker size of 10.
##
## @example
## @group
## t = 0:0.1:6.3;
## plot (t, cos(t), "-;cos(t);", t, sin(t), "-b;sin(t);");
## @end group
## @end example
##
## This will plot the cosine and sine functions and label them accordingly
## in the legend.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to
## the created line objects.
##
## To save a plot, in one of several image formats such as PostScript
## or PNG, use the @code{print} command.
##
## @seealso{axis, box, grid, hold, legend, title, xlabel, ylabel, xlim, ylim, ezplot, errorbar, fplot, line, plot3, polar, loglog, semilogx, semilogy, subplot}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def plot(varargin=None,*args,**kwargs):
    varargin = plot.varargin
    nargin = plot.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('plot',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:210
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:216
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:218
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:221
        htmp=__plt__('plot',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:222
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot.m:230
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
## Copyright (C) 2010 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pie3 (@var{x})
## @deftypefnx {Function File} {} pie3 (@dots{}, @var{explode})
## @deftypefnx {Function File} {} pie3 (@dots{}, @var{labels})
## @deftypefnx {Function File} {} pie3 (@var{hax}, @dots{});
## @deftypefnx {Function File} {@var{h} =} pie3 (@dots{});
## Plot a 3-D pie chart.
##
## Called with a single vector argument, produces a 3-D pie chart of the
## elements in @var{x}.  The size of the ith slice is the percentage that the
## element @var{x}i represents of the total sum of @var{x}:
## @code{pct = @var{x}(i) / sum (@var{x})}.
##
## The optional input @var{explode} is a vector of the same length as @var{x}
## that, if nonzero, "explodes" the slice from the pie chart.
##
## The optional input @var{labels} is a cell array of strings of the same
## length as @var{x} specifying the label for each slice.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a list of graphics handles to the
## patch, surface, and text objects generating the plot.
##
## Note: If @code{sum (@var{x}) @leq{} 1} then the elements of @var{x} are
## interpreted as percentages directly and are not normalized by @code{sum (x)}.
## Furthermore, if the sum is less than 1 then there will be a missing slice
## in the pie plot to represent the missing, unspecified percentage.
##
## @seealso{pie, bar, hist, rose}
## @end deftypefn
    
    ## Very roughly based on pie.m from octave-forge whose author was
## Daniel Heiserer <Daniel.heiserer@physik.tu-muenchen.de>
    
    
@function
def pie3(varargin=None,*args,**kwargs):
    varargin = pie3.varargin
    nargin = pie3.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('pie3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:58
    if (nargin < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:64
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:66
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:69
        htmp=__pie__('pie3',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:70
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/pie3.m:78
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} plot3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} plot3 (@var{x}, @var{y}, @var{z}, @var{prop}, @var{value}, @dots{})
## @deftypefnx {Function File} {} plot3 (@var{x}, @var{y}, @var{z}, @var{fmt})
## @deftypefnx {Function File} {} plot3 (@var{x}, @var{cplx})
## @deftypefnx {Function File} {} plot3 (@var{cplx})
## @deftypefnx {Function File} {} plot3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} plot3 (@dots{})
## Produce 3-D plots.
##
## Many different combinations of arguments are possible.  The simplest
## form is
##
## @example
## plot3 (@var{x}, @var{y}, @var{z})
## @end example
##
## @noindent
## in which the arguments are taken to be the vertices of the points to
## be plotted in three dimensions.  If all arguments are vectors of the
## same length, then a single continuous line is drawn.  If all arguments
## are matrices, then each column of is treated as a separate line.  No attempt
## is made to transpose the arguments to make the number of rows match.
##
## If only two arguments are given, as
##
## @example
## plot3 (@var{x}, @var{cplx})
## @end example
##
## @noindent
## the real and imaginary parts of the second argument are used
## as the @var{y} and @var{z} coordinates, respectively.
##
## If only one argument is given, as
##
## @example
## plot3 (@var{cplx})
## @end example
##
## @noindent
## the real and imaginary parts of the argument are used as the @var{y}
## and @var{z} values, and they are plotted versus their index.
##
## Arguments may also be given in groups of three as
##
## @example
## plot3 (@var{x1}, @var{y1}, @var{z1}, @var{x2}, @var{y2}, @var{z2}, @dots{})
## @end example
##
## @noindent
## in which each set of three arguments is treated as a separate line or
## set of lines in three dimensions.
##
## To plot multiple one- or two-argument groups, separate each group
## with an empty format string, as
##
## @example
## plot3 (@var{x1}, @var{c1}, "", @var{c2}, "", @dots{})
## @end example
##
## Multiple property-value pairs may be specified which will affect the line
## objects drawn by @code{plot3}.  If the @var{fmt} argument is supplied it
## will format the line objects in the same manner as @code{plot}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Example:
##
## @example
## @group
## z = [0:0.05:5];
## plot3 (cos (2*pi*z), sin (2*pi*z), z, ";helix;");
## plot3 (z, exp (2i*pi*z), ";complex sinusoid;");
## @end group
## @end example
## @seealso{ezplot3, plot}
## @end deftypefn
    
    ## Author: Paul Kienzle
##         (modified from __plt__.m)
    
    
@function
def plot3(varargin=None,*args,**kwargs):
    varargin = plot3.varargin
    nargin = plot3.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('plot3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:106
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:112
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:114
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:117
        x_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:119
        y_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:120
        z_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:121
        property_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:122
        fmt_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:123
        properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:124
        tlgnd=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:125
        hlgnd=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:126
        idx=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:127
        arg=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:130
        while (arg < nargs):

            new=varargin[arg]
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:132
            new_cell=varargin[arg]
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:133
            if (property_set):
                properties=matlabarray(cat(properties,new_cell))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:136
                property_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:137
                continue
            if (ischar(new)):
                if (logical_not(z_set)):
                    if (logical_not(y_set)):
                        if (logical_not(x_set)):
                            error('plot3: needs X, [ Y, [ Z ] ]')
                        else:
                            y=real(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:147
                            z=imag(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:148
                            y_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:149
                            z_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:150
                            if (rows(x) > 1):
                                x=repmat((arange(1,rows(x))).T,1,columns(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:152
                            else:
                                x=arange(1,columns(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:154
                    else:
                        z=imag(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:158
                        y=real(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:159
                        z_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:160
                if (logical_not(fmt_set)):
                    options,valid=__pltopt__('plot3',new,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:165
                    if (logical_not(valid)):
                        properties=matlabarray(cat(properties,new_cell))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:167
                        property_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:168
                        continue
                    else:
                        fmt_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:171
                        while (arg < nargs and ischar(varargin[arg + 1])):

                            if (nargs - arg < 2):
                                error('plot3: properties must appear followed by a value')
                            properties=matlabarray(cat(properties,varargin[arg + 1:arg + 2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:176
                            arg += 2

                else:
                    properties=matlabarray(cat(properties,new_cell))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:181
                    property_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:182
                    continue
                if (isvector(x) and isvector(y)):
                    if (isvector(z)):
                        x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:188
                        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:189
                        z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:190
                    else:
                        if (length(x) == rows(z) and length(y) == columns(z)):
                            x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:192
                        else:
                            error('plot3: [length(X), length(Y)] must match size (Z)')
                if (logical_not(size_equal(x,y,z))):
                    error('plot3: X, Y, and Z must have the same shape')
                else:
                    if (ndims(x) > 2):
                        error('plot3: X, Y, and Z must not have more than two dimensions')
                for i in arange(1,columns(x)).reshape(-1):
                    linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:205
                    marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:206
                    if (isempty(marker) and isempty(linestyle)):
                        linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:208
                    color=options.color
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:210
                    if (isempty(color)):
                        color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:212
                    htmp[++ idx]=line(x[:,i],y[:,i],z[:,i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:215
                    key=options.key
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:218
                    if (logical_not(isempty(key))):
                        hlgnd=matlabarray(cat(hlgnd,htmp[idx]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:220
                        tlgnd=cellarray([tlgnd[:],key])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:221
                x_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:225
                y_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:226
                z_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:227
                fmt_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:228
                properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:229
            else:
                if (logical_not(x_set)):
                    x=copy(new)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:231
                    x_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:232
                else:
                    if (logical_not(y_set)):
                        y=copy(new)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:234
                        y_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:235
                    else:
                        if (logical_not(z_set)):
                            z=copy(new)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:237
                            z_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:238
                        else:
                            if (isvector(x) and isvector(y)):
                                if (isvector(z)):
                                    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:242
                                    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:243
                                    z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:244
                                else:
                                    if (length(x) == rows(z) and length(y) == columns(z)):
                                        x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:246
                                    else:
                                        error('plot3: [length(X), length(Y)] must match size (Z)')
                            if (logical_not(size_equal(x,y,z))):
                                error('plot3: X, Y, and Z must have the same shape')
                            else:
                                if (ndims(x) > 2):
                                    error('plot3: X, Y, and Z must not have more than two dimensions')
                            options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:258
                            for i in arange(1,columns(x)).reshape(-1):
                                linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:260
                                marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:261
                                if (isempty(marker) and isempty(linestyle)):
                                    linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:263
                                color=options.color
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:265
                                if (isempty(color)):
                                    color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:267
                                htmp[++ idx]=line(x[:,i],y[:,i],z[:,i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:270
                                key=options.key
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:273
                                if (logical_not(isempty(key))):
                                    hlgnd=matlabarray(cat(hlgnd,htmp[idx]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:275
                                    tlgnd=cellarray([tlgnd[:],key])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:276
                            x=copy(new)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:280
                            y_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:281
                            z_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:282
                            fmt_set=0
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:283
                            properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:284

        if (property_set):
            error('plot3: properties must appear followed by a value')
        ## Handle last plot.
        if (x_set):
            if (y_set):
                if (logical_not(z_set)):
                    z=imag(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:298
                    y=real(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:299
                    z_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:300
            else:
                y=real(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:303
                z=imag(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:304
                y_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:305
                z_set=1
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:306
                if (rows(x) > 1):
                    x=repmat((arange(1,rows(x))).T,1,columns(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:308
                else:
                    x=arange(1,columns(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:310
            if (isvector(x) and isvector(y)):
                if (isvector(z)):
                    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:316
                    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:317
                    z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:318
                else:
                    if (length(x) == rows(z) and length(y) == columns(z)):
                        x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:320
                    else:
                        error('plot3: [length(X), length(Y)] must match size (Z)')
            if (logical_not(size_equal(x,y,z))):
                error('plot3: X, Y, and Z must have the same shape')
            else:
                if (ndims(x) > 2):
                    error('plot3: X, Y, and Z must not have more than two dimensions')
            options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:332
            for i in arange(1,columns(x)).reshape(-1):
                linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:335
                marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:336
                if (isempty(marker) and isempty(linestyle)):
                    linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:338
                color=options.color
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:340
                if (isempty(color)):
                    color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:342
                htmp[++ idx]=line(x[:,i],y[:,i],z[:,i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:345
                key=options.key
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:348
                if (logical_not(isempty(key))):
                    hlgnd=matlabarray(cat(hlgnd,htmp[idx]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:350
                    tlgnd=cellarray([tlgnd[:],key])
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:351
        if (logical_not(isempty(hlgnd))):
            legend(hax,hlgnd,tlgnd)
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30))
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0 and idx > 0):
        retval=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/plot3.m:371
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Michael Goffioul
## Copyright (C) 2007-2009 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} area (@var{y})
## @deftypefnx {Function File} {} area (@var{x}, @var{y})
## @deftypefnx {Function File} {} area (@dots{}, @var{lvl})
## @deftypefnx {Function File} {} area (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} area (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} area (@dots{})
## Area plot of the columns of @var{y}.
##
## This plot shows the contributions of each column value to the row sum.
## It is functionally similar to @code{plot (@var{x}, cumsum (@var{y}, 2))},
## except that the area under the curve is shaded.
##
## If the @var{x} argument is omitted it defaults to @code{1:rows (@var{y})}.
## A value @var{lvl} can be defined that determines where the base level of
## the shading under the curve should be defined.  The default level is 0.
##
## Additional property/value pairs are passed directly to the underlying patch
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the hggroup
## object comprising the area patch objects.  The @qcode{"BaseValue"} property
## of the hggroup can be used to adjust the level where shading begins.
##
## Example: Verify identity sin^2 + cos^2 = 1
##
## @example
## @group
## t = linspace (0, 2*pi, 100)';
## y = [sin(t).^2, cos(t).^2];
## area (t, y);
## legend ("sin^2", "cos^2", "location", "NorthEastOutside");
## @end group
## @end example
## @seealso{plot, patch}
## @end deftypefn
    
    
@function
def area(varargin=None,*args,**kwargs):
    varargin = area.varargin
    nargin = area.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('area',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:62
    if (nargin == 0):
        print_usage()
    
    x=y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:68
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:68
    bv=0
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:69
    num_numeric=find(cellfun('isclass',varargin,'char'),1) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:71
    if (isempty(num_numeric)):
        num_numeric=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:73
    
    if 1 == (num_numeric):
        y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:78
    else:
        if 2 == (num_numeric):
            if (isscalar(varargin[2])):
                y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:81
                bv=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:82
            else:
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:84
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:85
        else:
            if 3 == (num_numeric):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:88
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:89
                bv=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:90
            else:
                print_usage()
    
    if (logical_not(isreal(x)) or logical_not(isreal(y))):
        error('area: X and Y must be real vectors or matrices')
    
    if (logical_not(isreal(bv)) or logical_not(isscalar(bv))):
        error('area: LVL must be a real scalar')
    
    if (isvector(y)):
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:103
    
    if (isempty(x)):
        x=repmat(cat(arange(1,rows(y))).T,1,columns(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:106
    else:
        if (isvector(x)):
            x=repmat(ravel(x),1,columns(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:108
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:111
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:113
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:116
        htmp=__area__(hax,x,y,bv,varargin[num_numeric + 1:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:117
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:125
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __area__(ax=None,x=None,y=None,bv=None,varargin=None,*args,**kwargs):
    varargin = __area__.varargin
    nargin = __area__.nargin

    y0=dot(bv,ones(1,rows(y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:132
    y0=zeros(1,rows(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:133
    retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:134
    for i in arange(1,columns(y)).reshape(-1):
        lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:137
        hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:140
        retval=matlabarray(cat([retval],[hg]))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:141
        args=__add_datasource__('area',hg,cellarray(['x','y']),varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:142
        x1=x[:,1].T
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:144
        y1=y[:,i].T
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:145
        addproperty('xdata',hg,'data',x1)
        addproperty('ydata',hg,'data',y1)
        addlistener(hg,'xdata',update_data)
        addlistener(hg,'ydata',update_data)
        if (i == 1):
            h=patch(ax,cat(x1[1],x1,fliplr(x1)),cat(bv,y1,dot(bv,ones(1,length(y1)))),lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:153
        else:
            y1=y0 + y1
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:156
            h=patch(ax,cat(x1[1],x1,fliplr(x1)),cat(y0[1],y1,fliplr(y0)),lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:157
        y0=copy(y1)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:161
        addproperty('basevalue',hg,'data',bv)
        addlistener(hg,'basevalue',move_baseline)
        addproperty('edgecolor',hg,'patchedgecolor',get(h,'edgecolor'))
        addproperty('facecolor',hg,'patchfacecolor',get(h,'facecolor'))
        addproperty('linestyle',hg,'patchlinestyle',get(h,'linestyle'))
        addproperty('linewidth',hg,'patchlinewidth',get(h,'linewidth'))
        addlistener(hg,'edgecolor',update_props)
        addlistener(hg,'facecolor',update_props)
        addlistener(hg,'linestyle',update_props)
        addlistener(hg,'linewidth',update_props)
        addproperty('areagroup',hg,'data')
        set(retval,'areagroup',retval)
        addproperty('hittestarea',hg,'radio','on|{off}','off')
        if (logical_not(isempty(args))):
            set(hg,args[:])
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,d=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:190
    set(kids,'edgecolor',get(h,'edgecolor'),'facecolor',get(h,'facecolor'),'linestyle',get(h,'linestyle'),'linewidth',get(h,'linewidth'))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def move_baseline(h=None,d=None,*args,**kwargs):
    varargin = move_baseline.varargin
    nargin = move_baseline.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:203
            hlist=get(h,'areagroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:204
            b0=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:205
            for hh in ravel(hlist).T.reshape(-1):
                if (hh != h):
                    b1=get(hh,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:209
                    if (b1 != b0):
                        set(hh,'basevalue',b0)
            update_data(h,d)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:217
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,d=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    hlist=get(h,'areagroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:223
    bv=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:224
    for i in arange(1,length(hlist)).reshape(-1):
        hh=hlist[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:226
        x1=ravel(get(hh,'xdata'))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:227
        y1=ravel(get(hh,'ydata'))
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:228
        set(get(hh,'children'),'xdata',cat([x1[1]],[x1],[flipud(x1)]))
        if (i == 1):
            set(get(hh,'children'),'ydata',cat([bv],[y1],[dot(bv,ones(length(y1),1))]))
        else:
            y1=y0 + y1
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:234
            set(get(hh,'children'),'ydata',cat([y0[1]],[y1],[flipud(y0)]))
        y0=copy(y1)
# /home/lei/octave-4.0.2/scripts/plot/draw/area.m:238
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} semilogyerr (@var{y}, @var{ey})
## @deftypefnx {Function File} {} semilogyerr (@var{y}, @dots{}, @var{fmt})
## @deftypefnx {Function File} {} semilogyerr (@var{x}, @var{y}, @var{ey})
## @deftypefnx {Function File} {} semilogyerr (@var{x}, @var{y}, @var{err}, @var{fmt})
## @deftypefnx {Function File} {} semilogyerr (@var{x}, @var{y}, @var{lerr}, @var{uerr}, @var{fmt})
## @deftypefnx {Function File} {} semilogyerr (@var{x}, @var{y}, @var{ex}, @var{ey}, @var{fmt})
## @deftypefnx {Function File} {} semilogyerr (@var{x}, @var{y}, @var{lx}, @var{ux}, @var{ly}, @var{uy}, @var{fmt})
## @deftypefnx {Function File} {} semilogyerr (@var{x1}, @var{y1}, @dots{}, @var{fmt}, @var{xn}, @var{yn}, @dots{})
## @deftypefnx {Function File} {} semilogyerr (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} semilogyerr (@dots{})
## Produce 2-D plots using a logarithmic scale for the y-axis and errorbars
## at each data point.
##
## Many different combinations of arguments are possible.  The most common
## form is
##
## @example
## semilogyerr (@var{x}, @var{y}, @var{ey}, @var{fmt})
## @end example
##
## @noindent
## which produces a semi-logarithmic plot of @var{y} versus @var{x}
## with errors in the @var{y}-scale defined by @var{ey} and the plot
## format defined by @var{fmt}.  @xref{XREFerrorbar,,errorbar}, for available
## formats and additional information.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## @seealso{errorbar, semilogxerr, loglogerr}
## @end deftypefn
    
    ## Created: 20.2.2001
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def semilogyerr(varargin=None,*args,**kwargs):
    varargin = semilogyerr.varargin
    nargin = semilogyerr.nargin

    hax,varargin=__plt_get_axis_arg__('semilogyerr',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:58
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:60
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:62
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:65
        set(hax,'yscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'yminortick','on')
        htmp=__errcomm__('semilogyerr',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:72
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogyerr.m:81
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Sylvain Pelissier
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ellipsoid (@var{xc}, @var{yc}, @var{zc}, @var{xr}, @var{yr}, @var{zr}, @var{n})
## @deftypefnx {Function File} {} ellipsoid (@dots{}, @var{n})
## @deftypefnx {Function File} {} ellipsoid (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} ellipsoid (@dots{})
## Plot a 3-D ellipsoid.
##
## The inputs @var{xc}, @var{yc}, @var{zc} specify the center of the ellipsoid.
## The inputs @var{xr}, @var{yr}, @var{zr} specify the semi-major axis lengths.
##
## The optional input @var{n} determines the number of faces around the
## circumference of the cylinder.  The default value is 20.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## If outputs are requested @code{ellipsoid} returns three matrices in
## @code{meshgrid} format, such that @code{surf (@var{x}, @var{y}, @var{z})}
## generates the ellipsoid.
## @seealso{cylinder, rectangle, sphere}
## @end deftypefn
    
    ## Author: Sylvain Pelissier <sylvain.pelissier@gmail.com>
    
    
@function
def ellipsoid(varargin=None,*args,**kwargs):
    varargin = ellipsoid.varargin
    nargin = ellipsoid.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('ellipsoid',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:45
    if (nargin != 6 and nargin != 7):
        print_usage()
    
    xc=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:51
    yc=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:52
    zc=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:53
    xr=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:54
    yr=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:55
    zr=varargin[6]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:56
    if (nargin == 6):
        n=20
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:59
    else:
        n=varargin[7]
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:61
    
    theta=linspace(0,dot(2,pi),n + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:64
    phi=linspace(- pi / 2,pi / 2,n + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:65
    theta,phi=meshgrid(theta,phi,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:66
    x=multiply(multiply(xr,cos(phi)),cos(theta)) + xc
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:68
    y=multiply(multiply(yr,cos(phi)),sin(theta)) + yc
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:69
    z=multiply(zr,sin(phi)) + zc
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:70
    if (nargout > 0):
        xx=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:73
        yy=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:74
        zz=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:75
    else:
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:77
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:79
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/ellipsoid.m:82
            surf(x,y,z)
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
    
    return xx,yy,zz
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2009-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Author: Martin Helm <martin@mhelm.de>
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{vxyz}, @var{idx}, @var{frac}] =} __interp_cube__ (@var{x}, @var{y}, @var{z}, @var{val}, @var{v})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __interp_cube__(x=None,y=None,z=None,val=None,v=None,req='values',*args,**kwargs):
    varargin = __interp_cube__.varargin
    nargin = __interp_cube__.nargin

    if (isnumeric(x) and ndims(x) == 3 and isnumeric(y) and ndims(y) == 3 and isnumeric(z) and ndims(z) == 3 and size_equal(x,y,z,val)):
        x=ravel(squeeze(x[1,:,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:29
        y=ravel(squeeze(y[:,1,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:30
        z=ravel(squeeze(z[1,1,:]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:31
    else:
        if (isvector(x) and isvector(y) and isvector(z)):
            x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:33
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:34
            z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:35
        else:
            error('__interp_cube__: X, Y, Z have wrong dimensions')
    
    if (size(val) != cat(length(x),length(y),length(z))):
        error('__interp_cube__: VAL has wrong dimensions')
    
    if (columns(v) != 3):
        error('V has to be Nx3 matrix')
    
    ##if (! ischar (req))
  ## error ('__interp_cube__: Invalid request parameter use "values", "normals" or "normals8"');
  ##endif
    if (isempty(v)):
        Vxyz=idx=frac=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:49
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:49
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:49
        return Vxyz,idx,frac
    
    if 'normals' == (req):
        idx,frac=cube_idx(x,y,z,v,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:55
        dx=x[2:end()] - x[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:57
        dy=y[2:end()] - y[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:58
        dz=z[2:end()] - z[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:59
        dx=multiply(0.5,cat([dx],[dx[end()]])(idx[:,2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:60
        dy=multiply(0.5,cat([dy],[dy[end()]])(idx[:,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:61
        dz=multiply(0.5,cat([dz],[dz[end()]])(idx[:,3]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:62
        p000=matlabarray(cat(v[:,1] - dx,v[:,2] - dy,v[:,3] - dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:64
        p100=matlabarray(cat(v[:,1] + dx,v[:,2] - dy,v[:,3] - dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:65
        p010=matlabarray(cat(v[:,1] - dx,v[:,2] + dy,v[:,3] - dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:66
        p001=matlabarray(cat(v[:,1] - dx,v[:,2] - dy,v[:,3] + dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:67
        p011=matlabarray(cat(v[:,1] - dx,v[:,2] + dy,v[:,3] + dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:68
        p101=matlabarray(cat(v[:,1] + dx,v[:,2] - dy,v[:,3] + dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:69
        p110=matlabarray(cat(v[:,1] + dx,v[:,2] + dy,v[:,3] - dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:70
        p111=matlabarray(cat(v[:,1] + dx,v[:,2] + dy,v[:,3] + dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:71
        v000=interp_cube_trilin(x,y,z,val,p000)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:73
        v100=interp_cube_trilin(x,y,z,val,p100)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:74
        v010=interp_cube_trilin(x,y,z,val,p010)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:75
        v001=interp_cube_trilin(x,y,z,val,p001)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:76
        v011=interp_cube_trilin(x,y,z,val,p011)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:77
        v101=interp_cube_trilin(x,y,z,val,p101)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:78
        v110=interp_cube_trilin(x,y,z,val,p110)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:79
        v111=interp_cube_trilin(x,y,z,val,p111)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:80
        Dx=- v000+ v100- v010- v001- v011+ v101+ v110+ v111
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:82
        Dy=- v000- v100+ v010- v001+ v011- v101+ v110+ v111
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:83
        Dz=- v000- v100- v010+ v001+ v011+ v101- v110+ v111
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:84
        Vxyz=multiply(0.5,cat(Dx / dx,Dy / dy,Dz / dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:85
    else:
        if 'normals8' == (req):
            idx,frac=cube_idx(x,y,z,v,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:87
            dx=x[2:end()] - x[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:89
            dy=y[2:end()] - y[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:90
            dz=z[2:end()] - z[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:91
            dx=cat([dx],[dx[end()]])(idx[:,2])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:92
            dy=cat([dy],[dy[end()]])(idx[:,1])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:93
            dz=cat([dz],[dz[end()]])(idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:94
            Dx,Dy,Dz,idx,frac=interp_cube_trilin_grad(x,y,z,val,v,nargout=5)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:95
            Vxyz=matlabarray(cat(Dx / dx,Dy / dy,Dz / dz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:96
        else:
            if 'values' == (req):
                Vxyz,idx,frac=interp_cube_trilin(x,y,z,val,v,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:98
            else:
                error('__interp_cube__: Invalid request type "%s", use "values", "normals" or "normals8"',req)
    
    return Vxyz,idx,frac
    
if __name__ == '__main__':
    pass
    
    
@function
def interp_cube_trilin(x=None,y=None,z=None,val=None,v=None,*args,**kwargs):
    varargin = interp_cube_trilin.varargin
    nargin = interp_cube_trilin.nargin

    idx,frac=cube_idx(ravel(x),ravel(y),ravel(z),v,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:105
    sval=size(val)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:106
    i000=sub2ind(sval,idx[:,1],idx[:,2],idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:107
    i100=sub2ind(sval,idx[:,1] + 1,idx[:,2],idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:108
    i010=sub2ind(sval,idx[:,1],idx[:,2] + 1,idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:109
    i001=sub2ind(sval,idx[:,1],idx[:,2],idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:110
    i101=sub2ind(sval,idx[:,1] + 1,idx[:,2],idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:111
    i011=sub2ind(sval,idx[:,1],idx[:,2] + 1,idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:112
    i110=sub2ind(sval,idx[:,1] + 1,idx[:,2] + 1,idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:113
    i111=sub2ind(sval,idx[:,1] + 1,idx[:,2] + 1,idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:114
    Bx=frac[:,1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:115
    By=frac[:,2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:116
    Bz=frac[:,3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:117
    Vxyz=multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(val[i000],(1- Bx)),(1- By)),(1- Bz)+ val[i100]),Bx),(1- By)),(1- Bz)+ val[i010]),(1- Bx)),By),(1- Bz)+ val[i001]),(1- Bx)),(1- By)),Bz+ val[i011]),(1- Bx)),By),Bz+ val[i101]),Bx),(1- By)),Bz+ val[i110]),Bx),By),(1- Bz)+ val[i111]),Bx),By),Bz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:118
    return Vxyz,idx,frac
    
if __name__ == '__main__':
    pass
    
    
@function
def interp_cube_trilin_grad(x=None,y=None,z=None,val=None,v=None,*args,**kwargs):
    varargin = interp_cube_trilin_grad.varargin
    nargin = interp_cube_trilin_grad.nargin

    idx,frac=cube_idx(ravel(x),ravel(y),ravel(z),v,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:130
    sval=size(val)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:131
    i000=sub2ind(sval,idx[:,1],idx[:,2],idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:132
    i100=sub2ind(sval,idx[:,1] + 1,idx[:,2],idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:133
    i010=sub2ind(sval,idx[:,1],idx[:,2] + 1,idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:134
    i001=sub2ind(sval,idx[:,1],idx[:,2],idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:135
    i101=sub2ind(sval,idx[:,1] + 1,idx[:,2],idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:136
    i011=sub2ind(sval,idx[:,1],idx[:,2] + 1,idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:137
    i110=sub2ind(sval,idx[:,1] + 1,idx[:,2] + 1,idx[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:138
    i111=sub2ind(sval,idx[:,1] + 1,idx[:,2] + 1,idx[:,3] + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:139
    Bx=frac[:,1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:140
    By=frac[:,2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:141
    Bz=frac[:,3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:142
    Dx=multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(val[i000],- 1),(1- By)),(1- Bz)+ val[i100]),(1- By)),(1- Bz)+ val[i010]),- 1),By),(1- Bz)+ val[i001]),- 1),(1- By)),Bz+ val[i011]),- 1),By),Bz+ val[i101]),(1- By)),Bz+ val[i110]),By),(1- Bz)+ val[i111]),By),Bz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:143
    Dy=multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(val[i000],(1- Bx)),- 1),(1- Bz)+ val[i100]),Bx),- 1),(1- Bz)+ val[i010]),(1- Bx)),(1- Bz)+ val[i001]),(1- Bx)),- 1),Bz+ val[i011]),(1- Bx)),Bz+ val[i101]),Bx),- 1),Bz+ val[i110]),Bx),(1- Bz)+ val[i111]),Bx),Bz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:152
    Dz=multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(multiply(val[i000],(1- Bx)),(1- By)),- 1+ val[i100]),Bx),(1- By)),- 1+ val[i010]),(1- Bx)),By),- 1+ val[i001]),(1- Bx)),(1- By)+ val[i011]),(1- Bx)),By) + multiply(multiply(multiply(multiply(multiply(multiply(multiply(val[i101],Bx),(1- By)+ val[i110]),Bx),By),- 1+ val[i111]),Bx),By)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:161
    return Dx,Dy,Dz,idx,frac
    
if __name__ == '__main__':
    pass
    
    
@function
def cube_idx(x=None,y=None,z=None,v=None,*args,**kwargs):
    varargin = cube_idx.varargin
    nargin = cube_idx.nargin

    idx=zeros(size(v))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:173
    frac=zeros(size(v))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:174
    idx[:,2]=lookup(x[2:end() - 1],v[:,1]) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:175
    frac[:,2]=(v[:,1] - x[idx[:,2]]) / (x[idx[:,2] + 1] - x[idx[:,2]])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:176
    idx[:,1]=lookup(y[2:end() - 1],v[:,2]) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:178
    frac[:,1]=(v[:,2] - y[idx[:,1]]) / (y[idx[:,1] + 1] - y[idx[:,1]])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:179
    idx[:,3]=lookup(z[2:end() - 1],v[:,3]) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:181
    frac[:,3]=(v[:,3] - z[idx[:,3]]) / (z[idx[:,3] + 1] - z[idx[:,3]])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__interp_cube__.m:182
    return idx,frac
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2006-2015 Michel D. Schmid
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} __stem__ (@var{have_z}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
## Adapted-by: jwe
    
    
@function
def __stem__(have_z=None,varargin=None,*args,**kwargs):
    varargin = __stem__.varargin
    nargin = __stem__.nargin

    if (have_z):
        caller='stem3'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:30
    else:
        caller='stem'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:32
    
    hax,varargin,nargin=__plt_get_axis_arg__(caller,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:35
    x,y,z,dofill,llc,ls,mmc,ms,varargin=check_stem_arg(have_z,varargin[:],nargout=9)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:37
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:40
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:42
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:45
        hold_state=get(hax,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:46
        set(hax,'nextplot','add')
        h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:49
        nx=rows(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:50
        h_baseline=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:51
        for i in arange(1,columns(x)).reshape(-1):
            if (have_z):
                xt=ravel(x).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:55
                xt=ravel(cat([xt],[xt],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:56
                yt=ravel(y).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:57
                yt=ravel(cat([yt],[yt],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:58
                zt=ravel(z).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:59
                zt=ravel(cat([zeros(1,nx)],[zt],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:60
            else:
                xt=x[:,i].T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:62
                xt=ravel(cat([xt],[xt],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:63
                yt=y[:,i].T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:64
                yt=ravel(cat([zeros(1,nx)],[yt],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:65
            if (isempty(llc)):
                lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:69
            else:
                lc=copy(llc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:71
            if (isempty(mmc)):
                mc=copy(lc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:75
            else:
                mc=copy(mmc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:77
            if (dofill):
                fc=copy(mc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:81
            else:
                fc='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:83
            ## Must occur after __next_line_color__ in order to work correctly.
            hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:87
            h=matlabarray(cat([h],[hg]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:88
            args=__add_datasource__(caller,hg,cellarray(['x','y','z']),varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:89
            if (have_z):
                __line__(hax,xt,yt,zt,'color',lc,'linestyle',ls,'parent',hg)
                __line__(hax,x,y,z,'color',mc,'linestyle','none','marker',ms,'markerfacecolor',fc,'parent',hg)
            else:
                __line__(hax,xt,yt,'color',lc,'linestyle',ls,'parent',hg)
                __line__(hax,x[:,i],y[:,i],'color',mc,'linestyle','none','marker',ms,'markerfacecolor',fc,'parent',hg)
                x_axis_range=get(hax,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:100
                if (isempty(h_baseline)):
                    h_baseline=line(hax,x_axis_range,cat(0,0),'color',cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:102
                    set(h_baseline,'handlevisibility','off','xliminclude','off')
                    addproperty('basevalue',h_baseline,'data',0)
                else:
                    set(h_baseline,'xdata',x_axis_range)
            ## Setup the hggroup and listeners.
            addproperty('showbaseline',hg,'radio','{on}|off')
            addproperty('baseline',hg,'data',h_baseline)
            addproperty('basevalue',hg,'data',0)
            addproperty('color',hg,'linecolor',lc)
            addproperty('linestyle',hg,'linelinestyle',ls)
            addproperty('linewidth',hg,'linelinewidth',0.5)
            addproperty('marker',hg,'linemarker',ms)
            addproperty('markeredgecolor',hg,'linemarkerfacecolor',mc)
            addproperty('markerfacecolor',hg,'linemarkerfacecolor',fc)
            addproperty('markersize',hg,'linemarkersize',6)
            addlistener(hg,'color',update_props)
            addlistener(hg,'linestyle',update_props)
            addlistener(hg,'linewidth',update_props)
            addlistener(hg,'marker',update_props)
            addlistener(hg,'markeredgecolor',update_props)
            addlistener(hg,'markerfacecolor',update_props)
            addlistener(hg,'markersize',update_props)
            if (islogical(x)):
                x=double(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:132
            addproperty('xdata',hg,'data',x[:,i])
            if (islogical(y)):
                y=double(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:136
            addproperty('ydata',hg,'data',y[:,i])
            if (have_z):
                addproperty('zdata',hg,'data',z[:,i])
            else:
                addproperty('zdata',hg,'data',[])
            addlistener(hg,'xdata',update_data)
            addlistener(hg,'ydata',update_data)
            addlistener(hg,'zdata',update_data)
            addproperty('hittestarea',hg,'radio','on|{off}','off')
        ## baseline listeners
        if (logical_not(isempty(h_baseline))):
            addlistener(hax,'xlim',update_xlim)
            for hg in h.T.reshape(-1):
                addlistener(hg,'showbaseline',show_baseline)
                addlistener(hg,'visible',cellarray([show_baseline,h]))
                addlistener(hg,'basevalue',move_baseline)
            addlistener(h_baseline,'basevalue',cellarray([update_baseline,0]))
            addlistener(h_baseline,'ydata',cellarray([update_baseline,1]))
            addlistener(h_baseline,'visible',cellarray([update_baseline,2]))
            set(h_baseline,'parent',get(hg[1],'parent'))
        ## property/value pairs
        if (logical_not(isempty(args))):
            set(h,args[:])
        if (logical_not(strcmp(hold_state,'add')) and have_z):
            set(hax,'view',cat(- 37.5,30),'xgrid','on','ygrid','on','zgrid','on')
        set(hax,'nextplot',hold_state)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def check_stem_arg(have_z=None,varargin=None,*args,**kwargs):
    varargin = check_stem_arg.varargin
    nargin = check_stem_arg.nargin

    if (have_z):
        caller='stem3'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:191
    else:
        caller='stem'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:193
    
    nargin=nargin - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:195
    
    num_numeric=find(cellfun('isclass',varargin,'char'),1) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:197
    if (isempty(num_numeric)):
        num_numeric=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:199
    
    if (num_numeric < 1 or num_numeric > 3):
        print_usage(caller)
    
    x=y=z=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:206
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:206
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:206
    if (num_numeric == 1):
        if (have_z):
            z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:209
        else:
            y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:211
    else:
        if (num_numeric == 2):
            if (have_z):
                error('stem3: must define X, Y, and Z')
            else:
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:217
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:218
        else:
            if (have_z):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:222
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:223
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:224
            else:
                error('stem: can not define Z for 2-D stem plot')
    
    ## Validate numeric data
    if (have_z):
        if (isempty(x)):
            nr,nc=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:233
            if (nr >= nc):
                x=repmat(cat(arange(1,nc)),nr,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:235
                y=repmat(cat(arange(1,nr)).T,1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:236
            else:
                x=repmat(cat(arange(1,nc)),nr,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:238
                y=repmat(cat(arange(1,nr)).T,1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:239
        if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y))) or logical_not((isnumeric(z) or islogical(z)))):
            error('stem3: X, Y, and Z must be numeric')
    else:
        if (isempty(x)):
            if (isvector(y)):
                x=arange(1,length(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:250
            else:
                if (ismatrix(y)):
                    x=arange(1,rows(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:252
                else:
                    error('stem: Y must be a vector or 2-D array')
        if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y)))):
            error('stem: X and Y must be numeric')
    
    ## Check sizes of x, y and z.
    if (have_z):
        if (logical_not(size_equal(x,y,z))):
            error('stem3: inconsistent sizes for X, Y, and Z')
        x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:268
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:269
        z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:270
    else:
        if (isvector(x)):
            x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:273
            if (isvector(y)):
                if (length(x) != length(y)):
                    error('stem: inconsistent sizes for X and Y')
                y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:278
            else:
                if (length(x) == rows(y)):
                    x=repmat(ravel(x),1,columns(y))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:281
                else:
                    error('stem: inconsistent sizes for X and Y')
        else:
            if (logical_not(size_equal(x,y))):
                error('stem: inconsistent sizes for X and Y')
    
    dofill=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:291
    have_line_spec=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:292
    
    lc,ls,mc,ms=set_default_values(nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:294
    args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:296
    ioff=num_numeric + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:297
    while (ioff <= nargin):

        arg=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:299
        if (ischar(arg) and any(strcmpi(arg,cellarray(['fill','filled'])))):
            dofill=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:301
        else:
            if ((ischar(arg) or iscellstr(arg)) and logical_not(have_line_spec)):
                linespec,valid=__pltopt__(caller,arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:303
                if (valid):
                    have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:305
                    lc,ls,mc,ms=stem_line_spec(linespec,nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:306
                else:
                    args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:308
                    if (ioff <= nargin):
                        args[end() + 1]=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:310
                    else:
                        error('%s: No value specified for property "%s"',caller,arg)
            else:
                args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:316
                if (ioff <= nargin):
                    args[end() + 1]=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:318
                else:
                    error('%s: No value specified for property "%s"',caller,arg)

    
    return x,y,z,dofill,lc,ls,mc,ms,args
    
if __name__ == '__main__':
    pass
    
    
@function
def stem_line_spec(lspec=None,*args,**kwargs):
    varargin = stem_line_spec.varargin
    nargin = stem_line_spec.nargin

    lc,ls,mc,ms=set_default_values(nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:329
    if (logical_not(isempty(lspec.color))):
        lc=mc=lspec.color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:332
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:332
    
    if (logical_not(isempty(lspec.linestyle)) and logical_not(strcmp(lspec.linestyle,'none'))):
        ls=lspec.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:336
    
    if (logical_not(isempty(lspec.marker)) and logical_not(strcmp(lspec.marker,'none'))):
        ms=lspec.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:340
    
    return lc,ls,mc,ms
    
if __name__ == '__main__':
    pass
    
    
@function
def set_default_values(*args,**kwargs):
    varargin = set_default_values.varargin
    nargin = set_default_values.nargin

    mc=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:346
    lc=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:347
    ls='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:348
    ms='o'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:349
    return lc,ls,mc,ms
    
if __name__ == '__main__':
    pass
    
    
@function
def update_xlim(h=None,__=None,*args,**kwargs):
    varargin = update_xlim.varargin
    nargin = update_xlim.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:353
    xlim=get(h,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:354
    for i in arange(1,length(kids)).reshape(-1):
        obj=get(kids[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:357
        if (strcmp(obj.type,'hggroup') and isfield(obj,'baseline')):
            if (any(get(obj.baseline,'xdata') != xlim)):
                set(obj.baseline,'xdata',xlim)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_baseline(h=None,__=None,src=None,*args,**kwargs):
    varargin = update_baseline.varargin
    nargin = update_baseline.nargin

    visible=get(h,'visible')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:367
    if (src == 0):
        basevalue=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:369
    else:
        basevalue=get(h,'ydata')(1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:371
    
    kids=get(get(h,'parent'),'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:374
    for i in arange(1,length(kids)).reshape(-1):
        obj=get(kids[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:376
        if (strcmp(obj.type,'hggroup') and isfield(obj,'baseline') and obj.baseline == h):
            ## Avoid lots of unnecessary listener updates
            if (logical_not(strcmp(get(kids[i],'showbaseline'),visible))):
                set(kids[i],'showbaseline',visible)
            if (get(kids[i],'basevalue') != basevalue):
                set(kids[i],'basevalue',basevalue)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def show_baseline(h=None,__=None,hg=[],*args,**kwargs):
    varargin = show_baseline.varargin
    nargin = show_baseline.nargin

    if (isempty(hg)):
        set(get(h,'baseline'),'visible',get(h,'showbaseline'))
    else:
        if (all(strcmp(get(hg,'visible'),'off'))):
            set(get(h,'baseline'),'visible','off')
        else:
            set(get(h,'baseline'),'visible','on')
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def move_baseline(h=None,__=None,*args,**kwargs):
    varargin = move_baseline.varargin
    nargin = move_baseline.nargin

    b0=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:403
    bl=get(h,'baseline')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:404
    set(bl,'ydata',cat(b0,b0))
    set(bl,'basevalue',b0)
    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:409
    yt=ravel(get(h,'ydata')).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:410
    ny=length(yt)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:411
    yt=ravel(cat([dot(b0,ones(1,ny))],[yt],[NaN(1,ny)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:412
    set(kids[2],'ydata',yt)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,__=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:417
    set(kids[2],'color',get(h,'color'),'linestyle',get(h,'linestyle'),'linewidth',get(h,'linewidth'))
    set(kids[1],'color',get(h,'markeredgecolor'),'marker',get(h,'marker'),'markerfacecolor',get(h,'markerfacecolor'),'markersize',get(h,'markersize'))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    x=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:428
    y=get(h,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:429
    z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:430
    if (logical_not(isempty(z)) and size_equal(x,y,z)):
        sz=min(cat([size(x)],[size(y)],[size(z)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:433
        x=x[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:434
        y=y[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:435
        z=z[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:436
    else:
        if (numel(x) != numel(y)):
            sz=min(cat([size(x)],[size(y)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:438
            x=x[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:439
            y=y[1:sz[1],1:sz[2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:440
    
    bl=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:442
    nx=numel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:443
    x=ravel(x).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:444
    xt=ravel(cat([x],[x],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:445
    if (logical_not(isempty(z))):
        y=ravel(y).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:447
        yt=ravel(cat([y],[y],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:448
        z=ravel(z).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:449
        zt=ravel(cat([dot(bl,ones(1,nx))],[z],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:450
    else:
        y=ravel(y).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:452
        yt=ravel(cat([dot(bl,ones(1,nx))],[y],[NaN(1,nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:453
        zt=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:454
    
    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__stem__.m:457
    set(kids[2],'xdata',xt,'ydata',yt,'zdata',zt)
    set(kids[1],'xdata',x,'ydata',y,'zdata',z)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{c}, @var{hg}] =} __contour__ (@dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __contour__(varargin=None,*args,**kwargs):
    varargin = __contour__.varargin
    nargin = __contour__.nargin

    ax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:25
    zlevel=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:26
    filled='off'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:27
    linespec.color = copy('auto')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:29
    linespec.linestyle = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:30
    for i in arange(3,nargin,2).reshape(-1):
        arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:32
        if (ischar(arg) or iscellstr(arg)):
            lspec,valid=__pltopt__('__contour__',arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:34
            if (valid):
                have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:36
                varargin[i]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:37
                linespec=copy(lspec)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:38
                if (isempty(linespec.color)):
                    linespec.color = copy('auto')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:40
                if (isempty(linespec.linestyle)):
                    linespec.linestyle = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:43
                break
    
    opts=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:50
    i=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:51
    while (i < length(varargin)):

        if (ischar(varargin[i])):
            if (strcmpi(varargin[i],'fill')):
                filled=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:55
                varargin[i:i + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:56
            else:
                if (strcmpi(varargin[i],'linecolor')):
                    linespec.color = copy(varargin[i + 1])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:58
                    varargin[i:i + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:59
                else:
                    opts[end() + (arange(1,2))]=varargin[i:i + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:61
                    varargin[i:i + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:62
        else:
            i

    
    if (length(varargin) < 5):
        z1=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:70
        x1=arange(1,columns(z1))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:71
        y1=arange(1,rows(z1))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:72
    else:
        x1=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:74
        y1=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:75
        z1=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:76
    
    if (logical_not(ismatrix(z1)) or logical_not(ismatrix(x1)) or logical_not(ismatrix(y1))):
        error('__contour__: X, Y, and Z must be matrices')
    
    if (length(varargin) == 4 or length(varargin) == 6):
        vn=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:82
        vnauto=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:83
    else:
        vn=10
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:85
        vnauto=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:86
    
    if (isscalar(vn)):
        ## FIXME: The levels should be determined similarly to {x,y,z}ticks
    ##        so that they aren't set at extremely odd values.
        lvl=linspace(min(z1[logical_not(isinf(z1))]),max(z1[logical_not(isinf(z1))]),vn + 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:92
        lvl=lvl[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:94
    else:
        lvl=sort(vn)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:96
    
    if (strcmpi(filled,'on')):
        if (isvector(x1) or isvector(y1)):
            x1,y1=meshgrid(x1,y1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:101
        nr,nc=size(z1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:103
        x0=prepad(x1,nc + 1,dot(2,x1[1,1]) - x1[1,2],2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:104
        x0=postpad(x0,nc + 2,dot(2,x1[1,nc]) - x1[1,nc - 1],2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:105
        x0=matlabarray(cat([x0[1,:]],[x0],[x0[1,:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:106
        y0=prepad(y1,nr + 1,dot(2,y1[1,1]) - y1[2,1],1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:107
        y0=postpad(y0,nr + 2,dot(2,y1[nr,1]) - y1[nr - 1,1])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:108
        y0=matlabarray(cat(y0[:,1],y0,y0[:,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:109
        z0=- Inf(nr + 2,nc + 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:110
        z0[2:nr + 1,2:nc + 1]=z1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:111
        c,lev=contourc(x0,y0,z0,lvl,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:112
    else:
        c,lev=contourc(x1,y1,z1,lvl,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:114
    
    hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:117
    opts=__add_datasource__('__countour__',hg,cellarray(['x','y','z']),opts[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:118
    addproperty('xdata',hg,'data',x1)
    addproperty('ydata',hg,'data',y1)
    addproperty('zdata',hg,'data',z1)
    addproperty('contourmatrix',hg,'data',c)
    addlistener(hg,'xdata',update_data)
    addlistener(hg,'ydata',update_data)
    addlistener(hg,'zdata',update_data)
    addlistener(hg,'contourmatrix',update_data)
    addproperty('fill',hg,'radio','on|{off}',filled)
    
    ## use of contourgroups with the contour3, meshc, and surfc functions.
    if (isnumeric(zlevel)):
        addproperty('zlevelmode',hg,'radio','{none}|auto|manual','manual')
        addproperty('zlevel',hg,'data',zlevel)
    else:
        addproperty('zlevelmode',hg,'radio','{none}|auto|manual',zlevel)
        addproperty('zlevel',hg,'data',0.0)
    
    lvlstep=sum(diff(lvl)) / (length(lvl) - 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:142
    addproperty('levellist',hg,'data',lev)
    addproperty('levelstep',hg,'double',lvlstep)
    if (vnauto):
        addproperty('levellistmode',hg,'radio','{auto}|manual','auto')
        addproperty('levelstepmode',hg,'radio','{auto}|manual','auto')
    else:
        if (isscalar(vn)):
            addproperty('levellistmode',hg,'radio','{auto}|manual','auto')
            addproperty('levelstepmode',hg,'radio','{auto}|manual','manual')
        else:
            addproperty('levellistmode',hg,'radio','{auto}|manual','manual')
            addproperty('levelstepmode',hg,'radio','{auto}|manual','auto')
    
    addproperty('labelspacing',hg,'double',144)
    addproperty('textlist',hg,'data',lev)
    addproperty('textlistmode',hg,'radio','{auto}|manual','auto')
    addproperty('textstep',hg,'double',lvlstep)
    addproperty('textstepmode',hg,'radio','{auto}|manual','auto')
    addproperty('showtext',hg,'radio','on|{off}','off')
    addproperty('linecolor',hg,'color',linespec.color,'{auto}|none')
    addproperty('linestyle',hg,'linelinestyle',linespec.linestyle)
    addproperty('linewidth',hg,'linelinewidth',0.5)
    
    addproperty('hittestarea',hg,'radio','on|{off}','off')
    addlistener(hg,'fill',cellarray([update_data,'fill']))
    addlistener(hg,'zlevelmode',update_zlevel)
    addlistener(hg,'zlevel',update_zlevel)
    addlistener(hg,'levellist',cellarray([update_data,'levellist']))
    addlistener(hg,'levelstep',cellarray([update_data,'levelstep']))
    addlistener(hg,'levellistmode',update_data)
    addlistener(hg,'levelstepmode',update_data)
    addlistener(hg,'labelspacing',update_text)
    addlistener(hg,'textlist',cellarray([update_text,'textlist']))
    addlistener(hg,'textlistmode',update_text)
    addlistener(hg,'textstep',cellarray([update_text,'textstep']))
    addlistener(hg,'textstepmode',update_text)
    addlistener(hg,'showtext',update_text)
    addlistener(hg,'linecolor',update_line)
    addlistener(hg,'linestyle',update_line)
    addlistener(hg,'linewidth',update_line)
    
    ## new axis calculation.  No need if mode is already "manual".
    if (all(strcmp(get(gca(),cellarray(['xlimmode','ylimmode'])),'auto'))):
        axis(cat(min(ravel(x1)),max(ravel(x1)),min(ravel(y1)),max(ravel(y1))))
    
    add_patch_children(hg)
    if (logical_not(isempty(opts))):
        set(hg,opts[:])
    
    return c,hg
    
if __name__ == '__main__':
    pass
    
    
@function
def add_patch_children(hg=None,*args,**kwargs):
    varargin = add_patch_children.varargin
    nargin = add_patch_children.nargin

    c=get(hg,'contourmatrix')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:207
    lev=get(hg,'levellist')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:208
    fill=get(hg,'fill')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:209
    zlev=get(hg,'zlevel')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:210
    zmode=get(hg,'zlevelmode')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:211
    lc=get(hg,'linecolor')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:212
    lw=get(hg,'linewidth')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:213
    ls=get(hg,'linestyle')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:214
    filled=get(hg,'fill')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:215
    ca=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:216
    
    climmode=get(ca,'climmode')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:219
    set(ca,'climmode','manual')
    if (strcmp(lc,'auto')):
        lc='flat'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:223
    
    if (strcmp(filled,'on')):
        lvl_eps=get_lvl_eps(lev)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:228
        i=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:231
        ncont=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:232
        while (i < columns(c)):

            ncont
            cont_lev[ncont]=c[1,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:235
            cont_len[ncont]=c[2,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:236
            cont_idx[ncont]=i + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:237
            ii=i + (arange(1,cont_len[ncont]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:238
            cont_area[ncont]=polyarea(c[1,ii],c[2,ii])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:239
            i += cont_len[ncont] + 1

        ## Handle for each level the case where we have (a) hole(s) in a patch.
    ## Those are to be filled with the color of level below or with the
    ## background colour.
        for k in arange(1,numel(lev)).reshape(-1):
            lvl_idx=find(abs(cont_lev - lev[k]) < lvl_eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:247
            len_=numel(lvl_idx)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:248
            if (len_ > 1):
                mark=false(size(lvl_idx))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:250
                a=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:251
                while (a < len_):

                    ## take 1st patch
                    pa_idx=lvl_idx[a]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:254
                    curr_ct_idx=cont_idx[pa_idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:256
                    curr_ct_len=cont_len[pa_idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:257
                    curr_ct=c[:,curr_ct_idx:curr_ct_idx + curr_ct_len - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:259
                    b_vec=arange((a + 1),len_)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:260
                    next_ct_pt_vec=c[:,cont_idx[lvl_idx[b_vec]]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:261
                    in_=inpolygon(next_ct_pt_vec[1,:],next_ct_pt_vec[2,:],curr_ct[1,:],curr_ct[2,:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:262
                    mark[b_vec[in_]]=logical_not(mark[b_vec[in_]])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:264
                    a

                if (numel(mark) > 0):
                    ## All marked contours describe a hole in a larger contour of
          ## the same level and must be filled with colour of level below.
                    ma_idx=lvl_idx[mark]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:270
                    if (k > 1):
                        ## Find color of level below.
                        tmp=find(abs(cont_lev - lev[k - 1]) < lvl_eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:273
                        lvl_bel_idx=tmp[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:274
                        cont_lev[ma_idx]=cont_lev[lvl_bel_idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:276
                    else:
                        ## Set lowest level contour to NaN.
                        cont_lev[ma_idx]=NaN
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:279
        ## The algorithm can create patches with the size of the plotting
    ## area, we would like to draw only the patch with the highest level.
        del_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:287
        max_idx=find(cont_area == max(cont_area))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:288
        if (numel(max_idx) > 1):
            ## delete double entries
            del_idx=max_idx[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:291
            cont_area[del_idx]=cont_lev[del_idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:292
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:292
            cont_len[del_idx]=cont_idx[del_idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:293
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:293
        ## Now we have everything together and can start plotting the patches
    ## beginning with largest area.
        __,svec=sort(cont_area,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:298
        len_=ncont - numel(del_idx)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:299
        h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:300
        for n in arange(len_,1,- 1).reshape(-1):
            idx=svec[n]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:302
            ctmp=c[:,cont_idx[idx]:cont_idx[idx] + cont_len[idx] - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:303
            if (all(ctmp[:,1] == ctmp[:,end()])):
                ## patch() doesn't need/want closed contour.  It will do it itself.
                ctmp[:,end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:306
            if (isnan(cont_lev[idx])):
                fc=get(ca,'color')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:309
                if (strcmp(fc,'none')):
                    fc=get(ancestor(ca,'figure'),'color')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:311
            else:
                fc='flat'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:314
            h=matlabarray(cat([h],[__go_patch__(ca,'xdata',ravel(ctmp[1,:]),'ydata',ravel(ctmp[2,:]),'vertices',ctmp.T,'faces',arange(1,(cont_len[idx] - 1)),'facevertexcdata',cont_lev[idx],'facecolor',fc,'cdata',cont_lev[idx],'edgecolor',lc,'linestyle',ls,'linewidth',lw,'parent',hg)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:316
        if (min(lev) == max(lev)):
            set(ca,'clim',cat(min(lev) - 1,max(lev) + 1),'layer','top')
        else:
            set(ca,'clim',cat(min(lev),max(lev)),'layer','top')
    else:
        ## Decode contourc output format.
        h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:331
        i=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:332
        while (i < length(c)):

            clev=c[1,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:334
            clen=c[2,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:335
            if (all(c[:,i + 1] == c[:,i + clen])):
                p=c[:,i + 1:i + clen - 1].T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:338
            else:
                p=cat(c[:,i + 1:i + clen],NaN(2,1)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:340
            if 'none' == (zmode):
                h=matlabarray(cat([h],[__go_patch__(ca,'xdata',p[:,1],'ydata',p[:,2],'zdata',[],'vertices',p,'faces',arange(1,rows(p)),'facevertexcdata',clev,'facecolor','none','cdata',clev,'edgecolor',lc,'linestyle',ls,'linewidth',lw,'parent',hg)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:345
            else:
                if 'auto' == (zmode):
                    h=matlabarray(cat([h],[__go_patch__(ca,'xdata',p[:,1],'ydata',p[:,2],'zdata',dot(clev,ones(rows(p),1)),'vertices',cat(p,dot(clev,ones(rows(p),1))),'faces',arange(1,rows(p)),'facevertexcdata',clev,'facecolor','none','cdata',clev,'edgecolor',lc,'linestyle',ls,'linewidth',lw,'parent',hg)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:353
                else:
                    h=matlabarray(cat([h],[__go_patch__(ca,'xdata',p[:,1],'ydata',p[:,2],'zdata',dot(zlev,ones(rows(p),1)),'vertices',cat(p,dot(zlev,ones(rows(p),1))),'faces',arange(1,rows(p)),'facevertexcdata',clev,'facecolor','none','cdata',clev,'edgecolor',lc,'linestyle',ls,'linewidth',lw,'parent',hg)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:362
            i += clen + 1

    
    set(ca,'climmode',climmode)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_zlevel(h=None,__=None,*args,**kwargs):
    varargin = update_zlevel.varargin
    nargin = update_zlevel.nargin

    z=get(h,'zlevel')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:380
    zmode=get(h,'zlevelmode')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:381
    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:382
    if 'none' == (zmode):
        set(kids,'zdata',[])
    else:
        if 'auto' == (zmode):
            for i in arange(1,length(kids)).reshape(-1):
                set(kids[i],'zdata',multiply(get(kids[i],'cdata'),ones(size(get(kids[i],'xdata')))))
        else:
            for i in arange(1,length(kids)).reshape(-1):
                set(kids[i],'zdata',multiply(z,ones(size(get(kids[i],'xdata')))))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_line(h=None,__=None,*args,**kwargs):
    varargin = update_line.varargin
    nargin = update_line.nargin

    lc=get(h,'linecolor')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:400
    if (strcmp(lc,'auto')):
        lc='flat'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:402
    
    set(findobj(h,'type','patch'),'edgecolor',lc,'linewidth',get(h,'linewidth'),'linestyle',get(h,'linestyle'))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,prop='',*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    
    if (logical_not(recursive)):
        recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:412
        delete(get(h,'children'))
        if 'levellist' == (prop):
            set(h,'levellistmode','manual')
        else:
            if 'levelstep' == (prop):
                set(h,'levelstepmode','manual')
            else:
                if 'fill' == (prop):
                    ## Switching from filled ('k' linespec) to unfilled, reset linecolor
                    if (strcmp(get(h,'fill'),'off')):
                        set(h,'linecolor','auto')
                    else:
                        set(h,'linecolor','black')
        if (strcmp(get(h,'levellistmode'),'manual') and logical_not(strcmp(prop,'levelstep'))):
            lvl=get(h,'levellist')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:432
        else:
            if (strcmp(get(h,'levelstepmode'),'manual')):
                z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:434
                lvs=get(h,'levelstep')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:435
                lvl[1]=dot(ceil(min(ravel(z)) / lvs),lvs)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:436
                lvl[2]=dot(floor(max(ravel(z)) / lvs),lvs)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:437
                if (lvl[1] >= lvl[2]):
                    lvl=median(ravel(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:439
                else:
                    lvl=arange(lvl[1],lvl[2],lvs)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:441
                set(h,'levellist',lvl)
                set(h,'levellistmode','auto')
            else:
                z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:446
                ##        so that they aren't set at extremely odd values.
                lvl=linspace(min(z[logical_not(isinf(z))]),max(z[logical_not(isinf(z))]),10 + 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:449
                lvl=lvl[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:451
        if (strcmp(get(h,'fill'),'on')):
            X=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:455
            Y=get(h,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:456
            Z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:457
            if (isvector(X) or isvector(Y)):
                X,Y=meshgrid(X,Y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:459
            nr,nc=size(Z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:461
            X0=prepad(X,nc + 1,dot(2,X[1,1]) - X[1,2],2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:462
            X0=postpad(X0,nc + 2,dot(2,X[1,nc]) - X[1,nc - 1],2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:463
            X0=matlabarray(cat([X0[1,:]],[X0],[X0[1,:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:464
            Y0=prepad(Y,nr + 1,dot(2,Y[1,1]) - Y[2,1],1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:465
            Y0=postpad(Y0,nr + 2,dot(2,Y[nr,1]) - Y[nr - 1,1])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:466
            Y0=matlabarray(cat(Y0[:,1],Y0,Y0[:,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:467
            Z0=- Inf(nr + 2,nc + 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:468
            Z0[2:nr + 1,2:nc + 1]=Z
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:469
            c,lev=contourc(X0,Y0,Z0,lvl,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:470
        else:
            c,lev=contourc(get(h,'xdata'),get(h,'ydata'),get(h,'zdata'),lvl,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:472
        set(h,'contourmatrix',c)
        if (strcmp(get(h,'levellistmode'),'manual')):
            ## Do nothing
            pass
        else:
            if (strcmp(get(h,'levelstepmode'),'manual')):
                set(h,'levellist',lev)
            else:
                set(h,'levellist',lev)
                lvlstep=sum(diff(lvl)) / (length(lvl) - 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:483
                set(h,'levelstep',lvlstep)
        add_patch_children(h)
        update_text(h)
        recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:489
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_text(h=None,__=None,prop='',*args,**kwargs):
    varargin = update_text.varargin
    nargin = update_text.nargin

    
    if (logical_not(recursive)):
        recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:498
        delete(findobj(h,'type','text'))
        if 'textlist' == (prop):
            set(h,'textlistmode','manual')
        else:
            if 'textstep' == (prop):
                set(h,'textstepmode','manual')
        if (strcmp(get(h,'textlistmode'),'manual')):
            lvl=get(h,'textlist')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:510
        else:
            if (strcmp(get(h,'textstepmode'),'manual')):
                lev=get(h,'levellist')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:512
                lvl_eps=get_lvl_eps(lev)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:514
                stp=get(h,'textstep')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:516
                t=matlabarray(cat(0,floor(cumsum(diff(lev)) / (abs(stp) - lvl_eps))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:517
                lvl=lev[cat(true,t[1:end() - 1] != t[2:end()])]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:518
                set(h,'textlist',lvl)
            else:
                lvl=get(h,'levellist')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:521
                set(h,'textlist',lvl,'textstep',get(h,'levelstep'))
        if (strcmp(get(h,'showtext'),'on')):
            if 'manual' == (get(h,'zlevelmode')):
                __clabel__(get(h,'contourmatrix'),lvl,h,get(h,'labelspacing'),get(h,'zlevel'))
            else:
                if 'auto' == (get(h,'zlevelmode')):
                    __clabel__(get(h,'contourmatrix'),lvl,h,get(h,'labelspacing'),'auto')
                else:
                    __clabel__(get(h,'contourmatrix'),lvl,h,get(h,'labelspacing'),[])
        recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:539
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def get_lvl_eps(lev=None,*args,**kwargs):
    varargin = get_lvl_eps.varargin
    nargin = get_lvl_eps.nargin

    ## FIXME: is this the right thing to do for this tolerance?  Should
  ## it be an absolute or relative tolerance, or switch from one to the
  ## other depending on the value of lev?
    if (isscalar(lev)):
        lvl_eps=dot(abs(lev),sqrt(eps)) + sqrt(eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:548
    else:
        tmp=min(abs(diff(lev)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:550
        if (tmp < dot(10,eps)):
            lvl_eps=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:552
        else:
            lvl_eps=tmp / 1000.0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__contour__.m:554
    
    return lvl_eps
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
## Copyright (C) 2010 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{hlist} =} __pie__ (caller, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __pie__(caller=None,varargin=None,*args,**kwargs):
    varargin = __pie__.varargin
    nargin = __pie__.nargin

    h=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:27
    x=abs(varargin[2])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:28
    iarg=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:29
    if (logical_not(isvector(x))):
        error('%s: expecting vector argument',caller)
    
    len_=length(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:35
    have_explode=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:37
    have_labels=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:38
    while (iarg <= nargin - 1):

        arg=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:41
        if (iscell(arg)):
            labels=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:43
            have_labels=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:44
            if (numel(x) != numel(labels)):
                error('%s: mismatch in number of labels and data',caller)
        else:
            if (isnumeric(arg) or islogical(arg)):
                explode=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:49
                have_explode=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:50
                if (logical_not(size_equal(x,explode))):
                    error('%s: mismatch in number of elements in explode and data',caller)
            else:
                error('%s: %s is invalid as an optional argument',caller,class_(arg))

    
    if (logical_not(have_explode)):
        explode=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:61
    
    normalize=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:64
    if (sum(ravel(x)) < 1):
        normalize=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:66
    
    if (logical_not(have_labels)):
        if (normalize):
            xp=round(dot(100,x) / sum(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:71
        else:
            xp=round(dot(100,x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:73
        for i in arange(1,len_).reshape(-1):
            labels[i]=sprintf('%d%%',xp[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:76
    
    hlist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:80
    refinement=90
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:81
    phi=arange(0,360,refinement)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:82
    if (normalize):
        xphi=cumsum(dot(x / sum(x),360))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:84
    else:
        xphi=cumsum(dot(x,360))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:86
    
    for i in arange(1,len_).reshape(-1):
        if (i == 1):
            xn=arange(0,xphi[i],360 / refinement)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:91
        else:
            xn=arange(xphi[i - 1],xphi[i],360 / refinement)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:93
        if (xn[end()] != xphi[i]):
            xn=matlabarray(cat(xn,xphi[i]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:97
        xn2=(xn[1] + xn[end()]) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:100
        if (explode[i]):
            xoff=dot(- 0.1,sind(xn2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:102
            yoff=dot(0.1,cosd(xn2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:103
        else:
            xoff=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:105
            yoff=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:106
        xt=dot(- 1.2,sind(xn2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:108
        yt=dot(1.2,cosd(xn2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:109
        if (len_ == 1):
            set(h,'clim',cat(1,2))
        else:
            set(h,'clim',cat(1,len_))
        if (strcmp(caller,'pie3')):
            ln=length(xn)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:118
            zlvl=0.35
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:119
            sx=repmat(xoff + cat(0,- sind(xn),0),cat(2,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:120
            sy=repmat(yoff + cat(0,cosd(xn),0),cat(2,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:121
            sz=matlabarray(cat([zeros(1,ln + 2)],[dot(zlvl,ones(1,ln + 2))]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:122
            sc=dot(i,ones(size(sz)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:123
            hlist=matlabarray(cat([hlist],[patch(xoff + cat(0,- sind(xn)),yoff + cat(0,cosd(xn)),zeros(1,ln + 1),i)],[surface(sx,sy,sz,sc)],[patch(xoff + cat(0,- sind(xn)),yoff + cat(0,cosd(xn)),dot(zlvl,ones(1,ln + 1)),i)],[text(xt,yt,zlvl,labels[i])]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:125
        else:
            if (strcmp(caller,'pie')):
                if (xt > 0):
                    align='left'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:133
                else:
                    align='right'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:135
                hlist=matlabarray(cat([hlist],[patch(xoff + cat(0,- sind(xn)),yoff + cat(0,cosd(xn)),i)],[text(xt,yt,labels[i],'horizontalalignment',align)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:138
            else:
                error('__pie__: unknown caller \'%s\'',caller)
    
    addlistener(gca,'view',cellarray([update_text_pos,hlist]))
    if (strcmp(caller,'pie3')):
        axis(cat(- 1.25,1.25,- 1.25,1.25,- 0.05,0.4),'equal','off')
        view(- 37.5,30)
    else:
        if (strcmp(caller,'pie')):
            axis(cat(- 1.5,1.5,- 1.5,1.5),'square','off')
    
    return hlist
    
if __name__ == '__main__':
    pass
    
    
@function
def update_text_pos(all_handles=None,*args,**kwargs):
    varargin = update_text_pos.varargin
    nargin = update_text_pos.nargin

    ## Text objects in the foreground should be at the base level.
  ## Text objects in the background should be at the top level.
  ## Text objects on the right side should be aligned to the right
  ## and on the left side to the left.
    tobj=findobj(all_handles,'type','text')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:161
    
    s=findobj(all_handles,'type','surface')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:164
    is_pie3=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:165
    if (length(s) > 0):
        is_pie3=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:167
    
    if (length(tobj) > 0):
        ax=get(tobj[1],'parent')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:171
        azel=get(ax,'view')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:172
        pos=get(tobj,'position')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:173
        if (iscell(pos)):
            pos=cell2mat(pos)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:175
        phi=atand(pos[:,1] / pos[:,2])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:177
        theta,r=cart2pol(pos[:,1],pos[:,2],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:178
        theta *= 180 / pi
        theta -= azel[1]
        theta=mod(theta,360)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:181
        ud_mask=(theta > 180)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:182
        lr_mask=logical_and((theta > 90),(theta < 270))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__pie__.m:183
        for i in arange(1,length(tobj)).reshape(-1):
            if (is_pie3):
                if (ud_mask[i]):
                    set(tobj[i],'position',cat(pos[i,1],pos[i,2],- 0.05))
                else:
                    set(tobj[i],'position',cat(pos[i,1],pos[i,2],0.4))
            if (lr_mask[i]):
                set(tobj[i],'horizontalalignment','right')
            else:
                set(tobj[i],'horizontalalignment','left')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} __line__ (@var{p}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## __line__ (p, x, y, z)
## Create line object from x, y, and z with parent p.
## Return handle to line object.
    
    ## Author: jwe
    
    
@function
def __line__(p=None,varargin=None,*args,**kwargs):
    varargin = __line__.varargin
    nargin = __line__.nargin

    nvargs=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:32
    if (nvargs > 1 and logical_not(ischar(varargin[1])) and logical_not(ischar(varargin[2]))):
        if (nvargs > 2 and logical_not(ischar(varargin[3]))):
            num_data_args=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:36
        else:
            num_data_args=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:38
    else:
        num_data_args=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:41
    
    if (num_data_args > 0 and logical_not(size_equal(varargin[1:num_data_args]))):
        n=arange(1,num_data_args)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:45
        m=cellfun(numel,varargin[1:num_data_args])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:46
        __,m=max(m,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:47
        b=ones(size(varargin[m[1]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:48
        try:
            varargin[n]=cellfun(lambda x=None: bsxfun(times,b,x),varargin[n],'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:50
        finally:
            pass
    
    if (rem(nvargs - num_data_args,2) != 0):
        error('line: invalid number of PROPERTY / VALUE pairs')
    
    other_args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:61
    if (nvargs > num_data_args):
        other_args=varargin[num_data_args + 1:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:63
    
    nlines=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:66
    nvecpts=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:67
    ismat=false(1,3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:68
    for i in arange(1,num_data_args).reshape(-1):
        tmp=varargin[i](arange(),arange())
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:70
        if (isvector(tmp)):
            nlines=max(1,nlines)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:72
            if (logical_not(isscalar(tmp))):
                if (nvecpts == 0):
                    nvecpts=numel(tmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:75
                else:
                    if (nvecpts != numel(tmp)):
                        error('line: data size mismatch')
        else:
            ismat[i]=true
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:81
            nlines=max(columns(tmp),nlines)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:82
        varargin[i]=tmp
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:84
    
    if (num_data_args == 0):
        varargin=cellarray([cat(0,1),cat(0,1)])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:88
        num_data_args=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:89
        nlines=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:90
    
    handles=zeros(nlines,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:93
    data=cell(1,3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:95
    if (num_data_args > 1):
        data[1:num_data_args]=varargin[1:num_data_args]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:98
        for i in arange(1,num_data_args).reshape(-1):
            if (islogical(data[i])):
                data[i]=double(data[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:101
            else:
                if (iscomplex(data[i])):
                    data[i]=real(data[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:103
    
    data_args=reshape(cellarray([['xdata','ydata','zdata'],[data[:]]]),cat(1,6))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:108
    mask=reshape(cat([false(1,3)],[ismat]),cat(1,6))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:109
    for i in arange(1,nlines).reshape(-1):
        tmp=data[ismat]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:112
        if (logical_not(size_equal(tmp)) or (nvecpts != 0 and any(nvecpts != cellfun('size',tmp,1)))):
            error('line: data size_mismatch')
        data_args[mask]=cellfun(lambda x=None: x[:,i],data[ismat],'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:117
        handles[i]=__go_line__(p,data_args[:],other_args[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:120
    
    if (nargout > 0):
        h=copy(handles)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__line__.m:125
    
    return h
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2001-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __errcomm__ (@var{caller}, @var{hax}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Created: 20.02.2001
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def __errcomm__(caller=None,hax=None,varargin=None,*args,**kwargs):
    varargin = __errcomm__.varargin
    nargin = __errcomm__.nargin

    if (nargin < 4):
        print_usage(caller)
    
    retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:34
    data=cell(6,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:35
    nargs=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:36
    k=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:37
    while (k <= nargs):

        arg=varargin[k]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:39
        if (logical_not(isnumeric(arg))):
            error('%s: data argument %d must be numeric',caller,k - 1)
        if (isvector(arg)):
            arg=ravel(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:44
        sz=size(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:46
        ndata=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:47
        data[ndata]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:48
        while (k <= nargs):

            arg=varargin[k]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:50
            if (ischar(arg) or iscellstr(arg)):
                retval=matlabarray(cat([retval],[__errplot__(arg,hax,data[1:ndata])]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:52
                break
            if (logical_not(isnumeric(arg))):
                error('%s: data argument %d must be numeric',caller,k - 1)
            if (isvector(arg)):
                arg=ravel(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:59
            if (logical_not(isscalar(arg)) and ((isvector(arg) and numel(arg) != prod(sz)) or any(size(arg) != sz))):
                error('%s: size of argument %d does not match others',caller,k - 1)
            data[++ ndata]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:65
            if (ndata > 6):
                error('%s: too many arguments to plot',caller)


    
    ## No format code found, use yerrorbar
    if (logical_not((ischar(arg) or iscellstr(arg)))):
        retval=matlabarray(cat([retval],[__errplot__('~',hax,data[1:ndata])]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errcomm__.m:74
    
    drawnow()
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{t}, @var{p}] =} __marching_cube__ (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso})
## @deftypefnx {Function File} {[@var{t}, @var{p}, @var{c}] =} __marching_cube__ (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso}, @var{col})
## Undocumented internal function.
## @end deftypefn
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{t}, @var{p}] =} __marching_cube__ (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso})
## @deftypefnx {Function File} {[@var{t}, @var{p}, @var{c}] =} __marching_cube__ (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso}, @var{col})
##
## Return the triangulation information @var{t} at points @var{p} for
## the isosurface values resp. the volume data @var{val} and the iso
## level @var{iso}.  It is considered that the volume data @var{val} is
## given at the points @var{x}, @var{y} and @var{z} which are of type
## three--dimensional numeric arrays.  The orientation of the triangles
## is choosen such that the normals point from the higher values to the
## lower values.
##
## Optionally the color data @var{col} can be passed to this function
## whereas computed vertices color data @var{c} is returned as third
## argument.
##
## The marching cube algorithm is well known and described, for example, at
## Wikipedia.  The triangulation lookup table and the edge table used
## here are based on Cory Gene Bloyd's implementation and can be found
## beyond other surface and geometry stuff at Paul Bourke's website
## @uref{http://local.wasp.uwa.edu.au/~pbourke/geometry/polygonise}.
##
## For example:
##
## @example
## @group
## N = 20;
## lin = linspace (0, 2, N);
## [x, y, z] = meshgrid (lin, lin, lin);
##
## c = (x-.5).^2 + (y-.5).^2 + (z-.5).^2;
## [t, p] = __marching_cube__ (x, y, z, c, .5);
##
## figure ();
## trimesh (t, p(:,1), p(:,2), p(:,3));
## @end group
## @end example
##
## Instead of the @command{trimesh} function the @command{patch}
## function can be used to visualize the geometry.  For example:
##
## @example
## @group
## figure (); view (-38, 20);
## pa = patch ("Faces", t, "Vertices", p, "FaceVertexCData", p, ...
##             "FaceColor", "interp", "EdgeColor", "none");
##
## ## Revert normals
## set (pa, "VertexNormals", -get (pa, "VertexNormals"));
##
## ## Set lightning (available with the JHandles package)
## # set (pa, "FaceLighting", "gouraud");
## # light ( "Position", [1 1 5]);
## @end group
## @end example
##
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def __marching_cube__(xx=None,yy=None,zz=None,c=None,iso=None,colors=None,*args,**kwargs):
    varargin = __marching_cube__.varargin
    nargin = __marching_cube__.nargin

    
    
    calc_cols=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:90
    lindex=4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:91
    if (isempty(tri_table) or isempty(edge_table)):
        edge_table,tri_table=init_mc(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:94
    
    if ((nargin != 5 and nargin != 6) or (nargout != 2 and nargout != 3)):
        print_usage()
    
    if (logical_not(isnumeric(xx)) or logical_not(isnumeric(yy)) or logical_not(isnumeric(zz)) or logical_not(isnumeric(c)) or ndims(xx) != 3 or ndims(yy) != 3 or ndims(zz) != 3 or ndims(c) != 3):
        error('__marching_cube__: XX, YY, ZZ, C must be matrices of dim 3')
    
    if (logical_not(size_equal(xx,yy,zz,c))):
        error('__marching_cube__: XX, YY, ZZ, C must be of equal size')
    
    if (any(size(xx) < cat(2,2,2))):
        error('__marching_cube__: grid size must be at least 2x2x2')
    
    if (logical_not(isscalar(iso))):
        error('__marching_cube__: ISO must be scalar value')
    
    if (nargin == 6):
        if (logical_not(isnumeric(colors)) or ndims(colors) != 3 or size(colors) != size(c)):
            error('COLORS must be a matrix of dim 3 and of same size as C')
        calc_cols=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:123
        lindex=5
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:124
    
    n=size(c) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:127
    
    ## the isosurface
    cc=zeros(n[1],n[2],n[3],'uint16')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:131
    cedge=zeros(size(cc),'uint16')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:132
    vertex_idx=cellarray([[arange(1,n[1]),arange(1,n[2]),arange(1,n[3])],[arange(2,n[1] + 1),arange(1,n[2]),arange(1,n[3])],[arange(2,n[1] + 1),arange(2,n[2] + 1),arange(1,n[3])],[arange(1,n[1]),arange(2,n[2] + 1),arange(1,n[3])],[arange(1,n[1]),arange(1,n[2]),arange(2,n[3] + 1)],[arange(2,n[1] + 1),arange(1,n[2]),arange(2,n[3] + 1)],[arange(2,n[1] + 1),arange(2,n[2] + 1),arange(2,n[3] + 1)],[arange(1,n[1]),arange(2,n[2] + 1),arange(2,n[3] + 1)]])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:134
    
    for ii in arange(1,8).reshape(-1):
        idx=c[vertex_idx[ii,:]] > iso
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:145
        cc[idx]=bitset(cc[idx],ii)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:146
    
    cedge=edge_table[cc + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:149
    
    id=find(cedge)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:150
    
    if (isempty(id)):
        T=p=col=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:152
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:152
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:152
        return T,p,col
    
    ## phase II: calculate the list of intersection points
    xyz_off=matlabarray(cat([1,1,1],[2,1,1],[2,2,1],[1,2,1],[1,1,2],[2,1,2],[2,2,2],[1,2,2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:157
    edges=matlabarray(cat([1,2],[2,3],[3,4],[4,1],[5,6],[6,7],[7,8],[8,5],[1,5],[2,6],[3,7],[4,8]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:158
    offset=sub2ind(size(c),xyz_off[:,1],xyz_off[:,2],xyz_off[:,3]) - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:159
    pp=zeros(length(id),lindex,12)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:160
    ccedge=matlabarray(cat(vec(cedge[id]),id))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:161
    ix_offset=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:162
    for jj in arange(1,12).reshape(-1):
        id__=bitget(ccedge[:,1],jj)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:164
        id_=ccedge[id__,2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:165
        ix,iy,iz=ind2sub(size(cc),id_,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:166
        id_c=sub2ind(size(c),ix,iy,iz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:167
        id1=id_c + offset[edges[jj,1]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:168
        id2=id_c + offset[edges[jj,2]]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:169
        if (calc_cols):
            pp[id__,1:5,jj]=cat(vertex_interp(iso,xx[id1],yy[id1],zz[id1],xx[id2],yy[id2],zz[id2],c[id1],c[id2],colors[id1],colors[id2]),(arange(1,rows(id_))).T + ix_offset)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:171
        else:
            pp[id__,1:4,jj]=cat(vertex_interp(iso,xx[id1],yy[id1],zz[id1],xx[id2],yy[id2],zz[id2],c[id1],c[id2]),(arange(1,rows(id_))).T + ix_offset)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:175
        ix_offset += rows(id_)
    
    ## phase III: calculate the triangulation from the point list
    T=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:183
    tri=tri_table[cc[id] + 1,:]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:184
    for jj in arange(1,15,3).reshape(-1):
        id_=find(tri[:,jj] > 0)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:186
        p=matlabarray(cat(id_,dot(lindex,ones(rows(id_),1)),tri[id_,jj:jj + 2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:187
        if (logical_not(isempty(p))):
            p1=sub2ind(size(pp),p[:,1],p[:,2],p[:,3])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:189
            p2=sub2ind(size(pp),p[:,1],p[:,2],p[:,4])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:190
            p3=sub2ind(size(pp),p[:,1],p[:,2],p[:,5])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:191
            T=matlabarray(cat([T],[pp[p1],pp[p2],pp[p3]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:192
    
    p=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:196
    col=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:197
    for jj in arange(1,12).reshape(-1):
        idp=pp[:,lindex,jj] > 0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:199
        if (any(idp)):
            p[pp[idp,lindex,jj],1:3]=pp[idp,1:3,jj]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:201
            if (calc_cols):
                col[pp[idp,lindex,jj],1]=pp[idp,4,jj]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:203
    
    return T,p,col
    
if __name__ == '__main__':
    pass
    
    
@function
def vertex_interp(isolevel=None,p1x=None,p1y=None,p1z=None,p2x=None,p2y=None,p2z=None,valp1=None,valp2=None,col1=None,col2=None,*args,**kwargs):
    varargin = vertex_interp.varargin
    nargin = vertex_interp.nargin

    if (nargin == 9):
        p=zeros(length(p1x),3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:213
    else:
        if (nargin == 11):
            p=zeros(length(p1x),4)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:215
        else:
            error('__marching_cube__: wrong number of arguments')
    
    mu=zeros(length(p1x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:219
    id=abs(valp1 - valp2) < multiply((dot(10,eps)),(abs(valp1)+ abs(valp2)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:220
    if (any(id)):
        p[id,1:3]=cat(p1x[id],p1y[id],p1z[id])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:222
        if (nargin == 11):
            p[id,4]=col1[id]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:224
    
    nid=logical_not(id)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:227
    if (any(nid)):
        mu[nid]=(isolevel - valp1[nid]) / (valp2[nid] - valp1[nid])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:229
        p[nid,1:3]=cat(p1x[nid] + multiply(mu[nid],(p2x[nid] - p1x[nid])),p1y[nid] + multiply(mu[nid],(p2y[nid] - p1y[nid])),p1z[nid] + multiply(mu[nid],(p2z[nid] - p1z[nid])))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:230
        if (nargin == 11):
            p[nid,4]=col1[nid] + multiply(mu[nid],(col2[nid] - col1[nid]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:234
    
    return p
    
if __name__ == '__main__':
    pass
    
    
@function
def init_mc(*args,**kwargs):
    varargin = init_mc.varargin
    nargin = init_mc.nargin

    edge_table=matlabarray(cat(0,265,515,778,1030,1295,1541,1804,2060,2309,2575,2822,3082,3331,3593,3840,400,153,915,666,1430,1183,1941,1692,2460,2197,2975,2710,3482,3219,3993,3728,560,825,51,314,1590,1855,1077,1340,2620,2869,2111,2358,3642,3891,3129,3376,928,681,419,170,1958,1711,1445,1196,2988,2725,2479,2214,4010,3747,3497,3232,1120,1385,1635,1898,102,367,613,876,3180,3429,3695,3942,2154,2403,2665,2912,1520,1273,2035,1786,502,255,1013,764,3580,3317,4095,3830,2554,2291,3065,2800,1616,1881,1107,1370,598,863,85,348,3676,3925,3167,3414,2650,2899,2137,2384,1984,1737,1475,1226,966,719,453,204,4044,3781,3535,3270,3018,2755,2505,2240,2240,2505,2755,3018,3270,3535,3781,4044,204,453,719,966,1226,1475,1737,1984,2384,2137,2899,2650,3414,3167,3925,3676,348,85,863,598,1370,1107,1881,1616,2800,3065,2291,2554,3830,4095,3317,3580,764,1013,255,502,1786,2035,1273,1520,2912,2665,2403,2154,3942,3695,3429,3180,876,613,367,102,1898,1635,1385,1120,3232,3497,3747,4010,2214,2479,2725,2988,1196,1445,1711,1958,170,419,681,928,3376,3129,3891,3642,2358,2111,2869,2620,1340,1077,1855,1590,314,51,825,560,3728,3993,3219,3482,2710,2975,2197,2460,1692,1941,1183,1430,666,915,153,400,3840,3593,3331,3082,2822,2575,2309,2060,1804,1541,1295,1030,778,515,265,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:240
    tri_table=cat([- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,1,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,8,3,9,8,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,1,2,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,2,10,0,2,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,8,3,2,10,8,10,9,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,11,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,11,2,8,11,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,9,0,2,3,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,11,2,1,9,11,9,8,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,10,1,11,10,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,10,1,0,8,10,8,11,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,9,0,3,11,9,11,10,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,8,10,10,8,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,7,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,3,0,7,3,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,1,9,8,4,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,1,9,4,7,1,7,3,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,8,4,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,4,7,3,0,4,1,2,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,2,10,9,0,2,8,4,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,10,9,2,9,7,2,7,3,7,9,4,- 1,- 1,- 1,- 1],[8,4,7,3,11,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,4,7,11,2,4,2,0,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,0,1,8,4,7,2,3,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,7,11,9,4,11,9,11,2,9,2,1,- 1,- 1,- 1,- 1],[3,10,1,3,11,10,7,8,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,11,10,1,4,11,1,0,4,7,11,4,- 1,- 1,- 1,- 1],[4,7,8,9,0,11,9,11,10,11,0,3,- 1,- 1,- 1,- 1],[4,7,11,4,11,9,9,11,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,5,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,5,4,0,8,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,5,4,1,5,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,5,4,8,3,5,3,1,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,9,5,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,0,8,1,2,10,4,9,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,2,10,5,4,2,4,0,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,10,5,3,2,5,3,5,4,3,4,8,- 1,- 1,- 1,- 1],[9,5,4,2,3,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,11,2,0,8,11,4,9,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,5,4,0,1,5,2,3,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,1,5,2,5,8,2,8,11,4,8,5,- 1,- 1,- 1,- 1],[10,3,11,10,1,3,9,5,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,9,5,0,8,1,8,10,1,8,11,10,- 1,- 1,- 1,- 1],[5,4,0,5,0,11,5,11,10,11,0,3,- 1,- 1,- 1,- 1],[5,4,8,5,8,10,10,8,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,7,8,5,7,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,3,0,9,5,3,5,7,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,7,8,0,1,7,1,5,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,5,3,3,5,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,7,8,9,5,7,10,1,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,1,2,9,5,0,5,3,0,5,7,3,- 1,- 1,- 1,- 1],[8,0,2,8,2,5,8,5,7,10,5,2,- 1,- 1,- 1,- 1],[2,10,5,2,5,3,3,5,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,9,5,7,8,9,3,11,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,5,7,9,7,2,9,2,0,2,7,11,- 1,- 1,- 1,- 1],[2,3,11,0,1,8,1,7,8,1,5,7,- 1,- 1,- 1,- 1],[11,2,1,11,1,7,7,1,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,5,8,8,5,7,10,1,3,10,3,11,- 1,- 1,- 1,- 1],[5,7,0,5,0,9,7,11,0,1,0,10,11,10,0,- 1],[11,10,0,11,0,3,10,5,0,8,0,7,5,7,0,- 1],[11,10,5,7,11,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,6,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,5,10,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,0,1,5,10,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,8,3,1,9,8,5,10,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,6,5,2,6,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,6,5,1,2,6,3,0,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,6,5,9,0,6,0,2,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,9,8,5,8,2,5,2,6,3,2,8,- 1,- 1,- 1,- 1],[2,3,11,10,6,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,0,8,11,2,0,10,6,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,1,9,2,3,11,5,10,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,10,6,1,9,2,9,11,2,9,8,11,- 1,- 1,- 1,- 1],[6,3,11,6,5,3,5,1,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,11,0,11,5,0,5,1,5,11,6,- 1,- 1,- 1,- 1],[3,11,6,0,3,6,0,6,5,0,5,9,- 1,- 1,- 1,- 1],[6,5,9,6,9,11,11,9,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,10,6,4,7,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,3,0,4,7,3,6,5,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,9,0,5,10,6,8,4,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,6,5,1,9,7,1,7,3,7,9,4,- 1,- 1,- 1,- 1],[6,1,2,6,5,1,4,7,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,5,5,2,6,3,0,4,3,4,7,- 1,- 1,- 1,- 1],[8,4,7,9,0,5,0,6,5,0,2,6,- 1,- 1,- 1,- 1],[7,3,9,7,9,4,3,2,9,5,9,6,2,6,9,- 1],[3,11,2,7,8,4,10,6,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,10,6,4,7,2,4,2,0,2,7,11,- 1,- 1,- 1,- 1],[0,1,9,4,7,8,2,3,11,5,10,6,- 1,- 1,- 1,- 1],[9,2,1,9,11,2,9,4,11,7,11,4,5,10,6,- 1],[8,4,7,3,11,5,3,5,1,5,11,6,- 1,- 1,- 1,- 1],[5,1,11,5,11,6,1,0,11,7,11,4,0,4,11,- 1],[0,5,9,0,6,5,0,3,6,11,6,3,8,4,7,- 1],[6,5,9,6,9,11,4,7,9,7,11,9,- 1,- 1,- 1,- 1],[10,4,9,6,4,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,10,6,4,9,10,0,8,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,0,1,10,6,0,6,4,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,3,1,8,1,6,8,6,4,6,1,10,- 1,- 1,- 1,- 1],[1,4,9,1,2,4,2,6,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,0,8,1,2,9,2,4,9,2,6,4,- 1,- 1,- 1,- 1],[0,2,4,4,2,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,3,2,8,2,4,4,2,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,4,9,10,6,4,11,2,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,2,2,8,11,4,9,10,4,10,6,- 1,- 1,- 1,- 1],[3,11,2,0,1,6,0,6,4,6,1,10,- 1,- 1,- 1,- 1],[6,4,1,6,1,10,4,8,1,2,1,11,8,11,1,- 1],[9,6,4,9,3,6,9,1,3,11,6,3,- 1,- 1,- 1,- 1],[8,11,1,8,1,0,11,6,1,9,1,4,6,4,1,- 1],[3,11,6,3,6,0,0,6,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[6,4,8,11,6,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,10,6,7,8,10,8,9,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,7,3,0,10,7,0,9,10,6,7,10,- 1,- 1,- 1,- 1],[10,6,7,1,10,7,1,7,8,1,8,0,- 1,- 1,- 1,- 1],[10,6,7,10,7,1,1,7,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,6,1,6,8,1,8,9,8,6,7,- 1,- 1,- 1,- 1],[2,6,9,2,9,1,6,7,9,0,9,3,7,3,9,- 1],[7,8,0,7,0,6,6,0,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,3,2,6,7,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,3,11,10,6,8,10,8,9,8,6,7,- 1,- 1,- 1,- 1],[2,0,7,2,7,11,0,9,7,6,7,10,9,10,7,- 1],[1,8,0,1,7,8,1,10,7,6,7,10,2,3,11,- 1],[11,2,1,11,1,7,10,6,1,6,7,1,- 1,- 1,- 1,- 1],[8,9,6,8,6,7,9,1,6,11,6,3,1,3,6,- 1],[0,9,1,11,6,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,8,0,7,0,6,3,11,0,11,6,0,- 1,- 1,- 1,- 1],[7,11,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,6,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,0,8,11,7,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,1,9,11,7,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,1,9,8,3,1,11,7,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,1,2,6,11,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,3,0,8,6,11,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,9,0,2,10,9,6,11,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[6,11,7,2,10,3,10,8,3,10,9,8,- 1,- 1,- 1,- 1],[7,2,3,6,2,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[7,0,8,7,6,0,6,2,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,7,6,2,3,7,0,1,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,6,2,1,8,6,1,9,8,8,7,6,- 1,- 1,- 1,- 1],[10,7,6,10,1,7,1,3,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,7,6,1,7,10,1,8,7,1,0,8,- 1,- 1,- 1,- 1],[0,3,7,0,7,10,0,10,9,6,10,7,- 1,- 1,- 1,- 1],[7,6,10,7,10,8,8,10,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[6,8,4,11,8,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,6,11,3,0,6,0,4,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,6,11,8,4,6,9,0,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,4,6,9,6,3,9,3,1,11,3,6,- 1,- 1,- 1,- 1],[6,8,4,6,11,8,2,10,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,3,0,11,0,6,11,0,4,6,- 1,- 1,- 1,- 1],[4,11,8,4,6,11,0,2,9,2,10,9,- 1,- 1,- 1,- 1],[10,9,3,10,3,2,9,4,3,11,3,6,4,6,3,- 1],[8,2,3,8,4,2,4,6,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,4,2,4,6,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,9,0,2,3,4,2,4,6,4,3,8,- 1,- 1,- 1,- 1],[1,9,4,1,4,2,2,4,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,1,3,8,6,1,8,4,6,6,10,1,- 1,- 1,- 1,- 1],[10,1,0,10,0,6,6,0,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,6,3,4,3,8,6,10,3,0,3,9,10,9,3,- 1],[10,9,4,6,10,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,9,5,7,6,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,4,9,5,11,7,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,0,1,5,4,0,7,6,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,7,6,8,3,4,3,5,4,3,1,5,- 1,- 1,- 1,- 1],[9,5,4,10,1,2,7,6,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[6,11,7,1,2,10,0,8,3,4,9,5,- 1,- 1,- 1,- 1],[7,6,11,5,4,10,4,2,10,4,0,2,- 1,- 1,- 1,- 1],[3,4,8,3,5,4,3,2,5,10,5,2,11,7,6,- 1],[7,2,3,7,6,2,5,4,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,5,4,0,8,6,0,6,2,6,8,7,- 1,- 1,- 1,- 1],[3,6,2,3,7,6,1,5,0,5,4,0,- 1,- 1,- 1,- 1],[6,2,8,6,8,7,2,1,8,4,8,5,1,5,8,- 1],[9,5,4,10,1,6,1,7,6,1,3,7,- 1,- 1,- 1,- 1],[1,6,10,1,7,6,1,0,7,8,7,0,9,5,4,- 1],[4,0,10,4,10,5,0,3,10,6,10,7,3,7,10,- 1],[7,6,10,7,10,8,5,4,10,4,8,10,- 1,- 1,- 1,- 1],[6,9,5,6,11,9,11,8,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,6,11,0,6,3,0,5,6,0,9,5,- 1,- 1,- 1,- 1],[0,11,8,0,5,11,0,1,5,5,6,11,- 1,- 1,- 1,- 1],[6,11,3,6,3,5,5,3,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,10,9,5,11,9,11,8,11,5,6,- 1,- 1,- 1,- 1],[0,11,3,0,6,11,0,9,6,5,6,9,1,2,10,- 1],[11,8,5,11,5,6,8,0,5,10,5,2,0,2,5,- 1],[6,11,3,6,3,5,2,10,3,10,5,3,- 1,- 1,- 1,- 1],[5,8,9,5,2,8,5,6,2,3,8,2,- 1,- 1,- 1,- 1],[9,5,6,9,6,0,0,6,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,5,8,1,8,0,5,6,8,3,8,2,6,2,8,- 1],[1,5,6,2,1,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,3,6,1,6,10,3,8,6,5,6,9,8,9,6,- 1],[10,1,0,10,0,6,9,5,0,5,6,0,- 1,- 1,- 1,- 1],[0,3,8,5,6,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,5,6,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,5,10,7,5,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,5,10,11,7,5,8,3,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,11,7,5,10,11,1,9,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[10,7,5,10,11,7,9,8,1,8,3,1,- 1,- 1,- 1,- 1],[11,1,2,11,7,1,7,5,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,1,2,7,1,7,5,7,2,11,- 1,- 1,- 1,- 1],[9,7,5,9,2,7,9,0,2,2,11,7,- 1,- 1,- 1,- 1],[7,5,2,7,2,11,5,9,2,3,2,8,9,8,2,- 1],[2,5,10,2,3,5,3,7,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,2,0,8,5,2,8,7,5,10,2,5,- 1,- 1,- 1,- 1],[9,0,1,5,10,3,5,3,7,3,10,2,- 1,- 1,- 1,- 1],[9,8,2,9,2,1,8,7,2,10,2,5,7,5,2,- 1],[1,3,5,3,7,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,7,0,7,1,1,7,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,0,3,9,3,5,5,3,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,8,7,5,9,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,8,4,5,10,8,10,11,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[5,0,4,5,11,0,5,10,11,11,3,0,- 1,- 1,- 1,- 1],[0,1,9,8,4,10,8,10,11,10,4,5,- 1,- 1,- 1,- 1],[10,11,4,10,4,5,11,3,4,9,4,1,3,1,4,- 1],[2,5,1,2,8,5,2,11,8,4,5,8,- 1,- 1,- 1,- 1],[0,4,11,0,11,3,4,5,11,2,11,1,5,1,11,- 1],[0,2,5,0,5,9,2,11,5,4,5,8,11,8,5,- 1],[9,4,5,2,11,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,5,10,3,5,2,3,4,5,3,8,4,- 1,- 1,- 1,- 1],[5,10,2,5,2,4,4,2,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,10,2,3,5,10,3,8,5,4,5,8,0,1,9,- 1],[5,10,2,5,2,4,1,9,2,9,4,2,- 1,- 1,- 1,- 1],[8,4,5,8,5,3,3,5,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,4,5,1,0,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[8,4,5,8,5,3,9,0,5,0,3,5,- 1,- 1,- 1,- 1],[9,4,5,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,11,7,4,9,11,9,10,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,8,3,4,9,7,9,11,7,9,10,11,- 1,- 1,- 1,- 1],[1,10,11,1,11,4,1,4,0,7,4,11,- 1,- 1,- 1,- 1],[3,1,4,3,4,8,1,10,4,7,4,11,10,11,4,- 1],[4,11,7,9,11,4,9,2,11,9,1,2,- 1,- 1,- 1,- 1],[9,7,4,9,11,7,9,1,11,2,11,1,0,8,3,- 1],[11,7,4,11,4,2,2,4,0,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[11,7,4,11,4,2,8,3,4,3,2,4,- 1,- 1,- 1,- 1],[2,9,10,2,7,9,2,3,7,7,4,9,- 1,- 1,- 1,- 1],[9,10,7,9,7,4,10,2,7,8,7,0,2,0,7,- 1],[3,7,10,3,10,2,7,4,10,1,10,0,4,0,10,- 1],[1,10,2,8,7,4,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,9,1,4,1,7,7,1,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,9,1,4,1,7,0,8,1,8,7,1,- 1,- 1,- 1,- 1],[4,0,3,7,4,3,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[4,8,7,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,10,8,10,11,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,0,9,3,9,11,11,9,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,1,10,0,10,8,8,10,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,1,10,11,3,10,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,2,11,1,11,9,9,11,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,0,9,3,9,11,1,2,9,2,11,9,- 1,- 1,- 1,- 1],[0,2,11,8,0,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[3,2,11,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,3,8,2,8,10,10,8,9,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[9,10,2,0,9,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[2,3,8,2,8,10,0,1,8,1,10,8,- 1,- 1,- 1,- 1],[1,10,2,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[1,3,8,9,1,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,9,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[0,3,8,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1],[- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,- 1]) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__marching_cube__.m:274
    return edge_table,tri_table
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{hg} =} __scatter__ (@dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __scatter__(varargin=None,*args,**kwargs):
    varargin = __scatter__.varargin
    nargin = __scatter__.nargin

    hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:26
    
    nd=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:27
    fcn=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:28
    x=ravel(varargin[4])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:29
    y=ravel(varargin[5])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:30
    if (nd == 2):
        istart=6
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:33
    else:
        z=ravel(varargin[6])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:35
        istart=7
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:36
    
    if (istart <= nargin):
        s=ravel(varargin[istart])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:40
        if (isempty(s) or ischar(s)):
            s=6
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:42
        if (logical_not(ischar(varargin[istart]))):
            istart
    else:
        s=6
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:48
    
    ## Remove NaNs
    idx=logical_or(logical_or(isnan(x),isnan(y)),isnan(s))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:52
    if (nd == 3):
        idx |= isnan(z)
        z[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:55
    
    x[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:57
    y[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:58
    if (nd == 2):
        z=zeros(length(x),0)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:60
    
    if (numel(s) > 1):
        s[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:63
    
    firstnonnumeric=find(logical_not(cellfun('isnumeric',varargin[istart:nargin])),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:66
    if (isempty(firstnonnumeric)):
        firstnonnumeric=copy(Inf)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:68
    else:
        firstnonnumeric += istart - 1
    
    if (istart <= nargin and firstnonnumeric > istart):
        c=varargin[istart]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:74
        if (isvector(c) and columns(c) != 3):
            c=ravel(c)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:76
    else:
        if (firstnonnumeric == istart and ischar(varargin[istart]) and logical_not((strcmpi(varargin[istart],'filled') or strcmpi(varargin[istart],'fill')))):
            c=varargin[istart]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:81
            firstnonnumeric
        else:
            c=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:84
    
    ## Validate inputs
    if (nd == 2 and logical_not(size_equal(x,y))):
        error(cat(fcn,': X and Y must have the same size'))
    else:
        if (nd == 3 and logical_not(size_equal(x,y,z))):
            error(cat(fcn,': X, Y, and Z must have the same size'))
    
    if (logical_not(isscalar(s)) and logical_not(size_equal(x,s))):
        error(cat(fcn,': size of S must match X, Y, and Z'))
    
    if (rows(c) > 1 and rows(c) != rows(x)):
        error(cat(fcn,': number of colors in C must match number of points in X'))
    
    newargs=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:102
    filled=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:103
    have_marker=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:104
    marker='o'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:105
    iarg=copy(firstnonnumeric)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:106
    while (iarg <= nargin):

        arg=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:108
        if (ischar(arg) and (strcmpi(arg,'filled') or strcmpi(arg,'fill'))):
            filled=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:110
        else:
            if ((ischar(arg) or iscellstr(arg)) and logical_not(have_marker)):
                linespec,valid=__pltopt__(fcn,arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:112
                if (valid):
                    have_marker=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:114
                    marker=linespec.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:115
                    if (strcmp(marker,'none')):
                        marker='o'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:117
                    else:
                        if (isempty(marker)):
                            have_marker=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:119
                            __,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:120
                else:
                    error('%s: invalid linespec',fcn)
            else:
                newargs[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:126
                if (iarg <= nargin):
                    newargs[end() + 1]=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:128

    
    if (isempty(c)):
        c=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:134
    
    ## Must occur after __next_line_color__ in order to work correctly.
    hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:138
    newargs=__add_datasource__(fcn,hg,cellarray(['x','y','z','c','size']),newargs[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:139
    addproperty('xdata',hg,'data',x)
    addproperty('ydata',hg,'data',y)
    addproperty('zdata',hg,'data',z)
    if (ischar(c)):
        ## For single explicit color, cdata is unused
        addproperty('cdata',hg,'data',[])
    else:
        addproperty('cdata',hg,'data',c)
    
    addproperty('sizedata',hg,'data',s)
    addlistener(hg,'xdata',update_data)
    addlistener(hg,'ydata',update_data)
    addlistener(hg,'zdata',update_data)
    addlistener(hg,'cdata',update_data)
    addlistener(hg,'sizedata',update_data)
    one_explicit_color=ischar(c) or isequal(size(c),cat(1,3))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:158
    if (numel(x) <= 100):
        ## For small number of points, we'll construct an object for each point.
        if (numel(s) == 1):
            s=repmat(s,numel(x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:165
        if (one_explicit_color):
            for i in arange(1,numel(x)).reshape(-1):
                if (filled):
                    __go_patch__(hg,'xdata',x[i],'ydata',y[i],'zdata',z[i,:],'faces',1,'vertices',cat(x[i],y[i],z[i,:]),'facecolor','none','edgecolor','none','marker',marker,'markersize',s[i],'markeredgecolor',c,'markerfacecolor',c,'linestyle','none')
                else:
                    __go_patch__(hg,'xdata',x[i],'ydata',y[i],'zdata',z[i,:],'faces',1,'vertices',cat(x[i],y[i],z[i,:]),'facecolor','none','edgecolor','none','marker',marker,'markersize',s[i],'markeredgecolor',c,'markerfacecolor','none','linestyle','none')
        else:
            if (rows(c) == 1):
                c=repmat(c,rows(x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:188
            for i in arange(1,numel(x)).reshape(-1):
                if (filled):
                    __go_patch__(hg,'xdata',x[i],'ydata',y[i],'zdata',z[i,:],'faces',1,'vertices',cat(x[i],y[i],z[i,:]),'facecolor','none','edgecolor','none','marker',marker,'markersize',s[i],'markeredgecolor','none','markerfacecolor','flat','cdata',c[i,:],'facevertexcdata',c[i,:],'linestyle','none')
                else:
                    __go_patch__(hg,'xdata',x[i],'ydata',y[i],'zdata',z[i,:],'faces',1,'vertices',cat(x[i],y[i],z[i,:]),'facecolor','none','edgecolor','none','marker',marker,'markersize',s[i],'markeredgecolor','flat','markerfacecolor','none','cdata',c[i,:],'facevertexcdata',c[i,:],'linestyle','none')
    else:
        ## For larger numbers of points, we split the points by common color.
        vert=matlabarray(cat(x,y,z))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:217
        if (one_explicit_color):
            render_size_color(hg,vert,s,c,marker,filled,true)
        else:
            if (rows(c) == 1):
                c=repmat(c,rows(x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:222
            ## We want to group points by color.  So first get all the unique colors
            cc,__,c_to_cc=unique(c,'rows',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:225
            for i in arange(1,rows(cc)).reshape(-1):
                ## Now for each possible unique color, get the logical index of
        ## points that correspond to that color
                idx=(i == c_to_cc)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:230
                if (isscalar(s)):
                    render_size_color(hg,vert[idx,:],s,c[idx,:],marker,filled,true)
                else:
                    render_size_color(hg,vert[idx,:],s[idx],c[idx,:],marker,filled,true)
    
    if (logical_not(ischar(c)) and rows(c) > 1):
        ax=get(hg,'parent')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:244
        clim=get(ax,'clim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:245
        if (min(ravel(c)) < clim[1]):
            clim[1]=min(ravel(c))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:247
            set(ax,'clim',clim)
        if (max(ravel(c)) > clim[2]):
            set(ax,'clim',cat(clim[1],max(ravel(c))))
    
    addproperty('linewidth',hg,'patchlinewidth',0.5)
    addproperty('marker',hg,'patchmarker',marker)
    if (filled):
        addproperty('markeredgecolor',hg,'patchmarkeredgecolor','none')
        if (one_explicit_color):
            addproperty('markerfacecolor',hg,'patchmarkerfacecolor',c)
        else:
            addproperty('markerfacecolor',hg,'patchmarkerfacecolor','flat')
    else:
        addproperty('markerfacecolor',hg,'patchmarkerfacecolor','none')
        if (one_explicit_color):
            addproperty('markeredgecolor',hg,'patchmarkeredgecolor',c)
        else:
            addproperty('markeredgecolor',hg,'patchmarkeredgecolor','flat')
    
    addlistener(hg,'linewidth',update_props)
    addlistener(hg,'marker',update_props)
    addlistener(hg,'markerfacecolor',update_props)
    addlistener(hg,'markeredgecolor',update_props)
    
    addproperty('hittestarea',hg,'radio','on|{off}','off')
    if (logical_not(isempty(newargs))):
        set(hg,newargs[:])
    
    return hg
    
if __name__ == '__main__':
    pass
    
    
@function
def render_size_color(hg=None,vert=None,s=None,c=None,marker=None,filled=None,isflat=None,*args,**kwargs):
    varargin = render_size_color.varargin
    nargin = render_size_color.nargin

    if (isscalar(s)):
        x=vert[:,1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:288
        y=vert[:,2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:289
        z=vert[:,3:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:290
        toolkit=get(ancestor(hg,'figure'),'__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:291
        ## TODO: Verify gnuplot can only support one color.  If RGB triplets
    ##       can be assigned to each vertex, then fix __go_draw_axes__.m
        gnuplot_hack=(numel(x) > 1 and columns(c) == 3 and strcmp(toolkit,'gnuplot'))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:295
        if (ischar(c) or logical_not(isflat) or gnuplot_hack):
            if (filled):
                __go_patch__(hg,'xdata',x,'ydata',y,'zdata',z,'faces',arange(1,numel(x)),'vertices',vert,'facecolor','none','edgecolor','none','marker',marker,'markeredgecolor','none','markerfacecolor',c[1,:],'markersize',s,'linestyle','none')
            else:
                __go_patch__(hg,'xdata',x,'ydata',y,'zdata',z,'faces',arange(1,numel(x)),'vertices',vert,'facecolor','none','edgecolor','none','marker',marker,'markeredgecolor',c[1,:],'markerfacecolor','none','markersize',s,'linestyle','none')
        else:
            if (filled):
                __go_patch__(hg,'xdata',x,'ydata',y,'zdata',z,'faces',arange(1,numel(x)),'vertices',vert,'facecolor','none','edgecolor','none','marker',marker,'markersize',s,'markeredgecolor','none','markerfacecolor','flat','cdata',c,'facevertexcdata',c,'linestyle','none')
            else:
                __go_patch__(hg,'xdata',x,'ydata',y,'zdata',z,'faces',arange(1,numel(x)),'vertices',vert,'facecolor','none','edgecolor','none','marker',marker,'markersize',s,'markeredgecolor','flat','markerfacecolor','none','cdata',c,'facevertexcdata',c,'linestyle','none')
    else:
        ## Round size to one decimal place.
        ss,__,s_to_ss=unique(ceil(dot(s,10)) / 10,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:338
        for i in arange(1,rows(ss)).reshape(-1):
            idx=(i == s_to_ss)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:340
            render_size_color(hg,vert[idx,:],ss[i],c,marker,filled,isflat)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,d=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    lw=get(h,'linewidth')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:348
    m=get(h,'marker')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:349
    fc=get(h,'markerfacecolor')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:350
    ec=get(h,'markeredgecolor')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:351
    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:352
    set(kids,'linewidth',lw,'marker',m,'markerfacecolor',fc,'markeredgecolor',ec)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,d=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    x=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:359
    y=get(h,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:360
    z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:361
    c=get(h,'cdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:362
    if (rows(c) == 1):
        c=repmat(c,numel(x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:364
    
    s=get(h,'sizedata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:366
    if (numel(s) == 1):
        s=repmat(s,numel(x),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:368
    
    hlist=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__scatter__.m:370
    if (isempty(z)):
        for i in arange(1,length(hlist)).reshape(-1):
            set(hlist[i],'vertices',cat(x[i],y[i]),'cdata',reshape(c[i,:],cat(1,size(c)(arange(2,end())))),'facevertexcdata',c[i,:],'markersize',s[i])
    else:
        for i in arange(1,length(hlist)).reshape(-1):
            set(hlist[i],'vertices',cat(x[i],y[i],z[i]),'cdata',reshape(cd(i,arange()),cat(1,size(cd)(arange(2,end())))),'facevertexcdata',cd(i,arange()),'markersize',s[i])
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 John W. Eaton, Shai Ayal, Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{h}, @var{fail}] =} __patch__ (@var{p}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## __patch__ (p, x, y, c)
## Create patch object from x and y with color c and parent p.
## Return handle to patch object.
    
    ## Author: Kai Habel
    
    
@function
def __patch__(p=None,varargin=None,*args,**kwargs):
    varargin = __patch__.varargin
    nargin = __patch__.nargin

    h=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:32
    failed=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:33
    is_numeric_arg=cellfun(isnumeric,varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:35
    if (isempty(varargin)):
        args=copy(varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:38
    else:
        if (isstruct(varargin[1])):
            if (isfield(varargin[1],'vertices') and isfield(varargin[1],'faces')):
                fvs=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:41
                fvc=cell(1,dot(2,numfields(fvs)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:42
                fvc[1:2:end()]=fieldnames(fvs)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:43
                fvc[2:2:end()]=struct2cell(fvs)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:44
                args=matlabarray(cat(fvc[:],varargin[2:end()]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:45
            else:
                failed=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:47
        else:
            if (is_numeric_arg[1]):
                if (nargin < 3 or logical_not(is_numeric_arg[2])):
                    failed=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:51
                else:
                    if (nargin > 4 and all(is_numeric_arg[1:4])):
                        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:54
                        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:55
                        z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:56
                        c=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:57
                        iarg=5
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:58
                    else:
                        if (nargin > 3 and all(is_numeric_arg[1:3])):
                            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:60
                            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:61
                            iarg=4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:62
                            if (rem(nargin - iarg,2) == 1):
                                c=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:64
                                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:65
                                iarg=5
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:66
                            else:
                                z=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:68
                                c=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:69
                        else:
                            if (nargin > 2 and all(is_numeric_arg[1:2])):
                                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:72
                                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:73
                                z=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:74
                                iarg=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:75
                                if (rem(nargin - iarg,2) == 1):
                                    c=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:77
                                    iarg
                                else:
                                    c=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:80
                    if (isvector(x)):
                        x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:85
                        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:86
                        z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:87
                        if (isnumeric(c)):
                            if (isvector(c) and numel(c) == numel(x)):
                                c=ravel(c)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:90
                            else:
                                if (rows(c) != numel(x) and columns(c) == numel(x)):
                                    c=c.T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:92
                    args[1]='xdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:96
                    args[2]=x
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:97
                    args[3]='ydata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:98
                    args[4]=y
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:99
                    args[5]='zdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:100
                    args[6]=z
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:101
                    if (isnumeric(c)):
                        if (ndims(c) == 3 and columns(c) == 1):
                            c=permute(c,cat(1,3,2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:106
                        if (isvector(c) and numel(c) == columns(x)):
                            if (isnan(c)):
                                args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:111
                                args[8]=cat(1,1,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:112
                                args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:113
                                args[10]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:114
                            else:
                                if (isnumeric(c)):
                                    args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:116
                                    args[8]='flat'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:117
                                    args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:118
                                    args[10]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:119
                                else:
                                    error('patch: color data C must be numeric')
                        else:
                            if (isvector(c) and numel(c) == 3):
                                args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:124
                                args[8]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:125
                                args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:126
                                args[10]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:127
                            else:
                                if (ndims(c) == 3 and size(c,3) == 3):
                                    ## CDATA is specified as RGB data
                                    if ((rows(c) == 1 and columns(c) == 1) or (rows(c) == 1 and columns(c) == columns(x))):
                                        ## Single patch color or per-face color
                                        args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:133
                                        args[8]='flat'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:134
                                        args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:135
                                        args[10]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:136
                                    else:
                                        if (rows(c) == rows(x) and columns(c) == columns(x)):
                                            ## Per-vertex color
                                            args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:139
                                            args[8]='interp'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:140
                                            args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:141
                                            args[10]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:142
                                        else:
                                            error('patch: Invalid TrueColor data C')
                                else:
                                    ## Color Vectors
                                    if (isempty(c)):
                                        args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:149
                                        args[8]='interp'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:150
                                        args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:151
                                        args[10]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:152
                                    else:
                                        if (size_equal(c,x) and size_equal(c,y)):
                                            args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:154
                                            args[8]='interp'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:155
                                            args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:156
                                            args[10]=c
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:157
                                        else:
                                            error('patch: size of X, Y, and C must be equal')
                    else:
                        if (ischar(c) and rem(nargin - iarg,2) == 0):
                            ## Assume any additional argument over an even number is a color string.
                            args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:164
                            args[8]=tolower(c)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:165
                            args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:166
                            args[10]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:167
                        else:
                            args[7]='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:169
                            args[8]=cat(0,0,0)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:170
                            args[9]='cdata'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:171
                            args[10]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:172
                    args=matlabarray(cat(args,varargin[iarg:end()]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:175
            else:
                args=copy(varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:178
    
    if (logical_not(failed)):
        h=__go_patch__(p,args[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__patch__.m:182
    
    return h,failed
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{hg} =} __quiver__ (@dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __quiver__(varargin=None,*args,**kwargs):
    varargin = __quiver__.varargin
    nargin = __quiver__.nargin

    h=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:26
    is3d=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:27
    autoscale=0.9
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:29
    
    ## results if arrowsize=0.33.  Since this is just a non-dimensional
  ## scaling factor we scale the arrowsize property value by 0.33/0.20
  ## in order to get equivalent visual results while keeping equivalent
  ## property values.
    arrowsize=0.2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:35
    firstnonnumeric=find(logical_not(cellfun('isnumeric',varargin[3:nargin])),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:37
    if (isempty(firstnonnumeric)):
        firstnonnumeric=copy(Inf)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:39
    else:
        firstnonnumeric += 2
    
    ioff=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:44
    if (nargin < (6 + is3d) or firstnonnumeric < (6 + is3d)):
        u=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:46
        v=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:47
        if (is3d):
            w=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:49
            x,y,z=meshgrid(arange(1,columns(u)),arange(1,rows(u)),arange(1,max(size(w))),nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:50
        else:
            x,y=meshgrid(arange(1,columns(u)),arange(1,rows(u)),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:52
        if (nargin >= ioff and isnumeric(varargin[ioff]) and isscalar(varargin[ioff])):
            autoscale=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:56
    else:
        x=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:59
        y=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:60
        if (is3d):
            z=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:62
        u=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:64
        v=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:65
        if (is3d):
            w=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:67
            if (isvector(x) and isvector(y) and isvector(z) and (logical_not(isvector(u)) or logical_not(isvector(v)) or logical_not(isvector(w)))):
                x,y,z=meshgrid(x,y,z,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:70
        else:
            if (isvector(x) and isvector(y) and (logical_not(isvector(u)) or logical_not(isvector(v)))):
                x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:74
        if (nargin >= ioff and isnumeric(varargin[ioff]) and isscalar(varargin[ioff])):
            autoscale=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:79
    
    have_filled=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:83
    have_line_spec=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:84
    args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:85
    while (ioff <= nargin):

        arg=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:87
        if (ischar(arg) and strcmpi(arg,'filled')):
            have_filled=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:89
        else:
            if ((ischar(arg) or iscellstr(arg)) and logical_not(have_line_spec)):
                linespec,valid=__pltopt__('quiver',arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:92
                if (valid):
                    have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:94
                    if (isempty(linespec.linestyle) or strcmp(linespec.linestyle,'none')):
                        linespec.linestyle = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:96
                else:
                    args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:99
                    if (ioff <= nargin):
                        args[end() + 1]=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:101
            else:
                args[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:105
                if (ioff <= nargin):
                    args[end() + 1]=varargin[ioff]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:107

    
    ## Normalize 0.20 to 1/3 for plotting
    arrowsize /= dot(0.2,3)
    
    uu=copy(u)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:116
    vv=copy(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:117
    if (is3d):
        ww=copy(w)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:119
        len_=max(sqrt(ravel(u) ** 2 + ravel(v) ** 2 + ravel(w) ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:120
    else:
        len_=max(sqrt(ravel(u) ** 2 + ravel(v) ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:122
    
    if (len_ > 0 and autoscale and numel(u) > 1):
        if (isvector(x)):
            nx=ny=sqrt(length(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:126
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:126
        else:
            ny,nx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:128
        dx=(max(ravel(x)) - min(ravel(x))) / nx
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:130
        dy=(max(ravel(y)) - min(ravel(y))) / ny
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:131
        if (is3d):
            dz=(max(ravel(z)) - min(ravel(z))) / max(nx,ny)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:133
        else:
            dz=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:135
        sd=sqrt(dx ** 2 + dy ** 2 + dz ** 2) / len_
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:137
        if (sd != 0):
            s=dot(autoscale,sd)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:139
        else:
            s=copy(autoscale)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:141
        uu=dot(s,u)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:143
        vv=dot(s,v)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:144
        if (is3d):
            ww=dot(s,w)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:146
    
    hstate=get(h,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:150
    try:
        if (have_line_spec):
            ls=linespec.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:154
            lc=linespec.color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:155
        else:
            ls='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:157
            lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:158
        ## Must occur after __next_line_color__ in order to work correctly.
        hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:162
        if (is3d):
            args=__add_datasource__('quiver3',hg,cellarray(['x','y','z','u','v','w']),args[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:164
        else:
            args=__add_datasource__('quiver',hg,cellarray(['x','y','z','u','v','w']),args[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:167
        hold('on')
        addproperty('xdata',hg,'data',x)
        addproperty('ydata',hg,'data',y)
        addproperty('udata',hg,'data',u)
        addproperty('vdata',hg,'data',v)
        if (is3d):
            addproperty('zdata',hg,'data',z)
            addproperty('wdata',hg,'data',w)
        else:
            addproperty('zdata',hg,'data',[])
            addproperty('wdata',hg,'data',[])
        addlistener(hg,'xdata',update_data)
        addlistener(hg,'ydata',update_data)
        addlistener(hg,'zdata',update_data)
        addlistener(hg,'udata',update_data)
        addlistener(hg,'vdata',update_data)
        addlistener(hg,'wdata',update_data)
        x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:192
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:193
        xend=x + ravel(uu)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:194
        yend=y + ravel(vv)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:195
        if (is3d):
            z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:197
            zend=z + ravel(ww)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:198
        ## Draw arrow shaft as one line object
        if (is3d):
            h1=plot3(ravel(cat([x.T],[xend.T],[NaN(1,length(x))])),ravel(cat([y.T],[yend.T],[NaN(1,length(y))])),ravel(cat([z.T],[zend.T],[NaN(1,length(z))])),'linestyle',ls,'color',lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:203
        else:
            h1=plot(ravel(cat([x.T],[xend.T],[NaN(1,length(x))])),ravel(cat([y.T],[yend.T],[NaN(1,length(y))])),'linestyle',ls,'color',lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:208
        xtmp=x + dot(ravel(uu),(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:213
        ytmp=y + dot(ravel(vv),(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:214
        if (is3d):
            xydist=sqrt(ravel(uu) ** 2 + ravel(vv) ** 2 + ravel(ww) ** 2) / (sqrt(ravel(uu) ** 2 + ravel(vv) ** 2) + eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:217
            xarrw1=xtmp + dot(multiply(ravel(vv),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:219
            xarrw2=xtmp - dot(multiply(ravel(vv),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:220
            yarrw1=ytmp - dot(multiply(ravel(uu),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:221
            yarrw2=ytmp + dot(multiply(ravel(uu),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:222
            zarrw1=zarrw2=zend - dot(ravel(ww),arrowsize)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:223
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:223
        else:
            xarrw1=xtmp + dot(ravel(vv),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:225
            xarrw2=xtmp - dot(ravel(vv),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:226
            yarrw1=ytmp - dot(ravel(uu),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:227
            yarrw2=ytmp + dot(ravel(uu),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:228
        ## Draw arrowhead as one line object
        if (have_line_spec):
            if (logical_not(isempty(linespec.marker)) and logical_not(strcmp(linespec.marker,'none'))):
                ls='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:234
        if (is3d):
            h2=plot3(ravel(cat([xarrw1.T],[xend.T],[xarrw2.T],[NaN(1,length(x))])),ravel(cat([yarrw1.T],[yend.T],[yarrw2.T],[NaN(1,length(y))])),ravel(cat([zarrw1.T],[zend.T],[zarrw2.T],[NaN(1,length(z))])),'linestyle',ls,'color',lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:239
        else:
            h2=plot(ravel(cat([xarrw1.T],[xend.T],[xarrw2.T],[NaN(1,length(x))])),ravel(cat([yarrw1.T],[yend.T],[yarrw2.T],[NaN(1,length(y))])),'linestyle',ls,'color',lc,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:244
        ## Draw arrow base marker as a third line object
        if (logical_not(have_line_spec) or isempty(linespec.marker)):
            mk='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:251
        else:
            mk=linespec.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:253
        if (is3d):
            h3=plot3(x,y,z,'linestyle','none','marker',mk,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:256
        else:
            h3=plot(x,y,'linestyle','none','marker',mk,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:258
        if (have_filled):
            ## FIXME: gnuplot doesn't respect the markerfacecolor field
            set(h3,'markerfacecolor',get(h1,'color'))
        ## Set up the hggroup properties and listeners
        if (autoscale):
            addproperty('autoscale',hg,'radio','{on}|off','on')
            addproperty('autoscalefactor',hg,'data',autoscale)
        else:
            addproperty('autoscale',hg,'radio','{on}|off','off')
            addproperty('autoscalefactor',hg,'data',1.0)
        addlistener(hg,'autoscale',update_data)
        addlistener(hg,'autoscalefactor',update_data)
        addproperty('maxheadsize',hg,'data',dot(dot(arrowsize,0.2),3))
        addlistener(hg,'maxheadsize',update_data)
        addproperty('showarrowhead',hg,'radio','{on}|off','on')
        addlistener(hg,'showarrowhead',update_props)
        addproperty('color',hg,'linecolor',get(h1,'color'))
        addproperty('linestyle',hg,'linelinestyle',get(h1,'linestyle'))
        addproperty('linewidth',hg,'linelinewidth',get(h1,'linewidth'))
        addproperty('marker',hg,'linemarker',get(h3,'marker'))
        addproperty('markerfacecolor',hg,'linemarkerfacecolor',get(h3,'markerfacecolor'))
        addproperty('markersize',hg,'linemarkersize',get(h3,'markersize'))
        addlistener(hg,'color',update_props)
        addlistener(hg,'linestyle',update_props)
        addlistener(hg,'linewidth',update_props)
        addlistener(hg,'marker',update_props)
        addlistener(hg,'markerfacecolor',update_props)
        addlistener(hg,'markersize',update_props)
        addproperty('hittestarea',hg,'radio','on|{off}','off')
        if (logical_not(isempty(args))):
            set(hg,args[:])
    finally:
        set(h,'nextplot',hstate)
    
    return hg
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    x=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:311
    y=get(h,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:312
    z=get(h,'zdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:313
    u=get(h,'udata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:315
    v=get(h,'vdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:316
    w=get(h,'wdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:317
    s=get(h,'autoscalefactor')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:319
    arrowsize=get(h,'maxheadsize')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:320
    arrowsize /= dot(0.2,3)
    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:323
    if (isempty(z) or isempty(w)):
        is3d=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:326
    else:
        is3d=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:328
    
    if (strcmp(get(h,'autoscale'),'on') and s != 0):
        ## Scale the arrows to fit in the grid
        if (isvector(x)):
            nx=ny=sqrt(length(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:334
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:334
        else:
            ny,nx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:336
        dx=(max(ravel(x)) - min(ravel(x))) / nx
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:338
        dy=(max(ravel(y)) - min(ravel(y))) / ny
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:339
        if (is3d):
            dz=(max(ravel(z)) - min(ravel(z))) / max(nx,ny)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:341
            len_=max(sqrt(ravel(u) ** 2 + ravel(v) ** 2 + ravel(w) ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:342
        else:
            dz=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:344
            len_=max(sqrt(ravel(u) ** 2 + ravel(v) ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:345
        if (len_ > 0):
            sd=sqrt(dx ** 2 + dy ** 2 + dz ** 2) / len_
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:348
            if (sd != 0):
                s *= sd
            u=dot(s,u)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:352
            v=dot(s,v)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:353
            if (is3d):
                w=dot(s,w)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:355
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:360
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:361
    xend=x + ravel(u)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:362
    yend=y + ravel(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:363
    if (is3d):
        z=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:365
        zend=z + ravel(w)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:366
    
    set(kids[3],'xdata',ravel(cat([x.T],[xend.T],[NaN(1,length(x))])))
    set(kids[3],'ydata',ravel(cat([y.T],[yend.T],[NaN(1,length(y))])))
    if (is3d):
        set(kids[3],'zdata',ravel(cat([z.T],[zend.T],[NaN(1,length(z))])))
    
    xtmp=x + dot(ravel(u),(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:375
    ytmp=y + dot(ravel(v),(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:376
    if (is3d):
        xydist=sqrt(ravel(u) ** 2 + ravel(v) ** 2 + ravel(w) ** 2) / (sqrt(ravel(u) ** 2 + ravel(v) ** 2) + eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:379
        xarrw1=xtmp + dot(multiply(ravel(v),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:381
        xarrw2=xtmp - dot(multiply(ravel(v),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:382
        yarrw1=ytmp - dot(multiply(ravel(u),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:383
        yarrw2=ytmp + dot(multiply(ravel(u),xydist),arrowsize) / 4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:384
        zarrw1=zarrw2=zend - dot(ravel(w),arrowsize)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:385
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:385
    else:
        xarrw1=xtmp + dot(ravel(v),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:387
        xarrw2=xtmp - dot(ravel(v),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:388
        yarrw1=ytmp - dot(ravel(u),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:389
        yarrw2=ytmp + dot(ravel(u),arrowsize) / 3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:390
    
    set(kids[2],'xdata',ravel(cat([x.T],[xend.T],[NaN(1,length(x))])))
    set(kids[2],'ydata',ravel(cat([y.T],[yend.T],[NaN(1,length(y))])))
    if (is3d):
        set(kids[2],'zdata',ravel(cat([z.T],[zend.T],[NaN(1,length(z))])))
    
    set(kids[2],'xdata',ravel(cat([xarrw1.T],[xend.T],[xarrw2.T],[NaN(1,length(x))])))
    set(kids[2],'ydata',ravel(cat([yarrw1.T],[yend.T],[yarrw2.T],[NaN(1,length(y))])))
    if (is3d):
        set(kids[2],'zdata',ravel(cat([zarrw1.T],[zend.T],[zarrw2.T],[NaN(1,length(z))])))
    
    set(kids[1],'xdata',x)
    set(kids[1],'ydata',y)
    if (is3d):
        set(kids[1],'zdata',z)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,__=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__quiver__.m:414
    set(kids[cat(3,2)],cellarray(['color','linestyle','linewidth']),get(h,cellarray(['color','linestyle','linewidth'])))
    set(kids[2],'visible',get(h,'showarrowhead'))
    set(kids[1],cellarray(['color','marker','markerfacecolor','markersize']),get(h,cellarray(['color','marker','markerfacecolor','markersize'])))
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __bar__ (@var{vertical}, @var{func}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __bar__(vertical=None,func=None,varargin=None,*args,**kwargs):
    varargin = __bar__.varargin
    nargin = __bar__.nargin

    hax,varargin,nargin=__plt_get_axis_arg__(func,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:28
    
    width=0.8 - dot(10,eps)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:31
    group=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:32
    histc=copy(NA)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:33
    bv=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:34
    
    if (nargin > 1 and isnumeric(varargin[2])):
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:37
        if (isvector(x)):
            x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:39
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:41
        if (isvector(y)):
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:43
        if (rows(x) != rows(y)):
            y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:46
            if (isvector(y)):
                y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:48
            x=cat(arange(1,rows(y))).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:50
            idx=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:51
        else:
            if (logical_not(isvector(x))):
                error('%s: X must be a vector',func)
            idx=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:56
    else:
        y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:59
        if (isvector(y)):
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:61
        x=cat(arange(1,rows(y))).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:63
        idx=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:64
    
    newargs=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:67
    have_line_spec=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:68
    while (idx <= nargin):

        if (ischar(varargin[idx]) and strcmpi(varargin[idx],'grouped')):
            group=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:71
            idx
        else:
            if (ischar(varargin[idx]) and strcmpi(varargin[idx],'stacked')):
                group=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:74
                idx
            else:
                if (ischar(varargin[idx]) and strcmpi(varargin[idx],'histc')):
                    group=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:77
                    histc=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:78
                    idx
                else:
                    if (ischar(varargin[idx]) and strcmpi(varargin[idx],'hist')):
                        group=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:81
                        histc=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:82
                        idx
                    else:
                        if ((ischar(varargin[idx]) or iscellstr(varargin[idx])) and logical_not(have_line_spec)):
                            linespec,valid=__pltopt__(func,varargin[idx],false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:87
                            if (valid):
                                have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:89
                                ##        away from closing ']' on next line.
                                newargs=matlabarray(cat(cellarray(['facecolor',linespec.color]),newargs))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:92
                                idx
                                continue
                        if (isscalar(varargin[idx])):
                            width=varargin[idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:98
                        else:
                            if (idx == nargin):
                                newargs=matlabarray(cat(newargs,varargin[idx]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:100
                            else:
                                if (ischar(varargin[idx]) and strcmpi(varargin[idx],'basevalue') and isscalar(varargin[idx + 1])):
                                    bv=varargin[idx + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:104
                                    idx += 2
                                else:
                                    newargs=matlabarray(cat(newargs,varargin[idx:idx + 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:107
                                    idx += 2

    
    ngrp=rows(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:113
    if (ngrp != rows(y)):
        error('%s: length of X and Y must be equal',func)
    
    if (any(x[2:end()] < x[1:end() - 1])):
        error('%s: X vector values must be in ascending order',func)
    
    nbars=columns(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:121
    
    if (islogical(histc)):
        cwidth=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:125
        if (nbars == 1):
            gwidth=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:127
        else:
            gwidth=width ** 2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:129
    else:
        if (nbars == 1):
            cwidth=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:132
            gwidth=copy(width)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:133
        else:
            cwidth=gwidth=copy(width)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:135
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:135
    
    ## Complicated algorithm sizes bars with unitless parameter width.
  ## If width is 1.0, adjacent bars in a group are touching.
  ## Otherwise, bar size is cwidth and the remaining space is split evenly on
  ## either side of the bar.  For the default 0.8, spacing is [0.1 0.8 0.1].
  ## Groups of bars are spaced by gwidth.  If gwidth is 1.0 then adjacent
  ## groups will just touch.
    if (numel(x) > 1):
        cutoff=min(diff(double(x))) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:145
    else:
        cutoff=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:147
    
    if (group):
        gdelta=dot(cutoff,gwidth) / nbars
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:150
        cdelta=repmat(dot((1 - ((1 - cwidth) / 2)),gdelta),size(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:151
    else:
        cdelta=repmat(dot(cutoff,gwidth),size(x))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:153
    
    x1=ravel((x - cdelta)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:155
    x2=ravel((x + cdelta)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:156
    xb=repmat(ravel(cat([x1],[x1],[x2],[x2])),1,nbars)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:157
    if (group):
        if (islogical(histc) and histc):
            offset=dot(dot(2,cdelta),cat(arange(0,(nbars - 1)))) + cdelta[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:161
        else:
            offset=dot(dot(2,cdelta),cat(arange(- (nbars - 1) / 2,(nbars - 1) / 2)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:163
        xb[1:4:dot(4,ngrp),:] += offset + dot((1 - cwidth) / 2,(dot(2,gdelta)))
        xb[2:4:dot(4,ngrp),:] += offset + dot((1 - cwidth) / 2,(dot(2,gdelta)))
        xb[3:4:dot(4,ngrp),:] += offset - dot((1 - cwidth) / 2,(dot(2,gdelta)))
        xb[4:4:dot(4,ngrp),:] += offset - dot((1 - cwidth) / 2,(dot(2,gdelta)))
        y0=zeros(size(y)) + bv
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:171
        y1=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:172
    else:
        y1=cumsum(y,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:174
        y0=matlabarray(cat(zeros(ngrp,1) + bv,y1[:,1:end() - 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:175
    
    yb=zeros(dot(4,ngrp),nbars)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:178
    yb[1:4:dot(4,ngrp),:]=y0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:179
    yb[2:4:dot(4,ngrp),:]=y1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:180
    yb[3:4:dot(4,ngrp),:]=y1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:181
    yb[4:4:dot(4,ngrp),:]=y0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:182
    xb=reshape(xb,cat(4,ngrp,nbars))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:184
    yb=reshape(yb,cat(4,ngrp,nbars))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:185
    if (nargout < 2):
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:188
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:190
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:193
            htmp=bars(hax,vertical,x,y,xb,yb,gwidth,group,have_line_spec,bv,newargs[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:195
            if (logical_not(ishold(hax))):
                if (all(x[:,1] == fix(x[:,1]))):
                    if (vertical):
                        set(hax,'xtick',x[:,1])
                    else:
                        set(hax,'ytick',x[:,1])
                ## Hack prevents color and xlim setting changes when basevalue changes.
                if (vertical):
                    set(hax,'clim',cat(0,1),'xlimmode','manual')
                else:
                    set(hax,'clim',cat(0,1),'ylimmode','manual')
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
        if (nargout == 1):
            varargout[1]=htmp
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:219
    else:
        if (vertical):
            varargout[1]=xb
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:223
            varargout[2]=yb
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:224
        else:
            varargout[1]=yb
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:226
            varargout[2]=xb
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:227
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def bars(hax=None,vertical=None,x=None,y=None,xb=None,yb=None,width=None,group=None,have_color_spec=None,base_value=None,varargin=None,*args,**kwargs):
    varargin = bars.varargin
    nargin = bars.nargin

    nbars=columns(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:235
    clim=get(hax,'clim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:236
    hglist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:237
    for i in arange(1,nbars).reshape(-1):
        hg=hggroup()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:240
        hglist=matlabarray(cat([hglist],[hg]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:241
        args=__add_datasource__('bar',hg,cellarray(['x','y']),varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:242
        if (vertical):
            if (logical_not(have_color_spec)):
                if (nbars == 1):
                    lev=clim[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:247
                else:
                    lev=dot((i - 1),(clim[2] - clim[1])) / (nbars - 1) - clim[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:249
                h=patch(hax,xb[:,:,i],yb[:,:,i],'FaceColor','flat','cdata',lev,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:251
            else:
                h=patch(hax,xb[:,:,i],yb[:,:,i],'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:254
        else:
            if (logical_not(have_color_spec)):
                if (nbars == 1):
                    lev=clim[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:259
                else:
                    lev=dot((i - 1),(clim[2] - clim[1])) / (nbars - 1) - clim[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:261
                h=patch(hax,yb[:,:,i],xb[:,:,i],'FaceColor','flat','cdata',lev,'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:263
            else:
                h=patch(hax,yb[:,:,i],xb[:,:,i],'parent',hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:266
        if (i == 1):
            ## Add baseline object the first time through loop
            x_axis_range=get(hax,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:272
            h_baseline=line(hax,x_axis_range,cat(base_value,base_value),'color',cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:273
            set(h_baseline,'handlevisibility','off','xliminclude','off')
            set(h_baseline,'parent',get(hg,'parent'))
        ## Setup the hggroup and listeners
        addproperty('showbaseline',hg,'radio','{on}|off')
        addproperty('basevalue',hg,'data',base_value)
        addproperty('baseline',hg,'data',h_baseline)
        addlistener(hg,'showbaseline',cellarray([show_baseline,'showbl']))
        addlistener(hg,'visible',cellarray([show_baseline,'visib']))
        addlistener(hg,'basevalue',move_baseline)
        addproperty('barwidth',hg,'data',width)
        if (group):
            addproperty('barlayout',hg,'radio','stacked|{grouped}','grouped')
        else:
            addproperty('barlayout',hg,'radio','{stacked}|grouped','stacked')
        if (vertical):
            addproperty('horizontal',hg,'radio','on|{off}','off')
        else:
            addproperty('horizontal',hg,'radio','{on}|off','on')
        addlistener(hg,'barwidth',update_group)
        addlistener(hg,'barlayout',update_group)
        addlistener(hg,'horizontal',update_group)
        addproperty('edgecolor',hg,'patchedgecolor',get(h,'edgecolor'))
        addproperty('facecolor',hg,'patchfacecolor',get(h,'facecolor'))
        addproperty('linestyle',hg,'patchlinestyle',get(h,'linestyle'))
        addproperty('linewidth',hg,'patchlinewidth',get(h,'linewidth'))
        addlistener(hg,'edgecolor',update_props)
        addlistener(hg,'facecolor',update_props)
        addlistener(hg,'linestyle',update_props)
        addlistener(hg,'linewidth',update_props)
        if (isvector(x)):
            addproperty('xdata',hg,'data',x)
        else:
            addproperty('xdata',hg,'data',x[:,i])
        addproperty('ydata',hg,'data',y[:,i])
        addlistener(hg,'xdata',update_data)
        addlistener(hg,'ydata',update_data)
        addproperty('bargroup',hg,'data')
        set(hglist,'bargroup',hglist)
        addproperty('hittestarea',hg,'radio','on|{off}','off')
        if (logical_not(isempty(args))):
            set(hg,args[:])
    
    update_xlim(hax,[])
    
    ## creation of plot when patch objects are added.
    addlistener(hax,'xlim',update_xlim)
    addlistener(h_baseline,'ydata',update_baseline)
    addlistener(h_baseline,'visible',update_baseline)
    return hglist
    
if __name__ == '__main__':
    pass
    
    
@function
def update_xlim(h=None,__=None,*args,**kwargs):
    varargin = update_xlim.varargin
    nargin = update_xlim.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:345
    xlim=get(h,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:346
    for i in arange(1,length(kids)).reshape(-1):
        obj=get(kids[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:349
        if (strcmp(obj.type,'hggroup') and isfield(obj,'baseline')):
            if (any(get(obj.baseline,'xdata') != xlim)):
                set(obj.baseline,'xdata',xlim)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_baseline(h=None,__=None,*args,**kwargs):
    varargin = update_baseline.varargin
    nargin = update_baseline.nargin

    visible=get(h,'visible')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:359
    ydata=get(h,'ydata')(1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:360
    
    kids=get(get(h,'parent'),'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:363
    for i in arange(1,length(kids)).reshape(-1):
        obj=get(kids[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:365
        if (strcmp(obj.type,'hggroup') and isfield(obj,'baseline') and obj.baseline == h):
            set(obj.bargroup,'showbaseline',visible,'basevalue',ydata)
            break
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def show_baseline(h=None,__=None,prop='',*args,**kwargs):
    varargin = show_baseline.varargin
    nargin = show_baseline.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:380
            hlist=get(h,'bargroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:381
            if (strcmp(prop,'showbl')):
                showbaseline=get(h,'showbaseline')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:383
                hlist=hlist[hlist != h]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:384
                set(hlist,'showbaseline',showbaseline)
            else:
                if (strcmp(prop,'visib')):
                    showbaseline='on'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:387
                    if (all(strcmp(get(hlist,'visible'),'off'))):
                        showbaseline='off'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:389
            set(get(h,'baseline'),'visible',showbaseline)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:394
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def move_baseline(h=None,__=None,*args,**kwargs):
    varargin = move_baseline.varargin
    nargin = move_baseline.nargin

    
    
    if (logical_not(recursion)):
        recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:404
        try:
            b0=get(h,'basevalue')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:406
            bl=get(h,'baseline')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:407
            set(bl,'ydata',cat(b0,b0))
            if (strcmp(get(h,'barlayout'),'grouped')):
                update_data(h)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:414
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,__=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:420
    set(kids,cellarray(['edgecolor','linewidth','linestyle','facecolor']),get(h,cellarray(['edgecolor','linewidth','linestyle','facecolor'])))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:431
            hlist=get(h,'bargroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:432
            x=get(h,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:433
            if (logical_not(isvector(x))):
                x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:435
            ydat=get(hlist,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:437
            if (iscell(ydat)):
                y=cell2mat(ydat.T)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:439
            else:
                if (isvector(ydat)):
                    y=ravel(ydat)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:441
                else:
                    y=copy(ydat)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:443
            xb,yb=bar(x,y,get(h,'barwidth'),get(h,'barlayout'),'basevalue',get(h,'basevalue'),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:446
            vertical=strcmp(get(h,'horizontal'),'off')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:449
            for i in arange(1,columns(y)).reshape(-1):
                hp=get(hlist[i],'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:451
                if (vertical):
                    set(hp,'xdata',xb[:,:,i],'ydata',yb[:,:,i])
                else:
                    set(hp,'xdata',yb[:,:,i],'ydata',xb[:,:,i])
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:459
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_group(h=None,__=None,*args,**kwargs):
    varargin = update_group.varargin
    nargin = update_group.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:470
            hlist=get(h,'bargroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:471
            barwidth=get(h,'barwidth')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:472
            barlayout=get(h,'barlayout')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:473
            horizontal=get(h,'horizontal')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:474
            hlist=hlist[hlist != h]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:476
            set(hlist,'barwidth',barwidth,'barlayout',barlayout,'horizontal',horizontal)
            update_data(h)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__bar__.m:481
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{newargs} =} __add_datasource__ (@var{fcn}, @var{h}, @var{data}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __add_datasource__(fcn=None,h=None,data=None,varargin=None,*args,**kwargs):
    varargin = __add_datasource__.varargin
    nargin = __add_datasource__.nargin

    if (ischar(data)):
        data=cellarray([data])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:27
    
    for i in arange(1,numel(data)).reshape(-1):
        addproperty(strcat(data[i],'datasource'),h,'string','')
    
    i=0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:34
    newargs=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:35
    while (i < numel(varargin)):

        arg=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:37
        if (i != numel(varargin) and ischar(arg) and length(arg) > 9 and strcmpi(arg[end() - 9:end()],'datasource')):
            arg=tolower(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:40
            val=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:41
            if (ischar(val)):
                set(h,arg,val)
            else:
                error('%s: expecting data source to be a string',fcn)
        else:
            newargs[end() + 1]=arg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__add_datasource__.m:48

    
    return newargs
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2000-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} __errplot__ (@var{fstr}, @var{hax}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Created: 18.7.2000
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def __errplot__(fstr=None,hax=None,varargin=None,*args,**kwargs):
    varargin = __errplot__.varargin
    nargin = __errplot__.nargin

    fmt=__pltopt__('__errplot__',fstr)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:30
    
    if '~' == (fmt.errorstyle):
        ifmt='yerr'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:35
    else:
        if '>' == (fmt.errorstyle):
            ifmt='xerr'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:37
        else:
            if '~>' == (fmt.errorstyle):
                ifmt='xyerr'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:39
            else:
                if '#' == (fmt.errorstyle):
                    ifmt='box'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:41
                else:
                    if '#~' == (fmt.errorstyle):
                        ifmt='boxy'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:43
                    else:
                        if '#~>' == (fmt.errorstyle):
                            ifmt='boxxy'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:45
                        else:
                            ifmt='yerr'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:47
    
    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:50
    nplots=ifelse(isempty(varargin[1]),0,columns(varargin[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:51
    for i in arange(1,nplots).reshape(-1):
        if (isempty(fmt.color)):
            lc=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:55
        else:
            lc=fmt.color()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:57
        if (isempty(fmt.marker) and isempty(fmt.linestyle)):
            ls,mk=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:60
        else:
            ls=fmt.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:62
            mk=fmt.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:63
        ## Must occur after __next_line_color__ in order to work correctly.
        hg=hggroup('parent',hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:67
        h=matlabarray(cat([h],[hg]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:68
        args=__add_datasource__('__errplot__',hg,cellarray(['x','y','l','u','xl','xu']))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:69
        hl=matlabarray(cat((__line__(hg,'color',lc,'linestyle','-','marker','none')),(__line__(hg,'color',lc,'linestyle',ls,'marker',mk))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:72
        if 2 == (numel(varargin)):
            ydata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:77
            xdata=arange(1,numel(ydata))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:78
            if (strcmp(ifmt,'yerr') or strcmp(ifmt,'boxy')):
                ldata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:80
                udata=copy(ldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:81
                xldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:82
                xudata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:83
            else:
                if (strcmp(ifmt,'xerr') or strcmp(ifmt,'box')):
                    xldata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:85
                    xudata=copy(ldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:86
                    ldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:87
                    udata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:88
                else:
                    error('errorbar: 2 column errorplot is only valid for xerr or yerr')
        else:
            if 3 == (numel(varargin)):
                if (strcmp(ifmt,'yerr') or strcmp(ifmt,'boxy')):
                    xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:94
                    ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:95
                    ldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:96
                    udata=copy(ldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:97
                    xldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:98
                    xudata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:99
                else:
                    if (strcmp(ifmt,'xyerr') or strcmp(ifmt,'boxxy')):
                        ydata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:101
                        xdata=arange(1,numel(ydata))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:102
                        xldata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:103
                        xudata=copy(xldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:104
                        ldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:105
                        udata=copy(ldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:106
                    else:
                        xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:108
                        ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:109
                        xldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:110
                        xudata=copy(xldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:111
                        ldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:112
                        udata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:113
            else:
                if 4 == (numel(varargin)):
                    if (strcmp(ifmt,'yerr') or strcmp(ifmt,'boxy')):
                        xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:117
                        ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:118
                        ldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:119
                        udata=varargin[4](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:120
                        xldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:121
                        xudata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:122
                    else:
                        if (strcmp(ifmt,'xyerr') or strcmp(ifmt,'boxxy')):
                            xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:124
                            ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:125
                            xldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:126
                            xudata=copy(xldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:127
                            ldata=varargin[4](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:128
                            udata=copy(ldata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:129
                        else:
                            xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:131
                            ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:132
                            xldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:133
                            xudata=varargin[4](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:134
                            ldata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:135
                            udata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:136
                else:
                    if 6 == (numel(varargin)):
                        if (strcmp(ifmt,'xyerr') or strcmp(ifmt,'boxxy')):
                            xdata=varargin[1](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:140
                            ydata=varargin[2](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:141
                            xldata=varargin[3](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:142
                            xudata=varargin[4](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:143
                            ldata=varargin[5](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:144
                            udata=varargin[6](arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:145
                        else:
                            error('errorbar: error plot with 6 columns only valid for xyerr and boxxy')
                    else:
                        error('errorbar: error plot requires 2, 3, 4, or 6 arguments')
        addproperty('xdata',hg,'data',ravel(xdata))
        addproperty('ydata',hg,'data',ravel(ydata))
        addproperty('ldata',hg,'data',ravel(ldata))
        addproperty('udata',hg,'data',ravel(udata))
        addproperty('xldata',hg,'data',ravel(xldata))
        addproperty('xudata',hg,'data',ravel(xudata))
        addproperty('format',hg,'string',ifmt)
        addproperty('color',hg,'linecolor',get(hl[2],'color'))
        addproperty('linestyle',hg,'linelinestyle',get(hl[2],'linestyle'))
        addproperty('linewidth',hg,'linelinewidth',get(hl[2],'linewidth'))
        addproperty('marker',hg,'linemarker',get(hl[2],'marker'))
        addproperty('markeredgecolor',hg,'linemarkerfacecolor',get(hl[2],'markeredgecolor'))
        addproperty('markerfacecolor',hg,'linemarkerfacecolor',get(hl[2],'markerfacecolor'))
        addproperty('markersize',hg,'linemarkersize',get(hl[2],'markersize'))
        addproperty('hittestarea',hg,'radio','on|{off}','off')
        fcn=cellarray([update_props,hl])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:175
        addlistener(hg,'color',fcn)
        addlistener(hg,'linestyle',fcn)
        addlistener(hg,'linewidth',fcn)
        addlistener(hg,'marker',fcn)
        addlistener(hg,'markeredgecolor',fcn)
        addlistener(hg,'markerfacecolor',fcn)
        addlistener(hg,'markersize',fcn)
        fcn=cellarray([update_data,hl])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:184
        addlistener(hg,'xdata',fcn)
        addlistener(hg,'ydata',fcn)
        addlistener(hg,'ldata',fcn)
        addlistener(hg,'udata',fcn)
        addlistener(hg,'xldata',fcn)
        addlistener(hg,'xudata',fcn)
        addlistener(hg,'format',fcn)
        hax=ancestor(hg,'axes')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:193
        addlistener(hax,'xscale',fcn)
        addlistener(hax,'yscale',fcn)
        update_data(hg,[],hl)
    
    ## Process legend key
    if (logical_not(isempty(fmt.key)) and nplots > 0):
        hlegend=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:203
        fkids=get(gcf(),'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:204
        for i in arange(1,numel(fkids)).reshape(-1):
            if (strcmp(get(fkids[i],'type'),'axes') and strcmp(get(fkids[i],'tag'),'legend')):
                udata=get(fkids[i],'userdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:208
                if (logical_not(isempty(intersect(udata.handle,gca())))):
                    hlegend=fkids[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:210
                    break
        if (isempty(hlegend)):
            hlgnd=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:217
            tlgnd=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:218
        else:
            hlgnd,tlgnd=__getlegenddata__(hlegend,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:220
        hlgnd[end() + 1]=hg
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:223
        tlgnd[end() + 1]=fmt.key
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:224
        legend(gca(),hlgnd,tlgnd)
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def errorbar_data(xdata=None,ydata=None,ldata=None,udata=None,xldata=None,xudata=None,ifmt=None,xscale=None,yscale=None,*args,**kwargs):
    varargin = errorbar_data.varargin
    nargin = errorbar_data.nargin

    if (strcmp(xscale,'linear')):
        dx=dot(0.01,(max(ravel(xdata)) - min(ravel(xdata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:235
        xlo=xdata - dx
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:236
        xhi=xdata + dx
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:237
    else:
        n=xdata > 0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:239
        if (logical_not(any(n))):
            n=xdata < 0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:241
        logdata=log(abs(xdata[n]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:243
        rx=exp(dot(0.01,(max(logdata) - min(logdata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:244
        xlo=xdata / rx
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:245
        xhi=dot(xdata,rx)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:246
    
    if (strcmp(yscale,'linear')):
        dy=dot(0.01,(max(ravel(ydata)) - min(ravel(ydata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:249
        ylo=ydata - dy
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:250
        yhi=ydata + dy
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:251
    else:
        n=ydata > 0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:253
        if (logical_not(any(n))):
            n=ydata < 0
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:255
        logdata=log(abs(ydata[n]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:257
        ry=exp(dot(0.01,(max(logdata) - min(logdata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:258
        ylo=ydata / ry
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:259
        yhi=dot(ydata,ry)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:260
    
    nans=NaN + ravel(xdata)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:262
    
    if (strcmp(ifmt,'yerr')):
        xdata=matlabarray(cat(xdata,xdata,nans,xlo,xhi,nans,xlo,xhi,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:264
        ydata=matlabarray(cat(ydata - ldata,ydata + udata,nans,ydata + udata,ydata + udata,nans,ydata - ldata,ydata - ldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:267
    else:
        if (strcmp(ifmt,'xerr')):
            xdata=matlabarray(cat(xdata - xldata,xdata + xudata,nans,xdata + xudata,xdata + xudata,nans,xdata - xldata,xdata - xldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:271
            ydata=matlabarray(cat(ydata,ydata,nans,ylo,yhi,nans,ylo,yhi,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:274
        else:
            if (strcmp(ifmt,'boxy')):
                dx=dot(0.01,(max(ravel(xdata)) - min(ravel(xdata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:278
                xdata=matlabarray(cat(xlo,xhi,xhi,xlo,xlo,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:279
                ydata=matlabarray(cat(ydata - ldata,ydata - ldata,ydata + udata,ydata + udata,ydata - ldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:280
            else:
                if (strcmp(ifmt,'box')):
                    dy=dot(0.01,(max(ravel(ydata)) - min(ravel(ydata))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:283
                    xdata=matlabarray(cat(xdata - xldata,xdata + xudata,xdata + xudata,xdata - xldata,xdata - xldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:284
                    ydata=matlabarray(cat(ylo,ylo,yhi,yhi,ylo,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:286
                else:
                    if (strcmp(ifmt,'boxxy')):
                        xdata=matlabarray(cat(xdata - xldata,xdata + xudata,xdata + xudata,xdata - xldata,xdata - xldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:288
                        ydata=matlabarray(cat(ydata - ldata,ydata - ldata,ydata + udata,ydata + udata,ydata - ldata,nans))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:290
                    else:
                        if (strcmp(ifmt,'xyerr')):
                            x1,y1=errorbar_data(xdata,ydata,ldata,udata,xldata,xudata,'xerr',xscale,yscale,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:293
                            x2,y2=errorbar_data(xdata,ydata,ldata,udata,xldata,xudata,'yerr',xscale,yscale,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:295
                            xdata=matlabarray(cat([x1],[x2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:297
                            ydata=matlabarray(cat([y1],[y2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:298
                            return xdata,ydata
                        else:
                            error('errorbar: valid error bar types are xerr, yerr, xyerr, box, boxy, boxxy')
    
    xdata=ravel(xdata.T)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:304
    ydata=ravel(ydata.T)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:305
    return xdata,ydata
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(hg=None,__=None,hl=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    set(hl,'color',get(hg,'color'),'linewidth',get(hg,'linewidth'))
    set(hl[2],'linestyle',get(hg,'linestyle'),'marker',get(hg,'marker'),'markeredgecolor',get(hg,'markeredgecolor'),'markerfacecolor',get(hg,'markerfacecolor'),'markersize',get(hg,'markersize'))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(hg=None,__=None,hl=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    if (strcmp(get(hg,'type'),'axes')):
        hax=copy(hg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:322
        hg=ancestor(hl[2],'hggroup')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:323
    else:
        hax=ancestor(hg,'axes')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:325
    
    xscale=get(hax,'xscale')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:327
    yscale=get(hax,'yscale')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:328
    xdata=get(hg,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:330
    ydata=get(hg,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:331
    ldata=get(hg,'ldata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:332
    udata=get(hg,'udata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:333
    xldata=get(hg,'xldata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:334
    xudata=get(hg,'xudata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:335
    ifmt=get(hg,'format')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:336
    set(hl[2],'xdata',xdata)
    set(hl[2],'ydata',ydata)
    errorbar_xdata,errorbar_ydata=errorbar_data(xdata,ydata,ldata,udata,xldata,xudata,ifmt,xscale,yscale,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__errplot__.m:341
    set(hl[1],'xdata',errorbar_xdata)
    set(hl[1],'ydata',errorbar_ydata)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __plt__ (@var{caller}, @var{h}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __plt__(caller=None,h=None,varargin=None,*args,**kwargs):
    varargin = __plt__.varargin
    nargin = __plt__.nargin

    
    nargs=nargin - 2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:29
    if (nargs > 0):
        k=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:33
        x_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:35
        y_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:36
        property_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:37
        properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:38
        hlegend=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:40
        fkids=get(gcf(),'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:41
        for i in arange(1,numel(fkids)).reshape(-1):
            if (strcmp(get(fkids[i],'type'),'axes') and strcmp(get(fkids[i],'tag'),'legend')):
                udata=get(fkids[i],'userdata')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:45
                if (logical_not(isempty(intersect(udata.handle,gca())))):
                    hlegend=fkids[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:47
                    break
        setlgnd=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:53
        if (isempty(hlegend)):
            hlgnd=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:55
            tlgnd=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:56
        else:
            hlgnd,tlgnd=__getlegenddata__(hlegend,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:58
        ## Gather arguments, decode format, gather plot strings, and plot lines.
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:63
        while (nargs > 0 or x_set):

            if (nargs == 0):
                ## Force the last plot when input variables run out.
                next_cell=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:69
                next_arg=cellarray([''])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:70
            else:
                next_cell=varargin[k]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:72
                next_arg=varargin[k]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:73
            if (isnumeric(next_arg) and ndims(next_arg) > 2 and any(size(next_arg) == 1)):
                next_arg=squeeze(next_arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:78
                if (logical_not(any(strcmp(caller,warned_callers))) and ndims(next_arg) < 3):
                    warning(cat('%s: N-d inputs have been squeezed to less than ','three dimensions'),caller)
                    warned_callers[end() + 1]=caller
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:82
            if (isnumeric(next_arg) and ndims(next_arg) > 2):
                error('%s: plot arrays must have less than 2 dimensions',caller)
            nargs
            if (ischar(next_arg) or iscellstr(next_arg)):
                if (x_set):
                    options,valid=__pltopt__(caller,next_arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:93
                    if (logical_not(valid)):
                        if (nargs == 0):
                            error('%s: properties must appear followed by a value',caller)
                        properties=matlabarray(cat(properties,cat(next_cell,varargin[k])))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:98
                        nargs
                        continue
                    else:
                        while (nargs > 0 and ischar(varargin[k])):

                            if (nargs < 2):
                                error('%s: properties must appear followed by a value',caller)
                            properties=matlabarray(cat(properties,varargin[k:k + 1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:107
                            k += 2
                            nargs -= 2

                    if (y_set):
                        tmp=__plt2__(h,x,y,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:113
                        hlgnd,tlgnd,setlgnd=__plt_key__(tmp,options,hlgnd,tlgnd,setlgnd,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:114
                        properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:116
                        retval=matlabarray(cat([retval],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:117
                    else:
                        tmp=__plt1__(h,x,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:119
                        hlgnd,tlgnd,setlgnd=__plt_key__(tmp,options,hlgnd,tlgnd,setlgnd,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:120
                        properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:122
                        retval=matlabarray(cat([retval],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:123
                    x_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:125
                    y_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:126
                else:
                    error('plot: no data to plot')
            else:
                if (x_set):
                    if (y_set):
                        options=__pltopt__(caller,cellarray(['']))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:132
                        tmp=__plt2__(h,x,y,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:133
                        hlgnd,tlgnd,setlgnd=__plt_key__(tmp,options,hlgnd,tlgnd,setlgnd,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:134
                        retval=matlabarray(cat([retval],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:136
                        x=copy(next_arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:137
                        y_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:138
                        properties=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:139
                    else:
                        y=copy(next_arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:141
                        y_set=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:142
                else:
                    x=copy(next_arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:145
                    x_set=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:146

        if (setlgnd):
            legend(gca(),hlgnd,tlgnd)
    else:
        error('__plt__: invalid number of arguments')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt_key__(h=None,options=None,hlgnd=None,tlgnd=None,setlgnd=None,*args,**kwargs):
    varargin = __plt_key__.varargin
    nargin = __plt_key__.nargin

    n=numel(h)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:161
    if (numel(options) == 1):
        options=repmat(ravel(options),n,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:163
    
    for i in arange(1,n).reshape(-1):
        key=options[i].key
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:167
        if (logical_not(isempty(key))):
            hlgnd=matlabarray(cat([ravel(hlgnd)],[h[i]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:169
            tlgnd=cellarray([tlgnd[:],key])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:170
            setlgnd=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:171
    
    return hlgnd,tlgnd,setlgnd
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt1__(h=None,x1=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt1__.varargin
    nargin = __plt1__.nargin

    if (nargin < 3 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:179
    
    if (logical_not(isstruct(options))):
        error('__plt1__: options must be a struct array')
    
    nr,nc=size(x1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:186
    if (nr == 1):
        x1=x1.T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:188
        nr,nc=deal(nc,nr,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:189
    
    if (iscomplex(x1)):
        x1_i=imag(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:192
        if (any((ravel(x1_i)))):
            x2=copy(x1_i)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:194
            x1=real(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:195
        else:
            x2=copy(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:197
            x1=(arange(1,nr)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:198
    else:
        x2=copy(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:201
        x1=(arange(1,nr)).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:202
    
    retval=__plt2__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:205
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2__(h=None,x1=None,x2=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2__.varargin
    nargin = __plt2__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:212
    
    if (logical_not(isstruct(options))):
        error('__plt2__: options must be a struct array')
    
    if (islogical(x1)):
        x1=int8(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:220
    else:
        if (iscomplex((x1))):
            x1=real(x1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:222
    
    if (islogical(x2)):
        x2=int8(x2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:226
    else:
        if (iscomplex(x2)):
            x2=real(x2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:228
    
    h_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:231
    if (isempty(x1) and isempty(x2)):
        retval=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:233
    else:
        if (isscalar(x1)):
            if (isscalar(x2)):
                retval=__plt2ss__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:236
            else:
                if (isvector(x2)):
                    retval=__plt2sv__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:238
                else:
                    error('__plt2__: invalid data for plotting')
        else:
            if (isvector(x1)):
                if (isscalar(x2)):
                    retval=__plt2vs__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:244
                else:
                    if (isvector(x2)):
                        retval=__plt2vv__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:246
                    else:
                        if (ismatrix(x2)):
                            retval=__plt2vm__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:248
                        else:
                            error('__plt2__: invalid data for plotting')
            else:
                if (ismatrix(x1)):
                    if (isvector(x2)):
                        retval=__plt2mv__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:254
                    else:
                        if (ismatrix(x2)):
                            retval=__plt2mm__(h,x1,x2,options,properties)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:256
                        else:
                            error('__plt2__: invalid data for plotting')
                else:
                    error('__plt2__: invalid data for plotting')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2mm__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2mm__.varargin
    nargin = __plt2mm__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:269
    
    x_nr,x_nc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:272
    y_nr,y_nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:273
    if (x_nr != y_nr and x_nc != y_nc):
        error('__plt2mm__: matrix dimensions must match')
    
    if (numel(options) == 1):
        options=repmat(ravel(options),x_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:280
    
    retval=zeros(x_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:282
    for i in arange(1,x_nc).reshape(-1):
        linestyle=options[i].linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:284
        marker=options[i].marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:285
        if (isempty(marker) and isempty(linestyle)):
            linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:287
        color=options[i].color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:289
        if (isempty(color)):
            color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:291
        retval[i]=line(x[:,i],y[:,i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:294
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2mv__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2mv__.varargin
    nargin = __plt2mv__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:304
    
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:307
    y_nr,y_nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:308
    x_nr,x_nc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:309
    if (x_nr == y_nr):
        ## Correctly oriented.  Do nothing.
        pass
    else:
        if (x_nc == y_nr):
            x=x.T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:314
            x_nr,x_nc=deal(x_nc,x_nr,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:315
        else:
            error('__plt2mv__: matrix dimensions must match')
    
    if (numel(options) == 1):
        options=repmat(ravel(options),x_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:321
    
    retval=zeros(x_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:323
    for i in arange(1,x_nc).reshape(-1):
        linestyle=options[i].linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:325
        marker=options[i].marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:326
        if (isempty(marker) and isempty(linestyle)):
            linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:328
        color=options[i].color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:330
        if (isempty(color)):
            color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:332
        retval[i]=line(x[:,i],y,'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:335
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2ss__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2ss__.varargin
    nargin = __plt2ss__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:345
    
    if (numel(options) > 1):
        options=options[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:349
    
    linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:352
    marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:353
    if (isempty(marker) and isempty(linestyle)):
        ## If unspecified, marker for a single point is always "."
        linestyle='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:356
        marker='.'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:357
    
    color=options.color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:359
    if (isempty(color)):
        color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:361
    
    retval=line(x,y,'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:364
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2sv__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2sv__.varargin
    nargin = __plt2sv__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:373
    
    len_=numel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:376
    if (numel(options) == 1):
        options=repmat(ravel(options),len_,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:378
    
    retval=zeros(len_,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:380
    for i in arange(1,len_).reshape(-1):
        linestyle=options[i].linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:382
        marker=options[i].marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:383
        if (isempty(marker) and isempty(linestyle)):
            ## If unspecified, marker for a point is always "."
            linestyle='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:386
            marker='.'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:387
        color=options[i].color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:389
        if (isempty(color)):
            color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:391
        retval[i]=line(x,y[i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:394
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2vm__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2vm__.varargin
    nargin = __plt2vm__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:404
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:407
    x_nr,x_nc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:408
    y_nr,y_nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:409
    if (x_nr == y_nr):
        ## Correctly oriented.  Do nothing.
        pass
    else:
        if (x_nr == y_nc):
            y=y.T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:414
            y_nr,y_nc=deal(y_nc,y_nr,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:415
        else:
            error('__plt2vm__: matrix dimensions must match')
    
    if (numel(options) == 1):
        options=repmat(ravel(options),y_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:421
    
    retval=zeros(y_nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:423
    for i in arange(1,y_nc).reshape(-1):
        linestyle=options[i].linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:425
        marker=options[i].marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:426
        if (isempty(marker) and isempty(linestyle)):
            linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:428
        color=options[i].color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:430
        if (isempty(color)):
            color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:432
        retval[i]=line(x,y[:,i],'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:435
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2vs__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2vs__.varargin
    nargin = __plt2vs__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:445
    
    len_=numel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:448
    if (numel(options) == 1):
        options=repmat(ravel(options),len_,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:450
    
    retval=zeros(len_,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:452
    for i in arange(1,len_).reshape(-1):
        linestyle=options[i].linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:454
        marker=options[i].marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:455
        if (isempty(marker) and isempty(linestyle)):
            ## If unspecified, marker for a point is always "."
            linestyle='-'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:458
            marker='.'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:459
        color=options[i].color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:461
        if (isempty(color)):
            color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:463
        retval[i]=line(x[i],y,'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:466
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def __plt2vv__(h=None,x=None,y=None,options=None,properties=cellarray([]),*args,**kwargs):
    varargin = __plt2vv__.varargin
    nargin = __plt2vv__.nargin

    if (nargin < 4 or isempty(options)):
        options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:476
    
    if (numel(options) > 1):
        options=options[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:480
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:483
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:484
    if (length(x) != length(y)):
        error('__plt2vv__: vector lengths must match')
    
    linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:490
    marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:491
    if (isempty(marker) and isempty(linestyle)):
        linestyle,marker=__next_line_style__(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:493
    
    color=options.color
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:495
    if (isempty(color)):
        color=__next_line_color__()
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:497
    
    retval=line(x,y,'color',color,'linestyle',linestyle,'marker',marker,properties[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__plt__.m:500
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{h}, @var{needusage}] =} __ezplot__ (@var{pltfunc}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    ## Overview: This function is the back-end for the 9 ez* plot functions.
##           As such, most of the function is actually dedicated to sorting
##           out the inputs and verifying that the particular ez* function
##           called was called correctly.  The actual plotting occurs near
##           the end in an unwind_protect block.
    
    
@function
def __ezplot__(pltfunc=None,varargin=None,*args,**kwargs):
    varargin = __ezplot__.varargin
    nargin = __ezplot__.nargin

    ezfunc=matlabarray(cat('ez',pltfunc))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:32
    hax,varargin,nargin=__plt_get_axis_arg__(ezfunc,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:34
    
    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:37
    needusage=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:38
    if (nargin < 1):
        needusage=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:40
        return h,needusage
    
    iscontour=strncmp(pltfunc,'contour',7)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:44
    
    isplot=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:47
    isplot3=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:48
    ispolar=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:49
    nargs=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:50
    if 'plot' == (pltfunc):
        ## defaults already set
        pass
    else:
        if 'plot3' == (pltfunc):
            isplot=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:56
            isplot3=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:57
        else:
            if 'polar' == (pltfunc):
                isplot=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:60
                ispolar=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:61
            else:
                ## contour, mesh, surf plots
                isplot=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:65
                nargs=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:66
    
    parametric=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:70
    fun=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:71
    if (ischar(fun)):
        if (exist(fun,'file') or exist(fun,'builtin')):
            fun=str2func(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:74
        else:
            fun=vectorize(inline(fun))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:76
    
    if (strcmp(typeinfo(fun),'inline function')):
        argids=argnames(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:81
        if (isplot and length(argids) == 2):
            nargs=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:83
        else:
            if (numel(argids) != nargs):
                error('%s: expecting a function of %d arguments',ezfunc,nargs)
        fun=vectorize(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:87
        fstr=formula(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:88
        if (isplot):
            xarg=argids[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:90
            if (nargs == 2):
                yarg=argids[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:92
            else:
                yarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:94
        else:
            if (isplot3):
                xarg='x'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:97
                yarg='y'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:98
            else:
                if (isplot or ispolar):
                    xarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:100
                    yarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:101
                else:
                    xarg=argids[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:103
                    yarg=argids[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:104
    else:
        if (isa(fun,'function_handle')):
            fstr=func2str(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:107
            idx=index(fstr,')')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:108
            if (idx != 0):
                args=regexp(fstr[3:(idx - 1)],'\\w+','match')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:110
                fstr=fstr[idx + 2:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:111
            else:
                args=cellarray(['x'])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:113
                try:
                    if (builtin('nargin',fun) == 2):
                        args[2]='y'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:116
                finally:
                    pass
            if (isplot and length(args) == 2):
                nargs=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:121
            else:
                if (numel(args) != nargs):
                    error('%s: expecting a function of %d arguments',ezfunc,nargs)
            if (isplot):
                xarg=args[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:126
                if (nargs == 2):
                    yarg=args[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:128
                else:
                    yarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:130
            else:
                if (isplot3):
                    xarg='x'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:133
                    yarg='y'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:134
                else:
                    if (ispolar):
                        xarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:136
                        yarg=''
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:137
                    else:
                        xarg=args[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:139
                        yarg=args[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:140
        else:
            error('%s: expecting string, inline function, or function handle',ezfunc)
    
    if (nargin > 2 or (nargin == 2 and isplot)):
        funx=copy(fun)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:147
        fstrx=copy(fstr)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:148
        funy=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:149
        if (ischar(funy) and logical_not(strcmp(funy,'circ')) and logical_not(strcmp(funy,'animate'))):
            parametric=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:151
            if (exist(funy,'file') or exist(funy,'builtin')):
                funy=inline(cat(funy,'(t)'))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:153
            else:
                funy=vectorize(inline(funy))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:155
            if (numel(argnames(funy)) != nargs):
                error('%s: expecting a function of %d arguments',ezfunc,nargs)
            fstry=formula(funy)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:160
        else:
            if (strcmp(typeinfo(funy),'inline function')):
                parametric=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:162
                if (numel(argnames(funy)) != nargs):
                    error('%s: expecting a function of %d arguments',ezfunc,nargs)
                funy=vectorize(funy)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:166
                fstry=formula(funy)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:167
            else:
                if (isa(funy,'function_handle')):
                    parametric=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:169
                    fstry=func2str(funy)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:170
                    idx=index(fstry,')')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:171
                    if (idx != 0):
                        args=regexp(fstry[3:(idx - 1)],'\\w+','match')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:173
                        fstry=fstry[idx + 2:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:174
                    else:
                        args=cellarray(['y'])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:176
                    if (numel(args) != nargs):
                        error('%s: expecting a function of %d arguments',ezfunc,nargs)
        if (logical_not(parametric) and isplot3):
            needusage=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:184
            return h,needusage
        else:
            if (parametric and isplot):
                if (nargs == 2):
                    error('%s: can not define a parametric function in this manner',ezfunc)
                else:
                    xarg='x'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:190
                    yarg='y'
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:191
            else:
                if (parametric):
                    funz=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:194
                    if (ischar(funz) and logical_not(strcmp(funz,'circ')) and logical_not(strcmp(funz,'animate'))):
                        if (exist(funz,'file') or exist(funz,'builtin')):
                            funz=inline(cat(funz,'(t)'))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:198
                        else:
                            funz=vectorize(inline(funz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:200
                        if (numel(argnames(funz)) > nargs):
                            error('%s: expecting a function of %d arguments',ezfunc,nargs)
                        fstrz=formula(funz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:205
                    else:
                        if (strcmp(typeinfo(funz),'inline function')):
                            if (numel(argnames(funz)) != nargs):
                                error('%s: expecting a function of %d arguments',ezfunc,nargs)
                            funz=vectorize(funz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:210
                            fstrz=formula(funz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:211
                        else:
                            if (isa(funz,'function_handle')):
                                fstrz=func2str(funz)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:213
                                idx=index(fstrz,')')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:214
                                if (idx != 0):
                                    args=regexp(fstrz[3:(idx - 1)],'\\w+','match')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:216
                                    fstrz=fstrz[idx + 2:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:217
                                else:
                                    args=cellarray(['z'])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:219
                                if (numel(args) != nargs):
                                    error('%s: expecting a function of %d arguments',ezfunc,nargs)
                            else:
                                error('%s: parametric plots expect 3 functions',ezfunc)
    
    if ((isplot and nargs != 2) or isplot3 or ispolar):
        n=500
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:231
    else:
        n=60
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:233
    
    domain=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:235
    circ=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:236
    animate=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:237
    if (parametric):
        if (isplot):
            iarg=3
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:240
        else:
            iarg=4
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:242
    else:
        iarg=2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:245
    
    while (iarg <= nargin):

        arg=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:248
        if (ischar(arg) and strcmp(arg,'circ')):
            circ=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:250
        else:
            if (ischar(arg) and strcmp(arg,'animate')):
                animate=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:252
            else:
                if (isscalar(arg)):
                    n=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:254
                else:
                    if (numel(arg) == 2):
                        domain=matlabarray(cat(arg[1],arg[2],arg[1],arg[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:256
                    else:
                        if (numel(arg) == 4):
                            domain=ravel(arg).T
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:258
                        else:
                            error('%s: expecting scalar, 2-, or 4-element vector',ezfunc)

    
    if (circ and (iscontour or isplot3 or isplot)):
        needusage=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:265
        return h,needusage
    else:
        if (circ and parametric):
            error('%s: can not have both circular domain and parametric function',ezfunc)
    
    if (animate and logical_not(isplot3)):
        error('%s: animate option only valid for ezplot3',ezfunc)
    
    if (parametric):
        ## Make the label strings pretty by removing extra spaces between base
    ## and exponent, the '.' in vectorized code, and the '*' for multiply.
        fstrx=regexprep(regexprep(regexprep(fstrx,'\\s*\\.?(?:\\^|\\*\\*)\\s*','^'),'\\.([/+-])','$1'),'\\s*\\.?\\*\\s*',' ')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:279
        fstry=regexprep(regexprep(regexprep(fstry,'\\s*\\.?(?:\\^|\\*\\*)\\s*','^'),'\\.([/+-])','$1'),'\\s*\\.?\\*\\s*',' ')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:281
        if (isplot):
            fstr=matlabarray(cat('x = ',fstrx,', y = ',fstry))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:284
        else:
            fstrz=regexprep(regexprep(regexprep(fstrz,'\\s*\\.?(?:\\^|\\*\\*)\\s*','^'),'\\.([/+-])','$1'),'\\s*\\.?\\*\\s*',' ')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:286
            fstr=matlabarray(cat('x = ',fstrx,',y = ',fstry,', z = ',fstrz))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:288
    else:
        fstr=regexprep(regexprep(regexprep(fstr,'\\s*\\.?(?:\\^|\\*\\*)\\s*','^'),'\\.([/+-])','$1'),'\\s*\\.?\\*\\s*',' ')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:291
        if (isplot and nargs == 2):
            fstr=matlabarray(cat(fstr,' = 0'))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:294
    
    if (isempty(domain)):
        auto_domain=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:299
        if (isplot3 or ispolar):
            domain=matlabarray(cat(0,dot(2,pi),0,dot(2,pi)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:301
        else:
            domain=matlabarray(cat(dot(- 2,pi),dot(2,pi),dot(- 2,pi),dot(2,pi)))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:303
    else:
        auto_domain=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:306
    
    auto_domain_done=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:309
    do
    domain_ok=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:311
    if ((isplot and nargs == 1) or isplot3 or ispolar):
        X=linspace(domain[1],domain[2],n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:314
    else:
        if (isplot and numel(domain) == 2):
            x=linspace(domain[1],domain[2],n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:316
            X,Y=meshgrid(x,x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:317
        else:
            if (circ):
                ## To plot on circular domain develop grid in polar coordinates
      ## and then switch these to Cartesian coordinates.
                cent=cat(domain[1] + domain[2],domain[3] + domain[4]) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:321
                rmax=sqrt((domain[2] - cent[1]) ** 2 + (domain[4] - cent[2]) ** 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:322
                r=linspace(0,rmax,n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:323
                t=linspace(0,dot(2,pi),n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:324
                T,R=meshgrid(t,r,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:325
                X=multiply(R,cos(T)) + cent[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:326
                Y=multiply(R,sin(T)) + cent[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:327
                domain=matlabarray(cat(- rmax + cent[1],+ rmax + cent[1],- rmax + cent[2],+ rmax + cent[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:328
            else:
                x=linspace(domain[1],domain[2],n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:330
                y=linspace(domain[3],domain[4],n)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:331
                X,Y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:332
    
    if (parametric):
        if (isplot):
            XX=feval(funx,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:337
            Z=feval(funy,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:338
            X=copy(XX)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:339
        else:
            if (isplot3):
                Z=feval(funz,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:341
                XX=feval(funx,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:342
                YY=feval(funy,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:343
                X=copy(XX)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:344
                Y=copy(YY)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:345
            else:
                Z=feval(funz,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:347
                XX=feval(funx,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:348
                YY=feval(funy,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:349
                X=copy(XX)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:350
                Y=copy(YY)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:351
                X=__eliminate_sing__(X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:354
                Y=__eliminate_sing__(Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:355
                Z=__eliminate_sing__(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:356
    else:
        if (isplot and nargs == 2):
            Z=feval(fun,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:360
            ## contour directly as it returns patch objects to allow colormaps
        ## to work with contours.  Therefore recreate the lines from the
        ## output for contourc, and store in cell arrays.
            c,__=contourc(X,Y,Z,cat(0,0),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:366
            i=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:368
            XX=YY=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:369
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:369
            while (i < length(c)):

                clev=c[1,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:371
                clen=c[2,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:372
                XX=matlabarray(cat(XX,cellarray([c[1,i + 1:i + clen]])))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:373
                YY=matlabarray(cat(YY,cellarray([c[2,i + 1:i + clen]])))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:374
                i += clen + 1

        else:
            if (ispolar):
                Z=feval(fun,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:379
            else:
                if (isplot):
                    Z=feval(fun,X)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:382
                    Z=__eliminate_sing__(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:384
                    domain=find_valid_domain(X,[],Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:385
                else:
                    if (iscontour):
                        Z=feval(fun,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:387
                        Z=__eliminate_sing__(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:388
                    else:
                        Z=feval(fun,X,Y)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:390
                        Z=__eliminate_sing__(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:391
                        if (circ):
                            ## Use domain calculated at the start.
            ## The X, Y grids are non-monotonic after conversion from polar
            ## coordinates and find_valid_domain fails.
                            pass
                        else:
                            if (auto_domain and logical_not(auto_domain_done)):
                                valid_domain=find_valid_domain(X,Y,Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:398
                                domain_ok=isequal(domain,valid_domain)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:399
                                domain=copy(valid_domain)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:400
                                auto_domain_done=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:401
                            else:
                                if (logical_not(auto_domain_done)):
                                    domain=find_valid_domain(X,Y,Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:404
    
    until(domain_ok)
    ## Now, actually call the correct plot function with valid data and domain.
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:413
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:415
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:418
        if (iscontour):
            __,h=feval(pltfunc,hax,X,Y,Z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:420
        else:
            if (isplot and nargs == 2):
                h=zeros(length(XX),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:422
                hold_state=get(hax,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:423
                for i in arange(1,length(XX)).reshape(-1):
                    h[i]=plot(hax,XX[i],YY[i])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:425
                    if (i == 1):
                        set(hax,'nextplot','add')
                set(hax,'nextplot',hold_state)
                axis(hax,domain)
            else:
                if (isplot or ispolar):
                    h=feval(pltfunc,hax,X,Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:433
                    if (isplot):
                        if (logical_not(parametric)):
                            axis(hax,domain)
                        else:
                            axis('equal')
                else:
                    if (isplot3):
                        if (animate):
                            ## draw animation, then replace with true plot3
                            comet3(hax,X,Y,Z,0.05)
                        h=feval(pltfunc,hax,X,Y,Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:446
                        set(hax,'box','off')
                        grid(hax,'on')
                        zlabel(hax,'z')
                    else:
                        h=feval(pltfunc,hax,X,Y,Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:451
                        if (logical_not(parametric)):
                            axis(hax,domain)
        xlabel(hax,xarg)
        ylabel(hax,yarg)
        title(hax,fstr)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return h,needusage
    
if __name__ == '__main__':
    pass
    
    ## Eliminate bad data (complex values, infinities, singularities)
    
@function
def __eliminate_sing__(x=None,*args,**kwargs):
    varargin = __eliminate_sing__.varargin
    nargin = __eliminate_sing__.nargin

    if (iscomplex(x)):
        x[imag(x) != 0]=NaN
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:471
    
    x[isinf(x)]=NaN
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:473
    
    threshold=dot(0.2,(max(ravel(x)) - min(ravel(x))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:475
    x[abs(del2(x)) > threshold]=NaN
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:476
    return x
    
if __name__ == '__main__':
    pass
    
    ## Find: 1) range of function where there are not NaN values,
##       2) function is changing (not just flat surface)
    
@function
def find_valid_domain(X=None,Y=None,Z=None,*args,**kwargs):
    varargin = find_valid_domain.varargin
    nargin = find_valid_domain.nargin

    if (isvector(Z)):
        ## 2-D data for isplot
        domain=matlabarray(cat(X[1],X[end()]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:485
        ## median-based approach.  The center 3/4 of the data is used to
    ## determine the range of the data.
    ## This seems to be vaguely what Matlab does, but can't be sure.
        XX=sort(Z[isfinite(Z)])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:491
        if (length(X) > 4):
            irlo=XX[fix(dot(1 / 8,length(XX)))]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:493
            irhi=XX[fix(dot(7 / 8,length(XX)))]
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:494
            d=irhi - irlo
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:495
            domain[3]=max(XX[1] - d / 8,irlo - d)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:496
            domain[4]=min(XX[end()] + d / 8,irhi + d)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:497
        else:
            domain[3:4]=cat(XX[1],XX[end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:499
        #{
    ## FIXME: Old algorithm for removing singularities
    ## Deprecated in 3.8.  Can be removed if no problems appear in ezplot.
        idx=arange(2,length(Z))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:505
        idx=find(logical_or((logical_and((Z[idx] > yrange(2) / 2),(Z[idx - 1] < yrange(1) / 2))),(logical_and((Z[idx] < yrange(1) / 2),(Z[idx - 1] > yrange(2) / 2)))))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:506
        Z[idx]=NaN
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:508
    else:
        ## 3-D data such as mesh, surf
        Zfinite=logical_not(isnan(Z))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:513
        Zrows=any(Zfinite,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:514
        rmin=find(Zrows,1,'first')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:515
        rmax=find(Zrows,1,'last')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:516
        Zcols=any(Zfinite,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:517
        cmin=find(Zcols,1,'first')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:518
        cmax=find(Zcols,1,'last')
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:519
        if (isempty(rmin)):
            rmin=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:523
            rmax=rows(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:523
        if (isempty(cmin)):
            cmin=1
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:526
            cmax=columns(Z)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:526
        if (logical_not(any(isnan(ravel(Z[cat(rmin,rmax),:])))) and logical_not(any(isnan(ravel(Z[:,cat(cmin,cmax)]))))):
            ## Exclude surfaces along borders which are flat (gradient =~ 0).
      ## Technically, this calculation might be better done with actual
      ## deltaX, deltaY values.  But, data is usually meshgridded
      ## (constant spacing) so working with deltaROW#, deltaCOL# is fine.
            Zx,Zy=gradient(Z[rmin:rmax,cmin:cmax],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:535
            Zgrad=sqrt(Zx ** 2 + Zy ** 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:536
            slope=((max(ravel(Z)) - min(ravel(Z))) / sqrt((rmax - rmin) ** 2 + (cmax - cmin) ** 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:537
            slope /= 125
            Zrows=any(Zgrad > slope,2)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:540
            rmin += find(Zrows,1,'first') - 1
            rmax += find(Zrows,1,'last') - rows(Zrows)
            Zcols=any(Zgrad > slope,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:543
            cmin += find(Zcols,1,'first') - 1
            cmax += find(Zcols,1,'last') - columns(Zcols)
        domain=matlabarray(cat(X[1,cmin],X[1,cmax],Y[rmin,1],Y[rmax,1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/private/__ezplot__.m:548
    
    return domain
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezcontour (@var{f})
## @deftypefnx {Function File} {} ezcontour (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezcontour (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezcontour (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezcontour (@dots{})
##
## Plot the contour lines of a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Example:
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezcontour (f, [-3, 3]);
## @end group
## @end example
##
## @seealso{contour, ezcontourf, ezplot, ezmeshc, ezsurfc}
## @end deftypefn
    
    
@function
def ezcontour(varargin=None,*args,**kwargs):
    varargin = ezcontour.varargin
    nargin = ezcontour.nargin

    htmp,needusage=__ezplot__('contour',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezcontour.m:57
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezcontour.m:64
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} semilogx (@var{y})
## @deftypefnx {Function File} {} semilogx (@var{x}, @var{y})
## @deftypefnx {Function File} {} semilogx (@var{x}, @var{y}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} semilogx (@var{x}, @var{y}, @var{fmt})
## @deftypefnx {Function File} {} semilogx (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} semilogx (@dots{})
## Produce a 2-D plot using a logarithmic scale for the x-axis.
##
## See the documentation of @code{plot} for a description of the
## arguments that @code{semilogx} will accept.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
## @seealso{plot, semilogy, loglog}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def semilogx(varargin=None,*args,**kwargs):
    varargin = semilogx.varargin
    nargin = semilogx.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('semilogx',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:42
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:48
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:50
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:53
        set(hax,'xscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'xminortick','on')
        htmp=__plt__('semilogx',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:60
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogx.m:69
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pcolor (@var{x}, @var{y}, @var{c})
## @deftypefnx {Function File} {} pcolor (@var{c})
## @deftypefnx {Function File} {} pcolor (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} pcolor (@dots{})
## Produce a 2-D density plot.
##
## A @code{pcolor} plot draws rectangles with colors from the matrix @var{c}
## over the two-dimensional region represented by the matrices @var{x} and
## @var{y}.  @var{x} and @var{y} are the coordinates of the mesh's vertices
## and are typically the output of @code{meshgrid}.  If @var{x} and @var{y} are
## vectors, then a typical vertex is (@var{x}(j), @var{y}(i), @var{c}(i,j)).
## Thus, columns of @var{c} correspond to different @var{x} values and rows
## of @var{c} correspond to different @var{y} values.
##
## The values in @var{c} are scaled to span the range of the current
## colormap.  Limits may be placed on the color axis by the command
## @code{caxis}, or by setting the @code{clim} property of the parent axis.
##
## The face color of each cell of the mesh is determined by interpolating
## the values of @var{c} for each of the cell's vertices; Contrast this with
## @code{imagesc} which renders one cell for each element of @var{c}.
##
## @code{shading} modifies an attribute determining the manner by which the
## face color of each cell is interpolated from the values of @var{c},
## and the visibility of the cells' edges.  By default the attribute is
## @qcode{"faceted"}, which renders a single color for each cell's face with
## the edge visible.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## @seealso{caxis, shading, meshgrid, contour, imagesc}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def pcolor(varargin=None,*args,**kwargs):
    varargin = pcolor.varargin
    nargin = pcolor.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('pcolor',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:61
    if (nargin == 1):
        c=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:64
        nr,nc=size(c,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:65
        x=arange(1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:66
        y=arange(1,nr)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:67
        z=zeros(nr,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:68
    else:
        if (nargin == 3):
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:70
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:71
            c=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:72
            z=zeros(size(c))
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:73
        else:
            print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:78
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:80
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:83
        htmp=surface(x,y,z,c)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:84
        set(htmp,'facecolor','flat')
        if (logical_not(ishold())):
            set(hax,'view',cat(0,90),'box','on')
            ##        When values are integers (such as from meshgrid), we want to
      ##        use tight limits for pcolor, mesh, surf, etc.  Situation is
      ##        complicated immensely by vector or matrix input and meshgrid()
      ##        or ndgrid() format.
            meshgrid_fmt=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:94
            if (isvector(x)):
                xrng=x[isfinite(x)]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:96
            else:
                xrng=x[1,isfinite(x[1,:])]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:98
                if (all(xrng == xrng[1])):
                    xrng=x[isfinite(x[:,1]),1]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:100
                    meshgrid_fmt=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:101
            if (isvector(y)):
                yrng=y[isfinite(y)]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:105
            else:
                if (meshgrid_fmt):
                    yrng=y[isfinite(y[:,1]),1]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:108
                else:
                    yrng=y[1,isfinite(y[1,:])]
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:110
            if (all(xrng == fix(xrng))):
                xmin=min(xrng)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:114
                xmax=max(xrng)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:115
                if (xmin < xmax):
                    xlim(cat(xmin,xmax))
            if (all(yrng == fix(yrng))):
                ymin=min(yrng)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:121
                ymax=max(yrng)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:122
                if (ymin < ymax):
                    ylim(cat(ymin,ymax))
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/pcolor.m:136
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fill (@var{x}, @var{y}, @var{c})
## @deftypefnx {Function File} {} fill (@var{x1}, @var{y1}, @var{c1}, @var{x2}, @var{y2}, @var{c2})
## @deftypefnx {Function File} {} fill (@dots{}, @var{prop}, @var{val})
## @deftypefnx {Function File} {} fill (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} fill (@dots{})
## Create one or more filled 2-D polygons.
##
## The inputs @var{x} and @var{y} are the coordinates of the polygon vertices.
## If the inputs are matrices then the rows represent different vertices and
## each column produces a different polygon.  @code{fill} will close any open
## polygons before plotting.
##
## The input @var{c} determines the color of the polygon.  The simplest form
## is a single color specification such as a @code{plot} format or an
## RGB-triple.  In this case the polygon(s) will have one unique color.  If
## @var{c} is a vector or matrix then the color data is first scaled using
## @code{caxis} and then indexed into the current colormap.  A row vector will
## color each polygon (a column from matrices @var{x} and @var{y}) with a
## single computed color.  A matrix @var{c} of the same size as @var{x} and
## @var{y} will compute the color of each vertex and then interpolate the face
## color between the vertices.
##
## Multiple property/value pairs for the underlying patch object may be
## specified, but they must appear in pairs.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to
## the created patch objects.
##
## Example: red square
##
## @example
## @group
## vertices = [0 0
##             1 0
##             1 1
##             0 1];
## fill (vertices(:,1), vertices(:,2), "r");
## axis ([-0.5 1.5, -0.5 1.5])
## axis equal
## @end group
## @end example
##
## @seealso{patch, caxis, colormap}
## @end deftypefn
    
    
@function
def fill(varargin=None,*args,**kwargs):
    varargin = fill.varargin
    nargin = fill.nargin

    hax,varargin=__plt_get_axis_arg__('fill',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:70
    hlist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:72
    iargs=__find_patches__(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:73
    opts=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:75
    if (numel(varargin) > iargs[end()] + 2):
        opts=varargin[iargs[end()] + 3:end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:77
    
    if (logical_not(all(cellfun(lambda x=None: iscolorspec(x),varargin[iargs + 2])))):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:84
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:86
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:89
        old_nxtplt=get(hax,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:90
        try:
            set(hax,'nextplot','add')
            for i in arange(1,length(iargs)).reshape(-1):
                x=varargin[iargs[i]]
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:95
                y=varargin[iargs[i] + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:96
                cdata=varargin[iargs[i] + 2]
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:97
                if (logical_not(size_equal(x,y))):
                    if (iscolumn(y) and rows(y) == rows(x)):
                        y=repmat(y,cat(1,columns(x)))
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:101
                    else:
                        if (iscolumn(x) and rows(x) == rows(y)):
                            x=repmat(x,cat(1,columns(y)))
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:103
                        else:
                            error('fill: X annd Y must have same number of rows')
                ## For Matlab compatibility, replicate cdata to match size of data
                if (iscolumn(cdata) and logical_not(ischar(cdata))):
                    sz=size(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:110
                    if (all(sz > 1)):
                        cdata=repmat(cdata,cat(1,sz[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:112
                htmp,fail=__patch__(hax,x,y,cdata,opts[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:116
                if (fail):
                    print_usage()
                hlist[end() + 1,1]=htmp
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:121
        finally:
            if (strcmp(old_nxtplt,'replace')):
                set(hax,'nextplot',old_nxtplt)
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(hlist)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:137
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __find_patches__(varargin=None,*args,**kwargs):
    varargin = __find_patches__.varargin
    nargin = __find_patches__.nargin

    iargs=arange(1,nargin,3)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:143
    optidx=find(logical_not(cellfun(isnumeric,varargin[iargs])),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:144
    iargs[optidx:end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:145
    return iargs
    
if __name__ == '__main__':
    pass
    
    
@function
def iscolorspec(arg=None,*args,**kwargs):
    varargin = iscolorspec.varargin
    nargin = iscolorspec.nargin

    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:149
    if (ischar(arg)):
        if (any(strcmpi(arg,colors))):
            retval=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:155
    else:
        if (isnumeric(arg)):
            ## Assume any numeric argument is correctly formatted cdata.
    ## Let patch worry about the multple different input formats.
            retval=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/fill.m:160
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} semilogy (@var{y})
## @deftypefnx {Function File} {} semilogy (@var{x}, @var{y})
## @deftypefnx {Function File} {} semilogy (@var{x}, @var{y}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} semilogy (@var{x}, @var{y}, @var{fmt})
## @deftypefnx {Function File} {} semilogy (@var{h}, @dots{})
## @deftypefnx {Function File} {@var{h} =} semilogy (@dots{})
## Produce a 2-D plot using a logarithmic scale for the y-axis.
##
## See the documentation of @code{plot} for a description of the
## arguments that @code{semilogy} will accept.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
## @seealso{plot, semilogx, loglog}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def semilogy(varargin=None,*args,**kwargs):
    varargin = semilogy.varargin
    nargin = semilogy.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('semilogy',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:42
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:48
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:50
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:53
        set(hax,'yscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'yminortick','on')
        htmp=__plt__('semilogy',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:60
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogy.m:69
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2016 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{fv}] =} isosurface (@var{val}, @var{iso})
## @deftypefnx {Function File} {[@var{fv}] =} isosurface (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso})
## @deftypefnx {Function File} {[@var{fv}] =} isosurface (@dots{}, "noshare", "verbose")
## @deftypefnx {Function File} {[@var{fvc}] =} isosurface (@dots{}, @var{col})
## @deftypefnx {Function File} {[@var{f}, @var{v}] =} isosurface (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso})
## @deftypefnx {Function File} {[@var{f}, @var{v}, @var{c}] =} isosurface (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso}, @var{col})
## @deftypefnx {Function File} {} isosurface (@var{x}, @var{y}, @var{z}, @var{val}, @var{iso}, @var{col}, @var{opt})
##
## Calculate isosurface of 3-D data.
##
## If called with one output argument and the first input argument
## @var{val} is a three-dimensional array that contains the data of an
## isosurface geometry and the second input argument @var{iso} keeps the
## isovalue as a scalar value then return a structure array @var{fv}
## that contains the fields @var{Faces} and @var{Vertices} at computed
## points @command{[x, y, z] = meshgrid (1:l, 1:m, 1:n)}.  The output
## argument @var{fv} can directly be taken as an input argument for the
## @command{patch} function.
##
## If called with further input arguments @var{x}, @var{y} and @var{z}
## which are three--dimensional arrays with the same size than @var{val}
## then the volume data is taken at those given points.
##
## The string input argument @qcode{"noshare"} is only for compatibility and
## has no effect.  If given the string input argument
## @qcode{"verbose"} then print messages to the command line interface about the
## current progress.
##
## If called with the input argument @var{col} which is a
## three-dimensional array of the same size than @var{val} then take
## those values for the interpolation of coloring the isosurface
## geometry.  Add the field @var{FaceVertexCData} to the structure
## array @var{fv}.
##
## If called with two or three output arguments then return the
## information about the faces @var{f}, vertices @var{v} and color data
## @var{c} as separate arrays instead of a single structure array.
##
## If called with no output argument then directly process the
## isosurface geometry with the @command{patch} command.
##
## For example,
##
## @example
## @group
## [x, y, z] = meshgrid (1:5, 1:5, 1:5);
## val = rand (5, 5, 5);
## isosurface (x, y, z, val, .5);
## @end group
## @end example
##
## @noindent
## will directly draw a random isosurface geometry in a graphics window.
## Another example for an isosurface geometry with different additional
## coloring
## @c Set example in small font to prevent overfull line
##
## @smallexample
## N = 15;    # Increase number of vertices in each direction
## iso = .4;  # Change isovalue to .1 to display a sphere
## lin = linspace (0, 2, N);
## [x, y, z] = meshgrid (lin, lin, lin);
## c = abs ((x-.5).^2 + (y-.5).^2 + (z-.5).^2);
## figure (); # Open another figure window
##
## subplot (2,2,1); view (-38, 20);
## [f, v] = isosurface (x, y, z, c, iso);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "none");
## set (gca, "PlotBoxAspectRatioMode", "manual", ...
##           "PlotBoxAspectRatio", [1 1 1]);
## # set (p, "FaceColor", "green", "FaceLighting", "phong");
## # light ("Position", [1 1 5]); # Available with the JHandles package
##
## subplot (2,2,2); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "EdgeColor", "blue");
## set (gca, "PlotBoxAspectRatioMode", "manual", ...
##           "PlotBoxAspectRatio", [1 1 1]);
## # set (p, "FaceColor", "none", "FaceLighting", "phong");
## # light ("Position", [1 1 5]);
##
## subplot (2,2,3); view (-38, 20);
## [f, v, c] = isosurface (x, y, z, c, iso, y);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", c, ...
##            "FaceColor", "interp", "EdgeColor", "none");
## set (gca, "PlotBoxAspectRatioMode", "manual", ...
##           "PlotBoxAspectRatio", [1 1 1]);
## # set (p, "FaceLighting", "phong");
## # light ("Position", [1 1 5]);
##
## subplot (2,2,4); view (-38, 20);
## p = patch ("Faces", f, "Vertices", v, "FaceVertexCData", c, ...
##            "FaceColor", "interp", "EdgeColor", "blue");
## set (gca, "PlotBoxAspectRatioMode", "manual", ...
##           "PlotBoxAspectRatio", [1 1 1]);
## # set (p, "FaceLighting", "phong");
## # light ("Position", [1 1 5]);
## @end smallexample
##
## @seealso{isonormals, isocolors}
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def isosurface(varargin=None,*args,**kwargs):
    varargin = isosurface.varargin
    nargin = isosurface.nargin

    if (nargin < 2 or nargin > 8 or nargout > 3):
        print_usage()
    
    calc_colors=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:129
    f=v=c=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:130
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:130
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:130
    verbose=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:131
    noshare=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:132
    if (nargin >= 5):
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:134
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:135
        z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:136
        val=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:137
        iso=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:138
        if (nargin >= 6 and isnumeric(varargin[6])):
            colors=varargin[6]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:140
            calc_colors=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:141
    else:
        val=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:144
        n2,n1,n3=size(val,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:145
        x,y,z=meshgrid(arange(1,n1),arange(1,n2),arange(1,n3),nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:146
        iso=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:147
        if (nargin >= 3 and isnumeric(varargin[3])):
            colors=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:149
            calc_colors=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:150
    
    if (calc_colors):
        if (nargout == 2):
            warning('isosurface: colors will be calculated, but no output argument to receive it.')
        fvc.faces,fvc.vertices,fvc.facevertexcdata=__marching_cube__(x,y,z,val,iso,colors,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:157
    else:
        fvc.faces,fvc.vertices=__marching_cube__(x,y,z,val,iso,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:160
    
    if (isempty(fvc.vertices) or isempty(fvc.faces)):
        warning('isosurface: triangulation is empty')
    
    if 0 == (nargout):
        ## plot the calculated surface
        hax=newplot()
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:170
        if (calc_colors):
            pa=patch('Faces',fvc.faces,'Vertices',fvc.vertices,'FaceVertexCData',fvc.facevertexcdata,'FaceColor','flat','EdgeColor','none')
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:172
        else:
            pa=patch('Faces',fvc.faces,'Vertices',fvc.vertices,'FaceColor','g','EdgeColor','k')
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:176
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30),'box','off')
    else:
        if 1 == (nargout):
            varargout=cellarray([fvc])
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:183
        else:
            if 2 == (nargout):
                varargout=cellarray([fvc.faces,fvc.vertices])
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:185
            else:
                if 3 == (nargout):
                    varargout=cellarray([fvc.faces,fvc.vertices,fvc.facevertexcdata])
# /home/lei/octave-4.0.2/scripts/plot/draw/isosurface.m:187
                else:
                    print_usage()
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} barh (@var{y})
## @deftypefnx {Function File} {} barh (@var{x}, @var{y})
## @deftypefnx {Function File} {} barh (@dots{}, @var{w})
## @deftypefnx {Function File} {} barh (@dots{}, @var{style})
## @deftypefnx {Function File} {} barh (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} barh (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} barh (@dots{}, @var{prop}, @var{val}, @dots{})
## Produce a horizontal bar graph from two vectors of X-Y data.
##
## If only one argument is given, it is taken as a vector of Y values
## and the X coordinates are the range @code{1:numel (@var{y})}.
##
## The optional input @var{w} controls the width of the bars.  A value of
## 1.0 will cause each bar to exactly touch any adjacent bars.
## The default width is 0.8.
##
## If @var{y} is a matrix, then each column of @var{y} is taken to be a
## separate bar graph plotted on the same graph.  By default the columns
## are plotted side-by-side.  This behavior can be changed by the @var{style}
## argument which can take the following values:
##
## @table @asis
## @item @qcode{"grouped"} (default)
## Side-by-side bars with a gap between bars and centered over the Y-coordinate.
##
## @item  @qcode{"stacked"}
## Bars are stacked so that each Y value has a single bar composed of
## multiple segments.
##
## @item @qcode{"hist"}
## Side-by-side bars with no gap between bars and centered over the
## Y-coordinate.
##
## @item @qcode{"histc"}
## Side-by-side bars with no gap between bars and left-aligned to the
## Y-coordinate.
## @end table
##
## Optional property/value pairs are passed directly to the underlying patch
## objects.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## bar series hggroup.  For a description of the use of the
## bar series, @pxref{XREFbar,,bar}.
## @seealso{bar, hist, pie, plot, patch}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def barh(varargin=None,*args,**kwargs):
    varargin = barh.varargin
    nargin = barh.nargin

    varargout=cell(nargout,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/barh.m:73
    varargout[:]=__bar__(false,'barh',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/barh.m:74
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} plotyy (@var{x1}, @var{y1}, @var{x2}, @var{y2})
## @deftypefnx {Function File} {} plotyy (@dots{}, @var{fun})
## @deftypefnx {Function File} {} plotyy (@dots{}, @var{fun1}, @var{fun2})
## @deftypefnx {Function File} {} plotyy (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{ax}, @var{h1}, @var{h2}] =} plotyy (@dots{})
## Plot two sets of data with independent y-axes and a common x-axis.
##
## The arguments @var{x1} and @var{y1} define the arguments for the first plot
## and @var{x1} and @var{y2} for the second.
##
## By default the arguments are evaluated with
## @code{feval (@@plot, @var{x}, @var{y})}.  However the type of plot can be
## modified with the @var{fun} argument, in which case the plots are
## generated by @code{feval (@var{fun}, @var{x}, @var{y})}.  @var{fun} can be
## a function handle, an inline function, or a string of a function name.
##
## The function to use for each of the plots can be independently defined
## with @var{fun1} and @var{fun2}.
##
## If the first argument @var{hax} is an axes handle, then it defines
## the principal axis in which to plot the @var{x1} and @var{y1} data.
##
## The return value @var{ax} is a vector with the axis handles of the two
## y-axes.  @var{h1} and @var{h2} are handles to the objects generated by the
## plot commands.
##
## @example
## @group
## x = 0:0.1:2*pi;
## y1 = sin (x);
## y2 = exp (x - 1);
## ax = plotyy (x, y1, x - 1, y2, @@plot, @@semilogy);
## xlabel ("X");
## ylabel (ax(1), "Axis 1");
## ylabel (ax(2), "Axis 2");
## @end group
## @end example
## @seealso{plot}
## @end deftypefn
    
    
@function
def plotyy(varargin=None,*args,**kwargs):
    varargin = plotyy.varargin
    nargin = plotyy.nargin

    hax,varargin=__plt_get_axis_arg__('plotyy',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:62
    nargin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:64
    if (nargin < 4 or nargin > 6):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:69
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:71
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:74
        ##        'cla reset' needs to delete user properties like __plotyy_axes__.
        if (isprop(hax,'__plotyy_axes__') and isaxes(get(hax,'__plotyy_axes__')) == cat(true,true)):
            hax=get(hax,'__plotyy_axes__')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:80
        else:
            hax[2]=axes('nextplot',get(hax[1],'nextplot'))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:82
        axtmp,h1tmp,h2tmp=__plotyy__(hax,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:85
        set(gcf,'currentaxes',hax[1])
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        ax=copy(axtmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:96
        h1=copy(h1tmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:97
        h2=copy(h2tmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:98
    
    return ax,h1,h2
    
if __name__ == '__main__':
    pass
    
    
@function
def __plotyy__(ax=None,x1=None,y1=None,x2=None,y2=None,fun1=plot,fun2=None,*args,**kwargs):
    varargin = __plotyy__.varargin
    nargin = __plotyy__.nargin

    if (nargin < 7):
        fun2=copy(fun1)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:106
    
    xlim=matlabarray(cat(min(cat([ravel(x1)],[ravel(x2)])),max(cat([ravel(x1)],[ravel(x2)]))))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:109
    axes(ax[1])
    h1=feval(fun1,x1,y1)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:113
    set(ax[1],'color','none','ycolor',getcolor(h1[1]),'xlim',xlim)
    set(gcf(),'nextplot','add')
    axes(ax[2])
    colors=get(ax[1],'colororder')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:121
    set(ax[2],'colororder',cat([colors[2:end(),:]],[colors[1,:]]))
    if (strcmp(get(ax[1],'autopos_tag'),'subplot')):
        set(ax[2],'autopos_tag','subplot')
    else:
        set(ax,'activepositionproperty','position')
    
    ## Don't replace axis which has colororder property already modified
    if (strcmp(get(ax[1],'nextplot'),'replace')):
        set(ax[2],'nextplot','replacechildren')
    
    h2=feval(fun2,ax[2],x2,y2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:134
    set(ax[2],'yaxislocation','right','color','none','ycolor',getcolor(h2[1]),'box','off','xlim',xlim)
    if (strcmp(get(ax[1],'activepositionproperty'),'position')):
        set(ax[2],'position',get(ax[1],'position'))
    else:
        set(ax[2],cellarray(['outerposition','looseinset']),get(ax[1],cellarray(['outerposition','looseinset'])))
    
    ## Restore nextplot value by copying value from axis #1
    set(ax[2],'nextplot',get(ax[1],'nextplot'))
    
    ## also remove the other axis
    t1=text(0,0,'','parent',ax[1],'tag','plotyy','visible','off','handlevisibility','off','xliminclude','off','yliminclude','off')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:151
    t2=text(0,0,'','parent',ax[2],'tag','plotyy','visible','off','handlevisibility','off','xliminclude','off','yliminclude','off')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:154
    set(t1,'deletefcn',cellarray([deleteplotyy,ax[2],t2]))
    set(t2,'deletefcn',cellarray([deleteplotyy,ax[1],t1]))
    
    addlistener(ax[1],'position',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'position',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'outerposition',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'outerposition',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'looseinset',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'looseinset',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'view',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'view',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'plotboxaspectratio',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'plotboxaspectratio',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'plotboxaspectratiomode',cellarray([update_position,ax[2]]))
    addlistener(ax[2],'plotboxaspectratiomode',cellarray([update_position,ax[1]]))
    addlistener(ax[1],'nextplot',cellarray([update_nextplot,ax[2]]))
    addlistener(ax[2],'nextplot',cellarray([update_nextplot,ax[1]]))
    
    if (ishandle(ax[1]) and logical_not(isprop(ax[1],'__plotyy_axes__'))):
        addproperty('__plotyy_axes__',ax[1],'data')
        set(ax[1],'__plotyy_axes__',ax)
    else:
        if (ishandle(ax[1])):
            set(ax[1],'__plotyy_axes__',ax)
        else:
            error('plotyy.m: This shouldn\'t happen. File a bug report.')
    
    if (ishandle(ax[2]) and logical_not(isprop(ax[2],'__plotyy_axes__'))):
        addproperty('__plotyy_axes__',ax[2],'data')
        set(ax[2],'__plotyy_axes__',ax)
    else:
        if (ishandle(ax[2])):
            set(ax[2],'__plotyy_axes__',ax)
        else:
            error('plotyy.m: This shouldn\'t happen. File a bug report.')
    
    return ax,h1,h2
    
if __name__ == '__main__':
    pass
    
    
@function
def deleteplotyy(h=None,__=None,ax2=None,t2=None,*args,**kwargs):
    varargin = deleteplotyy.varargin
    nargin = deleteplotyy.nargin

    if (isaxes(ax2) and (isempty(gcbf()) or strcmp(get(gcbf(),'beingdeleted'),'off')) and strcmp(get(ax2,'beingdeleted'),'off')):
        set(t2,'deletefcn',[])
        delete(ax2)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_nextplot(h=None,__=None,ax2=None,*args,**kwargs):
    varargin = update_nextplot.varargin
    nargin = update_nextplot.nargin

    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:209
            set(ax2,'nextplot',get(h,'nextplot'))
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:212
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_position(h=None,__=None,ax2=None,*args,**kwargs):
    varargin = update_position.varargin
    nargin = update_position.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:223
            view=get(h,'view')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:224
            oldview=get(ax2,'view')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:225
            plotboxaspectratio=get(h,'plotboxaspectratio')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:226
            oldplotboxaspectratio=get(ax2,'plotboxaspectratio')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:227
            plotboxaspectratiomode=get(h,'plotboxaspectratiomode')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:228
            oldplotboxaspectratiomode=get(ax2,'plotboxaspectratiomode')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:229
            if (strcmp(get(h,'activepositionproperty'),'position')):
                position=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:232
                oldposition=get(ax2,'position')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:233
                if (logical_not((isequal(position,oldposition) and isequal(view,oldview)))):
                    set(ax2,'position',position,'view',view)
            else:
                outerposition=get(h,'outerposition')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:238
                oldouterposition=get(ax2,'outerposition')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:239
                if (logical_not((isequal(outerposition,oldouterposition) and isequal(view,oldview)))):
                    set(ax2,'outerposition',outerposition,'view',view)
            if (logical_not((isequal(plotboxaspectratio,oldplotboxaspectratio) and isequal(plotboxaspectratiomode,oldplotboxaspectratiomode)))):
                set(ax2,'plotboxaspectratio',plotboxaspectratio,'plotboxaspectratiomode',plotboxaspectratiomode)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:252
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def getcolor(ax=None,*args,**kwargs):
    varargin = getcolor.varargin
    nargin = getcolor.nargin

    obj=get(ax)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:258
    if (isfield(obj,'color')):
        color=obj.color
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:260
    else:
        if (isfield(obj,'facecolor') and logical_not(ischar(obj.facecolor))):
            color=obj.facecolor
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:262
        else:
            if (isfield(obj,'edgecolor') and logical_not(ischar(obj.edgecolor))):
                color=obj.edgecolor
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:264
            else:
                color=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotyy.m:266
    
    return color
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2003-2015 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{c}, @var{lev}] =} contourc (@var{z})
## @deftypefnx {Function File} {[@var{c}, @var{lev}] =} contourc (@var{z}, @var{vn})
## @deftypefnx {Function File} {[@var{c}, @var{lev}] =} contourc (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {[@var{c}, @var{lev}] =} contourc (@var{x}, @var{y}, @var{z}, @var{vn})
## Compute contour lines (isolines of constant Z value).
##
## The matrix @var{z} contains height values above the rectangular grid
## determined by @var{x} and @var{y}.  If only a single input @var{z} is
## provided then @var{x} is taken to be @code{1:rows (@var{z})} and @var{y} is
## taken to be @code{1:columns (@var{z})}.
##
## The optional input @var{vn} is either a scalar denoting the number of
## contour lines to compute or a vector containing the Z values where lines
## will be computed.  When @var{vn} is a vector the number of contour lines
## is @code{numel (@var{vn})}.  However, to compute a single contour line
## at a given value use @code{@var{vn} = [val, val]}.  If @var{vn} is omitted
## it defaults to 10.
##
## The return value @var{c} is a 2x@var{n} matrix containing the
## contour lines in the following format
##
## @example
## @group
## @var{c} = [lev1, x1, x2, @dots{}, levn, x1, x2, ...
##      len1, y1, y2, @dots{}, lenn, y1, y2, @dots{}]
## @end group
## @end example
##
## @noindent
## in which contour line @var{n} has a level (height) of @var{levn} and
## length of @var{lenn}.
##
## The optional return value @var{lev} is a vector with the Z values of
## the contour levels.
##
## Example:
##
## @example
## @group
## x = 0:2;
## y = x;
## z = x' * y;
## contourc (x, y, z, 2:3)
##    @result{}   2.0000   2.0000   1.0000   3.0000   1.5000   2.0000
##         2.0000   1.0000   2.0000   2.0000   2.0000   1.5000
## @end group
## @end example
## @seealso{contour, contourf, contour3, clabel}
## @end deftypefn
    
    ## Author: Shai Ayal <shaiay@users.sourceforge.net>
    
    
@function
def contourc(varargin=None,*args,**kwargs):
    varargin = contourc.varargin
    nargin = contourc.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (nargin == 1):
        z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:79
        x=arange(1,columns(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:80
        y=arange(1,rows(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:81
        vn=10
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:82
    else:
        if (nargin == 2):
            z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:84
            x=arange(1,columns(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:85
            y=arange(1,rows(z))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:86
            vn=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:87
        else:
            if (nargin == 3):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:89
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:90
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:91
                vn=10
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:92
            else:
                if (nargin == 4):
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:94
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:95
                    z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:96
                    vn=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:97
    
    if (logical_not(ismatrix(z)) or logical_not(ismatrix(x)) or logical_not(ismatrix(y))):
        error('contourc: X, Y, and Z must be matrices')
    
    if (isscalar(vn)):
        vv=linspace(min(ravel(z)),max(ravel(z)),vn + 2)(arange(2,end() - 1))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:105
    else:
        vv=unique(sort(vn))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:107
    
    if (isvector(x) and isvector(y)):
        cdat=__contourc__(ravel(x).T,ravel(y).T,z,vv)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:111
    else:
        if (logical_not(any(ravel(bsxfun(minus,x,x[1,:])))) and logical_not(any(ravel(bsxfun(minus,y,y[:,1]))))):
            ## x,y are uniform grid (such as from meshgrid)
            cdat=__contourc__(x[1,:],y[:,1].T,z,vv)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:115
        else:
            ## Data is sampled over non-uniform mesh.
    ## Algorithm calculates contours for uniform grid
    ## and then interpolates values back to the non-uniform mesh.
            ## Uniform grid for __contourc__.
            nr,nc=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:122
            ii=arange(1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:123
            jj=arange(1,nr)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:124
            cdat=__contourc__(ii,jj,z,vv)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:126
            ## back to the original grid (x,y)
            i=1
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:130
            while (i < columns(cdat)):

                clen=cdat[2,i]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:133
                idx=i + (arange(1,clen))
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:134
                ci=cdat[1,idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:136
                cj=cdat[2,idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:137
                ## can fall out of the range of ii and jj and
      ## interp2 would return NA for those values.
      ## The permitted range is enforced here:
                ci=max(ci,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:144
                ci=min(ci,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:144
                cj=max(cj,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:145
                cj=min(cj,nr)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:145
                cdat[1,idx]=interp2(ii,jj,x,ci,cj)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:147
                cdat[2,idx]=interp2(ii,jj,y,ci,cj)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:148
                i += clen + 1

    
    if (nargout > 0):
        c=copy(cdat)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:155
        lev=copy(vv)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourc.m:156
    
    return c,lev
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} feather (@var{u}, @var{v})
## @deftypefnx {Function File} {} feather (@var{z})
## @deftypefnx {Function File} {} feather (@dots{}, @var{style})
## @deftypefnx {Function File} {} feather (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} feather (@dots{})
##
## Plot the @code{(@var{u}, @var{v})} components of a vector field emanating
## from equidistant points on the x-axis.
##
## If a single complex argument @var{z} is given, then
## @code{@var{u} = real (@var{z})} and @code{@var{v} = imag (@var{z})}.
##
## The style to use for the plot can be defined with a line style @var{style}
## of the same format as the @code{plot} command.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to the
## line objects representing the drawn vectors.
##
## @example
## @group
## phi = [0 : 15 : 360] * pi/180;
## feather (sin (phi), cos (phi));
## @end group
## @end example
##
## @seealso{plot, quiver, compass}
## @end deftypefn
    
    
@function
def feather(varargin=None,*args,**kwargs):
    varargin = feather.varargin
    nargin = feather.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('feather',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:53
    if (nargin == 0 or nargin > 3):
        print_usage()
    
    if (nargin == 1 or (nargin == 2 and logical_not(isnumeric(varargin[2])))):
        z=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:60
        u=real(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:61
        v=imag(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:62
        have_line_spec=(nargin == 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:63
    else:
        if (nargin >= 2 and isnumeric(varargin[2])):
            ioff=3
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:65
            u=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:66
            v=ravel(varargin[2]).T
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:67
            have_line_spec=(nargin == 3)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:68
        else:
            print_usage()
    
    arrowsize=0.2
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:73
    line_spec='-b'
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:74
    if (have_line_spec):
        arg=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:77
        if (ischar(arg) or iscellstr(arg)):
            __,valid=__pltopt__('feather',arg,false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:79
            if (valid):
                line_spec=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:81
            else:
                error('feather: invalid linestyle STYLE')
        else:
            error('feather: invalid linestyle STYLE')
    
    ## Matlab draws feather plots, with the arrow head as one continous
  ## line, and each arrow separately. This is completely different from
  ## quiver and quite ugly.
    n=length(u)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:93
    xend=cat(arange(1,n)) + u
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:94
    xtmp=cat(arange(1,n)) + multiply(u,(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:95
    yend=copy(v)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:96
    ytmp=multiply(v,(1 - arrowsize))
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:97
    x=matlabarray(cat([cat(arange(1,n))],[xend],[xtmp - dot(v,arrowsize) / 3],[xend],[xtmp + dot(v,arrowsize) / 3]))
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:98
    y=matlabarray(cat([zeros(1,n)],[yend],[ytmp + dot(u,arrowsize) / 3],[yend],[ytmp - dot(u,arrowsize) / 3]))
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:100
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:103
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:105
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:108
        hlist=plot(x,y,line_spec,cat(1,n),cat(0,0),line_spec)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:109
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(hlist)
# /home/lei/octave-4.0.2/scripts/plot/draw/feather.m:117
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 Michael Goffioul and Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} cylinder
## @deftypefnx {Function File} {} cylinder (@var{r})
## @deftypefnx {Function File} {} cylinder (@var{r}, @var{n})
## @deftypefnx {Function File} {} cylinder (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} cylinder (@dots{})
## Plot a 3-D unit cylinder.
##
## The optional input @var{r} is a vector specifying the radius along the
## unit z-axis.  The default is [1 1] indicating radius 1 at @code{Z == 0}
## and at @code{Z == 1}.
##
## The optional input @var{n} determines the number of faces around the
## circumference of the cylinder.  The default value is 20.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## If outputs are requested @code{cylinder} returns three matrices in
## @code{meshgrid} format, such that @code{surf (@var{x}, @var{y}, @var{z})}
## generates a unit cylinder.
##
## Example:
##
## @example
## @group
## [x, y, z] = cylinder (10:-1:0, 50);
## surf (x, y, z);
## title ("a cone");
## @end group
## @end example
## @seealso{ellipsoid, rectangle, sphere}
## @end deftypefn
    
    
@function
def cylinder(varargin=None,*args,**kwargs):
    varargin = cylinder.varargin
    nargin = cylinder.nargin

    hax,args,nargs=__plt_get_axis_arg__('cylinder',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:55
    if (nargs == 0):
        r=matlabarray(cat(1,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:58
        n=20
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:59
    else:
        if (nargs == 1):
            r=args[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:61
            n=20
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:62
        else:
            if (nargs == 2):
                r=args[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:64
                n=args[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:65
            else:
                print_usage()
    
    if (length(r) < 2):
        error('cylinder: length (R) must be larger than 2')
    
    phi=linspace(0,dot(2,pi),n + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:74
    idx=arange(1,length(r))
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:75
    phi,idx=meshgrid(phi,idx,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:76
    z=(idx - 1) / (length(r) - 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:77
    r=r[idx]
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:78
    x,y=pol2cart(phi,r,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:79
    if (nargout > 0):
        xx=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:82
        yy=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:83
        zz=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:84
    else:
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:86
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:88
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/cylinder.m:91
            surf(x,y,z)
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
    
    return xx,yy,zz
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} line ()
## @deftypefnx {Function File} {} line (@var{x}, @var{y})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{z}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} line (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} line (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} line (@dots{})
## Create line object from @var{x} and @var{y} (and possibly @var{z}) and
## insert in the current axes.
##
## Multiple property-value pairs may be specified for the line object, but they
## must appear in pairs.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle (or vector of handles)
## to the line objects created.
##
## @seealso{image, patch, rectangle, surface, text}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def line(varargin=None,*args,**kwargs):
    varargin = line.varargin
    nargin = line.nargin

    ## Get axis argument which may be in a 'parent' PROP/VAL pair
    hax,varargin=__plt_get_axis_arg__('line',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/line.m:48
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/line.m:51
    else:
        hax=hax[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/line.m:53
    
    htmp=__line__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/line.m:56
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/line.m:59
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel
## Copyright (C) 2003 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} contourf (@var{z})
## @deftypefnx {Function File} {} contourf (@var{z}, @var{vn})
## @deftypefnx {Function File} {} contourf (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} contourf (@var{x}, @var{y}, @var{z}, @var{vn})
## @deftypefnx {Function File} {} contourf (@dots{}, @var{style})
## @deftypefnx {Function File} {} contourf (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{c}, @var{h}] =} contourf (@dots{})
## Create a 2-D contour plot with filled intervals.
##
## Plot level curves (contour lines) of the matrix @var{z} and fill the region
## between lines with colors from the current colormap.
##
## The level curves are taken from the contour matrix @var{c} computed by
## @code{contourc} for the same arguments; see the latter for their
## interpretation.
##
## The appearance of contour lines can be defined with a line style @var{style}
## in the same manner as @code{plot}.  Only line style and color are used;
## Any markers defined by @var{style} are ignored.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional output @var{c} contains the contour levels in @code{contourc}
## format.
##
## The optional return value @var{h} is a graphics handle to the hggroup
## comprising the contour lines.
##
## The following example plots filled contours of the @code{peaks} function.
##
## @example
## @group
## [x, y, z] = peaks (50);
## contourf (x, y, z, -7:9)
## @end group
## @end example
## @seealso{ezcontourf, contour, contourc, contour3, clabel, meshc, surfc, caxis, colormap, plot}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Author: Shai Ayal <shaiay@users.sourceforge.net>
    
    
@function
def contourf(varargin=None,*args,**kwargs):
    varargin = contourf.varargin
    nargin = contourf.nargin

    hax,varargin=__plt_get_axis_arg__('contour',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:66
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:68
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:70
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:73
        ctmp,htmp=__contour__(hax,'none','fill','on','linecolor','black',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:75
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        c=copy(ctmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:84
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/contourf.m:85
    
    return c,h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} semilogxerr (@var{y}, @var{ey})
## @deftypefnx {Function File} {} semilogxerr (@var{y}, @dots{}, @var{fmt})
## @deftypefnx {Function File} {} semilogxerr (@var{x}, @var{y}, @var{ey})
## @deftypefnx {Function File} {} semilogxerr (@var{x}, @var{y}, @var{err}, @var{fmt})
## @deftypefnx {Function File} {} semilogxerr (@var{x}, @var{y}, @var{lerr}, @var{uerr}, @var{fmt})
## @deftypefnx {Function File} {} semilogxerr (@var{x}, @var{y}, @var{ex}, @var{ey}, @var{fmt})
## @deftypefnx {Function File} {} semilogxerr (@var{x}, @var{y}, @var{lx}, @var{ux}, @var{ly}, @var{uy}, @var{fmt})
## @deftypefnx {Function File} {} semilogxerr (@var{x1}, @var{y1}, @dots{}, @var{fmt}, @var{xn}, @var{yn}, @dots{})
## @deftypefnx {Function File} {} semilogxerr (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} semilogxerr (@dots{})
## Produce 2-D plots using a logarithmic scale for the x-axis and errorbars
## at each data point.
##
## Many different combinations of arguments are possible.  The most common
## form is
##
## @example
## semilogxerr (@var{x}, @var{y}, @var{ey}, @var{fmt})
## @end example
##
## @noindent
## which produces a semi-logarithmic plot of @var{y} versus @var{x}
## with errors in the @var{y}-scale defined by @var{ey} and the plot
## format defined by @var{fmt}.  @xref{XREFerrorbar,,errorbar}, for available
## formats and additional information.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## @seealso{errorbar, semilogyerr, loglogerr}
## @end deftypefn
    
    ## Created: 20.2.2001
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def semilogxerr(varargin=None,*args,**kwargs):
    varargin = semilogxerr.varargin
    nargin = semilogxerr.nargin

    hax,varargin=__plt_get_axis_arg__('semilogxerr',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:58
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:60
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:62
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:65
        set(hax,'xscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'xminortick','on')
        htmp=__errcomm__('semilogxerr',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:72
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/semilogxerr.m:81
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} meshz (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} meshz (@var{z})
## @deftypefnx {Function File} {} meshz (@dots{}, @var{c})
## @deftypefnx {Function File} {} meshz (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} meshz (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} meshz (@dots{})
## Plot a 3-D wireframe mesh with a surrounding curtain.
##
## The wireframe mesh is plotted using rectangles.  The vertices of the
## rectangles [@var{x}, @var{y}] are typically the output of @code{meshgrid}.
## over a 2-D rectangular region in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.  If only a single @var{z} matrix is
## given, then it is plotted over the meshgrid
## @code{@var{x} = 0:columns (@var{z}) - 1, @var{y} = 0:rows (@var{z}) - 1}.
## Thus, columns of @var{z} correspond to different @var{x} values and rows
## of @var{z} correspond to different @var{y} values.
##
## The color of the mesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.
##
## Any property/value pairs are passed directly to the underlying surface
## object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## @seealso{mesh, meshc, contour, surf, surface, waterfall, meshgrid, hidden, shading, colormap, caxis}
## @end deftypefn
    
    
@function
def meshz(varargin=None,*args,**kwargs):
    varargin = meshz.varargin
    nargin = meshz.nargin

    if (logical_not(all(cellfun('isreal',varargin)))):
        error('meshz: X, Y, Z, C arguments must be real')
    
    hax,varargin,nargin=__plt_get_axis_arg__('meshz',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:62
    
    charidx=find(cellfun('isclass',varargin,'char'),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:65
    if (isempty(charidx)):
        charidx=nargin + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:68
    
    if (nargin == 1):
        z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:72
        m,n=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:73
        x=arange(0,(n - 1))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:74
        y=(arange(0,(m - 1))).T
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:75
        c=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:76
    else:
        if (nargin == 2):
            z=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:78
            m,n=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:79
            x=arange(0,(n - 1))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:80
            y=(arange(0,(m - 1))).T
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:81
            c=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:82
        else:
            if (charidx == 4):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:84
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:85
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:86
                c=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:87
            else:
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:89
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:90
                z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:91
                c=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:92
    
    ## Create a border of one rectangle (2 points) as the curtain around
  ## the data and draw it with the mean (max + min / 2) color of the data.
    
    if (isvector(x) and isvector(y)):
        x=matlabarray(cat(x[1],x[1],ravel(x).T,x[end()],x[end()]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:99
        y=matlabarray(cat([y[1]],[y[1]],[ravel(y)],[y[end()]],[y[end()]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:100
    else:
        x=matlabarray(cat([x[1,1],x[1,1],x[1,:],x[1,end()],x[1,end()]],[x[1,1],x[1,1],x[1,:],x[1,end()],x[1,end()]],[x[:,1],x[:,1],x,x[:,end()],x[:,end()]],[x[end(),1],x[end(),1],x[end(),:],x[end(),end()],x[end(),end()]],[x[end(),1],x[end(),1],x[end(),:],x[end(),end()],x[end(),end()]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:102
        y=matlabarray(cat([y[1,1],y[1,1],y[1,:],y[1,end()],y[1,end()]],[y[1,1],y[1,1],y[1,:],y[1,end()],y[1,end()]],[y[:,1],y[:,1],y,y[:,end()],y[:,end()]],[y[end(),1],y[end(),1],y[end(),:],y[end(),end()],y[end(),end()]],[y[end(),1],y[end(),1],y[end(),:],y[end(),end()],y[end(),end()]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:107
    
    zref=min(z[isfinite(z)])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:114
    z=matlabarray(cat([multiply(zref,ones(1,columns(z) + 4))],[multiply(zref,ones(1,2)),z[1,:],multiply(zref,ones(1,2))],[multiply(zref,ones(rows(z),1)),z[:,1],z,z[:,end()],multiply(zref,ones(rows(z),1))],[multiply(zref,ones(1,2)),z[end(),:],multiply(zref,ones(1,2))],[multiply(zref,ones(1,columns(z) + 4))]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:115
    cdat=c[isfinite(ravel(c))]
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:121
    cref=(min(cdat) + max(cdat)) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:122
    c=matlabarray(cat([multiply(cref,ones(2,columns(c) + 4))],[multiply(cref,ones(rows(c),2)),c,multiply(cref,ones(rows(c),2))],[multiply(cref,ones(2,columns(c) + 4))]))
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:123
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:127
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:129
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:132
        htmp=mesh(x,y,z,c,varargin[charidx:end()])
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:133
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/meshz.m:141
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rose (@var{th})
## @deftypefnx {Function File} {} rose (@var{th}, @var{nbins})
## @deftypefnx {Function File} {} rose (@var{th}, @var{bins})
## @deftypefnx {Function File} {} rose (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} rose (@dots{})
## @deftypefnx {Function File} {[@var{thout} @var{rout}] =} rose (@dots{})
## Plot an angular histogram.
##
## With one vector argument, @var{th}, plot the histogram with 20 angular bins.
## If @var{th} is a matrix then each column of @var{th} produces a separate
## histogram.
##
## If @var{nbins} is given and is a scalar, then the histogram is produced with
## @var{nbin} bins.  If @var{bins} is a vector, then the center of each bin is
## defined by the values of @var{bins} and the number of bins is
## given by the number of elements in @var{bins}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to the
## line objects representing each histogram.
##
## If two output arguments are requested then no plot is made and
## the polar vectors necessary to plot the histogram are returned instead.
##
## @example
## @group
## [th, r] = rose ([2*randn(1e5,1), pi + 2*randn(1e5,1)]);
## polar (th, r);
## @end group
## @end example
##
## @seealso{hist, polar}
## @end deftypefn
    
    
@function
def rose(varargin=None,*args,**kwargs):
    varargin = rose.varargin
    nargin = rose.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('rose',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:58
    if (nargin < 1):
        print_usage()
    
    ## Force theta to [0,2*pi] range
    th=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:65
    th=atan2(sin(th),cos(th)) + pi
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:66
    if (nargin > 1):
        x=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:69
        if (isscalar(x)):
            x=dot(dot(cat(arange(0.5 / x,1,1 / x)),2),pi)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:71
        else:
            ## Force theta to [0,2*pi] range
            x=atan2(sin(x),cos(x)) + pi
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:74
    else:
        x=dot(dot(cat(arange(1 / 40,1,1 / 20)),2),pi)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:77
    
    nn,xx=hist(th,x,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:80
    xx=ravel(xx).T
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:81
    if (isvector(nn)):
        nn=ravel(nn)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:83
    
    x1=xx[1:end() - 1] + diff(xx,1) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:85
    x1=ravel(cat([x1],[x1],[x1],[x1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:86
    th=matlabarray(cat([0],[0],[x1],[dot(2,pi)],[dot(2,pi)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:87
    r=zeros(dot(4,rows(nn)),columns(nn))
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:88
    r[2:4:end(),:]=nn
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:89
    r[3:4:end(),:]=nn
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:90
    if (nargout < 2):
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:93
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:95
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:98
            htmp=polar(th,r)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:99
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
        if (nargout > 0):
            thout=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:107
    else:
        thout=copy(th)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:110
        rout=copy(r)
# /home/lei/octave-4.0.2/scripts/plot/draw/rose.m:111
    
    return thout,rout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezsurfc (@var{f})
## @deftypefnx {Function File} {} ezsurfc (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {} ezsurfc (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezsurfc (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezsurfc (@dots{}, "circ")
## @deftypefnx {Function File} {} ezsurfc (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezsurfc (@dots{})
##
## Plot the surface and contour lines defined by a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If three functions are passed, then plot the parametrically defined
## function @code{[@var{fx} (@var{s}, @var{t}), @var{fy} (@var{s}, @var{t}),
## @var{fz} (@var{s}, @var{t})]}.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the argument @qcode{"circ"} is given, then the function is plotted over
## a disk centered on the middle of the domain @var{dom}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a 2-element vector with a graphics
## handle for the created surface plot and a second handle for the created
## contour plot.
##
## Example:
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezsurfc (f, [-3, 3]);
## @end group
## @end example
##
## @seealso{surfc, ezsurf, ezplot, ezmesh, ezmeshc, shading}
## @end deftypefn
    
    
@function
def ezsurfc(varargin=None,*args,**kwargs):
    varargin = ezsurfc.varargin
    nargin = ezsurfc.nargin

    htmp,needusage=__ezplot__('surfc',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezsurfc.m:68
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezsurfc.m:75
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} quiver3 (@var{u}, @var{v}, @var{w})
## @deftypefnx {Function File} {} quiver3 (@var{x}, @var{y}, @var{z}, @var{u}, @var{v}, @var{w})
## @deftypefnx {Function File} {} quiver3 (@dots{}, @var{s})
## @deftypefnx {Function File} {} quiver3 (@dots{}, @var{style})
## @deftypefnx {Function File} {} quiver3 (@dots{}, "filled")
## @deftypefnx {Function File} {} quiver3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} quiver3 (@dots{})
##
## Plot a 3-D vector field with arrows.
##
## Plot the (@var{u}, @var{v}, @var{w}) components of a vector field in
## an (@var{x}, @var{y}, @var{z}) meshgrid.  If the grid is uniform then
## @var{x}, @var{y}, and @var{z} can be specified as vectors.
##
## If @var{x}, @var{y}, and @var{z} are undefined they are assumed to be
## @code{(1:@var{m}, 1:@var{n}, 1:@var{p})} where @code{[@var{m}, @var{n}] =
## size (@var{u})} and @code{@var{p} = max (size (@var{w}))}.
##
## The variable @var{s} is a scalar defining a scaling factor to use for
## the arrows of the field relative to the mesh spacing.  A value of 0
## disables all scaling.  The default value is 0.9.
##
## The style to use for the plot can be defined with a line style @var{style}
## of the same format as the @code{plot} command.
## If a marker is specified then markers at the grid points of the vectors are
## drawn rather than arrows.  If the argument @qcode{"filled"} is given then the
## markers are filled.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to a quiver object.
## A quiver object regroups the components of the quiver plot (body, arrow,
## and marker), and allows them to be changed together.
##
## @example
## @group
## [x, y, z] = peaks (25);
## surf (x, y, z);
## hold on;
## [u, v, w] = surfnorm (x, y, z / 10);
## h = quiver3 (x, y, z, u, v, w);
## set (h, "maxheadsize", 0.33);
## @end group
## @end example
##
## @seealso{quiver, compass, feather, plot}
## @end deftypefn
    
    
@function
def quiver3(varargin=None,*args,**kwargs):
    varargin = quiver3.varargin
    nargin = quiver3.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('quiver3',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:71
    if (nargin < 2):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:77
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:79
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:82
        htmp=__quiver__(hax,true,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:83
        if (logical_not(ishold(hax))):
            set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/quiver3.m:96
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel, David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} slice (@var{x}, @var{y}, @var{z}, @var{v}, @var{sx}, @var{sy}, @var{sz})
## @deftypefnx {Function File} {} slice (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi})
## @deftypefnx {Function File} {} slice (@var{v}, @var{sx}, @var{sy}, @var{sz})
## @deftypefnx {Function File} {} slice (@var{v}, @var{xi}, @var{yi}, @var{zi})
## @deftypefnx {Function File} {} slice (@dots{}, @var{method})
## @deftypefnx {Function File} {} slice (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} slice (@dots{})
## Plot slices of 3-D data/scalar fields.
##
## Each element of the 3-dimensional array @var{v} represents a scalar value at
## a location given by the parameters @var{x}, @var{y}, and @var{z}.  The
## parameters @var{x}, @var{x}, and @var{z} are either 3-dimensional arrays of
## the same size as the array @var{v} in the @qcode{"meshgrid"} format or
## vectors.  The parameters @var{xi}, etc. respect a similar format to
## @var{x}, etc., and they represent the points at which the array @var{vi}
## is interpolated using interp3.  The vectors @var{sx}, @var{sy}, and
## @var{sz} contain points of orthogonal slices of the respective axes.
##
## If @var{x}, @var{y}, @var{z} are omitted, they are assumed to be
## @code{x = 1:size (@var{v}, 2)}, @code{y = 1:size (@var{v}, 1)} and
## @code{z = 1:size (@var{v}, 3)}.
##
## @var{method} is one of:
##
## @table @asis
## @item @qcode{"nearest"}
## Return the nearest neighbor.
##
## @item @qcode{"linear"}
## Linear interpolation from nearest neighbors.
##
## @item @qcode{"cubic"}
## Cubic interpolation from four nearest neighbors (not implemented yet).
##
## @item @qcode{"spline"}
## Cubic spline interpolation---smooth first and second derivatives
## throughout the curve.
## @end table
##
## The default method is @qcode{"linear"}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Examples:
##
## @example
## @group
## [x, y, z] = meshgrid (linspace (-8, 8, 32));
## v = sin (sqrt (x.^2 + y.^2 + z.^2)) ./ (sqrt (x.^2 + y.^2 + z.^2));
## slice (x, y, z, v, [], 0, []);
##
## [xi, yi] = meshgrid (linspace (-7, 7));
## zi = xi + yi;
## slice (x, y, z, v, xi, yi, zi);
## @end group
## @end example
## @seealso{interp3, surface, pcolor}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def slice(varargin=None,*args,**kwargs):
    varargin = slice.varargin
    nargin = slice.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('slice',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:87
    method='linear'
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:89
    if (ischar(varargin[end()])):
        method=varargin[end()]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:92
        nargs -= 1
    
    if (nargs == 4):
        v=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:97
        if (ndims(v) != 3):
            error('slice: V must be a 3-dimensional array of values')
        nx,ny,nz=size(v,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:101
        x,y,z=meshgrid(arange(1,nx),arange(1,ny),arange(1,nz),nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:102
        sx=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:103
        sy=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:104
        sz=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:105
    else:
        if (nargs == 7):
            v=varargin[4]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:107
            if (ndims(v) != 3):
                error('slice: V must be a 3-dimensional array of values')
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:111
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:112
            z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:113
            if (isvector(x) and isvector(y) and isvector(z)):
                x,y,z=meshgrid(x,y,z,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:115
            else:
                if (ndims(x) == 3 and size_equal(x,y,z)):
                    ## Do nothing.
                    pass
                else:
                    error('slice: X, Y, Z size mismatch')
            sx=varargin[5]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:121
            sy=varargin[6]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:122
            sz=varargin[7]
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:123
        else:
            print_usage()
    
    if (any(cat(isvector(sx),isvector(sy),isvector(sz)))):
        have_sval=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:129
    else:
        if (ndims(sx) == 2 and size_equal(sx,sy,sz)):
            have_sval=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:131
        else:
            error('slice: dimensional mismatch for (XI, YI, ZI) or (SX, SY, SZ)')
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:136
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:138
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:141
        sidx=1
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:143
        minv=min(ravel(v))
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:144
        maxv=max(ravel(v))
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:145
        set(hax,'clim',cat(minv,maxv))
        if (have_sval):
            ns=length(sx) + length(sy) + length(sz)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:149
            hs=zeros(ns,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:150
            ny,nx,nz=size(v,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:151
            if (length(sz) > 0):
                for i in arange(1,length(sz)).reshape(-1):
                    xi,yi,zi=meshgrid(squeeze(x[1,:,1]),squeeze(y[:,1,1]),sz[i],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:154
                    vz=squeeze(interp3(x,y,z,v,xi,yi,zi,method))
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:156
                    htmp[sidx]=surface(xi,yi,dot(sz[i],ones(size(yi))),vz)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:157
            if (length(sy) > 0):
                for i in arange(length(sy),1,- 1).reshape(-1):
                    xi,yi,zi=meshgrid(squeeze(x[1,:,1]),sy[i],squeeze(z[1,1,:]),nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:163
                    vy=squeeze(interp3(x,y,z,v,xi,yi,zi,method))
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:166
                    htmp[sidx]=surface(squeeze(xi),squeeze(dot(sy[i],ones(size(zi)))),squeeze(zi),vy)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:167
            if (length(sx) > 0):
                for i in arange(length(sx),1,- 1).reshape(-1):
                    xi,yi,zi=meshgrid(sx[i],squeeze(y[:,1,1]),squeeze(z[1,1,:]),nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:175
                    vx=squeeze(interp3(x,y,z,v,xi,yi,zi,method))
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:176
                    htmp[sidx]=surface(squeeze(dot(sx[i],ones(size(zi)))),squeeze(yi),squeeze(zi),vx)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:177
        else:
            vi=interp3(x,y,z,v,sx,sy,sz)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:182
            htmp=surface(sx,sy,sz,vi)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:183
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30.0),'box','off','xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/slice.m:198
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} plotmatrix (@var{x}, @var{y})
## @deftypefnx {Function File} {} plotmatrix (@var{x})
## @deftypefnx {Function File} {} plotmatrix (@dots{}, @var{style})
## @deftypefnx {Function File} {} plotmatrix (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{h}, @var{ax}, @var{bigax}, @var{p}, @var{pax}] =} plotmatrix (@dots{})
## Scatter plot of the columns of one matrix against another.
##
## Given the arguments @var{x} and @var{y} that have a matching number of
## rows, @code{plotmatrix} plots a set of axes corresponding to
##
## @example
## plot (@var{x}(:, i), @var{y}(:, j))
## @end example
##
## When called with a single argument @var{x} this is equivalent to
##
## @example
## plotmatrix (@var{x}, @var{x})
## @end example
##
## @noindent
## except that the diagonal of the set of axes will be replaced with the
## histogram @code{hist (@var{x}(:, i))}.
##
## The marker to use can be changed with the @var{style} argument, that is a
## string defining a marker in the same manner as the @code{plot} command.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} provides handles to the individual
## graphics objects in the scatter plots, whereas @var{ax} returns the
## handles to the scatter plot axis objects.
##
## @var{bigax} is a hidden axis object that surrounds the other axes, such
## that the commands @code{xlabel}, @code{title}, etc., will be associated
## with this hidden axis.
##
## Finally, @var{p} returns the graphics objects associated with the histogram
## and @var{pax} the corresponding axes objects.
##
## Example:
##
## @example
## plotmatrix (randn (100, 3), "g+")
## @end example
##
## @seealso{scatter, plot}
## @end deftypefn
    
    
@function
def plotmatrix(varargin=None,*args,**kwargs):
    varargin = plotmatrix.varargin
    nargin = plotmatrix.nargin

    bigax2,varargin,nargin=__plt_get_axis_arg__('plotmatrix',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:72
    if (nargin > 3 or nargin < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:78
    if (logical_not(isempty(bigax2))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:80
    
    try:
        bigax2=newplot(bigax2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:83
        h2,ax2,p2,pax2=__plotmatrix__(bigax2,varargin[:],nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:85
        axes(bigax2)
        ctext=text(0,0,'','visible','off','handlevisibility','off','xliminclude','off','yliminclude','off','zliminclude','off','deletefcn',cellarray([plotmatrixdelete,cat([ax2],[pax2])]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:88
        set(bigax2,'visible','off')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(h2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:101
        ax=copy(ax2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:102
        bigax=copy(bigax2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:103
        p=copy(p2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:104
        pax=copy(pax2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:105
    
    return h,ax,bigax,p,pax
    
if __name__ == '__main__':
    pass
    
    
    
    
    
@function
def plotmatrixdelete(h=None,d=None,ax=None,*args,**kwargs):
    varargin = plotmatrixdelete.varargin
    nargin = plotmatrixdelete.nargin

    for i in arange(1,numel(ax)).reshape(-1):
        hc=ax[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:118
        if (isaxes(hc) and strcmpi(get(hc,'beingdeleted'),'off')):
            parent=get(hc,'parent')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:120
            if (ishandle(parent) and strcmpi(get(parent,'beingdeleted'),'off')):
                delete(hc)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __plotmatrix__(bigax=None,varargin=None,*args,**kwargs):
    varargin = __plotmatrix__.varargin
    nargin = __plotmatrix__.nargin

    have_line_spec=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:130
    have_hist=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:131
    parent=get(bigax,'parent')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:132
    for i in arange(1,nargin - 1).reshape(-1):
        arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:134
        if (ischar(arg) or iscellstr(arg)):
            linespec,valid=__pltopt__('plotmatrix',varargin[i],false,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:136
            if (valid):
                have_line_spec=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:138
                linespec=varargin[i]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:139
                varargin[i]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:140
                nargin=nargin - 1
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:141
                break
            else:
                print_usage('plotmatrix')
    
    if (nargin == 2):
        X=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:150
        Y=copy(X)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:151
        have_hist=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:152
    else:
        if (nargin == 3):
            X=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:154
            Y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:155
        else:
            print_usage('plotmatrix')
    
    if (rows(X) != rows(Y)):
        error('plotmatrix: dimension mismatch in the arguments')
    
    dummy,m=size(X,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:164
    dummy,n=size(Y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:165
    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:167
    ax=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:168
    p=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:169
    pax=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:170
    xsize=0.9 / m
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:172
    ysize=0.9 / n
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:173
    xoff=0.05
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:174
    yoff=0.05
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:175
    border=multiply(cat(0.13,0.11,0.225,0.185),cat(xsize,ysize,xsize,ysize))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:176
    border[3:4]=- border[3:4] - border[1:2]
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:177
    for i in arange(1,m).reshape(-1):
        for j in arange(1,n).reshape(-1):
            pos=matlabarray(cat(dot(xsize,(i - 1)) + xoff,dot(ysize,(n - j)) + yoff,xsize,ysize))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:181
            tmp=axes('outerposition',pos,'position',pos + border,'parent',parent)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:182
            if (i == j and have_hist):
                pax=matlabarray(cat([pax],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:185
                nn,xx=hist(X[:,i],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:186
                tmp=bar(xx,nn,1.0)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:187
                p=matlabarray(cat([p],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:188
            else:
                ax=matlabarray(cat([ax],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:190
                if (have_line_spec):
                    tmp=plot(X[:,i],Y[:,j],linespec)
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:192
                else:
                    tmp=plot(X[:,i],Y[:,j],'.')
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:194
                h=matlabarray(cat([h],[tmp]))
# /home/lei/octave-4.0.2/scripts/plot/draw/plotmatrix.m:196
    
    return h,ax,p,pax
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2000-2015 Teemu Ikonen
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} loglogerr (@var{y}, @var{ey})
## @deftypefnx {Function File} {} loglogerr (@var{y}, @dots{}, @var{fmt})
## @deftypefnx {Function File} {} loglogerr (@var{x}, @var{y}, @var{ey})
## @deftypefnx {Function File} {} loglogerr (@var{x}, @var{y}, @var{err}, @var{fmt})
## @deftypefnx {Function File} {} loglogerr (@var{x}, @var{y}, @var{lerr}, @var{uerr}, @var{fmt})
## @deftypefnx {Function File} {} loglogerr (@var{x}, @var{y}, @var{ex}, @var{ey}, @var{fmt})
## @deftypefnx {Function File} {} loglogerr (@var{x}, @var{y}, @var{lx}, @var{ux}, @var{ly}, @var{uy}, @var{fmt})
## @deftypefnx {Function File} {} loglogerr (@var{x1}, @var{y1}, @dots{}, @var{fmt}, @var{xn}, @var{yn}, @dots{})
## @deftypefnx {Function File} {} loglogerr (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} loglogerr (@dots{})
## Produce 2-D plots on a double logarithm axis with errorbars.
##
## Many different combinations of arguments are possible.  The most common
## form is
##
## @example
## loglogerr (@var{x}, @var{y}, @var{ey}, @var{fmt})
## @end example
##
## @noindent
## which produces a double logarithm plot of @var{y} versus @var{x}
## with errors in the @var{y}-scale defined by @var{ey} and the plot
## format defined by @var{fmt}.  @xref{XREFerrorbar,,errorbar}, for available
## formats and additional information.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
## @seealso{errorbar, semilogxerr, semilogyerr}
## @end deftypefn
    
    ## Created: 20.2.2001
## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
## Keywords: errorbar, plotting
    
    
@function
def loglogerr(varargin=None,*args,**kwargs):
    varargin = loglogerr.varargin
    nargin = loglogerr.nargin

    hax,varargin=__plt_get_axis_arg__('loglogerr',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:56
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:58
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:60
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:63
        set(hax,'xscale','log','yscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'xminortick','on','yminortick','on')
        htmp=__errcomm__('loglogerr',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:69
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglogerr.m:78
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ribbon (@var{y})
## @deftypefnx {Function File} {} ribbon (@var{x}, @var{y})
## @deftypefnx {Function File} {} ribbon (@var{x}, @var{y}, @var{width})
## @deftypefnx {Function File} {} ribbon (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ribbon (@dots{})
## Draw a ribbon plot for the columns of @var{y} vs. @var{x}.
##
## The optional parameter @var{width} specifies the width of a single ribbon
## (default is 0.75).  If @var{x} is omitted, a vector containing the
## row numbers is assumed (@code{1:rows (Y)}).
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a vector of graphics handles to
## the surface objects representing each ribbon.
## @seealso{surface, waterfall}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel at gmx.de>
    
    
@function
def ribbon(varargin=None,*args,**kwargs):
    varargin = ribbon.varargin
    nargin = ribbon.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('ribbon',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:43
    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin == 1):
        y=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:50
        if (isvector(y)):
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:52
        nr,nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:54
        x=repmat((arange(1,nr)).T,1,nc)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:55
        width=0.75
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:56
    else:
        if (nargin == 2):
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:58
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:59
            width=0.75
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:60
        else:
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:62
            y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:63
            width=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:64
    
    if (isvector(x) and isvector(y)):
        if (length(x) != length(y)):
            error('ribbon: vectors X and Y must have the same length')
        else:
            x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:71
    else:
        if (logical_not(size_equal(x,y))):
            error('ribbon: matrices X and Y must have the same size')
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:79
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:81
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:84
        nr,nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:86
        htmp=zeros(nc,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:87
        for c in arange(nc,1,- 1).reshape(-1):
            zz=matlabarray(cat(y[:,c],y[:,c]))
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:90
            yy=x[:,c]
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:91
            xx=matlabarray(cat(c - width / 2,c + width / 2))
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:92
            xx,yy=meshgrid(xx,yy,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:93
            cc=repmat(c,size(zz))
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:94
            htmp[c]=surface(xx,yy,zz,cc)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:95
        if (logical_not(ishold())):
            set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ribbon.m:110
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} loglog (@var{y})
## @deftypefnx {Function File} {} loglog (@var{x}, @var{y})
## @deftypefnx {Function File} {} loglog (@var{x}, @var{y}, @var{prop}, @var{value}, @dots{})
## @deftypefnx {Function File} {} loglog (@var{x}, @var{y}, @var{fmt})
## @deftypefnx {Function File} {} loglog (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} loglog (@dots{})
## Produce a 2-D plot using logarithmic scales for both axes.
##
## See the documentation of @code{plot} for a description of the arguments
## that @code{loglog} will accept.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
## @seealso{plot, semilogx, semilogy}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def loglog(varargin=None,*args,**kwargs):
    varargin = loglog.varargin
    nargin = loglog.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('loglog',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:42
    if (nargs < 1):
        print_usage()
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:48
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:50
    
    try:
        hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:53
        set(hax,'xscale','log','yscale','log')
        if (logical_not(ishold(hax))):
            set(hax,'xminortick','on','yminortick','on')
        htmp=__plt__('loglog',hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:60
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/loglog.m:69
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sphere ()
## @deftypefnx {Function File} {} sphere (@var{n})
## @deftypefnx {Function File} {} sphere (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} sphere (@dots{})
## Plot a 3-D unit sphere.
##
## The optional input @var{n} determines the number of faces around the
## circumference of the sphere.  The default value is 20.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## If outputs are requested @code{sphere} returns three matrices in
## @code{meshgrid} format such that @code{surf (@var{x}, @var{y}, @var{z})}
## generates a unit sphere.
##
## Example:
##
## @example
## @group
## [x, y, z] = sphere (40);
## surf (3*x, 3*y, 3*z);
## axis equal;
## title ("sphere of radius 3");
## @end group
## @end example
## @seealso{cylinder, ellipsoid, rectangle}
## @end deftypefn
    
    
@function
def sphere(varargin=None,*args,**kwargs):
    varargin = sphere.varargin
    nargin = sphere.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('sphere',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:51
    if (nargin > 1):
        print_usage()
    else:
        if (nargin == 1):
            n=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:56
        else:
            n=20
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:58
    
    theta=linspace(0,dot(2,pi),n + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:61
    phi=linspace(- pi / 2,pi / 2,n + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:62
    theta,phi=meshgrid(theta,phi,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:63
    x=multiply(cos(phi),cos(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:65
    y=multiply(cos(phi),sin(theta))
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:66
    z=sin(phi)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:67
    if (nargout > 0):
        xx=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:70
        yy=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:71
        zz=copy(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:72
    else:
        oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:74
        if (logical_not(isempty(hax))):
            oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:76
        try:
            hax=newplot(hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/sphere.m:79
            surf(x,y,z)
        finally:
            if (logical_not(isempty(oldfig))):
                set(0,'currentfigure',oldfig)
    
    return xx,yy,zz
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} trisurf (@var{tri}, @var{x}, @var{y}, @var{z}, @var{c})
## @deftypefnx {Function File} {} trisurf (@var{tri}, @var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} trisurf (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} trisurf (@dots{})
## Plot a 3-D triangular surface.
##
## In contrast to @code{surf}, which plots a surface mesh using rectangles,
## @code{trisurf} plots the mesh using triangles.
##
## @var{tri} is typically the output of a Delaunay triangulation over the
## grid of @var{x}, @var{y}.  Every row of @var{tri} represents one triangle
## and contains three indices into [@var{x}, @var{y}] which are the
## vertices of the triangles in the x-y plane.  @var{z} determines the
## height above the plane of each vertex.
##
## The color of the trimesh is computed by linearly scaling the @var{z} values
## to fit the range of the current colormap.  Use @code{caxis} and/or
## change the colormap to control the appearance.
##
## Optionally, the color of the mesh can be specified independently of @var{z}
## by supplying a color matrix, @var{c}.  If @var{z} has N elements, then
## @var{c} should be an Nx1 vector for colormap data or an Nx3 matrix for
## RGB data.
##
## Any property/value pairs are passed directly to the underlying patch object.
##
## The optional return value @var{h} is a graphics handle to the created patch
## object.
## @seealso{surf, triplot, trimesh, delaunay, patch, shading}
## @end deftypefn
    
    
@function
def trisurf(tri=None,x=None,y=None,z=None,varargin=None,*args,**kwargs):
    varargin = trisurf.varargin
    nargin = trisurf.nargin

    if (nargin < 4):
        print_usage()
    
    if (nargin > 4 and isnumeric(varargin[1])):
        c=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:58
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:59
        if (isvector(c)):
            if (numel(c) != numel(z)):
                error('trisurf: C must have \'numel (Z)\' elements')
            c=ravel(c)
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:64
        else:
            if (rows(c) != numel(z) or columns(c) != 3):
                error('trisurf: TrueColor C matrix must be \'numel (Z)\' rows by 3 columns')
    else:
        c=ravel(z)
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:69
    
    ## FIXME: Is all this extra input parsing necessary?
  ##        Is it for Matlab compatibility?
    if (logical_not(any(strcmpi(varargin,'FaceColor')))):
        nfc=numel(varargin) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:74
        varargin[nfc + (arange(0,1))]=cellarray(['FaceColor','flat'])
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:75
    else:
        nfc=find(any(strcmpi(varargin,'FaceColor')),1)
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:77
    
    if (logical_not(any(strcmpi(varargin,'EdgeColor'))) and strcmpi(varargin[nfc + 1],'interp')):
        varargin[end() + (arange(1,2))]=cellarray(['EdgeColor','none'])
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:81
    
    hax=newplot()
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:84
    htmp=patch('Faces',tri,'Vertices',cat(ravel(x),ravel(y),ravel(z)),'FaceVertexCData',c,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:86
    if (logical_not(ishold())):
        set(hax,'view',cat(- 37.5,30),'box','off','xgrid','on','ygrid','on','zgrid','on')
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/trisurf.m:95
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rectangle ()
## @deftypefnx {Function File} {} rectangle (@dots{}, "Position", @var{pos})
## @deftypefnx {Function File} {} rectangle (@dots{}, "Curvature", @var{curv})
## @deftypefnx {Function File} {} rectangle (@dots{}, "EdgeColor", @var{ec})
## @deftypefnx {Function File} {} rectangle (@dots{}, "FaceColor", @var{fc})
## @deftypefnx {Function File} {} rectangle (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} rectangle (@dots{})
## Draw a rectangular patch defined by @var{pos} and @var{curv}.
##
## The variable @code{@var{pos}(1:2)} defines the lower left-hand corner of
## the patch and @code{@var{pos}(3:4)} defines its width and height.  By
## default, the value of @var{pos} is @code{[0, 0, 1, 1]}.
##
## The variable @var{curv} defines the curvature of the sides of the rectangle
## and may be a scalar or two-element vector with values between 0 and 1.
## A value of 0 represents no curvature of the side, whereas a value of 1
## means that the side is entirely curved into the arc of a circle.
## If @var{curv} is a two-element vector, then the first element is the
## curvature along the x-axis of the patch and the second along y-axis.
##
## If @var{curv} is a scalar, it represents the curvature of the shorter of the
## two sides of the rectangle and the curvature of the other side is defined
## by
##
## @example
## min (pos(1:2)) / max (pos(1:2)) * curv
## @end example
##
## Additional property/value pairs are passed to the underlying patch command.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## rectangle object.
## @end deftypefn
## @seealso{patch, line, cylinder, ellipsoid, sphere}
    
    
@function
def rectangle(varargin=None,*args,**kwargs):
    varargin = rectangle.varargin
    nargin = rectangle.nargin

    hax,varargin=__plt_get_axis_arg__('rectangle',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:60
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:63
    else:
        hax=hax[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:65
    
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:68
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:70
    
    try:
        htmp=__rectangle__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:73
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:81
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __rectangle__(hax=None,varargin=None,*args,**kwargs):
    varargin = __rectangle__.varargin
    nargin = __rectangle__.nargin

    iarg=1
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:87
    pos=matlabarray(cat(0,0,1,1))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:88
    curv2=matlabarray(cat(0,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:89
    ec=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:90
    fc='none'
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:91
    parent=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:92
    while (iarg < length(varargin)):

        arg=varargin[iarg]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:95
        if (ischar(arg)):
            if (strcmpi(arg,'position')):
                pos=varargin[iarg + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:98
                varargin[iarg:iarg + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:99
                if (logical_not(isvector(pos)) or numel(pos) != 4):
                    error('rectangle: position must be a 4 element vector')
            else:
                if (strcmpi(arg,'curvature')):
                    curv2=varargin[iarg + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:104
                    varargin[iarg:iarg + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:105
                    if (logical_not(isnumeric(curv2)) or (numel(curv2) != 1 and numel(curv2) != 2)):
                        error('rectangle: curvature must be a 2-element vector or a scalar')
                    if (any(curv2 < 0) or any(curv2 > 1)):
                        error('rectangle: curvature values must be between 0 and 1')
                else:
                    if (strcmpi(arg,'edgecolor')):
                        ec=varargin[iarg + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:113
                        varargin[iarg:iarg + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:114
                    else:
                        if (strcmpi(arg,'facecolor')):
                            fc=varargin[iarg + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:116
                            varargin[iarg:iarg + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:117
                        else:
                            if (strcmpi(arg,'parent')):
                                parent=varargin[iarg + 1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:119
                                varargin[iarg:iarg + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:120
                            else:
                                iarg
        else:
            iarg

    
    if (numel(curv2) == 1):
        a,ai=min(pos[3:4],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:130
        b,bi=max(pos[3:4],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:131
        if (ai < bi):
            curv=matlabarray(cat(curv2,multiply(curv2,a) / b))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:133
        else:
            curv=matlabarray(cat(multiply(curv2,a) / b,curv2))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:135
    else:
        curv=copy(curv2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:138
    
    if (all(curv < 0.01)):
        ## Special case : no curvature
        x=matlabarray(cat(pos[1],pos[1] + pos[3],pos[1] + pos[3],pos[1],pos[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:143
        y=matlabarray(cat(pos[2],pos[2],pos[2] + pos[4],pos[2] + pos[4],pos[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:144
    else:
        p=dot(pi / 2,cat(arange(0,15))) / 15
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:146
        c=multiply(curv,pos[3:4]) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:147
        cx=dot(c[1],sin(p)) - c[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:148
        cy=dot(c[2],cos(p)) - c[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:149
        x=matlabarray(cat(pos[1] - fliplr(cx),pos[1] + pos[3] + cx,pos[1] + pos[3] + fliplr(cx),pos[1] - cx,pos[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:150
        y=matlabarray(cat(pos[2] - fliplr(cy),pos[2] - cy,pos[2] + pos[4] + fliplr(cy),pos[2] + pos[4] + cy,pos[2] + c[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:152
    
    if (logical_not(isempty(parent))):
        hg=hggroup('parent',parent)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:157
    else:
        hg=hggroup('parent',hax)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:159
    
    h=patch('xdata',ravel(x),'ydata',ravel(y),'facecolor',fc,'edgecolor',ec,'parent',hg,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:162
    addproperty('curvature',hg,'data',curv2)
    addproperty('position',hg,'data',pos)
    addproperty('edgecolor',hg,'patchedgecolor',get(h,'edgecolor'))
    addproperty('linewidth',hg,'patchlinewidth',get(h,'linewidth'))
    addproperty('linestyle',hg,'patchlinestyle',get(h,'linestyle'))
    addproperty('facecolor',hg,'patchfacecolor',get(h,'facecolor'))
    addlistener(hg,'curvature',update_data)
    addlistener(hg,'position',update_data)
    addlistener(hg,'edgecolor',update_props)
    addlistener(hg,'linewidth',update_props)
    addlistener(hg,'linestyle',update_props)
    addlistener(hg,'facecolor',update_props)
    return hg
    
if __name__ == '__main__':
    pass
    
    
@function
def update_data(h=None,__=None,*args,**kwargs):
    varargin = update_data.varargin
    nargin = update_data.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:186
            kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:188
            pos=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:189
            curv2=get(h,'curvature')
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:190
            if (numel(curv2) == 1):
                a,ai=min(pos[3:4],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:193
                b,bi=max(pos[3:4],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:194
                if (ai < bi):
                    curv=matlabarray(cat(curv2,multiply(curv2,a) / b))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:196
                else:
                    curv=matlabarray(cat(multiply(curv2,a) / b,curv2))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:198
            else:
                curv=copy(curv2)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:201
            if (all(curv < 0.01)):
                ## Special case : no curvature
                x=matlabarray(cat(pos[1],pos[1] + pos[3],pos[1] + pos[3],pos[1],pos[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:206
                y=matlabarray(cat(pos[2],pos[2],pos[2] + pos[4],pos[2] + pos[4],pos[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:207
            else:
                p=dot(pi / 2,cat(arange(0,15))) / 15
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:209
                c=multiply(curv,pos[3:4]) / 2
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:210
                cx=dot(c[1],sin(p)) - c[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:211
                cy=dot(c[2],cos(p)) - c[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:212
                x=matlabarray(cat(pos[1] - fliplr(cx),pos[1] + pos[3] + cx,pos[1] + pos[3] + fliplr(cx),pos[1] - cx,pos[1]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:213
                y=matlabarray(cat(pos[2] - fliplr(cy),pos[2] - cy,pos[2] + pos[4] + fliplr(cy),pos[2] + pos[4] + cy,pos[2] + c[2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:215
            set(kids,'xdata',x,'ydata',y)
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:221
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_props(h=None,__=None,*args,**kwargs):
    varargin = update_props.varargin
    nargin = update_props.nargin

    kids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/draw/rectangle.m:227
    set(kids,cellarray(['edgecolor','linewidth','linestyle','facecolor']),get(h,cellarray(['edgecolor','linewidth','linestyle','facecolor'])))
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Martin Helm
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} tetramesh (@var{T}, @var{X})
## @deftypefnx {Function File} {} tetramesh (@var{T}, @var{X}, @var{C})
## @deftypefnx {Function File} {} tetramesh (@dots{}, @var{property}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} tetramesh (@dots{})
## Display the tetrahedrons defined in the m-by-4 matrix @var{T} as 3-D patches.
##
## @var{T} is typically the output of a Delaunay triangulation of a 3-D set
## of points.  Every row of @var{T} contains four indices into the n-by-3
## matrix @var{X} of the vertices of a tetrahedron.  Every row in @var{X}
## represents one point in 3-D space.
##
## The vector @var{C} specifies the color of each tetrahedron as an index
## into the current colormap.  The default value is 1:m where m is the number
## of tetrahedrons; the indices are scaled to map to the full range of the
## colormap.  If there are more tetrahedrons than colors in the colormap then
## the values in @var{C} are cyclically repeated.
##
## Calling @code{tetramesh (@dots{}, "property", "value", @dots{})} passes all
## property/value pairs directly to the patch function as additional arguments.
##
## The optional return value @var{h} is a vector of patch handles where each
## handle represents one tetrahedron in the order given by @var{T}.
## A typical use case for @var{h} is to turn the respective patch
## @qcode{"visible"} property @qcode{"on"} or @qcode{"off"}.
##
## Type @code{demo tetramesh} to see examples on using @code{tetramesh}.
## @seealso{trimesh, delaunay, delaunayn, patch}
## @end deftypefn
    
    ## Author: Martin Helm <martin@mhelm.de>
    
    
@function
def tetramesh(varargin=None,*args,**kwargs):
    varargin = tetramesh.varargin
    nargin = tetramesh.nargin

    reg,prop=parseparams(varargin,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:53
    if (length(reg) < 2 or length(reg) > 3):
        print_usage()
    
    T=reg[1]
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:59
    X=reg[2]
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:60
    if (logical_not(ismatrix(T)) or columns(T) != 4):
        error('tetramesh: T must be an n-by-4 matrix')
    else:
        if (logical_not(ismatrix(X)) or columns(X) != 3):
            error('tetramesh: X must be an n-by-3 matrix')
    
    size_T=rows(T)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:68
    cmap=colormap()
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:69
    if (length(reg) < 3):
        size_cmap=rows(cmap)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:72
        C=mod((arange(1,size_T)).T - 1,size_cmap) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:73
        if (size_T < size_cmap and size_T > 1):
            ## expand to the available range of colors
            C=floor(dot((C - 1),(size_cmap - 1)) / (size_T - 1)) + 1
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:76
    else:
        C=reg[3]
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:79
        if (logical_not(isvector(C)) or size_T != length(C)):
            error('tetramesh: C must be a vector of the same length as T')
    
    hax=newplot()
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:85
    hvec=zeros(size_T,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:87
    if (strcmp(graphics_toolkit(),'gnuplot')):
        ## Tiny reduction of the tetrahedron size to help gnuplot by
    ## avoiding identical faces with different colors
        for i in arange(1,size_T).reshape(-1):
            th,p=__shrink__(cat(1,2,3,4),X[T[i,:],:],1 - 1e-07,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:92
            hvec[i]=patch('Faces',th,'Vertices',p,'FaceColor',cmap[C[i],:],'FaceAlpha',0.9,prop[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:93
    else:
        ## FLTK does not support FaceAlpha.
        for i in arange(1,size_T).reshape(-1):
            th=matlabarray(cat([1,2,3],[2,3,4],[3,4,1],[4,1,2]))
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:100
            hvec[i]=patch('Faces',th,'Vertices',X[T[i,:],:],'FaceColor',cmap[C[i],:],'FaceAlpha',1.0,prop[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:101
    
    if (logical_not(ishold())):
        set(hax,'view',cat(- 37.5,30),'box','off')
    
    if (nargout > 0):
        h=copy(hvec)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:112
    
    return h
    
if __name__ == '__main__':
    pass
    
    ## shrink the tetrahedron relative to its center of gravity
    
@function
def __shrink__(T=None,X=None,sf=None,*args,**kwargs):
    varargin = __shrink__.varargin
    nargin = __shrink__.nargin

    midpoint=repmat(sum(X[T,:],1) / 4,12,1)
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:119
    p=matlabarray(cat([X[cat(1,2,3),:]],[X[cat(2,3,4),:]],[X[cat(3,4,1),:]],[X[cat(4,1,2),:]]))
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:120
    p=dot(sf,(p - midpoint)) + midpoint
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:121
    tri=reshape(arange(1,12),3,4).T
# /home/lei/octave-4.0.2/scripts/plot/draw/tetramesh.m:122
    return tri,p
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} stem3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} stem3 (@dots{}, @var{linespec})
## @deftypefnx {Function File} {} stem3 (@dots{}, "filled")
## @deftypefnx {Function File} {} stem3 (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} stem3 (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} stem3 (@dots{})
## Plot a 3-D stem graph.
##
## Stems are drawn from the height @var{z} to the location in the x-y plane
## determined by @var{x} and @var{y}.  The default color is @qcode{"b"} (blue),
## the default line style is @qcode{"-"}, and the default marker is @qcode{"o"}.
##
## The line style can be altered by the @code{linespec} argument in the same
## manner as the @code{plot} command.  If the @qcode{"filled"} argument is
## present the markers at the top of the stems will be filled in.
##
## Optional property/value pairs may be specified to control the appearance
## of the plot.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a handle to the @nospell{"stem series"}
## hggroup containing the line and marker objects used for the plot.
## @xref{XREFstem,,stem}, for a description of the @nospell{"stem series"}
## object.
##
## Example:
##
## @example
## @group
## theta = 0:0.2:6;
## stem3 (cos (theta), sin (theta), theta);
## @end group
## @end example
##
## @noindent
## plots 31 stems with heights from 0 to 6 lying on a circle.
##
## Implementation Note: Color definitions with RGB-triples are not valid.
## @seealso{stem, bar, hist, plot}
## @end deftypefn
    
    
@function
def stem3(varargin=None,*args,**kwargs):
    varargin = stem3.varargin
    nargin = stem3.nargin

    if (nargin < 1):
        print_usage()
    
    htmp=__stem__(true,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/draw/stem3.m:69
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/stem3.m:72
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezmesh (@var{f})
## @deftypefnx {Function File} {} ezmesh (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {} ezmesh (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezmesh (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezmesh (@dots{}, "circ")
## @deftypefnx {Function File} {} ezmesh (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezmesh (@dots{})
##
## Plot the mesh defined by a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If three functions are passed, then plot the parametrically defined
## function @code{[@var{fx} (@var{s}, @var{t}), @var{fy} (@var{s}, @var{t}),
## @var{fz} (@var{s}, @var{t})]}.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the argument @qcode{"circ"} is given, then the function is plotted over
## a disk centered on the middle of the domain @var{dom}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created
## surface object.
##
## Example 1: 2-argument function
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezmesh (f, [-3, 3]);
## @end group
## @end example
##
## Example 2: parametrically defined function
##
## @example
## @group
## fx = @@(s,t) cos (s) .* cos (t);
## fy = @@(s,t) sin (s) .* cos (t);
## fz = @@(s,t) sin (t);
## ezmesh (fx, fy, fz, [-pi, pi, -pi/2, pi/2], 20);
## @end group
## @end example
##
## @seealso{mesh, ezmeshc, ezplot, ezsurf, ezsurfc, hidden}
## @end deftypefn
    
    
@function
def ezmesh(varargin=None,*args,**kwargs):
    varargin = ezmesh.varargin
    nargin = ezmesh.nargin

    htmp,needusage=__ezplot__('mesh',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezmesh.m:78
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezmesh.m:85
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezcontourf (@var{f})
## @deftypefnx {Function File} {} ezcontourf (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezcontourf (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezcontourf (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezcontourf (@dots{})
##
## Plot the filled contour lines of a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created plot.
##
## Example:
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezcontourf (f, [-3, 3]);
## @end group
## @end example
##
## @seealso{contourf, ezcontour, ezplot, ezmeshc, ezsurfc}
## @end deftypefn
    
    
@function
def ezcontourf(varargin=None,*args,**kwargs):
    varargin = ezcontourf.varargin
    nargin = ezcontourf.nargin

    htmp,needusage=__ezplot__('contourf',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezcontourf.m:57
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezcontourf.m:64
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Michael D. Godfrey
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public
## License as published by the Free Software Foundation;
## either version 3 of the License, or (at your option) any
## later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied
## warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public
## License along with Octave; see the file COPYING. If not,
## see <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} stemleaf (@var{x}, @var{caption})
## @deftypefnx {Function File} {} stemleaf (@var{x}, @var{caption}, @var{stem_sz})
## @deftypefnx {Function File} {@var{plotstr} =} stemleaf (@dots{})
## Compute and display a stem and leaf plot of the vector @var{x}.
##
## The input @var{x} should be a vector of integers.  Any non-integer values
## will be converted to integer by @code{@var{x} = fix (@var{x})}.  By default
## each element of @var{x} will be plotted with the last digit of the element
## as a leaf value and the remaining digits as the stem.  For example, 123
## will be plotted with the stem @samp{12} and the leaf @samp{3}.  The second
## argument, @var{caption}, should be a character array which provides a
## description of the data.  It is included as a heading for the output.
##
## The optional input @var{stem_sz} sets the width of each stem.
## The stem width is determined by @code{10^(@var{stem_sz} + 1)}.
## The default stem width is 10.
##
## The output of @code{stemleaf} is composed of two parts: a
## "Fenced Letter Display," followed by the stem-and-leaf plot itself.
## The Fenced Letter Display is described in @cite{Exploratory Data Analysis}.
## Briefly, the entries are as shown:
##
## @example
## @group
##
##         Fenced Letter Display
## ## nx|___________________     nx = numel (x)
## M# mi|       md         |     mi median index, md median
## H# hi|hl              hu| hs  hi lower hinge index, hl,hu hinges,
## 1    |x(1)         x(nx)|     hs h_spreadx(1), x(nx) first
##            _______            and last data value.
##      ______|step |_______     step 1.5*h_spread
##     f|ifl            ifh|     inner fence, lower and higher
##      |nfl            nfh|     no.\ of data points within fences
##     F|ofl            ofh|     outer fence, lower and higher
##      |nFl            nFh|     no.\ of data points outside outer
##                               fences
## @end group
## @end example
##
## The stem-and-leaf plot shows on each line the stem value followed by the
## string made up of the leaf digits.  If the @var{stem_sz} is not 1 the
## successive leaf values are separated by ",".
##
## With no return argument, the plot is immediately displayed.  If an output
## argument is provided, the plot is returned as an array of strings.
##
## The leaf digits are not sorted.  If sorted leaf values are desired, use
## @code{@var{xs} = sort (@var{x})} before calling @code{stemleaf (@var{xs})}.
##
## The stem and leaf plot and associated displays are described in:
## Ch. 3, @cite{Exploratory Data Analysis} by J. W. Tukey, Addison-Wesley, 1977.
## @seealso{hist, printd}
## @end deftypefn
    
    ## Author: Michael D. Godfrey <michaeldgodfrey@gmail.com>
## Description: Compute stem and leaf plot
    
    
@function
def stemleaf(x=None,caption=None,stem_sz=None,*args,**kwargs):
    varargin = stemleaf.varargin
    nargin = stemleaf.nargin

    ## Compute and display a stem and leaf plot of the vector x.  The x
  ## vector is converted to integer by x = fix(x).  If an output argument
  ## is provided, the plot is returned as an array of strings.  The
  ## first element is the heading followed by an element for each stem.
  ##
  ## The default stem step is 10.  If stem_sz is provided the stem
  ## step is set to: 10^(stem_sz+1).  The x vector should be integers.
  ## It will be treated so that the last digit is the leaf value and the
  ## other digits are the stems.
  ##
  ## When we first implemented stem and leaf plots in the early 1960's
  ## there was some discussion about sorting vs. leaving the leaf
  ## entries in the original order in the data.  We decided in favor of
  ## sorting the leaves for most purposes.  This is the choice
  ## implemented in the SNAP/IEDA system that was written at that time.
  ##
  ## SNAP/IEDA, and particularly its stem and leaf plotting, were further
  ## developed by Hale Trotter, David Hoagland (at Princeton and MIT),
  ## and others.
  ##
  ## Tukey, in EDA, generally uses unsorted leaves.  In addition, he
  ## described a wide range of additional display formats.  This
  ## implementation does not sort the leaves, but if the x vector is
  ## sorted then the leaves come out sorted.  A simple display format is
  ## used.
  ##
  ## I doubt if providing other options is worthwhile.  The code can
  ## quite easily be modified to provide specific display results.  Or,
  ## the returned output string can be edited.  The returned output is an
  ## array of strings with each row containing a line of the plot
  ## preceded by the lines of header text as the first row.  This
  ## facilitates annotation.
  ##
  ## Note that the code has some added complexity due to the need to
  ## distinguish both + and - 0 stems.  The +- stem values are essential
  ## for all plots which span 0. After dealing with +-0 stems, the added
  ## complexity of putting +- data values in the correct stem is minor,
  ## but the sign of 0 leaves must be checked.  And, the cases where the
  ## stems start or end at +- 0 must also be considered.
  ##
  ## The fact that IEEE floating point defines +- 0 helps make this
  ## easier.
  ##
  ## Michael D. Godfrey   January 2013
    
    ## More could be implemented for better data scaling.  And, of course,
  ## other options for the kinds of plots described by Tukey could be
  ## provided.  This may best be left to users.
    
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(isvector(x))):
        error('stemleaf: X must be a vector')
    
    if (isinteger(x)):
        ## Avoid use of integers because rounding rules do not use fix():
    ## Example: floor (int32 (-44)/10) == -4, floor (int32 (-46)/10) = -5 !!!
        x=single(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:142
    else:
        if (isfloat(x)):
            xint=fix(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:144
            if (any(x != xint)):
                warning('stemleaf: X truncated to integer values')
                x=copy(xint)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:147
        else:
            error('stemleaf: X must be a numeric vector')
    
    if (logical_not(ischar(caption))):
        error('stemleaf: CAPTION must be a character array')
    
    if (nargin == 2):
        stem_step=10
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:158
    else:
        if (isscalar(stem_sz) and stem_sz >= 0 and isreal(stem_sz)):
            stem_sz=fix(stem_sz)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:161
            stem_step=10 ** (stem_sz + 1)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:162
        else:
            error('stemleaf: STEM_SZ must be a real integer >= 0')
    
    ## Note that IEEE 754 states that -+ 0 should compare equal. This has
  ## led to C sort (and therefore Octave) treating them as equal.  Thus,
  ## sort([-1 0 -0 1]) yields [-1 0 -0 1], and sort([-1 -0 0 1])
  ## yields: [-1 -0 0 1].  This means that stem-and-leaf plotting cannot
  ## rely on sort to order the data as needed for display.
  ## This also applies to min()/max() so these routines can't be relied
  ## upon if the max or min is -+ 0.
    
    ## Compute hinges and fences based on ref: EDA pgs. 33 and 44.
  ## Note that these outlier estimates are meant to be "distribution free".
    
    nx=numel(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:179
    xs=sort(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:180
    
    mdidx=fix((nx + 1) / 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:181
    
    hlidx=fix((mdidx + 1) / 2)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:182
    
    huidx=fix(nx + 1 - hlidx)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:183
    
    md=xs[mdidx]
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:184
    
    hl=xs[hlidx]
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:185
    
    hu=xs[huidx]
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:186
    
    h_spread=hu - hl
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:187
    
    step=fix(dot(1.5,h_spread))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:188
    
    i_fence_l=hl - step
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:189
    
    o_fence_l=hl - dot(2,step)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:190
    
    i_fence_h=hu + step
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:191
    o_fence_h=hu + dot(2,step)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:192
    n_out_l=sum(x < i_fence_l) - sum(x < o_fence_l)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:193
    n_out_h=sum(x > i_fence_h) - sum(x > o_fence_h)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:194
    n_far_l=sum(x < o_fence_l)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:195
    n_far_h=sum(x > o_fence_h)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:196
    
    plot_out=sprintf('       Data: %s',caption)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:199
    plot_out=matlabarray(cat([plot_out],[sprintf(' ')]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:200
    plot_out=matlabarray(cat([plot_out],[sprintf('         Fenced Letter Display')]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:201
    plot_out=matlabarray(cat([plot_out],[sprintf(' ')]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:202
    plot_out=matlabarray(cat([plot_out],[sprintf('     #%3d|___________________',nx)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:203
    plot_out=matlabarray(cat([plot_out],[sprintf('     M%3d|       %5d      |',mdidx,md)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:204
    plot_out=matlabarray(cat([plot_out],[sprintf('     H%3d|%5d        %5d|   %d',hlidx,hl,hu,h_spread)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:205
    plot_out=matlabarray(cat([plot_out],[sprintf('     1   |%5d        %5d|',xs[1],xs[nx])]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:206
    plot_out=matlabarray(cat([plot_out],[sprintf('               _______')]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:207
    plot_out=matlabarray(cat([plot_out],[sprintf('         ______|%5d|_______',step)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:208
    plot_out=matlabarray(cat([plot_out],[sprintf('        f|%5d        %5d|',i_fence_l,i_fence_h)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:209
    plot_out=matlabarray(cat([plot_out],[sprintf('         |%5d        %5d|  out',n_out_l,n_out_h)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:210
    plot_out=matlabarray(cat([plot_out],[sprintf('        F|%5d        %5g|',o_fence_l,o_fence_h)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:211
    plot_out=matlabarray(cat([plot_out],[sprintf('         |%5d        %5d|  far',n_far_l,n_far_h)]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:212
    plot_out=matlabarray(cat([plot_out],[' ']))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:213
    
    min_x=min(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:216
    max_x=max(x)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:217
    if (min_x > 0):
        stems=matlabarray(cat(arange(fix(min(x) / stem_step),(fix(max(x) / stem_step) + 1))))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:219
    else:
        if (max_x < 0):
            stems=matlabarray(cat(arange((fix(min_x / stem_step) - 1),fix(max_x / stem_step))))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:221
        else:
            if (min_x < 0 and max_x > 0):
                stems=matlabarray(cat(arange((fix(min_x / stem_step) - 1),- 0),arange(0,fix(max_x / stem_step) + 1)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:223
            else:
                if (min_x == 0):
                    if (any(x == logical_and(0,signbit(x)))):
                        min_x=- 0
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:227
                    else:
                        min_x=+ 0
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:229
                if (max_x == 0):
                    if (any(x == logical_and(0,logical_not(signbit(x))))):
                        max_x=+ 0
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:234
                    else:
                        max_x=- 0
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:236
                stems=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:239
                if (signbit(min_x)):
                    stems=matlabarray(cat(arange((fix(min_x / stem_step) - 1),- 0)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:241
                if (logical_not(signbit(max_x))):
                    stems=matlabarray(cat(stems,arange(0,fix(max_x / stem_step) + 1)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:244
    
    ## Vectorized version provided by Rik Wehbring (rik@octave.org)
  ## Determine leaves for each stem:
    new_line=1
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:250
    for kx in arange(2,numel(stems)).reshape(-1):
        stem_sign=signbit(stems[kx])
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:253
        if (stems[kx] <= 0):
            idx=(logical_and(logical_and((x <= dot(stems[kx],stem_step)),(x > (dot(stems[kx - 1],stem_step)))),(signbit(x) == stem_sign)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:255
            xlf=abs(x[idx] - dot(stems[kx],stem_step))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:257
        else:
            idx=(logical_and(logical_and((x < dot(stems[kx],stem_step)),(x >= (dot(stems[kx - 1],stem_step)))),(signbit(x) == stem_sign)))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:259
            xlf=abs(x[idx] - dot(stems[kx - 1],stem_step))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:261
        ## Convert leaves to a string
        if (stem_step == 10):
            lf_str=sprintf('%d',xlf)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:265
        else:
            lf_str=''
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:267
            if (logical_not(isempty(xlf))):
                lf_str=sprintf('%d',xlf[1])
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:269
                if (numel(xlf) > 1):
                    lf_str=matlabarray(cat(lf_str,sprintf(',%d',xlf[2:end()])))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:271
        ## Set correct -0
        if (stems[kx] == 0 and signbit(stems[kx])):
            line=sprintf('  -0 | %s',lf_str)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:278
        else:
            if (stems[kx] < 0):
                line=sprintf('%4d | %s',stems[kx],lf_str)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:280
            else:
                if (stems[kx] > 0):
                    line=sprintf('%4d | %s',stems[kx - 1],lf_str)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:282
                else:
                    line=''
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:284
        if (logical_not(isempty(lf_str)) or stems[kx] == 0 or stems[kx - 1] == 0):
            plot_out=matlabarray(cat([plot_out],[line]))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:288
            new_line=1
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:289
        else:
            if (new_line == 1):
                plot_out=matlabarray(cat([plot_out],['     :']))
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:292
                new_line=0
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:293
    
    if (nargout == 0):
        disp(plot_out)
    else:
        plotstr=copy(plot_out)
# /home/lei/octave-4.0.2/scripts/plot/draw/stemleaf.m:302
    
    return plotstr
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ezmeshc (@var{f})
## @deftypefnx {Function File} {} ezmeshc (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {} ezmeshc (@dots{}, @var{dom})
## @deftypefnx {Function File} {} ezmeshc (@dots{}, @var{n})
## @deftypefnx {Function File} {} ezmeshc (@dots{}, "circ")
## @deftypefnx {Function File} {} ezmeshc (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ezmeshc (@dots{})
##
## Plot the mesh and contour lines defined by a function.
##
## @var{f} is a string, inline function, or function handle with two arguments
## defining the function.  By default the plot is over the meshed domain
## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
##
## If three functions are passed, then plot the parametrically defined
## function @code{[@var{fx} (@var{s}, @var{t}), @var{fy} (@var{s}, @var{t}),
## @var{fz} (@var{s}, @var{t})]}.
##
## If @var{dom} is a two element vector, it represents the minimum and maximum
## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
## then the minimum and maximum values are @code{[xmin xmax ymin ymax]}.
##
## @var{n} is a scalar defining the number of points to use in each dimension.
##
## If the argument @qcode{"circ"} is given, then the function is plotted over
## a disk centered on the middle of the domain @var{dom}.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a 2-element vector with a graphics
## handle for the created mesh plot and a second handle for the created contour
## plot.
##
## Example: 2-argument function
##
## @example
## @group
## f = @@(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
## ezmeshc (f, [-3, 3]);
## @end group
## @end example
##
## @seealso{meshc, ezmesh, ezplot, ezsurf, ezsurfc, hidden}
## @end deftypefn
    
    
@function
def ezmeshc(varargin=None,*args,**kwargs):
    varargin = ezmeshc.varargin
    nargin = ezmeshc.nargin

    htmp,needusage=__ezplot__('meshc',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezmeshc.m:68
    if (needusage):
        print_usage()
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/draw/ezmeshc.m:75
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} __clabel__ (@var{c}, @var{v}, @var{hparent}, @var{label_spacing}, @var{z}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __clabel__(c=None,v=None,hparent=None,label_spacing=None,z=None,varargin=None,*args,**kwargs):
    varargin = __clabel__.varargin
    nargin = __clabel__.nargin

    hax=ancestor(hparent,'axes')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:26
    units=get(hax,'units')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:27
    set(hax,'units','points')
    axpos=get(hax,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:29
    set(hax,'units',units)
    lims=axis()
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:31
    xspacing=axpos[3] / (lims[2] - lims[1])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:32
    yspacing=axpos[4] / (lims[4] - lims[3])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:33
    if (isscalar(hparent) and ishandle(hparent) and strcmp(get(hparent,'type'),'hggroup')):
        x=get(hparent,'xdata')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:37
        xmin=min(ravel(x))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:38
        xmax=max(ravel(x))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:39
        y=get(hparent,'ydata')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:40
        ymin=min(ravel(y))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:41
        ymax=max(ravel(y))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:42
    else:
        xmin=xmax=ymin=ymax=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:44
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:44
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:44
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:44
        i=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:45
        while (i < length(c)):

            clen=c[2,i]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:47
            data=c[:,i + (arange(1,clen))]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:48
            xmin=min(cat(xmin,data[1,:]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:50
            xmax=max(cat(xmax,data[1,:]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:51
            ymin=min(cat(ymin,data[2,:]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:52
            ymax=max(cat(ymax,data[2,:]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:53
            i += clen + 1

    
    ## Decode contourc output format and place labels.
    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:60
    i=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:61
    while (i < length(c)):

        clev=c[1,i]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:63
        clen=c[2,i]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:64
        if (logical_not(isempty(v)) and logical_not(any(v == clev))):
            i += clen + 1
            continue
        p=bsxfun(times,c[:,i + (arange(1,clen))],cat([xspacing],[yspacing]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:71
        d=sqrt(sumsq(diff(p,1,2)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:72
        cumd=cumsum(d)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:73
        td=cumd[end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:74
        ntag=ceil(td / label_spacing)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:75
        if (all(c[:,i + 1] == c[:,i + clen])):
            ## Closed contour
      ## FIXME: This spreads the tags uniformly around the contour which
      ## looks nice, but it does not respect the label_spacing attribute.
      ## Should we follow user input, which can result in two labels being
      ## quite close to each other?
            spacing=td / ntag
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:83
            pos=spacing / 2 + dot(spacing,cat(arange(0,ntag - 1)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:84
        else:
            ## Open contour
            pos=zeros(1,ntag)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:87
            pos[1]=(td - dot(label_spacing,(ntag - 1))) / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:88
            pos[2:ntag]=pos[1] + dot(label_spacing,cat(arange(1,ntag - 1)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:89
        tlabel=sprintf('%.5g',clev)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:92
        for tagpos in pos.reshape(-1):
            j=find(cumd > tagpos,1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:96
            if (isempty(j)):
                j=copy(clen)
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:98
            tpos=sum(c[:,i + j - 1:i + j],2) / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:100
            if (tpos[1] != xmin and tpos[1] != xmax and tpos[2] != ymin and tpos[2] != ymax):
                trot=dot(180 / pi,atan2(diff(c[2,i + j - 1:i + j]),diff(c[1,i + j - 1:i + j])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:104
                if (abs(trot) > 90):
                    trot += 180
                if (ischar(z)):
                    ht=text(tpos[1],tpos[2],clev,tlabel,'rotation',trot,'horizontalalignment','center','userdata',clev,'parent',hparent,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:110
                else:
                    if (logical_not(isempty(z))):
                        ht=text(tpos[1],tpos[2],z,tlabel,'rotation',trot,'horizontalalignment','center','userdata',clev,'parent',hparent,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:114
                    else:
                        ht=text(tpos[1],tpos[2],tlabel,'rotation',trot,'horizontalalignment','center','userdata',clev,'parent',hparent,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:118
                h=matlabarray(cat([h],[ht]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__clabel__.m:122
        i += clen + 1

    
    return h
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} gtext (@var{s})
## @deftypefnx {Function File} {} gtext (@{@var{s1}, @var{s2}, @dots{}@})
## @deftypefnx {Function File} {} gtext (@{@var{s1}; @var{s2}; @dots{}@})
## @deftypefnx {Function File} {} gtext (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} gtext (@dots{})
## Place text on the current figure using the mouse.
##
## The text is defined by the string @var{s}.  If @var{s} is a cell string
## organized as a row vector then each string of the cell array is written to a
## separate line.  If @var{s} is organized as a column vector then one string
## element of the cell array is placed for every mouse click.
##
## Optional property/value pairs are passed directly to the underlying text
## objects.
##
## The optional return value @var{h} is a graphics handle to the created
## text object(s).
## @seealso{ginput, text}
## @end deftypefn
    
    
@function
def gtext(s=None,varargin=None,*args,**kwargs):
    varargin = gtext.varargin
    nargin = gtext.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not((ischar(s) or iscellstr(s)))):
        error('gtext: S must be a string or cell array of strings')
    
    htmp=- 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:50
    if (logical_not(isempty(s))):
        if (ischar(s) or isrow(s)):
            x,y=ginput(1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:53
            htmp=text(x,y,s,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:54
        else:
            for i in arange(1,numel(s)).reshape(-1):
                x,y=ginput(1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:57
                htmp=text(x,y,s[i],varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:58
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/gtext.m:64
    
    return h
    
if __name__ == '__main__':
    pass
    
    ## Remove from test statistics.  No real tests possible.
    
    ## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} text (@var{x}, @var{y}, @var{string})
## @deftypefnx {Function File} {} text (@var{x}, @var{y}, @var{z}, @var{string})
## @deftypefnx {Function File} {} text (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} text (@dots{})
## Create a text object with text @var{string} at position @var{x}, @var{y},
## (@var{z}) on the current axes.
##
## Multiple locations can be specified if @var{x}, @var{y}, (@var{z}) are
## vectors.  Multiple strings can be specified with a character matrix or
## a cell array of strings.
##
## Optional property/value pairs may be used to control the appearance of the
## text.
##
## The optional return value @var{h} is a vector of graphics handles to the
## created text objects.
## @seealso{gtext, title, xlabel, ylabel, zlabel}
## @end deftypefn
    
    ## Author: jwe
    
    ## Note: The following code is rigged for Matlab compatibility and is
##       full of hidden assumptions.  Be very wary when modifying.
    
    
@function
def text(varargin=None,*args,**kwargs):
    varargin = text.varargin
    nargin = text.nargin

    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:46
    offset=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:47
    if (nargs > 2 and isnumeric(varargin[1]) and isnumeric(varargin[2])):
        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:50
        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:51
        if (nargin > 3 and isnumeric(varargin[3])):
            z=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:54
            offset=4
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:55
        else:
            z=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:57
            offset=3
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:58
        string=varargin[offset]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:61
        varargin[1:offset]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:62
        nx=numel(x)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:64
        ny=numel(y)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:65
        nz=numel(z)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:66
        if (ischar(string)):
            do_keyword_repl=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:69
            nt=rows(string)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:70
            if (nx == 1 and nt == 1):
                ## Single text object with one line
                string=cellarray([string])
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:73
            else:
                if (nx == 1 and nt > 1):
                    ## Single text object with multiple lines
        ## FIXME: "default" or "factory" as first row
        ##        should be escaped to "\default" or "\factory"
        ##        Other rows do not require escaping.
                    do_keyword_repl=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:79
                    string=cellarray([string])
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:80
                else:
                    if (nx > 1 and nt == nx):
                        ## Mutiple text objects with different strings
                        string=cellstr(string)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:83
                    else:
                        ## Mutiple text objects with same string
                        string=repmat(cellarray([string]),cat(nx,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:86
                        nt=copy(nx)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:87
            ## Escape special keywords
            if (do_keyword_repl):
                string=regexprep(string,'^(default|factory)$','\\\\$1')
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:92
        else:
            if (iscell(string)):
                nt=numel(string)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:97
                if (nx == 1):
                    ## Single text object with one or more lines
                    string=cellarray([string])
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:100
                    nt=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:101
                else:
                    if (nx > 1 and nt == nx):
                        ## Mutiple text objects with different strings
                        pass
                    else:
                        ## Mutiple text objects with same string
                        string=repmat(cellarray([string]),cat(nx,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:106
                        nt=copy(nx)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:107
            else:
                error('text: STRING must be a character string or cell array of character strings')
    else:
        x=y=z=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:116
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:116
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:116
        nx=ny=nz=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:117
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:117
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:117
        string=cellarray([''])
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:118
        nt=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:119
    
    ## Any remaining inputs must occur as PROPERTY/VALUE pairs
    if (rem(numel(varargin),2) != 0):
        print_usage()
    
    ## Get axis argument which may be in a 'parent' PROP/VAL pair
    hax,varargin=__plt_get_axis_arg__('text',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:128
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:131
    else:
        hax=hax[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:133
    
    ## Position argument may alse be in PROP/VAL pair
    idx=find(strcmpi(varargin,'position'),1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:137
    if (idx):
        pos=varargin[idx + 1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:139
        varargin[idx:idx + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:140
    else:
        pos=matlabarray(cat(ravel(x),ravel(y),ravel(z)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:142
    
    if (nx == ny and nx == nz and (nt == nx or nt == 1 or nx == 1)):
        htmp=zeros(nt,1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:146
        if (nx == 1):
            htmp=__go_text__(hax,'string',string[1],varargin[:],'position',pos)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:148
        else:
            if (nx == nt):
                for n in arange(1,nt).reshape(-1):
                    htmp[n]=__go_text__(hax,'string',string[n],varargin[:],'position',pos[n,:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:154
                __request_drawnow__()
            else:
                error('text: dimension mismatch for coordinates and STRING')
    else:
        if (nt == nx or nt == 1 or nx == 1):
            error('text: dimension mismatch for coordinates')
        else:
            error('text: dimension mismatch between coordinates and strings')
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/text.m:169
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} specular (@var{sx}, @var{sy}, @var{sz}, @var{lv}, @var{vv})
## @deftypefnx {Function File} {} specular (@var{sx}, @var{sy}, @var{sz}, @var{lv}, @var{vv}, @var{se})
## Calculate the specular reflection strength of a surface defined by the
## normal vector elements @var{sx}, @var{sy}, @var{sz} using Phong's
## approximation.
##
## The light source location and viewer location vectors are specified using
## parameters @var{lv} and @var{vv} respectively.  The location vectors can
## given as 2-element vectors [azimuth, elevation] in degrees or as 3-element
## vectors [x, y, z].
##
## An optional sixth argument specifies the specular exponent (spread) @var{se}.
## If not given, @var{se} defaults to 10.
## @seealso{diffuse, surfl}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def specular(sx=None,sy=None,sz=None,lv=None,vv=None,se=None,*args,**kwargs):
    varargin = specular.varargin
    nargin = specular.nargin

    if (nargin < 5 or nargin > 6):
        print_usage()
    
    ## Check normal vectors
    if (logical_not(size_equal(sx,sy,sz))):
        error('specular: SX, SY, and SZ must be the same size')
    
    ## Check light vector (lv) argument
    if (logical_not(isvector(lv)) or length(lv) < 2 or length(lv) > 3):
        error('specular: light vector LV must be a 2- or 3-element vector')
    else:
        if (length(lv) == 2):
            lv[1],lv[2],lv[3]=sph2cart(dot(lv[1],pi) / 180,dot(lv[2],pi) / 180,1.0,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:53
    
    ## Check view vector (vv) argument
    if (logical_not(isvector(vv)) or length(vv) < 2 or length(lv) > 3):
        error('specular: view vector VV must be a 2- or 3-element vector')
    else:
        if (length(vv) == 2):
            vv[1],vv[2],vv[3]=sph2cart(dot(vv[1],pi) / 180,dot(vv[2],pi) / 180,1.0,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:60
    
    ## Check specular exponent (se) argument
    if (nargin < 6):
        se=10
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:65
    else:
        if (logical_not((isnumeric(se) and numel(se) == 1 and se > 0))):
            error('specular: exponent SE must be a positive scalar')
    
    ## Normalize view and light vectors
    if (sum(abs(lv)) > 0):
        lv /= norm(lv)
    
    if (sum(abs(vv)) > 0):
        vv /= norm(vv)
    
    ## Calculate normal vector lengths and dot-products
    ns=sqrt(sx ** 2 + sy ** 2 + sz ** 2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:79
    l_dot_n=(dot(sx,lv[1]) + dot(sy,lv[2]) + dot(sz,lv[3])) / ns
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:80
    v_dot_n=(dot(sx,vv[1]) + dot(sy,vv[2]) + dot(sz,vv[3])) / ns
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:81
    
    retval=multiply(dot(2,l_dot_n),v_dot_n) - dot(lv,vv)
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:84
    
    retval[l_dot_n < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:87
    
    retval[retval < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:90
    retval=retval ** se
# /home/lei/octave-4.0.2/scripts/plot/appearance/specular.m:91
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{hplots}, @var{strings}] =} __getlegenddata__ (@var{h})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __getlegenddata__(hlegend=None,*args,**kwargs):
    varargin = __getlegenddata__.varargin
    nargin = __getlegenddata__.nargin

    hplots=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:26
    text_strings=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:27
    ca=getfield(get(hlegend,'userdata'),'handle')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:28
    if (numel(ca) == 1):
        kids=get(ca,'children')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:30
    else:
        kids=cell2mat(get(ca,'children'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:32
    
    for i in arange(numel(kids),1,- 1).reshape(-1):
        typ=get(kids[i],'type')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:36
        if (any(strcmp(typ,cellarray(['line','patch','surface','hggroup'])))):
            if (strcmp(typ,'hggroup')):
                hgkids=get(kids[i],'children')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:39
                for j in arange(1,length(hgkids)).reshape(-1):
                    try:
                        dname=get(hgkids[j],'DisplayName')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:42
                        if (logical_not(isempty(dname))):
                            hplots[end() + 1]=hgkids[j]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:44
                            text_strings[end() + 1]=dname
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:45
                            break
                    finally:
                        pass
            else:
                dname=get(kids[i],'DisplayName')
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:51
                if (logical_not(isempty(dname))):
                    hplots[end() + 1]=kids[i]
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:53
                    text_strings[end() + 1]=dname
# /home/lei/octave-4.0.2/scripts/plot/appearance/__getlegenddata__.m:54
    
    return hplots,text_strings
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ylabel (@var{string})
## @deftypefnx {Function File} {} ylabel (@var{string}, @var{property}, @var{val}, @dots{})
## @deftypefnx {Function File} {} ylabel (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} ylabel (@dots{})
## Specify the string used to label the y-axis of the current axis.
##
## If @var{hax} is specified then label the axis defined by @var{hax}.
##
## An optional list of @var{property}/@var{value} pairs can be used to change
## the properties of the created text label.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created text
## object.
## @seealso{xlabel, zlabel, datetick, title, text}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def ylabel(varargin=None,*args,**kwargs):
    varargin = ylabel.varargin
    nargin = ylabel.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('ylabel',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylabel.m:43
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylabel.m:46
    
    if (rem(nargin,2) != 1):
        print_usage()
    
    htmp=__axis_label__(hax,'ylabel',varargin[1],'color',get(hax,'ycolor'),varargin[2:end()])
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylabel.m:53
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylabel.m:57
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} box
## @deftypefnx {Command} {} box on
## @deftypefnx {Command} {} box off
## @deftypefnx {Function File} {} box (@var{hax}, @dots{})
## Control display of the axis border.
##
## The argument may be either @qcode{"on"} or @qcode{"off"}.  If it is
## omitted, the current box state is toggled.
##
## If the first argument @var{hax} is an axes handle, then operate on this
## axis rather than the current axes returned by @code{gca}.
## @seealso{axis, grid}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def box(varargin=None,*args,**kwargs):
    varargin = box.varargin
    nargin = box.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('box',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:38
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:41
    
    if (nargs == 0):
        box_state=get(hax,'box')
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:45
        if (strcmp(box_state,'on')):
            box_state='off'
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:47
        else:
            box_state='on'
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:49
    else:
        if (nargs == 1):
            state=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:52
            if (ischar(state)):
                if (strcmpi(state,'off')):
                    box_state='off'
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:55
                else:
                    if (strcmpi(state,'on')):
                        box_state='on'
# /home/lei/octave-4.0.2/scripts/plot/appearance/box.m:57
                    else:
                        error('box: argument must be "on" or "off"')
            else:
                error('box: argument must be "on" or "off"')
        else:
            print_usage()
    
    set(hax,'box',box_state)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} clabel (@var{c}, @var{h})
## @deftypefnx {Function File} {} clabel (@var{c}, @var{h}, @var{v})
## @deftypefnx {Function File} {} clabel (@var{c}, @var{h}, "manual")
## @deftypefnx {Function File} {} clabel (@var{c})
## @deftypefnx {Function File} {} clabel (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{h} =} clabel (@dots{})
## Add labels to the contours of a contour plot.
##
## The contour levels are specified by the contour matrix @var{c} which is
## returned by @code{contour}, @code{contourc}, @code{contourf}, and
## @code{contour3}.  Contour labels are rotated to match the local line
## orientation and centered on the line.  The position of labels along the
## contour line is chosen randomly.
##
## If the argument @var{h} is a handle to a contour group object, then label
## this plot rather than the one in the current axes returned by @code{gca}.
##
## By default, all contours are labeled.  However, the contours to label can be
## specified by the vector @var{v}.  If the @qcode{"manual"} argument is
## given then the contours to label can be selected with the mouse.
##
## Additional property/value pairs that are valid properties of text objects
## can be given and are passed to the underlying text objects.  Moreover,
## the contour group property @qcode{"LabelSpacing"} is available which
## determines the spacing between labels on a contour to be specified.  The
## default is 144 points, or 2 inches.
##
## The optional return value @var{h} is a vector of graphics handles to
## the text objects representing each label.
## The @qcode{"userdata"} property of the text objects contains the numerical
## value of the contour label.
##
## An example of the use of @code{clabel} is
##
## @example
## @group
## [c, h] = contour (peaks (), -4 : 6);
## clabel (c, h, -4:2:6, "fontsize", 12);
## @end group
## @end example
##
## @seealso{contour, contourf, contour3, meshc, surfc, text}
## @end deftypefn
    
    
@function
def clabel(c=None,varargin=None,*args,**kwargs):
    varargin = clabel.varargin
    nargin = clabel.nargin

    have_hg=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:66
    have_labelspacing=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:67
    label_spacing=144
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:68
    
    if (nargin < 1):
        print_usage()
    else:
        if (nargin == 1):
            hparent=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:73
        else:
            arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:75
            if (isscalar(arg) and ishandle(arg) and strcmp(get(arg,'type'),'hggroup')):
                try:
                    get(arg,'contourmatrix')
                finally:
                    pass
                have_hg=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:83
                hg=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:84
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:85
            else:
                hparent=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:87
    
    if (length(varargin) > 0 and isnumeric(varargin[1])):
        v=ravel(varargin[1])
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:92
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:93
    else:
        v=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:95
    
    idx=strcmpi(varargin[1:2:end()],'manual')
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:98
    if (any(idx)):
        error('clabel: "manual" contour mode is not supported')
    
    idx=find(strcmpi(varargin[1:2:end()],'labelspacing'),1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:103
    if (logical_not(isempty(idx))):
        have_labelspacing=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:105
        label_spacing=varargin[dot(2,idx)]
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:106
        varargin[dot(2,idx) + (arange(- 1,0))]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:107
    
    if (have_hg):
        if (logical_not(isempty(v))):
            if (have_labelspacing):
                set(hg,'textlistmode','manual','textlist',v,'labelspacing',label_spacing,'showtext','on')
            else:
                set(hg,'textlistmode','manual','textlist',v,'showtext','on')
        else:
            if (have_labelspacing):
                set(hg,'showtext','on','labelspacing',label_spacing)
            else:
                set(hg,'showtext','on')
        htmp=findobj(hg,'type','text')
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:125
        if (logical_not(isempty(varargin))):
            set(htmp,varargin[:])
    else:
        htmp=__clabel__(c,v,hparent,label_spacing,[],varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:130
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/clabel.m:134
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} datetick ()
## @deftypefnx {Function File} {} datetick (@var{form})
## @deftypefnx {Function File} {} datetick (@var{axis}, @var{form})
## @deftypefnx {Function File} {} datetick (@dots{}, "keeplimits")
## @deftypefnx {Function File} {} datetick (@dots{}, "keepticks")
## @deftypefnx {Function File} {} datetick (@var{hax}, @dots{})
## Add date formatted tick labels to an axis.
##
## The axis to apply the ticks to is determined by @var{axis} which can take
## the values @qcode{"x"}, @qcode{"y"}, or @qcode{"z"}.  The default value is
## @qcode{"x"}.
##
## The formatting of the labels is determined by the variable @var{form}, which
## can either be a string or positive integer that @code{datestr} accepts.
## @seealso{datenum, datestr}
## @end deftypefn
    
    
@function
def datetick(varargin=None,*args,**kwargs):
    varargin = datetick.varargin
    nargin = datetick.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('datetick',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:39
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:41
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:43
    
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:46
    
    try:
        ## FIXME: This will bring the axes to the top of the stack.
    ##        This may not be desirable if there are multiple axes objects,
    ##        such as can occur with plotyy.
        axes(hax)
        __datetick__(varargin[:])
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Remove from test statistics.  No real tests possible.
    
    
@function
def __datetick__(varargin=None,*args,**kwargs):
    varargin = __datetick__.varargin
    nargin = __datetick__.nargin

    keeplimits=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:92
    idx=strcmpi(varargin,'keeplimits')
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:93
    if (any(idx)):
        keeplimits=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:95
        varargin=varargin[logical_not(idx)]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:96
    
    keepticks=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:98
    idx=strcmpi(varargin,'keepticks')
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:99
    if (any(idx)):
        keepticks=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:101
        varargin=varargin[logical_not(idx)]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:102
    
    nargin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:105
    form=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:106
    ax='x'
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:107
    if (nargin != 0):
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:110
        if (ischar(arg) and any(strcmpi(arg,cellarray(['x','y','z'])))):
            ax=tolower(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:112
            if (nargin > 1):
                form=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:114
                varargin[1:2]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:115
            else:
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:117
        else:
            form=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:120
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:121
    
    ## Don't publish the existence of this variable for use with dateaxis
    if (length(varargin) > 0):
        startdate=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:127
    else:
        startdate=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:129
    
    if (logical_not(isempty(form))):
        if (isnumeric(form)):
            if (logical_not(isscalar(form)) or form < 0 or form != fix(form)):
                error('datetick: expecting FORM argument to be a positive integer')
        else:
            if (logical_not(ischar(form))):
                error('datetick: expecting valid date format string')
    
    if (keepticks):
        ticks=get(gca(),cat(ax,'tick'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:143
    else:
        ## Need to do our own axis tick position calculation as
    ## year, etc, don't fallback on nice datenum values.
        objs=findall(gca())
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:147
        xmax=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:148
        xmin=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:149
        for i in arange(1,length(objs)).reshape(-1):
            fld=get(objs[i])
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:151
            if (isfield(fld,cat(ax,'data'))):
                xdata=ravel(getfield(fld,cat(ax,'data')))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:153
                xmin=min(xmin,min(xdata))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:154
                xmax=max(xmax,max(xdata))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:155
        if (isnan(xmin) or isnan(xmax)):
            xmin=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:160
            xmax=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:161
        else:
            if (xmin == xmax):
                xmax=xmin + 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:163
        N=3
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:166
        if (xmax - xmin < N):
            ## Day scale or less
            if (xmax - xmin < N / 24 / 60 / 60):
                scl=1 / 24 / 60 / 60
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:170
            else:
                if (xmax - xmin < N / 24 / 60):
                    scl=1 / 24 / 60
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:172
                else:
                    scl=1 / 24
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:174
            sep=__calc_tick_sep__(xmin / scl,xmax / scl)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:176
            xmin=dot(sep,floor(xmin / scl / sep))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:177
            xmax=dot(sep,ceil(xmax / scl / sep))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:178
            nticks=(xmax - xmin) / sep + 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:179
            xmin *= scl
            xmax *= scl
        else:
            ymin,mmin,dmin=datevec(xmin,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:183
            ymax,mmax,dmax=datevec(xmax,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:184
            minyear=ymin + (mmin - 1) / 12 + (dmin - 1) / 12 / 30
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:185
            maxyear=ymax + (mmax - 1) / 12 + (dmax - 1) / 12 / 30
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:186
            minmonth=mmin + (dmin - 1) / 30
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:187
            maxmonth=dot((ymax - ymin),12) + mmax + (dmax - 1) / 30
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:188
            if (maxmonth - minmonth < N):
                sep=__calc_tick_sep__(xmin,xmax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:191
                xmin=dot(sep,floor(xmin / sep))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:192
                xmax=dot(sep,ceil(xmax / sep))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:193
                nticks=(xmax - xmin) / sep + 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:194
            else:
                if (maxyear - minyear < N):
                    sep=__calc_tick_sep__(minmonth,maxmonth)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:196
                    xmin=datenum(ymin,dot(sep,floor(minmonth / sep)),1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:197
                    xmax=datenum(ymax,dot(sep,ceil(maxmonth / sep)),1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:198
                    nticks=ceil(maxmonth / sep) - floor(minmonth / sep) + 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:199
                else:
                    sep=__calc_tick_sep__(minyear,maxyear)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:201
                    xmin=datenum(dot(sep,floor(minyear / sep)),1,1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:202
                    xmax=datenum(dot(sep,ceil(maxyear / sep)),1,1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:203
                    nticks=ceil(maxyear / sep) - floor(minyear / sep) + 1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:204
        ticks=xmin + dot(cat(arange(0,nticks - 1)) / (nticks - 1),(xmax - xmin))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:207
    
    if (isempty(form)):
        r=max(ticks) - min(ticks)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:211
        if (r < 10 / 60 / 24):
            ## minutes and seconds
            form=13
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:214
        else:
            if (r < 2):
                ## hours
                form=15
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:217
            else:
                if (r < 15):
                    ## days
                    form=8
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:220
                else:
                    if (r < 365):
                        ## FIXME: FORM should be 19 for European users who use dd/mm
      ## instead of mm/dd.  How can that be determined automatically?
      ## months
                        form=6
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:225
                    else:
                        if (r < dot(90,12)):
                            ## quarters
                            form=27
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:228
                        else:
                            ## years
                            form=10
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:231
    
    if (length(ticks) == 6):
        ## Careful that its not treated as a datevec
        if (logical_not(isempty(startdate))):
            sticks=strvcat(datestr(ticks[1:end() - 1] - ticks[1] + startdate,form),datestr(ticks[end()] - ticks[1] + startdate,form))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:238
        else:
            sticks=strvcat(datestr(ticks[1:end() - 1],form),datestr(ticks[end()],form))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:241
    else:
        if (logical_not(isempty(startdate))):
            sticks=datestr(ticks - ticks[1] + startdate,form)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:246
        else:
            sticks=datestr(ticks,form)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:248
    
    sticks=mat2cell(sticks,ones(rows(sticks),1),columns(sticks))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:252
    if (keepticks):
        if (keeplimits):
            set(gca(),cat(ax,'ticklabel'),sticks)
        else:
            set(gca(),cat(ax,'ticklabel'),sticks,cat(ax,'lim'),cat(min(ticks),max(ticks)))
    else:
        if (keeplimits):
            set(gca(),cat(ax,'tick'),ticks,cat(ax,'ticklabel'),sticks)
        else:
            set(gca(),cat(ax,'tick'),ticks,cat(ax,'ticklabel'),sticks,cat(ax,'lim'),cat(min(ticks),max(ticks)))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __magform__(x=None,*args,**kwargs):
    varargin = __magform__.varargin
    nargin = __magform__.nargin

    if (x == 0):
        a=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:273
        b=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:274
    else:
        l=log10(abs(x))
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:276
        r=rem(l,1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:277
        a=10 ** r
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:278
        b=fix(l - r)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:279
        if (a < 1):
            a *= 10
            b -= 1
        if (x < 0):
            a=- a
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:285
    
    return a,b
    
if __name__ == '__main__':
    pass
    
    ## A translation from Tom Holoryd's python code at
## http://kurage.nimh.nih.gov/tomh/tics.py
    
@function
def __calc_tick_sep__(lo=None,hi=None,*args,**kwargs):
    varargin = __calc_tick_sep__.varargin
    nargin = __calc_tick_sep__.nargin

    
    
    
    ticint=5
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:297
    
    ## SCALE3 for Determination of Scales on Computer Generated
  ## Plots", Communications of the ACM, 10 (1973), 639-640.
  ## Also cited as ACM Algorithm 463.
    
    a,b=__magform__((hi - lo) / ticint,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:304
    if (a < sqrt_2):
        x=1
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:307
    else:
        if (a < sqrt_10):
            x=2
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:309
        else:
            if (a < sqrt_50):
                x=5
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:311
            else:
                x=10
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:313
    
    sep=dot(x,10 ** b)
# /home/lei/octave-4.0.2/scripts/plot/appearance/datetick.m:315
    return sep
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} xlabel (@var{string})
## @deftypefnx {Function File} {} xlabel (@var{string}, @var{property}, @var{val}, @dots{})
## @deftypefnx {Function File} {} xlabel (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} xlabel (@dots{})
## Specify the string used to label the x-axis of the current axis.
##
## An optional list of @var{property}/@var{value} pairs can be used to change
## the properties of the created text label.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created text
## object.
## @seealso{ylabel, zlabel, datetick, title, text}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def xlabel(varargin=None,*args,**kwargs):
    varargin = xlabel.varargin
    nargin = xlabel.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('xlabel',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlabel.m:41
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlabel.m:44
    
    if (rem(nargin,2) != 1):
        print_usage()
    
    htmp=__axis_label__(hax,'xlabel',varargin[1],'color',get(hax,'xcolor'),varargin[2:end()])
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlabel.m:51
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlabel.m:55
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} caxis ([cmin cmax])
## @deftypefnx {Function File} {} caxis ("auto")
## @deftypefnx {Function File} {} caxis ("manual")
## @deftypefnx {Function File} {} caxis (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{limits} =} caxis ()
## Query or set color axis limits for plots.
##
## The limits argument should be a 2-element vector specifying the lower and
## upper limits to assign to the first and last value in the colormap.  Data
## values outside this range are clamped to the first and last colormap
## entries.
##
## If the @qcode{"auto"} option is given then automatic colormap limits are
## applied.  The automatic algorithm sets @var{cmin} to the minimum data value
## and @var{cmax} to the maximum data value.  If @qcode{"manual"} is specified
## then the @qcode{"climmode"} property is set to @qcode{"manual"} and the
## numeric values in the @qcode{"clim"} property are used for limits.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## Called without arguments the current color axis limits are returned.
## @seealso{colormap}
## @end deftypefn
    
    
@function
def caxis(varargin=None,*args,**kwargs):
    varargin = caxis.varargin
    nargin = caxis.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('caxis',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:47
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:49
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:51
    
    try:
        if (isempty(hax)):
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:55
        if (nargin == 0):
            limits=__caxis__(hax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:58
        else:
            __caxis__(hax,varargin[:])
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return limits
    
if __name__ == '__main__':
    pass
    
    
@function
def __caxis__(ca=None,ax=None,varargin=None,*args,**kwargs):
    varargin = __caxis__.varargin
    nargin = __caxis__.nargin

    if (nargin == 1):
        limits=get(ca,'clim')
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:73
    else:
        if (ischar(ax)):
            if (strcmpi(ax,'auto')):
                set(ca,'climmode','auto')
            else:
                if (strcmpi(ax,'manual')):
                    set(ca,'climmode','manual')
        else:
            if (isvector(ax)):
                len_=length(ax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/caxis.m:81
                if (len_ != 2):
                    error('caxis: expecting vector with 2 elements')
                set(ca,'clim',cat(ax[1],ax[2]))
            else:
                error('caxis: expecting no args, a string, or a 2 element vector')
    
    ## FIXME: Why should it be possible to call __caxis__ recursively?
    if (nargin > 2):
        __caxis__(ca,varargin[:]).T
    
    return limits
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2015 Pantxo Diribarne
##
##   This program is free software; you can redistribute it and/or modify
##   it under the terms of the GNU General Public License as published by
##   the Free Software Foundation; either version 3 of the License, or
##   (at your option) any later version.
##
##   This program is distributed in the hope that it will be useful,
##   but WITHOUT ANY WARRANTY; without even the implied warranty of
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##   GNU General Public License for more details.
##
##   You should have received a copy of the GNU General Public License
##   along with Octave; see the file COPYING.  If not, see
##   <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} annotation (@var{type})
## @deftypefnx {Function File} {} annotation ("line", @var{x}, @var{y})
## @deftypefnx {Function File} {} annotation ("arrow", @var{x}, @var{y})
## @deftypefnx {Function File} {} annotation ("doublearrow", @var{x}, @var{y})
## @deftypefnx {Function File} {} annotation ("textarrow", @var{x}, @var{y})
## @deftypefnx {Function File} {} annotation ("textbox", @var{pos})
## @deftypefnx {Function File} {} annotation ("rectangle", @var{pos})
## @deftypefnx {Function File} {} annotation ("ellipse", @var{pos})
## @deftypefnx {Function File} {} annotation (@dots{}, @var{prop}, @var{val})
## @deftypefnx {Function File} {} annotation (@var{hf}, @dots{})
## @deftypefnx {Function File} {@var{h} =} annotation (@dots{})
## Draw annotations to emphasize parts of a figure.
##
## You may build a default annotation by specifying only the @var{type}
## of the annotation.
##
## Otherwise you can select the type of annotation and then set its position
## using either @var{x} and @var{y} coordinates for line-based annotations or a
## position vector @var{pos} for others.  In either case, coordinates are
## interpreted using the @qcode{"units"} property of the annotation object.
## The default is @qcode{"normalized"}, which means the lower left hand corner
## of the figure has coordinates @samp{[0 0]} and the upper right hand corner
## @samp{[1 1]}.
##
## If the first argument @var{hf} is a figure handle, then plot into this
## figure, rather than the current figure returned by @code{gcf}.
##
## Further arguments can be provided in the form of @var{prop}/@var{val} pairs
## to customize the annotation appearance.
##
## The optional return value @var{h} is a graphics handle to the created
## annotation object.  This can be used with the @code{set} function to
## customize an existing annotation object.
##
## All annotation objects share two properties:
##
## @itemize
## @item @qcode{"units"}: the units in which coordinates are interpreted.@*
## Its value may be one of @qcode{"centimeters"} | @qcode{"characters"} |
## @qcode{"inches"} | @qcode{"@{normalized@}"} | @qcode{"pixels"} |
## @qcode{"points"}.
##
## @item @qcode{"position"}: a four-element vector [x0 y0 width height].@*
## The vector specifies the coordinates (x0,y0) of the origin of the annotation
## object, its width, and its height.  The width and height may be negative,
## depending on the orientation of the object.
##
## @end itemize
##
## Valid annotation types and their specific properties are described
## below:
##
## @table @asis
## @item @qcode{"line"}
## Constructs a line.  @var{x} and @var{y} must be two-element vectors
## specifying the x and y coordinates of the two ends of the line.
##
## The line can be customized using @qcode{"linewidth"}, @qcode{"linestyle"},
## and @qcode{"color"} properties the same way as for @code{line} objects.
##
## @item @qcode{"arrow"}
## Construct an arrow.  The second point in vectors @var{x} and @var{y}
## specifies the arrowhead coordinates.
##
## Besides line properties, the arrowhead can be customized using
## @qcode{"headlength"}, @qcode{"headwidth"}, and @qcode{"headstyle"}
## properties.  Supported values for @qcode{"headstyle"} property are:
## [@qcode{"diamond"} | @qcode{"ellipse"} | @qcode{"plain"} |
## @qcode{"rectangle"} | @qcode{"vback1"} | @qcode{"@{vback2@}"} |
## @qcode{"vback3"}]
##
## @item @qcode{"doublearrow"}
## Construct a double arrow.  Vectors @var{x} and @var{y} specify the
## arrowhead coordinates.
##
## The line and the arrowhead can be customized as for arrow annotations, but
## some property names are duplicated:
## @qcode{"head1length"}/@qcode{"head2length"},
## @qcode{"head1width"}/@qcode{"head2width"}, etc.  The index 1 marks the
## properties of the arrowhead at the first point in @var{x} and @var{y}
## coordinates.
##
## @item @qcode{"textarrow"}
## Construct an arrow with a text label at the opposite end from the arrowhead.
##
## Use the "string" property to change the text string.
## The line and the arrowhead can be customized as for arrow annotations, and
## the text can be customized using the same properties as @code{text} graphics
## objects.  Note, however, that some text property names are prefixed with
## "text" to distinguish them from arrow properties:
## @qcode{"textbackgroundcolor"}, @qcode{"textcolor"},
## @qcode{"textedgecolor"}, @qcode{"textlinewidth"},
## @qcode{"textmargin"}, @qcode{"textrotation"}.
##
## @item @qcode{"textbox"}
## Construct a box with text inside.  @var{pos} specifies the
## @qcode{"position"} property of the annotation.
##
## Use the "string" property to change the text string.
## You may use @qcode{"backgroundcolor"}, @qcode{"edgecolor"},
## @qcode{"linestyle"}, and @qcode{"linewidth"} properties to customize
## the box background color and edge appearance.  A limited set of @code{text}
## objects properties are also available; Besides @qcode{"font@dots{}"}
## properties, you may also use @qcode{"horizontalalignment"} and
## @qcode{"verticalalignment"} to position the text inside the box.
##
## Finally, the @qcode{"fitboxtotext"} property controls the actual extent of
## the box.  If @qcode{"on"} (the default) the box limits are fitted to the
## text extent.
##
## @item @qcode{"rectangle"}
## Construct a rectangle.  @var{pos} specifies the @qcode{"position"} property
## of the annotation.
##
## You may use @qcode{"facecolor"}, @qcode{"color"}, @qcode{"linestyle"}, and
## @qcode{"linewidth"} properties to customize the rectangle background color
## and edge appearance.
##
## @item @qcode{"ellipse"}
## Construct an ellipse.  @var{pos} specifies the @qcode{"position"} property
## of the annotation.
##
## See @qcode{"rectangle"} annotations for customization.
## @end table
##
## @seealso{xlabel, ylabel, zlabel, title, text, gtext, legend, colorbar}
## @end deftypefn
    
    
@function
def annotation(varargin=None,*args,**kwargs):
    varargin = annotation.varargin
    nargin = annotation.nargin

    objtype=''
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:148
    hf=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:149
    lims=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:150
    x=y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:151
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:151
    opts=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:152
    nargin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:154
    if (nargin == 0):
        print_usage()
    
    ## Parent figure
    if (isfigure(varargin[1])):
        hf=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:162
        varargin=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:163
        nargin
    
    ## Annotation type
    types=cellarray(['line','arrow','doublearrow','textarrow','textbox','ellipse','rectangle'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:168
    if (ischar(varargin[1])):
        objtype=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:171
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:172
        nargin
    else:
        print_usage()
    
    if types[1:4] == (objtype):
        if (nargin == 0):
            lims=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:182
        else:
            if (nargin >= 2):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:184
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:185
                varargin[1:2]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:186
                if (isnumeric(x) and isnumeric(y) and length(x) == 2 and length(y) == 2):
                    lims=matlabarray(cat(x[1],y[1],diff(x),diff(y)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:190
                else:
                    error('annotation: expect 2 elements vectors for X and Y')
            else:
                print_usage()
    else:
        if types[5:end()] == (objtype):
            if (nargin == 0):
                lims=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:199
            else:
                lims=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:201
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:202
                if (logical_not(isvector(lims)) or length(lims) != 4):
                    error('annotation: expect 4 elements vector for POS')
        else:
            error('annotation: unknown annotation type %s',objtype)
    
    ## options
    opts=copy(varargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:213
    nopts=numel(opts)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:214
    if (logical_not(isempty(opts))):
        if (fix(nopts / 2) != nopts / 2 or logical_not(all(cellfun(ischar,opts[1:2:end()])))):
            warning('annotation: couldn\'t parse PROP/VAL pairs, skipping')
            opts=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:219
    
    ## create annotation
    showhidden=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:224
    set(0,'showhiddenhandles','on')
    try:
        if (isempty(hf)):
            hf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:229
        ## Axes
        hca=get(hf,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:233
        hax=findall(hf,'-depth',1,'tag','scribeoverlay')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:235
        if (isempty(hax)):
            hax=buildoverlay(hf)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:237
        else:
            ## Make sure the annotations are on top of other axes
            axes(hax)
        ## Build annotation
        htmp=buildannot(hax,objtype,lims)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:244
        if (logical_not(isempty(opts))):
            set(htmp,opts[:])
    finally:
        set(0,'showhiddenhandles',showhidden)
        set(hf,'currentaxes',hca)
    
    if (nargout != 0):
        varargout[1]=htmp
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:257
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def buildoverlay(hf=None,*args,**kwargs):
    varargin = buildoverlay.varargin
    nargin = buildoverlay.nargin

    hax=axes('parent',hf,'position',cat(0,0,1,1),'visible','off','tag','scribeoverlay','xlim',cat(0,1),'ylim',cat(0,1),'handlevisibility','off')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:264
    
    ## coordinates
    addproperty('figsize_points',hax,'axesxmtick',[])
    update_figsize_points(hf,cellarray([]),hax)
    listener=cellarray([update_figsize_points,hax])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:275
    addlistener(hf,'position',listener)
    delfcn=lambda : dellistener(hf,'position',listener)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:278
    set(hax,'deletefcn',delfcn)
    return hax
    
if __name__ == '__main__':
    pass
    
    
@function
def update_figsize_points(hf=None,dummy=None,hax=None,*args,**kwargs):
    varargin = update_figsize_points.varargin
    nargin = update_figsize_points.nargin

    
    if (logical_not(recursive)):
        recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:287
        units=get(hf,'units')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:288
        set(hf,'units','points')
        pos=get(hf,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:290
        set(hf,'units',units)
        set(hax,'figsize_points',pos[3:4])
        recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:294
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def buildannot(hax=None,objtype=None,pos=None,*args,**kwargs):
    varargin = buildannot.varargin
    nargin = buildannot.nargin

    ## Base hggroup
    h=hggroup('parent',hax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:302
    
    hui=uicontextmenu(get(hax,'parent'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:305
    
    if (strcmp(graphics_toolkit(),'gnuplot')):
        ## FIXME: this is a workaround for bug #39394 (gnuplot toolkit)
        defprops=cellarray(['position','axesposition',cat(0.3,0.3,0.1,0.1),'units','textunits','data'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:310
    else:
        defprops=cellarray(['position','axesposition',cat(0.3,0.3,0.1,0.1),'units','axesunits','normalized'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:313
    
    addbaseprops(h,defprops)
    setappdata(h,'__former_units__','normalized')
    
    prop='units'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:320
    vals=set(h,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:321
    addbasemenu(hui,h,prop,vals,'Units')
    
    listener=cellarray([update_position,h,true])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:325
    addlistener(hax,'figsize_points',listener)
    delfcn=lambda : dellistener(hax,'figsize_points',listener)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:329
    set(h,'deletefcn',delfcn)
    addlistener(h,'units',cellarray([update_position,h]))
    
    if (logical_not(isempty(pos))):
        set(h,'position',pos)
    
    pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:338
    
    if cellarray(['line','arrow','doublearrow','textarrow']) == (objtype):
        ## Add properties
        proptable=lineprops()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:344
        if (strcmp(objtype,'arrow')):
            proptable=matlabarray(cat(proptable,arrowprops()))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:346
        else:
            if (strcmp(objtype,'doublearrow')):
                proptable=matlabarray(cat(proptable,dblarrowprops()))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:348
            else:
                if (strcmp(objtype,'textarrow')):
                    proptable=matlabarray(cat(proptable,arrowprops()))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:350
                    proptable=matlabarray(cat(proptable,textprops()))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:351
        addbaseprops(h,proptable)
        hli=line(cat([pos[1]],[(pos[1] + pos[3])]),cat([pos[2]],[(pos[2] + pos[4])]),'parent',h,'color',get(h,'color'),'linestyle',get(h,'linestyle'),'linewidth',get(h,'linewidth'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:357
        linemenu(hui,h)
        set(hli,'uicontextmenu',hui)
        if (strcmp(objtype,'arrow')):
            x,y=arrowcoordinates(h,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:368
            hpa=patch(x,y,get(h,'color'),'parent',h,'edgecolor',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:369
            update_arrow(h,cellarray([]),'position',hpa)
            arrowmenu(hui,h)
            set(hpa,'uicontextmenu',hui)
        else:
            if (strcmp(objtype,'doublearrow')):
                x,y=arrowcoordinates(h,1,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:377
                hpa=patch(x,y,get(h,'color'),'parent',h,'edgecolor',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:378
                x,y=arrowcoordinates(h,2,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:381
                hpa[2]=patch(x,y,get(h,'color'),'parent',h,'edgecolor',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:382
                update_arrow(h,cellarray([]),'position',hpa)
                dblarrowmenu(hui,h)
                set(hpa,'uicontextmenu',hui)
            else:
                if (strcmp(objtype,'textarrow')):
                    x,y=arrowcoordinates(h,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:391
                    hpa=patch(x,y,get(h,'color'),'parent',h,'edgecolor',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:392
                    update_arrow(h,cellarray([]),'position',hpa)
                    hte=text(get(h,'position')(1),get(h,'position')(2),get(h,'string'),'parent',h,'color',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:396
                    propnames=textprops('names')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:400
                    for ii in arange(1,numel(propnames)).reshape(-1):
                        update_text(h,cellarray([]),propnames[ii],hte)
                    update_text(h,cellarray([]),'position',hte)
                    arrowmenu(hui,h)
                    textmenu(hui,h)
                    set(hpa,'uicontextmenu',hui)
                    set(hte,'uicontextmenu',hui)
        ## updaters
        addlistener(h,'color',cellarray([update_line,'color',hli]))
        addlistener(h,'linestyle',cellarray([update_line,'linestyle',hli]))
        addlistener(h,'linewidth',cellarray([update_line,'linewidth',hli]))
        addlistener(h,'x',cellarray([update_line,'x',hli]))
        addlistener(h,'y',cellarray([update_line,'y',hli]))
        addlistener(h,'position',cellarray([update_line,'position',hli]))
        if (strcmp(objtype,'arrow')):
            addlistener(h,'position',cellarray([update_arrow,'position',hpa]))
            addlistener(h,'headwidth',cellarray([update_arrow,'position',hpa]))
            addlistener(h,'headstyle',cellarray([update_arrow,'position',hpa]))
            addlistener(h,'headlength',cellarray([update_arrow,'position',hpa]))
            addlistener(h,'color',cellarray([update_arrow,'color',hpa]))
        else:
            if (strcmp(objtype,'doublearrow')):
                addlistener(h,'position',cellarray([update_arrow,'position',hpa]))
                addlistener(h,'head1width',cellarray([update_arrow,'position',cat(hpa[1],0)]))
                addlistener(h,'head2width',cellarray([update_arrow,'position',cat(0,hpa[2])]))
                addlistener(h,'head1style',cellarray([update_arrow,'position',cat(hpa[1],0)]))
                addlistener(h,'head2style',cellarray([update_arrow,'position',cat(0,hpa[2])]))
                addlistener(h,'head1length',cellarray([update_arrow,'position',cat(hpa[1],0)]))
                addlistener(h,'head2length',cellarray([update_arrow,'position',cat(0,hpa[2])]))
                addlistener(h,'color',cellarray([update_arrow,'color',hpa]))
            else:
                if (strcmp(objtype,'textarrow')):
                    addlistener(h,'position',cellarray([update_arrow,'position',hpa]))
                    addlistener(h,'headwidth',cellarray([update_arrow,'position',hpa]))
                    addlistener(h,'headstyle',cellarray([update_arrow,'position',hpa]))
                    addlistener(h,'headlength',cellarray([update_arrow,'position',hpa]))
                    addlistener(h,'color',cellarray([update_arrow,'color',hpa]))
                    propnames=textprops('names')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:449
                    for ii in arange(1,numel(propnames)).reshape(-1):
                        addlistener(h,propnames[ii],cellarray([update_text,propnames[ii],hte]))
                        if (any(strcmp(propnames[ii],cellarray(['fontangle','fontname','fontsize','fontweight','horizontalalignment','string','textmargin','textrotation','verticalalignment'])))):
                            addlistener(h,propnames[ii],cellarray([update_text,'position',hte]))
                    addlistener(h,'position',cellarray([update_text,'position',hte]))
                    addlistener(h,'color',cellarray([update_text,'color',hte]))
    else:
        if cellarray(['rectangle','ellipse']) == (objtype):
            ## Add properties
            addbaseprops(h,rectprops())
            if (strcmp(objtype,'rectangle')):
                x,y=pos2rect(pos,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:474
            else:
                x,y=pos2ell(pos,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:476
            hr=patch(x,y,'parent',h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:479
            propnames=rectprops('names')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:481
            for ii in arange(1,numel(propnames)).reshape(-1):
                update_rect(h,cellarray([]),propnames[ii],hr,objtype)
            rectmenu(hui,h)
            set(hr,'uicontextmenu',hui)
            addlistener(h,'position',cellarray([update_rect,'position',hr,objtype]))
            for ii in arange(1,numel(propnames)).reshape(-1):
                addlistener(h,propnames[ii],cellarray([update_rect,propnames[ii],hr,objtype]))
        else:
            if 'textbox' == (objtype):
                ## Add properties
                addbaseprops(h,textboxprops())
                hpa=patch('parent',h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:502
                hte=text(pos[1],pos[2],get(h,'string'),'parent',h,'color',get(h,'color'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:503
                update_textbox(h,cellarray([]),'position',cat(hte,hpa))
                propnames=textboxprops('names')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:507
                for ii in arange(1,numel(propnames)).reshape(-1):
                    update_textbox(h,cellarray([]),propnames[ii],cat(hte,hpa))
                textboxmenu(hui,h)
                set(hpa,'uicontextmenu',hui)
                set(hte,'uicontextmenu',hui)
                addlistener(h,'position',cellarray([update_textbox,'position',cat(hte,hpa)]))
                for ii in arange(1,numel(propnames)).reshape(-1):
                    addlistener(h,propnames[ii],cellarray([update_textbox,propnames[ii],cat(hte,hpa)]))
                addlistener(h,'horizontalalignment',cellarray([update_textbox,'position',cat(hte,hpa)]))
                addlistener(h,'verticalalignment',cellarray([update_textbox,'position',cat(hte,hpa)]))
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def lineprops(varargin=None,*args,**kwargs):
    varargin = lineprops.varargin
    nargin = lineprops.nargin

    ## FIXME: Use "axesx(y)lim" instead of "linex(y)data"
    props=cellarray(['color','color',cat(0,0,0),'linestyle','linelinestyle','-','linewidth','linelinewidth',0.5,'x','linexdata',cat(0.3,0.4),'y','lineydata',cat(0.3,0.4)])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:533
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:539
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def basecolors(*args,**kwargs):
    varargin = basecolors.varargin
    nargin = basecolors.nargin

    col=cellarray(['blue','black','cyan','green','magenta','red','white','yellow','none'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:544
    return col
    
if __name__ == '__main__':
    pass
    
    
@function
def linemenu(hui=None,hpar=None,*args,**kwargs):
    varargin = linemenu.varargin
    nargin = linemenu.nargin

    hm=uimenu('parent',hui,'label','Line')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:549
    
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:552
    addbasemenu(hm,hpar,'Color',vals)
    
    vals=set(hpar,'linestyle')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:557
    addbasemenu(hm,hpar,'Linestyle',vals)
    
    vals=matlabarray(cat(0.5,1,1.5,2))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:561
    addbasemenu(hm,hpar,'Linewidth',vals)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def arrowprops(varargin=None,*args,**kwargs):
    varargin = arrowprops.varargin
    nargin = arrowprops.nargin

    props=cellarray(['headlength','data',10,'headstyle','radio','diamond|ellipse|none|plain|rectangle|vback1|{vback2}|vback3','headwidth','data',10])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:566
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:570
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def arrowmenu(hui=None,hpar=None,*args,**kwargs):
    varargin = arrowmenu.varargin
    nargin = arrowmenu.nargin

    hm=uimenu('parent',hui,'label','Arrowhead')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:575
    
    vals=arange(6,16,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:578
    addbasemenu(hm,hpar,'headlength',vals,'Length')
    addbasemenu(hm,hpar,'headwidth',vals,'Width')
    
    vals=set(hpar,'headstyle')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:583
    addbasemenu(hm,hpar,'Headstyle',vals)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def dblarrowprops(varargin=None,*args,**kwargs):
    varargin = dblarrowprops.varargin
    nargin = dblarrowprops.nargin

    props=cellarray(['head1length','data',10,'head1style','radio','diamond|ellipse|none|plain|rectangle|vback1|{vback2}|vback3','head1width','data',10,'head2length','data',10,'head2style','radio','diamond|ellipse|none|plain|rectangle|vback1|{vback2}|vback3','head2width','data',10])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:588
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:595
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def dblarrowmenu(hui=None,hpar=None,*args,**kwargs):
    varargin = dblarrowmenu.varargin
    nargin = dblarrowmenu.nargin

    hm1=uimenu('parent',hui,'label','Arrowhead #1')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:600
    hm2=uimenu('parent',hui,'label','Arrowhead #2')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:601
    
    vals=arange(6,16,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:604
    addbasemenu(hm1,hpar,'head1length',vals,'Length')
    addbasemenu(hm1,hpar,'head1width',vals,'Width')
    addbasemenu(hm2,hpar,'head2length',vals,'Length')
    addbasemenu(hm2,hpar,'head2width',vals,'Width')
    
    vals=set(hpar,'head1style')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:611
    addbasemenu(hm1,hpar,'head1style',vals,'Headstyle')
    addbasemenu(hm2,hpar,'head2style',vals,'Headstyle')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def textprops(varargin=None,*args,**kwargs):
    varargin = textprops.varargin
    nargin = textprops.nargin

    props=cellarray(['fontangle','textfontangle','normal','fontname','textfontname','Helvetica','fontsize','textfontsize',10,'fontunits','textfontunits','points','fontweight','textfontweight','normal','horizontalalignment','texthorizontalalignment','left','interpreter','textinterpreter','tex','string','textstring','','textbackgroundcolor','textbackgroundcolor','none','textcolor','textcolor','k','textedgecolor','textedgecolor','none','textlinewidth','textlinewidth',0.5,'textmargin','textmargin',5,'textrotation','textrotation',0,'verticalalignment','textverticalalignment','middle'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:617
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:633
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def stringdlg(hpar=None,prop=None,*args,**kwargs):
    varargin = stringdlg.varargin
    nargin = stringdlg.nargin

    def_=get(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:638
    if (iscell(def_)):
        prompt=arrayfun(lambda n=None: sprintf('Line #%d:',n),arange(1,numel(def_)),'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:640
    else:
        prompt=''
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:643
        def_=cellarray([def_])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:644
    
    cstr=inputdlg(prompt,prop,1,def_)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:647
    if (logical_not(isempty(cstr))):
        set(hpar,prop,cstr)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def textmenu(hui=None,hpar=None,*args,**kwargs):
    varargin = textmenu.varargin
    nargin = textmenu.nargin

    hm=uimenu('parent',hui,'label','Text')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:655
    
    prop='String'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:658
    fcn=lambda : stringdlg(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:659
    uimenu(hm,'label',prop,'callback',fcn)
    
    prop='textcolor'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:663
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:664
    addbasemenu(hm,hpar,prop,vals,'Color')
    prop='fontsize'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:666
    vals=arange(8,20,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:667
    addbasemenu(hm,hpar,prop,vals,'Size')
    prop='fontangle'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:669
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:670
    addbasemenu(hm,hpar,prop,vals,'Angle')
    prop='fontweight'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:672
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:673
    addbasemenu(hm,hpar,prop,vals,'Weight')
    prop='textrotation'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:675
    vals=arange(0,270,90)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:676
    addbasemenu(hm,hpar,prop,vals,'Rotation')
    prop='horizontalalignment'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:679
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:680
    addbasemenu(hm,hpar,prop,vals,'Horizontal Alignment','separator','on')
    prop='verticalalignment'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:683
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:684
    addbasemenu(hm,hpar,prop,vals,'Vertical Alignment')
    
    prop='interpreter'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:689
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:690
    addbasemenu(hm,hpar,prop,vals,'Interpreter','separator','on')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def textboxprops(varargin=None,*args,**kwargs):
    varargin = textboxprops.varargin
    nargin = textboxprops.nargin

    props=cellarray(['backgroundcolor','patchfacecolor','none','color','textcolor',cat(0,0,0),'edgecolor','patchedgecolor',cat(0,0,0),'facealpha','patchfacealpha',1,'fontangle','textfontangle','normal','fontname','textfontname','Helvetica','fontsize','textfontsize',10,'fontunits','textfontunits','points','fontweight','textfontweight','normal','horizontalalignment','texthorizontalalignment','left','interpreter','textinterpreter','tex','linestyle','linelinestyle','-','linewidth','linelinewidth',0.5,'string','textstring','','fitboxtotext','radio','{on}|off','margin','data',5,'verticalalignment','textverticalalignment','middle'])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:697
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:715
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def textboxmenu(hui=None,hpar=None,*args,**kwargs):
    varargin = textboxmenu.varargin
    nargin = textboxmenu.nargin

    ## Text properties
    hm1=uimenu('parent',hui,'label','Text')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:721
    prop='String'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:723
    fcn=lambda : stringdlg(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:724
    uimenu(hm1,'label',prop,'callback',fcn)
    prop='Color'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:727
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:728
    addbasemenu(hm1,hpar,prop,vals)
    prop='fontsize'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:730
    vals=arange(8,20,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:731
    addbasemenu(hm1,hpar,prop,vals,'Size')
    prop='fontangle'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:733
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:734
    addbasemenu(hm1,hpar,prop,vals,'Angle')
    prop='fontweight'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:736
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:737
    addbasemenu(hm1,hpar,prop,vals,'Weight')
    prop='horizontalalignment'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:740
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:741
    addbasemenu(hm1,hpar,prop,vals,'Horizontal Alignment','separator','on')
    prop='verticalalignment'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:744
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:745
    addbasemenu(hm1,hpar,prop,vals,'Vertical Alignment')
    prop='Margin'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:747
    vals=arange(2,10,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:748
    addbasemenu(hm1,hpar,prop,vals)
    prop='interpreter'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:751
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:752
    addbasemenu(hm1,hpar,prop,vals,'Interpreter','separator','on')
    
    hm2=uimenu('parent',hui,'label','Background')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:757
    prop='fitboxtotext'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:759
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:760
    addbasemenu(hm2,hpar,prop,vals,'Fit box to text')
    prop='backgroundcolor'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:762
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:763
    addbasemenu(hm2,hpar,prop,vals,'Face Color')
    prop='edgecolor'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:765
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:766
    addbasemenu(hm2,hpar,prop,vals,'Edge Color')
    prop='linestyle'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:768
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:769
    addbasemenu(hm2,hpar,prop,vals,'Line Style')
    prop='linewidth'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:771
    vals=arange(0.5,2,0.5)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:772
    addbasemenu(hm2,hpar,prop,vals,'Line Width')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def rectprops(varargin=None,*args,**kwargs):
    varargin = rectprops.varargin
    nargin = rectprops.nargin

    props=cellarray(['edgecolor','patchedgecolor','k','facealpha','patchfacealpha',1,'facecolor','patchfacecolor','none','linestyle','patchlinestyle','-','linewidth','patchlinewidth',0.5])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:777
    if (strcmp(varargin,'names')):
        props=props[1:3:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:783
    
    return props
    
if __name__ == '__main__':
    pass
    
    
@function
def rectmenu(hui=None,hpar=None,*args,**kwargs):
    varargin = rectmenu.varargin
    nargin = rectmenu.nargin

    prop='facecolor'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:788
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:789
    addbasemenu(hui,hpar,prop,vals,'Face Color')
    prop='edgecolor'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:791
    vals=basecolors()
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:792
    addbasemenu(hui,hpar,prop,vals,'Edge Color')
    prop='linestyle'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:794
    vals=set(hpar,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:795
    addbasemenu(hui,hpar,prop,vals,'Line Style')
    prop='linewidth'
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:797
    vals=arange(0.5,2,0.5)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:798
    addbasemenu(hui,hpar,prop,vals,'Line Width')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def addbaseprops(h=None,proptable=None,*args,**kwargs):
    varargin = addbaseprops.varargin
    nargin = addbaseprops.nargin

    cellfun(lambda pname=None,ptype=None,parg=None: addproperty(pname,h,ptype,parg),proptable[1:3:end()],proptable[2:3:end()],proptable[3:3:end()])
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def addbasemenu(hm=None,hpar=None,pname=None,vals=None,mainlabel='',*args,**kwargs):
    varargin = addbasemenu.varargin
    nargin = addbasemenu.nargin

    if (isempty(mainlabel)):
        mainlabel=copy(pname)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:809
    
    h=uimenu('parent',hm,'label',mainlabel)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:812
    is_numeric=logical_not(iscell(vals))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:814
    nv=numel(vals)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:815
    htmp=zeros(1,nv)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:816
    for ii in arange(1,nv).reshape(-1):
        if (logical_not(is_numeric)):
            val=label=vals[ii]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:819
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:819
        else:
            val=vals[ii]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:821
            label=num2str(val)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:822
        fcn=lambda : set(hpar,pname,val)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:825
        htmp[ii]=uimenu(h,'label',label,'callback',fcn)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:826
    
    handle_check(hpar,cellarray([]),htmp,pname,is_numeric)
    addlistener(hpar,pname,cellarray([handle_check,htmp,pname,is_numeric]))
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def handle_check(h=None,dummy=None,hmenus=None,prop=None,is_numeric=None,*args,**kwargs):
    varargin = handle_check.varargin
    nargin = handle_check.nargin

    vals=get(hmenus,'label')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:833
    current=get(h,prop)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:834
    if (is_numeric):
        current=num2str(current)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:836
    
    idx=strcmp(vals,current)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:839
    set(hmenus[idx],'checked','on')
    set(hmenus[logical_not(idx)],'checked','off')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_position(h1=None,dummy=None,h=None,force=false,*args,**kwargs):
    varargin = update_position.varargin
    nargin = update_position.nargin

    if (logical_not(force)):
        pos=convertposition(h,getappdata(h,'__former_units__'),get(h,'units'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:846
        setappdata(h,'__former_units__',get(h,'units'))
        set(h,'position',pos)
    else:
        ## FIXME: Inefficient trick to force all objects to be redrawn
        set(h,'position',cat(0,0,0.5,0.5),'position',get(h,'position'))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_line(h=None,dummy=None,prop=None,hli=None,*args,**kwargs):
    varargin = update_line.varargin
    nargin = update_line.nargin

    
    if (logical_not(recursive)):
        if 'color' == (prop):
            set(hli,'color',get(h,'color'))
        else:
            if 'linestyle' == (prop):
                set(hli,'linestyle',get(h,'linestyle'))
            else:
                if 'linewidth' == (prop):
                    set(hli,'linewidth',get(h,'linewidth'))
                else:
                    if 'x' == (prop):
                        ## Update position
                        x=get(h,'x')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:870
                        pos=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:871
                        pos[1]=x[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:872
                        pos[3]=diff(x)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:873
                        recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:874
                        set(h,'position',pos)
                        recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:876
                        pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:879
                        x=matlabarray(cat(pos[1],(pos[1] + pos[3])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:880
                        set(hli,'xdata',x)
                    else:
                        if 'y' == (prop):
                            ## Update position
                            y=get(h,'y')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:885
                            pos=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:886
                            pos[2]=y[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:887
                            pos[4]=diff(y)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:888
                            recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:889
                            set(h,'position',pos)
                            recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:891
                            pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:894
                            y=matlabarray(cat(pos[2],(pos[2] + pos[4])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:895
                            set(hli,'ydata',y)
                        else:
                            if 'position' == (prop):
                                ## Update x and y
                                pos=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:899
                                x=matlabarray(cat(pos[1],(pos[1] + pos[3])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:900
                                y=matlabarray(cat(pos[2],(pos[2] + pos[4])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:901
                                recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:903
                                set(h,'x',x)
                                set(h,'y',y)
                                recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:906
                                pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:909
                                x=matlabarray(cat(pos[1],(pos[1] + pos[3])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:910
                                y=matlabarray(cat(pos[2],(pos[2] + pos[4])))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:911
                                set(hli,'xdata',x)
                                set(hli,'ydata',y)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def arrowcoordinates(h=None,nar=[],*args,**kwargs):
    varargin = arrowcoordinates.varargin
    nargin = arrowcoordinates.nargin

    pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:920
    ppos=norm2pts(h,pos[3:4].T)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:921
    ang=angle(complex(ppos[1],ppos[2]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:922
    if (isempty(nar)):
        ln=get(h,'headlength')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:925
        wd=get(h,'headwidth')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:926
        headstyle=get(h,'headstyle')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:927
        pos=pos[1:2]+ pos[3:4]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:928
    else:
        if (nar == 1):
            ln=get(h,'head1length')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:930
            wd=get(h,'head1width')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:931
            headstyle=get(h,'head1style')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:932
            pos=pos[1:2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:933
            ang += pi
        else:
            if (nar == 2):
                ln=get(h,'head2length')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:936
                wd=get(h,'head2width')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:937
                headstyle=get(h,'head2style')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:938
                pos=pos[1:2]+ pos[3:4]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:939
            else:
                error('annotation: %d, no such arrow number')
    
    if 'diamond' == (headstyle):
        x=matlabarray(cat(0,- ln / 2,- ln,- ln / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:946
        y=matlabarray(cat(0,- wd / 2,0,wd / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:947
    else:
        if 'ellipse' == (headstyle):
            pts=linspace(0,dot(2,pi),12)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:949
            x=dot(ln / 2,(cos(pts) - 1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:950
            y=dot(wd / 2,sin(pts))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:951
        else:
            if 'rectangle' == (headstyle):
                x=matlabarray(cat(0,0,- ln,- ln,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:953
                y=matlabarray(cat(wd / 2,- wd / 2,- wd / 2,wd / 2,wd / 2))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:954
            else:
                if 'vback1' == (headstyle):
                    x=matlabarray(cat(0,- ln,dot(- 0.85,ln),- ln,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:956
                    y=matlabarray(cat(0,wd / 2,0,- wd / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:957
                else:
                    if 'vback2' == (headstyle):
                        x=matlabarray(cat(0,- ln,dot(- 0.65,ln),- ln,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:959
                        y=matlabarray(cat(0,wd / 2,0,- wd / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:960
                    else:
                        if 'vback3' == (headstyle):
                            x=matlabarray(cat(0,- ln,dot(- 0.2,ln),- ln,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:962
                            y=matlabarray(cat(0,wd / 2,0,- wd / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:963
                        else:
                            if 'plain' == (headstyle):
                                x=matlabarray(cat(0,- ln,- ln,- ln,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:965
                                y=matlabarray(cat(0,wd / 2,0,- wd / 2,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:966
                            else:
                                if 'none' == (headstyle):
                                    x=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:968
                                    y=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:969
                                else:
                                    error('annotation: "%s" headstyle not implemented',headstyle)
    
    R=matlabarray(cat([cos(ang),- sin(ang)],[sin(ang),cos(ang)]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:974
    XY=dot(R,cat([x],[y]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:976
    XY=pts2norm(h,XY)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:977
    XY=pos[1:2].T+ XY
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:978
    x=XY[1,:].T
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:980
    y=XY[2,:].T
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:981
    return x,y
    
if __name__ == '__main__':
    pass
    
    
@function
def update_arrow(h=None,dummy=None,prop=None,hpa=[],*args,**kwargs):
    varargin = update_arrow.varargin
    nargin = update_arrow.nargin

    
    nar=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:987
    for ii in arange(1,numel(hpa)).reshape(-1):
        if (numel(hpa) == 2):
            nar=copy(ii)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:990
        if (hpa[ii]):
            if 'position' == (prop):
                x,y=arrowcoordinates(h,nar,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:995
                set(hpa[ii],'xdata',x,'ydata',y)
            else:
                if 'color' == (prop):
                    set(hpa[ii],'facecolor',get(h,'color'))
                    set(hpa[ii],'edgecolor',get(h,'color'))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_text(h=None,dummy=None,prop=None,hte=None,*args,**kwargs):
    varargin = update_text.varargin
    nargin = update_text.nargin

    
    if (logical_not(recursive)):
        if 'position' == (prop):
            if (isempty(get(h,'string'))):
                return
            pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1015
            set(hte,'position',cat(textcoordinates(hte,pos),0))
        else:
            if (strncmp(prop,'text',4)):
                set(hte,prop[5:end()],get(h,prop))
            else:
                set(hte,prop,get(h,prop))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_textbox(h=None,dummy=None,prop=None,htb=None,*args,**kwargs):
    varargin = update_textbox.varargin
    nargin = update_textbox.nargin

    
    hte=htb[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1032
    hpa=htb[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1033
    if (logical_not(recursive)):
        if cellarray(['edgecolor','facealpha','linestyle','linewidth']) == (prop):
            set(hpa,prop,get(h,prop))
        else:
            if cellarray(['backgroundcolor']) == (prop):
                set(hpa,'facecolor',get(h,prop))
            else:
                if (logical_not(any(strcmp(prop,cellarray(['fitboxtotext','position']))))):
                    set(hte,prop,get(h,prop))
                pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1047
                if (strcmp(get(h,'fitboxtotext'),'on')):
                    pos[3:4]=multiply(get(hte,'extent')(arange(3,4)),sign(pos[3:4]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1050
                x,y=pos2rect(pos,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1053
                set(hpa,'xdata',x.T,'ydata',y.T)
                if 'left' == (get(h,'horizontalalignment')):
                    x=x[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1058
                else:
                    if 'center' == (get(h,'horizontalalignment')):
                        x=mean(x[1:2])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1060
                    else:
                        if 'right' == (get(h,'horizontalalignment')):
                            x=x[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1062
                if cellarray(['top','cap']) == (get(h,'verticalalignment')):
                    y=y[3]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1067
                else:
                    if 'middle' == (get(h,'verticalalignment')):
                        y=mean(y[2:3])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1069
                    else:
                        if cellarray(['bottom','baseline']) == (get(h,'verticalalignment')):
                            y=y[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1071
                set(hte,'position',cat(x,y,0))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def textcoordinates(hte=None,pos=None,*args,**kwargs):
    varargin = textcoordinates.varargin
    nargin = textcoordinates.nargin

    ## Get the "tight" extent of the text object in points units
    textpos=get(hte,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1081
    rot=get(hte,'rotation')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1082
    units=get(hte,'units')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1083
    set(hte,'rotation',0,'units','points','position',cat(0,0,0))
    ext=get(hte,'extent')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1086
    set(hte,'rotation',rot,'units',units,'position',textpos)
    
    ## arrow with
  ##  8-----7-----6
  ##  1  text box 5
  ##  2-----3-----4
    
    ## FIXME: Matlab's horizontal/verticalalignment properties are
  ## interpreted differently: horizontalalignment is passed to the
  ## underlying text object whereas the verticalalignement controls
  ## the vertical alignment of the arrow.
    
    ang=angle(complex(pos[3],pos[4]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1100
    rot=dot(rot / 180,pi)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1101
    __,pt=min(abs((arange(- pi,pi,pi / 4)) - ang),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1103
    pt -= floor(rot / (pi / 4))
    if (pt <= 0):
        pt=rem(pt,8) + 8
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1106
    else:
        if (pt > 8):
            pt=rem(pt,8)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1108
    
    ## Compute the text actual "position" property
    dx=ext[3] / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1112
    dy=ext[4] / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1113
    XY=matlabarray(cat([- dx,- dx,0,dx,dx,dx,0,- dx],[0,- dy,- dy,- dy,0,dy,dy,dy]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1114
    if 'left' == (get(hte,'horizontalalignment')):
        XY[1,:] += dx
    else:
        if 'right' == (get(hte,'horizontalalignment')):
            XY[1,:] -= dx
    
    if cellarray(['baseline','bottom']) == (get(hte,'verticalalignment')):
        XY[2,:] += dy
    else:
        if cellarray(['cap','top']) == (get(hte,'verticalalignment')):
            XY[2,:] -= dy
    
    R=matlabarray(cat([cos(rot),- sin(rot)],[sin(rot),cos(rot)]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1131
    XY=dot(R,XY)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1133
    XY=pts2norm(get(hte,'parent'),XY)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1134
    XY=pos[1:2]- XY[:,pt].T
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1135
    return XY
    
if __name__ == '__main__':
    pass
    
    
@function
def pts2norm(h=None,pXY=None,*args,**kwargs):
    varargin = pts2norm.varargin
    nargin = pts2norm.nargin

    sz=get(get(h,'parent'),'figsize_points')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1140
    nXY[1,:]=pXY[1,:] / sz[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1142
    nXY[2,:]=pXY[2,:] / sz[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1143
    return nXY
    
if __name__ == '__main__':
    pass
    
    
@function
def norm2pts(h=None,nXY=None,*args,**kwargs):
    varargin = norm2pts.varargin
    nargin = norm2pts.nargin

    sz=get(get(h,'parent'),'figsize_points')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1147
    pXY[1,:]=multiply(nXY[1,:],sz[1])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1149
    pXY[2,:]=multiply(nXY[2,:],sz[2])
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1150
    return pXY
    
if __name__ == '__main__':
    pass
    
    
@function
def convertposition(h=None,from_=None,to=None,*args,**kwargs):
    varargin = convertposition.varargin
    nargin = convertposition.nargin

    ## FIXME: handle "characters" units
    pos=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1155
    
    sz=get(get(h,'parent'),'figsize_points')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1158
    if 'centimeters' == (from_):
        pos /= 2.54
        pos *= 72
        pos[1:2:end()] /= sz[1]
        pos[2:2:end()] /= sz[2]
    else:
        if 'inches' == (from_):
            pos *= 72
            pos[1:2:end()] /= sz[1]
            pos[2:2:end()] /= sz[2]
        else:
            if 'pixels' == (from_):
                pos /= get(0,'screenpixelsperinch')
                pos *= 72
                pos[1:2:end()] /= sz[1]
                pos[2:2:end()] /= sz[2]
    
    ## Then convert to requested coordinates
    if 'centimeters' == (to):
        sz /= 72
        sz *= 2.54
        pos[1:2:end()] *= sz[1]
        pos[2:2:end()] *= sz[2]
    else:
        if 'inches' == (to):
            sz /= 72
            pos[1:2:end()] *= sz[1]
            pos[2:2:end()] *= sz[2]
        else:
            if 'pixels' == (to):
                sz /= 72
                sz *= get(0,'screenpixelsperinch')
                pos[1:2:end()] *= sz[1]
                pos[2:2:end()] *= sz[2]
    
    return pos
    
if __name__ == '__main__':
    pass
    
    
@function
def getnormpos(h=None,*args,**kwargs):
    varargin = getnormpos.varargin
    nargin = getnormpos.nargin

    units=get(h,'units')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1197
    pos=convertposition(h,units,'normalized')
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1198
    return pos
    
if __name__ == '__main__':
    pass
    
    
@function
def pos2rect(pos=None,*args,**kwargs):
    varargin = pos2rect.varargin
    nargin = pos2rect.nargin

    x=matlabarray(cat(pos[1],pos[1] + pos[3],pos[1] + pos[3],pos[1]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1202
    y=matlabarray(cat(pos[2],pos[2],pos[2] + pos[4],pos[2] + pos[4]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1203
    return x,y
    
if __name__ == '__main__':
    pass
    
    
@function
def pos2ell(pos=None,*args,**kwargs):
    varargin = pos2ell.varargin
    nargin = pos2ell.nargin

    a=pos[3] / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1207
    b=pos[4] / 2
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1208
    
    ## when it is spread over
    ang=linspace(0,dot(2,pi),100)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1212
    x=dot(a,cos(ang))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1214
    y=dot(b,sin(ang))
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1215
    x += pos[1] + a
    y += pos[2] + b
    return x,y
    
if __name__ == '__main__':
    pass
    
    
@function
def update_rect(h=None,dummy=None,prop=None,hre=None,typ=None,*args,**kwargs):
    varargin = update_rect.varargin
    nargin = update_rect.nargin

    
    if (logical_not(recursive)):
        if 'position' == (prop):
            pos=getnormpos(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1227
            if (strcmp(typ,'rectangle')):
                x,y=pos2rect(pos,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1229
            else:
                x,y=pos2ell(pos,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/annotation.m:1231
            set(hre,'xdata',x,'ydata',y)
        else:
            set(hre,prop,get(h,prop))
    
    return
    
if __name__ == '__main__':
    pass
    
    ## FIXME: the additionnal regular axes is necessary for fltk to draw the
##        annotation axes.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test line properties
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test textarrow properties
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test textbox properties
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test units conversion
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test annotated figure
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 2007-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} hidden
## @deftypefnx {Command} {} hidden on
## @deftypefnx {Command} {} hidden off
## @deftypefnx {Function File} {@var{mode} =} hidden (@dots{})
## Control mesh hidden line removal.
##
## When called with no argument the hidden line removal state is toggled.
##
## When called with one of the modes @qcode{"on"} or @qcode{"off"} the state
## is set accordingly.
##
## The optional output argument @var{mode} is the current state.
##
## Hidden Line Removal determines what graphic objects behind a mesh plot
## are visible.  The default is for the mesh to be opaque and lines behind
## the mesh are not visible.  If hidden line removal is turned off then
## objects behind the mesh can be seen through the faces (openings) of the
## mesh, although the mesh grid lines are still opaque.
##
## @seealso{mesh, meshc, meshz, ezmesh, ezmeshc, trimesh, waterfall}
## @end deftypefn
    
    
@function
def hidden(mode='toggle',*args,**kwargs):
    varargin = hidden.varargin
    nargin = hidden.nargin

    if (nargin > 2):
        print_usage()
    else:
        if (nargin == 1):
            if (logical_not(ischar(mode))):
                error('hidden: expecting MODE to be a string')
            else:
                if (logical_not(any(strcmpi(mode,cellarray(['on','off']))))):
                    error('hidden: MODE must be "on" or "off"')
    
    for h in (get(gca(),'children')).T.reshape(-1):
        htype=get(h,'type')
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:55
        htag=get(h,'tag')
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:56
        if (strcmp(htype,'surface') or strcmp(htag,'trimesh')):
            fc=get(h,'facecolor')
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:58
            if ((logical_not(ischar(fc)) and is_white(fc)) or (ischar(fc) and strcmp(fc,'none'))):
                if 'on' == (mode):
                    set(h,'facecolor','w')
                else:
                    if 'off' == (mode):
                        set(h,'facecolor','none')
                    else:
                        if 'toggle' == (mode):
                            if (ischar(fc)):
                                set(h,'facecolor','w')
                                mode='on'
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:69
                            else:
                                set(h,'facecolor','none')
                                mode='off'
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:72
    
    if (nargout > 0):
        state=copy(mode)
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:80
    
    return state
    
if __name__ == '__main__':
    pass
    
    
@function
def is_white(color=None,*args,**kwargs):
    varargin = is_white.varargin
    nargin = is_white.nargin

    retval=all(color == 1)
# /home/lei/octave-4.0.2/scripts/plot/appearance/hidden.m:86
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} grid
## @deftypefnx {Command} {} grid on
## @deftypefnx {Command} {} grid off
## @deftypefnx {Command} {} grid minor
## @deftypefnx {Command} {} grid minor on
## @deftypefnx {Command} {} grid minor off
## @deftypefnx {Function File} {} grid (@var{hax}, @dots{})
## Control the display of plot grid lines.
##
## The function state input may be either @qcode{"on"} or @qcode{"off"}.
## If it is omitted, the current grid state is toggled.
##
## When the first argument is @qcode{"minor"} all subsequent commands
## modify the minor grid rather than the major grid.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## To control the grid lines for an individual axis use the @code{set}
## function.  For example:
##
## @example
## set (gca, "ygrid", "on");
## @end example
## @seealso{axis, box}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def grid(varargin=None,*args,**kwargs):
    varargin = grid.varargin
    nargin = grid.nargin

    hax,varargin,nargs=__plt_get_axis_arg__('grid',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:51
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:54
    
    if (nargs > 2):
        print_usage()
    
    grid_on=any(strcmp(get(hax,cellarray(['xgrid','ygrid','zgrid'])),'on'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:61
    minor_on=any(strcmp(get(hax,cellarray(['xminorgrid','yminorgrid','zminorgrid'])),'on'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:63
    minor_auto=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:66
    if (nargs == 0):
        grid_on=logical_not(grid_on)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:68
    else:
        arg1=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:70
        if (logical_not(ischar(arg1))):
            error('grid: argument 1 must be an axis handle or a string')
        if (strcmpi(arg1,'off')):
            grid_on=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:75
        else:
            if (strcmpi(arg1,'on')):
                grid_on=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:77
            else:
                if (strcmpi(arg1,'minor')):
                    minor_auto=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:79
                    if (nargs == 2):
                        arg2=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:81
                        if (strcmpi(arg2,'on')):
                            minor_on=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:83
                            grid_on=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:84
                        else:
                            if (strcmpi(arg2,'off')):
                                minor_on=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:86
                            else:
                                print_usage()
                    else:
                        minor_on=logical_not(minor_on)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:91
                        if (minor_on):
                            grid_on=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:93
                else:
                    print_usage()
    
    if (grid_on):
        set(hax,'xgrid','on','ygrid','on','zgrid','on','gridlinestyle',':')
        if (minor_on):
            set(hax,'xminorgrid','on','yminorgrid','on','zminorgrid','on','gridlinestyle','-','minorgridlinestyle',':')
            xg=ifelse(strcmp(get(hax,'xscale'),'log'),'off','on')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:107
            yg=ifelse(strcmp(get(hax,'yscale'),'log'),'off','on')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:108
            zg=ifelse(strcmp(get(hax,'zscale'),'log'),'off','on')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:109
            set(hax,'xgrid',xg,'ygrid',yg,'zgrid',zg)
        else:
            if (minor_auto):
                xmg=ifelse(strcmp(get(hax,'xscale'),'log'),'on','off')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:112
                ymg=ifelse(strcmp(get(hax,'yscale'),'log'),'on','off')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:113
                zmg=ifelse(strcmp(get(hax,'zscale'),'log'),'on','off')
# /home/lei/octave-4.0.2/scripts/plot/appearance/grid.m:114
                set(hax,'xminorgrid',xmg,'yminorgrid',ymg,'zminorgrid',zmg)
            else:
                set(hax,'xminorgrid','off','yminorgrid','off','zminorgrid','off')
    else:
        set(hax,'xgrid','off','ygrid','off','zgrid','off','xminorgrid','off','yminorgrid','off','zminorgrid','off')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{ylimits} =} ylim ()
## @deftypefnx {Function File} {@var{xmode} =} ylim ("mode")
## @deftypefnx {Function File} {} ylim ([@var{y_lo} @var{y_hi}])
## @deftypefnx {Function File} {} ylim ("auto")
## @deftypefnx {Function File} {} ylim ("manual")
## @deftypefnx {Function File} {} ylim (@var{hax}, @dots{})
## Query or set the limits of the y-axis for the current plot.
##
## Called without arguments @code{ylim} returns the y-axis limits of the
## current plot.
##
## With the input query @qcode{"mode"}, return the current
## y-limit calculation mode which is either @qcode{"auto"} or @qcode{"manual"}.
##
## If passed a 2-element vector [@var{y_lo} @var{y_hi}], the limits of the
## y-axis are set to these values and the mode is set to @qcode{"manual"}.
##
## The current plotting mode can be changed by using either @qcode{"auto"}
## or @qcode{"manual"} as the argument.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
## @seealso{xlim, zlim, axis, set, get, gca}
## @end deftypefn
    
    
@function
def ylim(varargin=None,*args,**kwargs):
    varargin = ylim.varargin
    nargin = ylim.nargin

    ret=__axis_limits__('ylim',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylim.m:46
    if (logical_not(isempty(ret))):
        retval=copy(ret)
# /home/lei/octave-4.0.2/scripts/plot/appearance/ylim.m:49
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} zlabel (@var{string})
## @deftypefnx {Function File} {} zlabel (@var{string}, @var{property}, @var{val}, @dots{})
## @deftypefnx {Function File} {} zlabel (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} zlabel (@dots{})
## Specify the string used to label the z-axis of the current axis.
##
## An optional list of @var{property}/@var{value} pairs can be used to change
## the properties of the created text label.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created text
## object.
## @seealso{xlabel, ylabel, datetick, title, text}
## @end deftypefn
## Author: jwe
    
    
@function
def zlabel(varargin=None,*args,**kwargs):
    varargin = zlabel.varargin
    nargin = zlabel.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('zlabel',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlabel.m:40
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlabel.m:43
    
    if (rem(nargin,2) != 1):
        print_usage()
    
    htmp=__axis_label__(hax,'zlabel',varargin[1],'color',get(hax,'zcolor'),varargin[2:end()])
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlabel.m:50
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlabel.m:54
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{data_aspect_ratio} =} daspect ()
## @deftypefnx {Function File} {} daspect (@var{data_aspect_ratio})
## @deftypefnx {Function File} {} daspect (@var{mode})
## @deftypefnx {Function File} {@var{data_aspect_ratio_mode} =} daspect ("mode")
## @deftypefnx {Function File} {} daspect (@var{hax}, @dots{})
## Query or set the data aspect ratio of the current axes.
##
## The aspect ratio is a normalized 3-element vector representing the span of
## the x, y, and z-axis limits.
##
## @code{daspect (@var{mode})}
##
## Set the data aspect ratio mode of the current axes.  @var{mode} is
## either @qcode{"auto"} or @qcode{"manual"}.
##
## @code{daspect (@qcode{"mode"})}
##
## Return the data aspect ratio mode of the current axes.
##
## @code{daspect (@var{hax}, @dots{})}
##
## Operate on the axes in handle @var{hax} instead of the current axes.
##
## @seealso{axis, pbaspect, xlim, ylim, zlim}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-01-26
    
    
@function
def daspect(varargin=None,*args,**kwargs):
    varargin = daspect.varargin
    nargin = daspect.nargin

    ## Grab axes handle if present
    if (nargin > 0):
        if (isscalar(varargin[1]) and isaxes(varargin[1])):
            hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:54
            varargin=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:55
        else:
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:57
    else:
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:60
    
    nargin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:63
    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        daratio=get(hax,'dataaspectratio')
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:69
    else:
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:71
        if (isnumeric(arg)):
            if (numel(arg) == 2):
                set(hax,'dataaspectratio',cat(arg,1))
            else:
                if (numel(arg) == 3):
                    set(hax,'dataaspectratio',arg)
                else:
                    error('daspect: DATA_ASPECT_RATIO must be a 2 or 3 element vector')
        else:
            if (ischar(arg)):
                arg=tolower(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:81
                if 'auto' == (arg):
                    set(hax,'dataaspectratiomode','auto')
                else:
                    if 'manual' == (arg):
                        set(hax,'dataaspectratiomode','manual')
                    else:
                        if 'mode' == (arg):
                            daratio=get(hax,'dataaspectratiomode')
# /home/lei/octave-4.0.2/scripts/plot/appearance/daspect.m:88
                        else:
                            error('daspect: Invalid mode <%s>',arg)
            else:
                print_usage()
    
    return daratio
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: need some input validation tests
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} orient (@var{orientation})
## @deftypefnx {Function File} {} orient (@var{hfig}, @var{orientation})
## @deftypefnx {Function File} {@var{orientation} =} orient ()
## @deftypefnx {Function File} {@var{orientation} =} orient (@var{hfig})
## Query or set the print orientation for figure @var{hfig}.
##
## Valid values for @var{orientation} are @qcode{"portrait"},
## @qcode{"landscape"}, and @qcode{"tall"}.
##
## The @qcode{"landscape"} option changes the orientation so the plot width
## is larger than the plot height.  The @qcode{"paperposition"} is also
## modified so that the plot fills the page, while leaving a 0.25 inch border.
##
## The @qcode{"tall"} option sets the orientation to @qcode{"portrait"} and
## fills the page with the plot, while leaving a 0.25 inch border.
##
## The @qcode{"portrait"} option (default) changes the orientation so the plot
## height is larger than the plot width.  It also restores the default
## @qcode{"paperposition"} property.
##
## When called with no arguments, return the current print orientation.
##
## If the argument @var{hfig} is omitted, then operate on the current figure
## returned by @code{gcf}.
## @seealso{print, saveas}
## @end deftypefn
    
    ## Author: Paul Kienzle
## Adapted-By: jwe
    
    
@function
def orient(varargin=None,*args,**kwargs):
    varargin = orient.varargin
    nargin = orient.nargin

    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:52
    if (nargs > 0 and numel(varargin[1]) == 1 and isfigure(varargin[1])):
        cf=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:55
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:56
        nargs
    else:
        cf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:59
    
    if (nargs > 1):
        print_usage()
    
    paperunits=get(cf,'paperunits')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:66
    try:
        set(cf,'paperunits','inches')
        if (nargs == 0):
            retval=get(cf,'paperorientation')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:71
            if (strcmp(retval,'portrait')):
                papersize=get(cf,'papersize')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:73
                paperposition=get(cf,'paperposition')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:74
                if (paperposition == cat(0.25,0.25(papersize - 0.5))):
                    retval='tall'
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:76
        else:
            orientation=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:80
            if (strcmpi(orientation,'landscape') or strcmpi(orientation,'portrait')):
                if (logical_not(strcmpi(get(cf,'paperorientation'),orientation))):
                    ## FIXME: with the proper listeners in place there won't be a need to
          ##        set the papersize and paperposition here.
                    papersize=get(cf,'papersize')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:86
                    paperposition=get(cf,'paperposition')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:87
                    set(cf,'paperorientation',orientation)
                    set(cf,'papersize',papersize[cat(2,1)])
                    set(cf,'paperposition',paperposition[cat(2,1,4,3)])
                if (strcmpi(orientation,'portrait')):
                    ## portrait restores the default
          ## FIXME: Should use "default" here, but Octave complains
          ##        that "paperposition" is not a default property.
                    set(cf,'paperposition','factory')
                else:
                    ## landscape also sets the plot to occupy the entire page
                    papersize=get(cf,'papersize')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:99
                    set(cf,'paperposition',cat(0.25,0.25,(papersize - 0.5)))
            else:
                if (strcmpi(varargin[1],'tall')):
                    orient('portrait')
                    papersize=get(cf,'papersize')
# /home/lei/octave-4.0.2/scripts/plot/appearance/orient.m:104
                    set(cf,'paperposition',cat(0.25,0.25,(papersize - 0.5)))
                else:
                    error('orient: unknown ORIENTATION')
    finally:
        set(cf,'paperunits',paperunits)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __axis_limits__ (@var{fcn}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __axis_limits__(fcn=None,varargin=None,*args,**kwargs):
    varargin = __axis_limits__.varargin
    nargin = __axis_limits__.nargin

    hax,varargin,nargin=__plt_get_axis_arg__(fcn,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:26
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:29
    
    if (nargin == 0):
        retval=get(hax,fcn)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:33
    else:
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:35
        fcnmode=matlabarray(cat(fcn,'mode'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:36
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:37
        if (ischar(arg)):
            if (strcmpi(arg,'mode')):
                retval=get(hax,fcnmode)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:40
            else:
                if (any(strcmpi(arg,cellarray(['auto','manual'])))):
                    set(hax,fcnmode,arg)
        else:
            if (logical_not(isnumeric(arg)) and any(size(ravel(arg)) != cat(2,1))):
                error('%s: LIMITS must be a 2-element vector',fcn)
            else:
                if (arg[1] >= arg[2]):
                    error('%s: axis limits must be increasing',fcn)
                else:
                    autoscale=isinf(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:51
                    if (any(autoscale)):
                        set(hax,fcnmode,'auto')
                        arg[autoscale]=get(hax,fcn)(autoscale)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_limits__.m:54
                    set(hax,fcn,ravel(arg))
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __axis_label__ (@var{caller}, @var{h}, @var{txt}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __axis_label__(hax=None,caller=None,txt=None,varargin=None,*args,**kwargs):
    varargin = __axis_label__.varargin
    nargin = __axis_label__.nargin

    h=get(hax,caller)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_label__.m:28
    set(h,'fontangle',get(hax,'fontangle'),'fontname',get(hax,'fontname'),'fontunits',get(hax,'fontunits'),'fontsize',get(hax,'fontsize'),'fontweight',get(hax,'fontweight'),'string',txt,varargin[:])
    if (nargout > 0):
        retval=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/private/__axis_label__.m:39
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} whitebg ()
## @deftypefnx {Function File} {} whitebg (@var{color})
## @deftypefnx {Function File} {} whitebg ("none")
## @deftypefnx {Function File} {} whitebg (@var{hfig}, @dots{})
## Invert the colors in the current color scheme.
##
## The root properties are also inverted such that all subsequent plot use the
## new color scheme.
##
## If the optional argument @var{color} is present then the background color
## is set to @var{color} rather than inverted.  @var{color} may be a string
## representing one of the eight known colors or an RGB triplet.  The special
## string argument @qcode{"none"} restores the plot to the default colors.
##
## If the first argument @var{hfig} is a figure handle, then operate on
## this figure rather than the current figure returned by @code{gcf}.  The
## root properties will not be changed.
## @seealso{reset, get, set}
## @end deftypefn
    
    
@function
def whitebg(varargin=None,*args,**kwargs):
    varargin = whitebg.varargin
    nargin = whitebg.nargin

    h=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:41
    color=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:42
    if (nargin > 0 and nargin < 3):
        if (ishandle(varargin[1])):
            h=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:46
            if (nargin == 2):
                color=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:48
        else:
            if (nargin == 1):
                color=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:51
            else:
                print_usage()
    else:
        if (nargin != 0):
            print_usage()
    
    typ=get(h,'type')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:59
    if (strcmp(typ,'root')):
        isroot=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:62
        fig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:63
    else:
        if (strcmp(typ,'figure')):
            isroot=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:65
            fig=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:66
        else:
            error('expecting a figure handle')
    
    axes=findall(fig,'type','axes')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:71
    if (isnan(color)):
        ## Root figure. Set the default axes and figure properties so that
    ## subsequent plots have the new color scheme
        if (isroot):
            fac=get(0,'factory')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:76
            fields=fieldnames(fac)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:77
            fieldindex=intersect(find(logical_not(cellfun('isempty',regexp(fields,'color')))),union(find(logical_not(cellfun('isempty',regexp(fields,'factoryaxes.*')))),find(logical_not(cellfun('isempty',regexp(fields,'factoryfigure.*'))))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:78
            for nf in arange(1,numel(fieldindex)).reshape(-1):
                defaultfield=strrep(fields[fieldindex[nf]],'factory','default')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:82
                try:
                    defaultvalue=1 - get(0,defaultfield[n])
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:84
                finally:
                    pass
                set(0,defaultfield,defaultvalue)
        ## Load all objects which qualify for being searched.
        handles=copy(fig)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:94
        h=copy(fig)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:95
        while (numel(handles)):

            children=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:97
            for n in arange(1,numel(handles)).reshape(-1):
                children=union(children,get(handles[n],'children'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:99
            handles=copy(children)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:101
            h=union(h,children)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:102

        for nh in arange(1,numel(h)).reshape(-1):
            p=get(h[nh])
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:106
            fields=fieldnames(p)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:107
            fieldindex=find(logical_not(cellfun('isempty',regexp(fields,'color'))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:108
            if (numel(fieldindex)):
                for nf in arange(1,numel(fieldindex)).reshape(-1):
                    field=fields[fieldindex[nf]]
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:111
                    c=subsref(p,struct('type','.','subs',field))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:112
                    if (logical_not(ischar(c)) and columns(c) == 3):
                        set(h[nh],field,1 - c)
            ## If h(nh) is a figure or axes invert default color properties
            typ=subsref(p,struct('type','.','subs','type'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:120
            if (strcmp(typ,'axes') or strcmp(typ,'figure')):
                def_=get(h[nh],'default')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:122
                fields=fieldnames(def_)
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:123
                if (logical_not(isempty(fields))):
                    fieldindex=find(logical_not(cellfun('isempty',regexp(fields,'color'))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:125
                    for nf in arange(1,numel(fieldindex)).reshape(-1):
                        defaultfield=fields[fieldindex[nf]]
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:127
                        defaultvalue=1 - subsref(def_,struct('type','.','subs',defaultfield))
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:128
                        set(h[nh],defaultfield,defaultvalue)
    else:
        ## FIXME
    ## Is this the right thing to do in this case?
        set(findall(fig,'type','axes'),'color',color)
        if (isroot):
            defs=get(0,'default')
# /home/lei/octave-4.0.2/scripts/plot/appearance/whitebg.m:140
            if (isfield(defs,'defaultaxescolor') and strcmp(defs.defaultaxescolor,'none')):
                set(0,'defaultaxescolor',color)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} title (@var{string})
## @deftypefnx {Function File} {} title (@var{string}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} title (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} title (@dots{})
## Specify the string used as a title for the current axis.
##
## An optional list of @var{property}/@var{value} pairs can be used to change
## the appearance of the created title text object.
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
##
## The optional return value @var{h} is a graphics handle to the created text
## object.
## @seealso{xlabel, ylabel, zlabel, text}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def title(varargin=None,*args,**kwargs):
    varargin = title.varargin
    nargin = title.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('title',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/title.m:41
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/title.m:44
    
    if (rem(nargin,2) != 1):
        print_usage()
    
    htmp=__axis_label__(hax,'title',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/title.m:51
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/appearance/title.m:54
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} diffuse (@var{sx}, @var{sy}, @var{sz}, @var{lv})
## Calculate the diffuse reflection strength of a surface defined by the normal
## vector elements @var{sx}, @var{sy}, @var{sz}.
##
## The light source location vector @var{lv} can be given as a 2-element vector
## [azimuth, elevation] in degrees or as a 3-element vector [x, y, z].
## @seealso{specular, surfl}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def diffuse(sx=None,sy=None,sz=None,lv=None,*args,**kwargs):
    varargin = diffuse.varargin
    nargin = diffuse.nargin

    if (nargin != 4):
        print_usage()
    
    ## Check normal vectors
    if (logical_not(size_equal(sx,sy,sz))):
        error('diffuse: SX, SY, and SZ must be the same size')
    
    ## Check light vector (lv) argument
    if (logical_not(isvector(lv)) or length(lv) < 2 or length(lv) > 3):
        error('diffuse: light vector LV must be a 2- or 3-element vector')
    else:
        if (length(lv) == 2):
            lv[1],lv[2],lv[3]=sph2cart(dot(lv[1],pi) / 180,dot(lv[2],pi) / 180,1.0,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/diffuse.m:46
    
    ## Normalize view and light vector.
    if (sum(abs(lv)) > 0):
        lv /= norm(lv)
    
    ns=sqrt(sx ** 2 + sy ** 2 + sz ** 2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/diffuse.m:54
    retval=(dot(sx,lv[1]) + dot(sy,lv[2]) + dot(sz,lv[3])) / ns
# /home/lei/octave-4.0.2/scripts/plot/appearance/diffuse.m:55
    retval[retval < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/diffuse.m:56
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{xlimits} =} xlim ()
## @deftypefnx {Function File} {@var{xmode} =} xlim ("mode")
## @deftypefnx {Function File} {} xlim ([@var{x_lo} @var{x_hi}])
## @deftypefnx {Function File} {} xlim ("auto")
## @deftypefnx {Function File} {} xlim ("manual")
## @deftypefnx {Function File} {} xlim (@var{hax}, @dots{})
## Query or set the limits of the x-axis for the current plot.
##
## Called without arguments @code{xlim} returns the x-axis limits of the
## current plot.
##
## With the input query @qcode{"mode"}, return the current x-limit
## calculation mode which is either @qcode{"auto"} or @qcode{"manual"}.
##
## If passed a 2-element vector [@var{x_lo} @var{x_hi}], the limits of the
## x-axis are set to these values and the mode is set to @qcode{"manual"}.
##
## The current plotting mode can be changed by using either @qcode{"auto"}
## or @qcode{"manual"} as the argument.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
## @seealso{ylim, zlim, axis, set, get, gca}
## @end deftypefn
    
    
@function
def xlim(varargin=None,*args,**kwargs):
    varargin = xlim.varargin
    nargin = xlim.nargin

    ret=__axis_limits__('xlim',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlim.m:46
    if (logical_not(isempty(ret))):
        retval=copy(ret)
# /home/lei/octave-4.0.2/scripts/plot/appearance/xlim.m:49
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} axis ()
## @deftypefnx {Function File} {} axis ([@var{x}_lo @var{x}_hi])
## @deftypefnx {Function File} {} axis ([@var{x}_lo @var{x}_hi @var{y}_lo @var{y}_hi])
## @deftypefnx {Function File} {} axis ([@var{x}_lo @var{x}_hi @var{y}_lo @var{y}_hi @var{z}_lo @var{z}_hi])
## @deftypefnx {Function File} {} axis (@var{option})
## @deftypefnx {Function File} {} axis (@dots{}, @var{option})
## @deftypefnx {Function File} {} axis (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{limits} =} axis ()
## Set axis limits and appearance.
##
## The argument @var{limits} should be a 2-, 4-, or 6-element vector.  The
## first and second elements specify the lower and upper limits for the
## x-axis.  The third and fourth specify the limits for the y-axis, and the
## fifth and sixth specify the limits for the z-axis.  The special values
## -Inf and Inf may be used to indicate that the limit should automatically be
## computed based on the data in the axis.
##
## Without any arguments, @code{axis} turns autoscaling on.
##
## With one output argument, @code{@var{limits} = axis} returns the current
## axis limits.
##
## The vector argument specifying limits is optional, and additional string
## arguments may be used to specify various axis properties.  For example,
##
## @example
## axis ([1, 2, 3, 4], "square");
## @end example
##
## @noindent
## forces a square aspect ratio, and
##
## @example
## axis ("tic", "labely");
## @end example
##
## @noindent
## turns tic marks on for all axes and tic mark labels on for the y-axis only.
##
## @noindent
## The following options control the aspect ratio of the axes.
##
## @table @asis
## @item @qcode{"square"}
## Force a square aspect ratio.
##
## @item @qcode{"equal"}
## Force x distance to equal y-distance.
##
## @item @qcode{"normal"}
## Restore default aspect ratio.
## @end table
##
## @noindent
## The following options control the way axis limits are interpreted.
##
## @table @asis
## @item @qcode{"auto"}
## Set the specified axes to have nice limits around the data or all if no
## axes are specified.
##
## @item @qcode{"manual"}
## Fix the current axes limits.
##
## @item @qcode{"tight"}
## Fix axes to the limits of the data.
##
## @item @qcode{"image"}
## Equivalent to @qcode{"tight"} and @qcode{"equal"}.
## @end table
##
## @noindent
## The following options affect the appearance of tic marks.
##
## @table @asis
## @item @qcode{"on"}
## Turn tic marks and labels on for all axes.
##
## @item @qcode{"off"}
## Turn tic marks off for all axes.
##
## @item @qcode{"tic[xyz]"}
## Turn tic marks on for all axes, or turn them on for the specified axes and
## off for the remainder.
##
## @item @qcode{"label[xyz]"}
## Turn tic labels on for all axes, or turn them on for the specified axes
## and off for the remainder.
##
## @item @qcode{"nolabel"}
## Turn tic labels off for all axes.
## @end table
##
## Note, if there are no tic marks for an axis, there can be no labels.
##
## @noindent
## The following options affect the direction of increasing values on the axes.
##
## @table @asis
## @item @qcode{"ij"}
## Reverse y-axis, so lower values are nearer the top.
##
## @item @qcode{"xy"}
## Restore y-axis, so higher values are nearer the top.
## @end table
##
## If the first argument @var{hax} is an axes handle, then operate on this
## axes rather than the current axes returned by @code{gca}.
##
## @seealso{xlim, ylim, zlim, daspect, pbaspect, box, grid}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def axis(varargin=None,*args,**kwargs):
    varargin = axis.varargin
    nargin = axis.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('axis',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:136
    oldfig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:138
    if (logical_not(isempty(hax))):
        oldfig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:140
    
    try:
        if (isempty(hax)):
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:144
        if (nargin == 0):
            limits=__axis__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:147
        else:
            __axis__(hax,varargin[:])
    finally:
        if (logical_not(isempty(oldfig))):
            set(0,'currentfigure',oldfig)
    
    return limits
    
if __name__ == '__main__':
    pass
    
    
@function
def __axis__(ca=None,ax=None,varargin=None,*args,**kwargs):
    varargin = __axis__.varargin
    nargin = __axis__.nargin

    if (nargin == 1):
        if (nargout == 0):
            set(ca,'xlimmode','auto','ylimmode','auto','zlimmode','auto')
        else:
            xlim=get(ca,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:165
            ylim=get(ca,'ylim')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:166
            view=get(ca,'view')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:167
            if (view[2] == 90):
                limits=matlabarray(cat(xlim,ylim))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:169
            else:
                zlim=get(ca,'zlim')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:171
                limits=matlabarray(cat(xlim,ylim,zlim))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:172
    else:
        if (ischar(ax)):
            len_=length(ax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:177
            if (strcmpi(ax,'ij')):
                set(ca,'ydir','reverse')
            else:
                if (strcmpi(ax,'xy')):
                    set(ca,'ydir','normal')
                else:
                    if (strcmpi(ax,'image')):
                        __axis__(ca,'equal')
                        set(ca,'plotboxaspectratiomode','auto')
                        __do_tight_option__(ca)
                    else:
                        if (strcmpi(ax,'square')):
                            set(ca,'dataaspectratiomode','auto','plotboxaspectratio',cat(1,1,1))
                        else:
                            if (strcmp(ax,'equal')):
                                if (strcmp(get(ancestor(ca,'figure'),'__graphics_toolkit__'),'gnuplot')):
                                    ## FIXME: gnuplot applies the aspect ratio activepostionproperty.
                                    set(ca,'activepositionproperty','position')
                                    ## aspect related magnitudes even if the aspect ratio is the same
        ## (useful with the x11 gnuplot terminal after a window resize)
                                    set(ca,'dataaspectratiomode','auto')
                                set(ca,'dataaspectratio',cat(1,1,1),'plotboxaspectratio',cat(5,4,4))
                            else:
                                if (strcmpi(ax,'normal')):
                                    ## Set plotboxaspectratio to something obtuse so that switching
      ## back to "auto" will force a re-calculation.
                                    set(ca,'plotboxaspectratio',cat(3,2,1))
                                    set(ca,'plotboxaspectratiomode','auto','dataaspectratiomode','auto')
                                else:
                                    if (len_ >= 4 and strcmpi(ax[1:4],'auto')):
                                        if (len_ > 4):
                                            if (any(ax == 'x')):
                                                set(ca,'xlimmode','auto')
                                            if (any(ax == 'y')):
                                                set(ca,'ylimmode','auto')
                                            if (any(ax == 'z')):
                                                set(ca,'zlimmode','auto')
                                        else:
                                            set(ca,'xlimmode','auto','ylimmode','auto','zlimmode','auto')
                                    else:
                                        if (strcmpi(ax,'manual')):
                                            ## fixes the axis limits, like axis(axis) should;
                                            set(ca,'xlimmode','manual','ylimmode','manual','zlimmode','manual')
                                        else:
                                            if (strcmpi(ax,'tight')):
                                                ## sets the axis limits to the min and max of all data.
                                                __do_tight_option__(ca)
                                            else:
                                                if (strcmpi(ax,'on') or strcmpi(ax,'tic')):
                                                    set(ca,'xtickmode','auto','ytickmode','auto','ztickmode','auto')
                                                    if (strcmpi(ax,'on')):
                                                        set(ca,'xticklabelmode','auto','yticklabelmode','auto','zticklabelmode','auto')
                                                    set(ca,'visible','on')
                                                else:
                                                    if (strcmpi(ax,'off')):
                                                        set(ca,'xtick',[],'ytick',[],'ztick',[])
                                                        set(ca,'visible','off')
                                                    else:
                                                        if (len_ > 3 and strcmpi(ax[1:3],'tic')):
                                                            if (any(ax == 'x')):
                                                                set(ca,'xtickmode','auto')
                                                            else:
                                                                set(ca,'xtick',[])
                                                            if (any(ax == 'y')):
                                                                set(ca,'ytickmode','auto')
                                                            else:
                                                                set(ca,'ytick',[])
                                                            if (any(ax == 'z')):
                                                                set(ca,'ztickmode','auto')
                                                            else:
                                                                set(ca,'ztick',[])
                                                        else:
                                                            if (strcmpi(ax,'label')):
                                                                set(ca,'xticklabelmode','auto','yticklabelmode','auto','zticklabelmode','auto')
                                                            else:
                                                                if (strcmpi(ax,'nolabel')):
                                                                    set(ca,'xticklabel','','yticklabel','','zticklabel','')
                                                                else:
                                                                    if (len_ > 5 and strcmpi(ax[1:5],'label')):
                                                                        if (any(ax == 'x')):
                                                                            set(ca,'xticklabelmode','auto')
                                                                        else:
                                                                            set(ca,'xticklabel','')
                                                                        if (any(ax == 'y')):
                                                                            set(ca,'yticklabelmode','auto')
                                                                        else:
                                                                            set(ca,'yticklabel','')
                                                                        if (any(ax == 'z')):
                                                                            set(ca,'zticklabelmode','auto')
                                                                        else:
                                                                            set(ca,'zticklabel','')
                                                                    else:
                                                                        warning('unknown axis option \'%s\'',ax)
        else:
            if (isvector(ax)):
                len_=length(ax)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:287
                if (len_ != 2 and len_ != 4 and len_ != 6):
                    error('axis: expecting vector with 2, 4, or 6 elements')
                for i in arange(1,len_,2).reshape(-1):
                    if (ax[i] >= ax[i + 1]):
                        error('axis: limits(%d) must be less than limits(%d)',i,i + 1)
                if (len_ > 1):
                    xlim(ca,ax[1:2])
                if (len_ > 3):
                    ylim(ca,ax[3:4])
                if (len_ > 5):
                    zlim(ca,ax[5:6])
            else:
                error('axis: expecting no args, or a vector with 2, 4, or 6 elements')
    
    if (logical_not(isempty(varargin))):
        __axis__(ca,varargin[:])
    
    return limits
    
if __name__ == '__main__':
    pass
    
    
@function
def __get_tight_lims__(ca=None,ax=None,*args,**kwargs):
    varargin = __get_tight_lims__.varargin
    nargin = __get_tight_lims__.nargin

    ## Get the limits for axis ("tight").
  ## AX should be one of "x", "y", or "z".
    kids=findobj(ca,'-property',strcat(ax,'data'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:325
    
    ## Exclude the redundant hgroup values.
    hg_kids=findobj(kids,'type','hggroup')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:328
    kids=setdiff(kids,hg_kids)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:329
    if (isempty(kids)):
        ## Return the current limits.
        lims=get(ca,strcat(ax,'lim'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:332
    else:
        data=get(kids,strcat(ax,'data'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:334
        types=get(kids,'type')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:335
        scale=get(ca,strcat(ax,'scale'))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:337
        if (logical_not(iscell(data))):
            data=cellarray([data])
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:339
        ## Extend image data one pixel
        idx=strcmp(types,'image')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:343
        if (any(idx) and (ax == 'x' or ax == 'y')):
            imdata=data[idx]
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:345
            px=arrayfun(__image_pixel_size__,kids[idx],'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:346
            ipx=ifelse(ax == 'x',1,2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:347
            imdata=cellfun(lambda x=None,dx=None: cat((min(x) - dx[ipx]),(max(x) + dx[ipx])),imdata,px,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:348
            data[idx]=imdata
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:350
        if (strcmp(scale,'log')):
            tmp=copy(data)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:354
            data=cellfun(lambda x=None: x[x > 0],tmp,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:355
            n=cellfun('isempty',data)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:356
            data[n]=cellfun(lambda x=None: x[x < 0],tmp[n],'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:357
        data=cellfun(lambda x=None: x[isfinite(x)],data,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:359
        data=data[logical_not(cellfun('isempty',data))]
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:360
        if (logical_not(isempty(data))):
            ## Change data from cell array of various sizes to a single column vector
            data=cat(1,cellindexmat(data,':')[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:363
            lims=matlabarray(cat(min(data),max(data)))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:364
        else:
            lims=matlabarray(cat(0,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:366
    
    return lims
    
if __name__ == '__main__':
    pass
    
    
@function
def __do_tight_option__(ca=None,*args,**kwargs):
    varargin = __do_tight_option__.varargin
    nargin = __do_tight_option__.nargin

    xlim=__get_tight_lims__(ca,'x')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:374
    if (all(xlim == 0)):
        xlim=dot(eps(),cat(- 1,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:376
    else:
        if (diff(xlim == 0)):
            xlim=multiply(xlim,(1 + dot(eps(),cat(- 1,1))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:378
    
    ylim=__get_tight_lims__(ca,'y')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:380
    if (all(ylim == 0)):
        ylim=dot(eps(),cat(- 1,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:382
    else:
        if (diff(ylim == 0)):
            ylim=multiply(ylim,(1 + dot(eps(),cat(- 1,1))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:384
    
    set(ca,'xlim',xlim,'ylim',ylim)
    nd=__calc_dimensions__(ca)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:387
    is3dview=(get(ca,'view')(2) != 90)
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:388
    if (nd > 2 and is3dview):
        zlim=__get_tight_lims__(ca,'z')
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:390
        if (all(zlim == 0)):
            zlim=dot(eps(),cat(- 1,1))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:392
        else:
            if (diff(zlim == 0)):
                zlim=multiply(zlim,(1 + dot(eps(),cat(- 1,1))))
# /home/lei/octave-4.0.2/scripts/plot/appearance/axis.m:394
        set(ca,'zlim',zlim)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test 'axis tight' with differently oriented, differently numbered data vecs
## Bug #40036.
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{zlimits} =} zlim ()
## @deftypefnx {Function File} {@var{xmode} =} zlim ("mode")
## @deftypefnx {Function File} {} zlim ([@var{z_lo} @var{z_hi}])
## @deftypefnx {Function File} {} zlim ("auto")
## @deftypefnx {Function File} {} zlim ("manual")
## @deftypefnx {Function File} {} zlim (@var{hax}, @dots{})
## Query or set the limits of the z-axis for the current plot.
##
## Called without arguments @code{zlim} returns the z-axis limits of the
## current plot.
##
## With the input query @qcode{"mode"}, return the current
## z-limit calculation mode which is either @qcode{"auto"} or @qcode{"manual"}.
##
## If passed a 2-element vector [@var{z_lo} @var{z_hi}], the limits of the
## x-axis are set to these values and the mode is set to @qcode{"manual"}.
##
## The current plotting mode can be changed by using either @qcode{"auto"}
## or @qcode{"manual"} as the argument.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
## @seealso{xlim, ylim, axis, set, get, gca}
## @end deftypefn
    
    
@function
def zlim(varargin=None,*args,**kwargs):
    varargin = zlim.varargin
    nargin = zlim.nargin

    ret=__axis_limits__('zlim',varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlim.m:46
    if (logical_not(isempty(ret))):
        retval=copy(ret)
# /home/lei/octave-4.0.2/scripts/plot/appearance/zlim.m:49
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} view (@var{azimuth}, @var{elevation})
## @deftypefnx {Function File} {} view ([@var{azimuth} @var{elevation}])
## @deftypefnx {Function File} {} view ([@var{x} @var{y} @var{z}])
## @deftypefnx {Function File} {} view (2)
## @deftypefnx {Function File} {} view (3)
## @deftypefnx {Function File} {} view (@var{hax}, @dots{})
## @deftypefnx {Function File} {[@var{azimuth}, @var{elevation}] =} view ()
## Query or set the viewpoint for the current axes.
##
## The parameters @var{azimuth} and @var{elevation} can be given as two
## arguments or as 2-element vector.  The viewpoint can also be specified with
## Cartesian coordinates @var{x}, @var{y}, and @var{z}.
##
## The call @code{view (2)} sets the viewpoint to @w{@var{azimuth} = 0}
## and @w{@var{elevation} = 90}, which is the default for 2-D graphs.
##
## The call @code{view (3)} sets the viewpoint to @w{@var{azimuth} = -37.5}
## and @w{@var{elevation} = 30}, which is the default for 3-D graphs.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
##
## If no inputs are given, return the current @var{azimuth} and @var{elevation}.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def view(varargin=None,*args,**kwargs):
    varargin = view.varargin
    nargin = view.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('view',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:49
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:51
    
    if (nargin > 3):
        print_usage()
    
    if (nargin == 0):
        x=get(hax,'view')
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:59
        az=x[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:60
        el=x[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:61
    else:
        if (length(varargin) == 1):
            x=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:63
            if (length(x) == 2):
                az=x[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:65
                el=x[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:66
            else:
                if (length(x) == 3):
                    az,el=cart2sph(x[1],x[2],x[3],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:68
                    az *= 180 / pi
                    az += 90
                    el *= 180 / pi
                else:
                    if (x == 2):
                        az=0
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:73
                        el=90
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:74
                    else:
                        if (x == 3):
                            az=- 37.5
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:76
                            el=30
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:77
                        else:
                            print_usage()
        else:
            if (length(varargin) == 2):
                az=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:82
                el=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:83
    
    if (nargin > 0):
        set(hax,'view',cat(az,el))
    else:
        if (nargout == 1):
            azimuth=matlabarray(cat(az,el))
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:90
        else:
            if (nargout == 2):
                azimuth=copy(az)
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:92
                elevation=copy(el)
# /home/lei/octave-4.0.2/scripts/plot/appearance/view.m:93
    
    return azimuth,elevation
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{plot_box_aspect_ratio} =} pbaspect ( )
## @deftypefnx {Function File} {} pbaspect (@var{plot_box_aspect_ratio})
## @deftypefnx {Function File} {} pbaspect (@var{mode})
## @deftypefnx {Function File} {@var{plot_box_aspect_ratio_mode} =} pbaspect ("mode")
## @deftypefnx {Function File} {} pbaspect (@var{hax}, @dots{})
##
## Query or set the plot box aspect ratio of the current axes.
##
## The aspect ratio is a normalized 3-element vector representing the rendered
## lengths of the x, y, and z axes.
##
## @code{pbaspect(@var{mode})}
##
## Set the plot box aspect ratio mode of the current axes.  @var{mode} is
## either @qcode{"auto"} or @qcode{"manual"}.
##
## @code{pbaspect ("mode")}
##
## Return the plot box aspect ratio mode of the current axes.
##
## @code{pbaspect (@var{hax}, @dots{})}
##
## Operate on the axes in handle @var{hax} instead of the current axes.
##
## @seealso{axis, daspect, xlim, ylim, zlim}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-01-26
    
    
@function
def pbaspect(varargin=None,*args,**kwargs):
    varargin = pbaspect.varargin
    nargin = pbaspect.nargin

    ## Grab axes handle if present
    if (nargin > 0):
        if (isscalar(varargin[1]) and isaxes(varargin[1])):
            hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:55
            varargin=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:56
        else:
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:58
    else:
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:61
    
    nargin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:64
    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        pbratio=get(hax,'plotboxaspectratio')
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:70
    else:
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:72
        if (isnumeric(arg)):
            if (numel(arg) == 2):
                set(hax,'plotboxaspectratio',cat(arg,1))
            else:
                if (numel(arg) == 3):
                    set(hax,'plotboxaspectratio',arg)
                else:
                    error('pbaspect: PLOT_BOX_ASPECT_RATIO must be a 2 or 3 element vector')
        else:
            if (ischar(arg)):
                arg=tolower(arg)
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:82
                if 'auto' == (arg):
                    set(hax,'plotboxaspectratiomode','auto')
                else:
                    if 'manual' == (arg):
                        set(hax,'plotboxaspectratiomode','manual')
                    else:
                        if 'mode' == (arg):
                            pbratio=get(hax,'plotboxaspectratiomode')
# /home/lei/octave-4.0.2/scripts/plot/appearance/pbaspect.m:89
                        else:
                            error('pbaspect: Invalid mode <%s>',arg)
            else:
                print_usage()
    
    return pbratio
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} shading (@var{type})
## @deftypefnx {Function File} {} shading (@var{hax}, @var{type})
## Set the shading of patch or surface graphic objects.
##
## Valid arguments for @var{type} are
##
## @table @asis
## @item @qcode{"flat"}
## Single colored patches with invisible edges.
##
## @item @qcode{"faceted"}
## Single colored patches with visible edges.
##
## @item @qcode{"interp"}
## Color between patch vertices are interpolated and the patch edges are
## invisible.
## @end table
##
## If the first argument @var{hax} is an axes handle, then plot into this axis,
## rather than the current axes returned by @code{gca}.
## @seealso{fill, mesh, patch, pcolor, surf, surface, hidden}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def shading(varargin=None,*args,**kwargs):
    varargin = shading.varargin
    nargin = shading.nargin

    hax,varargin,nargin=__plt_get_axis_arg__('shading',varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:47
    if (nargin != 1):
        print_usage()
    
    mode=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:53
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:56
    
    ## Find all patch and surface objects that are descendants of hax
  ## and  which are not part of a contour plot hggroup.
    hlist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:61
    kids=get(hax,'children')
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:62
    while (logical_not(isempty(kids))):

        types=get(kids,'type')
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:64
        hlist=matlabarray(cat([hlist],[kids[strcmp(types,'patch')]]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:65
        hlist=matlabarray(cat([hlist],[kids[strcmp(types,'surface')]]))
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:66
        parents=kids[strcmp(types,'axes')]
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:67
        hglist=kids[strcmp(types,'hggroup')]
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:68
        for i in arange(1,numel(hglist)).reshape(-1):
            props=get(hglist[i])
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:70
            if (logical_not(isfield(props,'levelstep'))):
                parents[end() + 1]=hglist[i]
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:72
        kids=get(parents,'children')
# /home/lei/octave-4.0.2/scripts/plot/appearance/shading.m:75

    
    ## FIXME: This is the old, simple code.
  ##        Unfortunately, it also shades contour plots which is not desirable.
  ##hp = findobj (hax, "type", "patch");
  ##hs = findobj (hax, "type", "surface");
  ##hlist = [hp(:); hs(:)];
    
    if 'flat' == (lower(mode)):
        set(hlist,'facecolor','flat')
        set(hlist,'edgecolor','none')
    else:
        if 'interp' == (lower(mode)):
            set(hlist,'facecolor','interp')
            set(hlist,'edgecolor','none')
        else:
            if 'faceted' == (lower(mode)):
                set(hlist,'facecolor','flat')
                set(hlist,'edgecolor',cat(0,0,0))
            else:
                error('shading: Invalid MODE "%s"',mode)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} findobj ()
## @deftypefnx {Function File} {@var{h} =} findobj (@var{prop_name}, @var{prop_value}, @dots{})
## @deftypefnx {Function File} {@var{h} =} findobj (@var{prop_name}, @var{prop_value}, "-@var{logical_op}", @var{prop_name}, @var{prop_value})
## @deftypefnx {Function File} {@var{h} =} findobj ("-property", @var{prop_name})
## @deftypefnx {Function File} {@var{h} =} findobj ("-regexp", @var{prop_name}, @var{pattern})
## @deftypefnx {Function File} {@var{h} =} findobj (@var{hlist}, @dots{})
## @deftypefnx {Function File} {@var{h} =} findobj (@var{hlist}, "flat", @dots{})
## @deftypefnx {Function File} {@var{h} =} findobj (@var{hlist}, "-depth", @var{d}, @dots{})
## Find graphics object with specified property values.
##
## The simplest form is
##
## @example
## findobj (@var{prop_name}, @var{prop_value})
## @end example
##
## @noindent
## which returns the handles of all objects which have a property named
## @var{prop_name} that has the value @var{prop_value}.  If multiple
## property/value pairs are specified then only objects meeting all of the
## conditions are returned.
##
## The search can be limited to a particular set of objects and their
## descendants, by passing a handle or set of handles @var{hlist} as the first
## argument.
##
## The depth of the object hierarchy to search can be limited with the
## @qcode{"-depth"} argument.  An example of searching only three generations
## of children is:
##
## @example
## findobj (@var{hlist}, "-depth", 3, @var{prop_name}, @var{prop_value})
## @end example
##
## Specifying a depth @var{d} of 0, limits the search to the set of objects
## passed in @var{hlist}.  A depth @var{d} of 0 is equivalent to the
## @qcode{"flat"} argument.
##
## A specified logical operator may be applied to the pairs of @var{prop_name}
## and @var{prop_value}.  The supported logical operators are:
## @qcode{"-and"}, @qcode{"-or"},
## @qcode{"-xor"}, @qcode{"-not"}.
##
## Objects may also be matched by comparing a regular expression to the
## property values, where property values that match
## @code{regexp (@var{prop_value}, @var{pattern})} are returned.
##
## Finally, objects may be matched by property name only by using the
## @qcode{"-property"} option.
##
## Implementation Note: The search only includes objects with visible
## handles (HandleVisibility = @qcode{"on"}).  @xref{XREFfindall,,findall}, to
## search for all objects including hidden ones.
## @seealso{findall, allchild, get, set}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
    
    
@function
def findobj(varargin=None,*args,**kwargs):
    varargin = findobj.varargin
    nargin = findobj.nargin

    depth=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:80
    if (nargin == 0):
        handles=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:82
        n1=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:83
    else:
        if (logical_not(isempty(varargin[1]))):
            if (ishandle(varargin[1](1))):
                handles=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:87
                n1=2
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:88
            else:
                handles=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:90
                n1=1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:91
        else:
            ## Return [](0x1) for compatibility.
            h=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:95
            return h
        if (n1 <= nargin):
            if (ischar(varargin[n1])):
                if (strcmpi(varargin[n1],'flat')):
                    depth=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:101
                    n1=n1 + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:102
            else:
                error('findobj: properties and options must be strings')
    
    if (n1 <= nargin and nargin > 0):
        args=varargin[n1:nargin]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:111
    else:
        args=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:113
    
    regularexpression=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:116
    property=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:117
    logicaloperator=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:118
    extranegation=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:119
    pname=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:120
    pvalue=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:121
    np=1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:122
    na=1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:123
    operatorprecedence=cellarray(['-not','-and','-or','-xor'])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:124
    while (na <= numel(args)):

        regularexpression[np]=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:127
        property[np]=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:128
        if (numel(extranegation) < np):
            extranegation[np]=false
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:130
        logicaloperator[np]='and'
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:132
        if (ischar(args[na])):
            if (strcmpi(args[na],'-property')):
                if (na + 1 <= numel(args)):
                    na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:136
                    property[np]=1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:137
                    pname[np]=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:138
                    na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:139
                    pvalue[np]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:140
                    np=np + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:141
                else:
                    error('findobj: inconsistent number of arguments')
            else:
                if (strcmpi(args[na],'-regexp')):
                    if (na + 2 <= numel(args)):
                        regularexpression[np]=1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:147
                        na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:148
                        pname[np]=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:149
                        na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:150
                        pvalue[np]=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:151
                        na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:152
                        np=np + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:153
                    else:
                        error('findobj: inconsistent number of arguments')
                else:
                    if (strcmpi(args[na],'-depth')):
                        if (na + 1 <= numel(args)):
                            na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:159
                            depth=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:160
                            na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:161
                        else:
                            error('findobj: inconsistent number of arguments')
                    else:
                        if (logical_not(strcmp(args[na](1),'-'))):
                            ## Parameter/value pairs.
                            if (na + 1 <= numel(args)):
                                pname[np]=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:168
                                na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:169
                                pvalue[np]=args[na]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:170
                                na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:171
                                if (na <= numel(args)):
                                    if (ischar(args[na])):
                                        if (any(strcmpi(args[na],operatorprecedence))):
                                            logicaloperator[np]=args[na](arange(2,end()))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:175
                                            na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:176
                                    else:
                                        error('findobj: properties and options must be strings')
                                else:
                                    logicaloperator[np]='and'
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:182
                                np=np + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:184
                            else:
                                error('findobj: inconsistent number of arguments')
                        else:
                            if (strcmpi(args[na],'-not')):
                                extranegation[np]=true
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:190
                            na=na + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:192
        else:
            error('findobj: properties and options must be strings')

    
    numpairs=np - 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:199
    if (logical_not(isempty(logicaloperator))):
        logicaloperator=shift(logicaloperator,1)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:201
    
    ## Load all objects which qualify for being searched.
    idepth=0
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:205
    h=copy(handles)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:206
    while (numel(handles) and logical_not((idepth >= depth))):

        children=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:208
        for n in arange(1,numel(handles)).reshape(-1):
            children=matlabarray(cat([children],[get(handles[n],'children')]))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:210
        handles=copy(children)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:212
        h=matlabarray(cat([h],[children]))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:213
        idepth=idepth + 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:214

    
    if (numpairs > 0):
        match=true(numel(h),numpairs)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:218
        for nh in arange(1,numel(h)).reshape(-1):
            p=get(h[nh])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:220
            for np in arange(1,numpairs).reshape(-1):
                fields=fieldnames(p)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:222
                fieldindex=find(strcmpi(fields,pname[np]),1)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:223
                if (numel(fieldindex)):
                    pname[np]=fields[fieldindex]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:225
                    if (property[np]):
                        match[nh,np]=true
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:227
                    else:
                        if (regularexpression[np]):
                            found=regexp(getattr(p,(pname[np])),pvalue[np],'once')
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:230
                            if (isempty(found)):
                                match[nh,np]=false
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:232
                            else:
                                match[nh,np]=true
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:234
                        else:
                            if (numel(getattr(p,(pname[np]))) == numel(pvalue[np])):
                                if (ischar(pvalue[np]) and ischar(getattr(p,(pname[np])))):
                                    match[nh,np]=strcmpi(pvalue[np],getattr(p,(pname[np])))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:238
                                else:
                                    if (isnumeric(pvalue[np] and isnumeric(getattr(p,(pname[np]))))):
                                        match[nh,np]=(pvalue[np] == getattr(p,(pname[np])))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:240
                                    else:
                                        match[nh,np]=isequal(pvalue[np],getattr(p,(pname[np])))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:242
                            else:
                                match[nh,np]=false
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:245
                else:
                    match[nh,np]=false
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:249
                if (extranegation[np]):
                    match[nh,np]=logical_not(match[nh,np])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:252
        if (numpairs > 1):
            for no in arange(1,numel(operatorprecedence)).reshape(-1):
                pairs=find(strcmp(logicaloperator[2:end()],operatorprecedence[no](arange(2,end()))))
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:259
                for np in sort(pairs,'descend').reshape(-1):
                    if (no == 1):
                        match[:,np + 1]=logical_not(match[:,np + 1])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:263
                        logicaloperator[np + 1]=cellarray(['and'])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:264
                    else:
                        match[:,np]=feval(logicaloperator[np + 1],match[:,np],match[:,np + 1])
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:266
                        logicaloperator[np + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:268
                        match[:,np + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:269
                        numpairs=numpairs - 1
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:270
                    if (numpairs < 2):
                        break
                if (numpairs < 2):
                    break
    else:
        match=true(numel(h),1)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:282
    
    h=h[match]
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:285
    h=ravel(h)
# /home/lei/octave-4.0.2/scripts/plot/util/findobj.m:286
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} hgload (@var{filename})
## Load the graphics object in @var{filename} into the graphics handle @var{h}.
##
## If @var{filename} has no extension, Octave will try to find the file with
## and without the standard extension of @file{.ofig}.
## @seealso{hgsave, struct2hdl}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def hgload(filename=None,*args,**kwargs):
    varargin = hgload.varargin
    nargin = hgload.nargin

    ## Check input arguments
    if (nargin != 1):
        print_usage()
    
    ## Check file existence
    __,__,ext=fileparts(filename,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/hgload.m:38
    if (isempty(ext)):
        if (logical_not(isempty(file_in_loadpath(cat(filename,'.ofig'))))):
            filename=matlabarray(cat(filename,'.ofig'))
# /home/lei/octave-4.0.2/scripts/plot/util/hgload.m:41
        else:
            if (isempty(file_in_loadpath(filename))):
                error('hgload: unable to locate file %s',filename)
    else:
        if (isempty(file_in_loadpath(filename))):
            error('hgload: unable to locate file %s',filename)
    
    ## Load the handle
    try:
        stmp=load(filename,'s_oct40')
# /home/lei/octave-4.0.2/scripts/plot/util/hgload.m:53
    finally:
        pass
    
    h=struct2hdl(stmp.s_oct40)
# /home/lei/octave-4.0.2/scripts/plot/util/hgload.m:58
    return h
    
if __name__ == '__main__':
    pass
    
    ## Functional test for hgload/hgsave pair is in hgsave.m
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} cla
## @deftypefnx {Command} {} cla reset
## @deftypefnx {Function File} {} cla (@var{hax})
## @deftypefnx {Function File} {} cla (@var{hax}, "reset")
## Clear the current axes.
##
## @code{cla} operates by deleting child graphic objects with visible
## handles (HandleVisibility = @qcode{"on"}).
##
## If the optional argument @qcode{"reset"} is specified, delete all child
## objects including those with hidden handles and reset all axis properties
## to their defaults.  However, the following properties are not reset:
## Position, Units.
##
## If the first argument @var{hax} is an axes handle, then operate on
## this axis rather than the current axes returned by @code{gca}.
## @seealso{clf, delete, reset}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2008-10-03
    
    
@function
def cla(varargin=None,*args,**kwargs):
    varargin = cla.varargin
    nargin = cla.nargin

    if (nargin > 2):
        print_usage()
    else:
        if (nargin == 0):
            hax=copy(gca)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:47
            do_reset=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:48
        else:
            if (nargin == 1):
                if (isscalar(varargin[1]) and isaxes(varargin[1])):
                    hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:51
                    do_reset=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:52
                else:
                    if (ischar(varargin[1]) and strcmpi(varargin[1],'reset')):
                        hax=copy(gca)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:54
                        do_reset=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:55
                    else:
                        print_usage()
            else:
                if (isscalar(varargin[1]) and isaxes(varargin[1]) and ischar(varargin[2]) and strcmpi(varargin[2],'reset')):
                    hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:62
                    do_reset=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/cla.m:63
                else:
                    print_usage()
    
    if (logical_not(do_reset)):
        delete(get(hax,'children'))
    else:
        __go_axes_init__(hax,'replace')
        __request_drawnow__()
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rotate (@var{h}, @var{dir}, @var{alpha})
## @deftypefnx {Function File} {} rotate (@dots{}, @var{origin})
## Rotate the plot object @var{h} through @var{alpha} degrees around the line
## with direction @var{dir} and origin @var{origin}.
##
## The default value of @var{origin} is the center of the axes object that is
## the parent of @var{h}.
##
## If @var{h} is a vector of handles, they must all have the same parent axes
## object.
##
## Graphics objects that may be rotated are lines, surfaces, patches, and
## images.
## @end deftypefn
    
    
@function
def rotate(h=None,direction=None,alpha=None,origin=None,*args,**kwargs):
    varargin = rotate.varargin
    nargin = rotate.nargin

    ## Note in doc string about compatibility issues with calculation of
  ## default origin due to possible differences in the auto-scaling
  ## algorithm between Octave and Matlab.
    
    if (nargin < 3 or nargin > 4):
        print_usage()
    
    is_h=ishandle(h)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:45
    if (is_h):
        ax_list=get(h,'parent')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:47
        if (iscell(ax_list)):
            ax_list=cell2mat(ax_list)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:49
        if (ax_list == ax_list[1]):
            ax=ax_list[1]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:52
        else:
            error('rotate: all handles must be children of the same axes object')
    else:
        error('rotate: H must be an array of one or more graphics handles')
    
    if (logical_not((isnumeric(direction) and numel(direction) == 3))):
        error('rotate: invalid direction')
    
    if (logical_not((isnumeric(alpha) and isscalar(alpha)))):
        error('rotate: invalid rotation angle')
    
    t=get(h,'type')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:68
    is_image=strcmp(t,'image')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:70
    is_line=strcmp(t,'line')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:71
    is_patch=strcmp(t,'patch')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:72
    is_surface=strcmp(t,'surface')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:73
    if (logical_not(all(logical_or(logical_or(logical_or(is_image,is_line),is_patch),is_surface)))):
        error('rotate: expecting image, line, patch, or surface objects')
    
    if (nargin == 4):
        if (logical_not((isnumeric(origin) and numel(origin) == 3))):
            error('rotate: invalid origin')
    else:
        ## Should Z limit be considered when computing origin?
        use_zlim=any(logical_or(is_patch,is_surface))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:86
        if (logical_not(use_zlim) and any(is_line)):
            idx=find(is_line).T
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:89
            for i in idx.reshape(-1):
                if (logical_not(isempty(get(h[i],'zdata')))):
                    use_zlim=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:92
                    break
        xlim=get(ax,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:98
        ylim=get(ax,'ylim')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:99
        a=(xlim[1] + xlim[2]) / 2
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:101
        b=(ylim[1] + ylim[2]) / 2
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:102
        if (use_zlim):
            zlim=get(ax,'zlim')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:105
            c=(zlim[1] + zlim[2]) / 2
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:106
        else:
            c=0
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:108
        origin=matlabarray(cat(a,b,c))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:111
    
    direction=direction / norm(direction)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:114
    u=direction[1]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:116
    v=direction[2]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:117
    w=direction[3]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:118
    a=origin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:120
    b=origin[2]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:121
    c=origin[3]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:122
    sa=sind(alpha)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:124
    ca=cosd(alpha)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:125
    for i in arange(1,numel(h)).reshape(-1):
        x=get(h[i],'xdata')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:128
        y=get(h[i],'ydata')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:129
        if (is_image[i]):
            z=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:132
        else:
            z=get(h[i],'zdata')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:134
            if (isempty(z)):
                z=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:136
            else:
                if (isvector(x) and isvector(y) and logical_not(isvector(z))):
                    x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:138
        if (a == 0 and b == 0 and c == 0):
            tmp=dot((dot(u,x) + dot(v,y) + dot(w,z)),(1 - ca))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:143
            xr=dot(u,tmp) + dot(x,ca) + dot((dot(- w,y) + dot(v,z)),sa)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:145
            yr=dot(v,tmp) + dot(y,ca) + dot((dot(w,x) - dot(u,z)),sa)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:146
            zr=dot(w,tmp) + dot(z,ca) + dot((dot(- v,x) + dot(u,y)),sa)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:147
        else:
            one_m_ca=1 - ca
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:149
            tmp=dot(u,x) + dot(v,y) + dot(w,z)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:150
            xr=(dot((dot(a,(v ** 2 + w ** 2)) - dot(u,(dot(b,v) + dot(c,w) - tmp))),one_m_ca) + dot(x,ca) + dot((dot(- c,v) + dot(b,w) - dot(w,y) + dot(v,z)),sa))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:152
            yr=(dot((dot(b,(u ** 2 + w ** 2)) - dot(v,(dot(a,u) + dot(c,w) - tmp))),one_m_ca) + dot(y,ca) + dot((dot(c,u) - dot(a,w) + dot(w,x) - dot(u,z)),sa))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:154
            zr=(dot((dot(c,(u ** 2 + v ** 2)) - dot(w,(dot(a,u) + dot(b,v) - tmp))),one_m_ca) + dot(z,ca) + dot((dot(- b,u) + dot(a,v) - dot(v,x) + dot(u,y)),sa))
# /home/lei/octave-4.0.2/scripts/plot/util/rotate.m:156
        set(h[i],'xdata',xr,'ydata',yr)
        if (logical_not(is_image[i])):
            set(h[i],'zdata',zr)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} gco ()
## @deftypefnx {Function File} {@var{h} =} gco (@var{fig})
## Return a handle to the current object of the current figure, or a handle
## to the current object of the figure with handle @var{fig}.
##
## The current object of a figure is the object that was last clicked on.  It
## is stored in the @qcode{"CurrentObject"} property of the target figure.
##
## If the last mouse click did not occur on any child object of the figure,
## then the current object is the figure itself.
##
## If no mouse click occurred in the target figure, this function returns an
## empty matrix.
##
## Programming Note: The value returned by this function is not necessarily the
## same as the one returned by @code{gcbo} during callback execution.  An
## executing callback can be interrupted by another callback and the current
## object may be changed.
##
## @seealso{gcbo, gca, gcf, gcbf, get, set}
## @end deftypefn
    
    
@function
def gco(*args,**kwargs):
    varargin = gco.varargin
    nargin = gco.nargin

    h=get(get(0,'currentfigure'),'currentobject')
# /home/lei/octave-4.0.2/scripts/plot/util/gco.m:44
    return h
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{xx}, @var{yy}] =} meshgrid (@var{x}, @var{y})
## @deftypefnx {Function File} {[@var{xx}, @var{yy}, @var{zz}] =} meshgrid (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {[@var{xx}, @var{yy}] =} meshgrid (@var{x})
## @deftypefnx {Function File} {[@var{xx}, @var{yy}, @var{zz}] =} meshgrid (@var{x})
## Given vectors of @var{x} and @var{y} coordinates, return matrices @var{xx}
## and @var{yy} corresponding to a full 2-D grid.
##
## The rows of @var{xx} are copies of @var{x}, and the columns of @var{yy} are
## copies of @var{y}.  If @var{y} is omitted, then it is assumed to be the same
## as @var{x}.
##
## If the optional @var{z} input is given, or @var{zz} is requested, then the
## output will be a full 3-D grid.
##
## @code{meshgrid} is most frequently used to produce input for a 2-D or 3-D
## function that will be plotted.  The following example creates a surface
## plot of the ``sombrero'' function.
##
## @example
## @group
## f = @@(x,y) sin (sqrt (x.^2 + y.^2)) ./ sqrt (x.^2 + y.^2);
## range = linspace (-8, 8, 41);
## [@var{X}, @var{Y}] = meshgrid (range, range);
## Z = f (X, Y);
## surf (X, Y, Z);
## @end group
## @end example
##
## Programming Note: @code{meshgrid} is restricted to 2-D or 3-D grid
## generation.  The @code{ndgrid} function will generate 1-D through N-D
## grids.  However, the functions are not completely equivalent.  If @var{x}
## is a vector of length M and @var{y} is a vector of length N, then
## @code{meshgrid} will produce an output grid which is NxM@.  @code{ndgrid}
## will produce an output which is @nospell{MxN} (transpose) for the same
## input.  Some core functions expect @code{meshgrid} input and others expect
## @code{ndgrid} input.  Check the documentation for the function in question
## to determine the proper input format.
## @seealso{ndgrid, mesh, contour, surf}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def meshgrid(x=None,y=None,z=None,*args,**kwargs):
    varargin = meshgrid.varargin
    nargin = meshgrid.nargin

    if (nargin == 0 or nargin > 3):
        print_usage()
    
    if (nargin < 2):
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:69
    
    ## Use repmat to ensure that result values have the same type as the inputs
    
    if (nargout < 3):
        if (logical_not((isvector(x) and isvector(y)))):
            error('meshgrid: X and Y must be vectors')
        xx=repmat(ravel(x).T,length(y),1)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:78
        yy=repmat(ravel(y),1,length(x))
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:79
    else:
        if (nargin < 3):
            z=copy(y)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:82
        if (logical_not((isvector(x) and isvector(y) and isvector(z)))):
            error('meshgrid: X, Y, and Z must be vectors')
        lenx=length(x)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:87
        leny=length(y)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:88
        lenz=length(z)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:89
        xx=repmat(repmat(ravel(x).T,leny,1),cat(1,1,lenz))
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:90
        yy=repmat(repmat(ravel(y),1,lenx),cat(1,1,lenz))
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:91
        zz=reshape(ravel(repmat(ravel(z).T,dot(lenx,leny),1)),leny,lenx,lenz)
# /home/lei/octave-4.0.2/scripts/plot/util/meshgrid.m:92
    
    return xx,yy,zz
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 pdiribarne
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} struct2hdl (@var{s})
## @deftypefnx {Function File} {@var{h} =} struct2hdl (@var{s}, @var{p})
## @deftypefnx {Function File} {@var{h} =} struct2hdl (@var{s}, @var{p}, @var{hilev})
## Construct a graphics handle object @var{h} from the structure @var{s}.
##
## The structure must contain the fields @qcode{"handle"}, @qcode{"type"},
## @qcode{"children"}, @qcode{"properties"}, and @qcode{"special"}.
##
## If the handle of an existing figure or axes is specified, @var{p}, the new
## object will be created as a child of that object.  If no parent handle is
## provided then a new figure and the necessary children will be constructed
## using the default values from the root figure.
##
## A third boolean argument @var{hilev} can be passed to specify whether the
## function should preserve listeners/callbacks, e.g., for legends or
## hggroups.  The default is false.
## @seealso{hdl2struct, hgload, findobj}
## @end deftypefn
    
    ## Author: pdiribarne <pdiribarne@new-host.home>
## Created: 2012-03-04
    
    
@function
def struct2hdl(s=None,p=[],hilev=false,*args,**kwargs):
    varargin = struct2hdl.varargin
    nargin = struct2hdl.nargin

    fields=cellarray(['handle','type','children','properties','special'])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:44
    partypes=cellarray(['root','figure','axes','hggroup'])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:45
    othertypes=cellarray(['line','patch','surface','image','text'])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:46
    alltypes=matlabarray(cat(partypes,othertypes))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:47
    if (nargin > 3 or logical_not(isstruct(s))):
        print_usage()
    else:
        if (logical_not(all(isfield(s,fields)))):
            print_usage()
        else:
            if (isscalar(p)):
                if (logical_not(ishandle(p))):
                    error('struct2hdl: P is not a handle to a graphic object')
                if (any(strcmp(get(p).type,partypes))):
                    paridx=find(strcmp(get(p).type,alltypes))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:58
                    kididx=find(strcmp(s.type,alltypes))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:59
                    if (kididx <= paridx):
                        error('struct2hdl: incompatible input handles')
                else:
                    error('struct2hdl: %s object can\'t be parent object',get(p).type)
                hpar=copy(p)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:66
                p=matlabarray(cat([NaN],[hpar]))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:67
                if (any(strcmp(s.type,othertypes))):
                    for ii in arange((paridx + 1),(numel(partypes) - 1)).reshape(-1):
                        eval(cat('hpar = ',partypes[ii],'("parent", hpar);'))
                        p=matlabarray(cat(p,cat([NaN],[hpar])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:72
                else:
                    if (any(strcmp(s.type,cellarray(['hggroup','axes'])))):
                        for ii in arange((paridx + 1),(kididx - 1)).reshape(-1):
                            eval(cat('hpar = ',partypes[ii],'("parent", hpar);'))
                            p=matlabarray(cat(p,cat([NaN],[hpar])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:77
                    else:
                        par=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:80
            else:
                if (isempty(p)):
                    if (any(strcmp(s.type,othertypes))):
                        par=axes()
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:84
                    else:
                        if (any(strcmp(s.type,cellarray(['hggroup','axes'])))):
                            par=figure()
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:86
                        else:
                            par=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:88
                    p=matlabarray(cat([NaN],[par]))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:90
    
    ## read parent (last column) in p and remove it if duplicate
    par=p[2,end()]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:93
    tst=find(p[2,:] == par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:94
    if (numel(tst) > 1):
        p=p[1:2,1:(tst[end()] - 1)]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:96
    
    ## Place the "*mode" properties at the end to avoid having the updaters
  ## change the mode to "manual" when the value is "auto".
    names=fieldnames(s.properties)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:101
    n=strncmp(cellfun(fliplr,names,'uniformoutput',false),'edom',4)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:102
    n=(logical_or(n,strcmp(names,'activepositionproperty')))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:103
    names=matlabarray(cat([names[logical_not(n)]],[names[n]]))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:104
    if (strcmp(s.type,'axes')):
        n_pos=find(logical_or(strcmp(names,'position'),strcmp(names,'outerposition')))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:106
        if (strcmp(s.properties.activepositionproperty,'position')):
            names[n_pos[1]]='outerposition'
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:108
            names[n_pos[2]]='position'
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:109
        else:
            names[n_pos[1]]='position'
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:111
            names[n_pos[2]]='outerposition'
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:112
    
    ## Reorder the properties with the mode properties coming last
    s.properties = copy(orderfields(s.properties,names))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:116
    
    if (strcmp(s.type,'root')):
        h=0
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:120
        s.properties = copy(rmfield(s.properties,cellarray(['callbackobject','commandwindowsize','screendepth','screenpixelsperinch','screensize'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:121
    else:
        if (strcmp(s.type,'figure')):
            h=figure()
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:126
        else:
            if (strcmp(s.type,'axes')):
                ## legends and colorbars are "transformed" in normal axes
    ## if hilev is not requested
                if (logical_not(hilev)):
                    if (strcmp(s.properties.tag,'legend')):
                        s.properties.tag = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:132
                        s.properties.userdata = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:133
                        par=copy(gcf)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:134
                    else:
                        if (strcmp(s.properties.tag,'colorbar')):
                            s.properties.tag = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:136
                            s.properties.userdata = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:137
                            par=copy(gcf)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:138
                h,s=createaxes(s,p,par,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:142
            else:
                if (strcmp(s.type,'line')):
                    h=createline(s,par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:144
                else:
                    if (strcmp(s.type,'patch')):
                        h,s=createpatch(s,par,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:146
                    else:
                        if (strcmp(s.type,'text')):
                            h=createtext(s,par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:148
                        else:
                            if (strcmp(s.type,'image')):
                                h=createimage(s,par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:150
                            else:
                                if (strcmp(s.type,'surface')):
                                    h=createsurface(s,par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:152
                                else:
                                    if (strcmp(s.type,'hggroup')):
                                        h,s,p=createhg(s,p,par,hilev,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:154
                                    else:
                                        error('struct2hdl: %s objects are not implemented yet',s.type)
    
    ## children
    p=matlabarray(cat(p,cat([s.handle],[h])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:160
    
    kids=s.children
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:161
    nkids=length(kids)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:162
    ii=0
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:163
    while (nkids):

        ii
        if (logical_not(any(ii == s.special))):
            h2,p=struct2hdl(s.children(ii),cat(p,cat([s.handle],[h])),hilev,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:167
        nkids

    
    ## paste properties
    setprops(s,h,p,hilev)
    pout=copy(p)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:175
    return h,pout
    
if __name__ == '__main__':
    pass
    
    
@function
def createaxes(s=None,p=None,par=None,*args,**kwargs):
    varargin = createaxes.varargin
    nargin = createaxes.nargin

    ## regular axes
    if (logical_not(any(strcmpi(s.properties.tag,cellarray(['colorbar','legend']))))):
        propval=cellarray(['position',s.properties.position])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:182
        hid=cellarray(['autopos_tag','looseinset'])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:183
        for ii in arange(1,numel(hid)).reshape(-1):
            prop=hid[ii]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:185
            if (isfield(s.properties,prop)):
                val=getattr(s.properties,(prop))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:187
                propval=matlabarray(cat(propval,prop,val))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:188
        h=axes(propval[:],'parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:191
        if (isfield(s.properties,'__plotyy_axes__')):
            plty=s.properties.__plotyy_axes__
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:194
            addproperty('__plotyy_axes__',h,'data')
            tmp=matlabarray(cat(p,cat([s.handle],[h])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:196
            tst=ismember(tmp[1:2:end()],plty)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:197
            if (sum(tst) == numel(plty)):
                for ii in arange(1,numel(plty)).reshape(-1):
                    plty[ii]=tmp[find(tmp == plty[ii]) + 1]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:200
                for ii in arange(1,numel(plty)).reshape(-1):
                    set(plty[ii],'__plotyy_axes__',plty)
            s.properties = copy(rmfield(s.properties,'__plotyy_axes__'))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:206
        ## delete non-default and already set properties
        fields=fieldnames(s.properties)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:210
        tst=cellfun(lambda x=None: isprop(h,x),fields)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:211
        s.properties = copy(rmfield(s.properties,fields[find(tst == 0)]))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:212
    else:
        if (strcmp(s.properties.tag,'legend')):
            ## legends
            oldax=s.properties.userdata.handle
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:216
            idx=find(p == oldax)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:217
            newax=p[idx + 1]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:218
            strings=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:219
            kids=s.children
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:220
            kids[s.special]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:221
            oldh=unique(arrayfun(lambda x=None: x.properties.userdata(end()),kids))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:222
            for ii in arange(1,length(oldh)).reshape(-1):
                idx=dot(find(p[1:2:end()] == oldh[ii]),2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:224
                if (logical_not(isempty(idx))):
                    newh[ii]=p[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:226
                    if (logical_not(strcmp(get(newh[ii],'type'),'hggroup'))):
                        str=get(newh[ii],'displayname')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:228
                        strings=matlabarray(cat(strings,str))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:229
                    else:
                        str=get(get(newh[ii],'children')(1),'displayname')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:231
                        strings=matlabarray(cat(strings,str))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:232
                else:
                    error('struct2hdl: didn\'t find a legend item')
            location=s.properties.location
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:238
            orientation=s.properties.orientation
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:239
            textpos=s.properties.textposition
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:240
            box=s.properties.box
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:241
            h=legend(newax,newh,strings,'location',location,'orientation',orientation)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:243
            set(h,'textposition',textpos)
            # redefine the legend
            h=legend(newax,newh,strings,'location',location,'orientation',orientation)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:247
            if (strcmp(box,'on')):
                legend('boxon')
            ## visibility
            tst=arrayfun(lambda x=None: strcmp(x.properties.visible,'on'),kids)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:255
            if (logical_not(any(tst))):
                legend('hide')
            ## remove all properties such as "textposition" that redefines
    ## the entire legend. Also remove chidren
            s.properties = copy(rmfield(s.properties,cellarray(['userdata','xlabel','ylabel','zlabel','location','title','string','orientation','visible','textposition'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:262
            s.children = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:268
        else:
            if (strcmp(s.properties.tag,'colorbar')):
                ## colorbar
                oldax=s.properties.axes
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:272
                if (logical_not(isempty(idx=find(oldax == p)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:273))):
                    ax=p[idx + 1]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:274
                    location=s.properties.location
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:275
                    h=colorbar('peer',ax,location)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:276
                    s.properties = copy(rmfield(s.properties,cellarray(['userdata','xlabel','ylabel','zlabel','title','axes'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:277
                    s.children = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:281
                else:
                    error('hdl2struct: didn\'t find an object')
    
    sout=copy(s)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:286
    return h,sout
    
if __name__ == '__main__':
    pass
    
    
@function
def createline(s=None,par=None,*args,**kwargs):
    varargin = createline.varargin
    nargin = createline.nargin

    h=line('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:290
    addmissingprops(h,s.properties)
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def createpatch(s=None,par=None,*args,**kwargs):
    varargin = createpatch.varargin
    nargin = createpatch.nargin

    prp.faces = copy(s.properties.faces)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:295
    prp.vertices = copy(s.properties.vertices)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:296
    prp.facevertexcdata = copy(s.properties.facevertexcdata)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:297
    h=patch(prp)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:298
    set(h,'parent',par)
    s.properties = copy(rmfield(s.properties,cellarray(['faces','vertices','facevertexcdata'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:300
    
    ## a segfault when 'set (h, properties)' is used to restore properties
  ## which do not match in size the ones created with from the call to patch().
    s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','zdata','cdata'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:305
    addmissingprops(h,s.properties)
    sout=copy(s)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:307
    return h,sout
    
if __name__ == '__main__':
    pass
    
    
@function
def createtext(s=None,par=None,*args,**kwargs):
    varargin = createtext.varargin
    nargin = createtext.nargin

    h=text('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:311
    addmissingprops(h,s.properties)
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def createimage(s=None,par=None,*args,**kwargs):
    varargin = createimage.varargin
    nargin = createimage.nargin

    h=image(1,'parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:316
    addmissingprops(h,s.properties)
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def createsurface(s=None,par=None,*args,**kwargs):
    varargin = createsurface.varargin
    nargin = createsurface.nargin

    h=surface('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:321
    addmissingprops(h,s.properties)
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def createhg(s=None,p=None,par=None,hilev=None,*args,**kwargs):
    varargin = createhg.varargin
    nargin = createhg.nargin

    ## Here we infer from properties the type of hggroup we should build
  ## an call corresponding high level functions
  ## We manually set "hold on" to avoid next hggroup be deleted
  ## the proper value of axes "nextplot" will finally be recovered
    
    hold('on')
    if (hilev):
        h,s,p=createhg_hilev(s,p,par,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:333
        if (numel(s.children) != numel(get(h).children)):
            warning(cat('struct2hdl: could not infer the hggroup type. ','Will build objects but listener/callback functions ','will be lost'))
            if (isfield(h,'bargroup')):
                delete(get(h).bargroup)
            else:
                delete(h)
            h=hggroup('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:343
            addmissingprops(h,s.properties)
            s.special = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:345
        else:
            oldkids=s.children
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:347
            newkids=get(h).children
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:348
            nkids=numel(oldkids)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:349
            ii=1
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:350
            while (nkids):

                p=matlabarray(cat(p,cat([oldkids[ii].handle],[newkids[nkids]])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:352

    else:
        h=hggroup('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:356
        addmissingprops(h,s.properties)
        s.special = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:358
    
    sout=copy(s)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:360
    pout=copy(p)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:361
    return h,sout,pout
    
if __name__ == '__main__':
    pass
    
    
@function
def createhg_hilev(s=None,p=None,par=None,*args,**kwargs):
    varargin = createhg_hilev.varargin
    nargin = createhg_hilev.nargin

    fields=s.properties
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:365
    if (isfield(fields,'contourmatrix')):
        ## contours
        xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:368
        ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:369
        zdata=s.properties.zdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:370
        levellist=s.properties.levellist
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:371
        textlist=s.properties.textlist
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:372
        if (isempty(s.children(1).properties.zdata)):
            if (strcmpi(s.properties.fill,'on')):
                cm2,h=contourf(xdata,ydata,zdata,levellist,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:377
            else:
                cm2,h=contour(xdata,ydata,zdata,levellist,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:379
            ## labels
            if (strcmpi(s.properties.showtext,'on')):
                clabel(cm2,h,textlist)
        else:
            cm2,h=contour3(xdata,ydata,zdata,levellist,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:387
        ## delete already set properties and children
        s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','zdata','contourmatrix','levellist','fill','labelspacing','levellistmode','levelstep','levelstepmode','textlist','textlistmode','textstep','textstepmode','zlevel','zlevelmode'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:391
    else:
        if (isfield(fields,'udata') and isfield(fields,'vdata')):
            ## quiver
            xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:403
            ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:404
            udata=s.properties.udata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:406
            vdata=s.properties.vdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:407
            h=quiver(xdata,ydata,udata,vdata)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:409
            s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','zdata','xdatasource','ydatasource','zdatasource','udata','vdata','wdata','udatasource','vdatasource','wdatasource'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:412
        else:
            if (isfield(fields,'format')):
                ##errorbar
                form=s.properties.format
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:420
                xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:421
                ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:422
                xldata=s.properties.xldata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:423
                ldata=s.properties.ldata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:424
                xudata=s.properties.xudata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:425
                udata=s.properties.udata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:426
                if 'xerr' == (form):
                    h=errorbar(xdata,ydata,xldata,xudata,'>')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:430
                else:
                    if 'yerr' == (form):
                        h=errorbar(xdata,ydata,ldata,udata,'~')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:432
                    else:
                        if 'xyerr' == (form):
                            h=errorbar(xdata,ydata,xldata,xudata,ldata,udata,'~>')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:434
                        else:
                            if 'box' == (form):
                                h=errorbar(xdata,ydata,xldata,xudata,'#')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:436
                            else:
                                if 'boxy' == (form):
                                    h=errorbar(xdata,ydata,ldata,udata,'#~')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:438
                                else:
                                    if 'boxxy' == (form):
                                        h=errorbar(xdata,ydata,xldata,xudata,ldata,udata,'#~>')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:440
                                    else:
                                        error('struct2hdl: couldn\'t guess the errorbar format')
                ## delete already set properties
                s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','xldata','ldata','xudata','udata','xldatasource','ldatasource','xudatasource','udatasource','format'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:445
            else:
                if (isfield(fields,'bargroup')):
                    ## bar plot
    ## FIXME: Here we don't have access to brothers so we first create all
    ## the barseries of the bargroup (but the last), then retrieve information,
    ## and rebuild the whole bargroup.
    ## The duplicate are deleted after calling "setprops"
                    bargroup=s.properties.bargroup
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:460
                    oldh=s.handle
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:461
                    temp=ismember(cat(p[1:2:end()],oldh),bargroup)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:463
                    tst=sum(temp) == length(bargroup)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:465
                    if (isscalar(bargroup) or logical_not(tst)):
                        xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:468
                        ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:469
                        h=bar(xdata,ydata)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:471
                        s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','xdatasource','ydatasource','bargroup','barwidth','baseline'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:474
                    else:
                        xdata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:480
                        ydata=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:481
                        nbar=length(bargroup)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:484
                        tmp=struct('handle',NaN,'type','','children',[],'special',[])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:485
                        for ii in arange(1,(nbar - 1)).reshape(-1):
                            idx=dot(find(p[1:2:end()] == bargroup[ii]),2)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:487
                            hdl=p[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:488
                            xdata=matlabarray(cat(xdata,get(hdl).xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:489
                            ydata=matlabarray(cat(ydata,get(hdl).ydata))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:490
                            tmp.children[ii]=hdl2struct(hdl)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:491
                        xdata=matlabarray(cat(xdata,s.properties.xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:494
                        ydata=matlabarray(cat(ydata,s.properties.ydata))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:495
                        width=s.properties.barwidth
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:496
                        h=bar(ydata,width)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:497
                        for ii in arange(1,(nbar - 1)).reshape(-1):
                            props=tmp.children(ii).properties
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:501
                            bl=props.baseline
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:502
                            tmp.children(ii).properties = copy(rmfield(props,cellarray(['baseline','bargroup'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:503
                            setprops(tmp.children(ii),h[ii],p,1)
                            delete(tmp.children(ii).handle)
                            delete(bl)
                            idxpar=find(p == tmp.children(ii).handle)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:507
                            p[idxpar]=h[ii]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:508
                            idxkid=idxpar - 2
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:509
                            p[idxkid]=get(h[ii],'children')
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:510
                        p[2,(arange((end() - nbar + 2),end()))]=h[1:(end() - 1)]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:512
                        h=h[end()]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:513
                        s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','bargroup','barwidth','baseline'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:516
                else:
                    if (isfield(fields,'baseline')):
                        ## stem plot
                        xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:522
                        ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:523
                        h=stem(xdata,ydata)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:525
                        s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','xdatasource','ydatasource','baseline'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:528
                    else:
                        if (isfield(fields,'basevalue')):
                            ## area plot
                            xdata=s.properties.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:534
                            ydata=s.properties.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:535
                            level=s.properties.basevalue
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:536
                            h=area(xdata,ydata,level)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:538
                            s.properties = copy(rmfield(s.properties,cellarray(['xdata','ydata','xdatasource','ydatasource'])))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:541
                        else:
                            warning('struct2hdl: could not infer the hggroup type. Will build objects but listener/callback functions will be lost')
                            h=hggroup('parent',par)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:546
                            addmissingprops(h,s.properties)
                            s.special = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:548
    
    sout=copy(s)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:550
    pout=copy(p)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:551
    return h,sout,pout
    
if __name__ == '__main__':
    pass
    
    
@function
def setprops(s=None,h=None,p=None,hilev=None,*args,**kwargs):
    varargin = setprops.varargin
    nargin = setprops.nargin

    if (logical_not(any(strcmpi(s.properties.tag,cellarray(['colorbar','legend']))))):
        specs=s.children(s.special)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:556
        if (isempty(specs)):
            hdls=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:558
        else:
            hdls=matlabarray(cat(specs.handle))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:560
        nh=length(hdls)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:562
        msg=''
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:563
        if (logical_not(nh)):
            set(h,s.properties)
        else:
            ## Specials are objects that where automatically constructed with
      ## current object. Among them are "x(yz)labels", "title", high
      ## level hggroup children
            fields=fieldnames(s.properties)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:570
            vals=struct2cell(s.properties)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:571
            idx=find(cellfun(lambda x=None: valcomp(x,hdls),vals))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:572
            s.properties = copy(rmfield(s.properties,fields[idx]))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:573
            set(h,s.properties)
            nf=length(idx)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:579
            fields=fields[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:580
            vals=vals[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:581
            while (nf):

                field=fields[nf]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:583
                idx=find(hdls == vals[nf])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:584
                spec=specs[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:585
                if (isprop(h,field)):
                    h2=get(h,field)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:587
                    set(h2,spec.properties)
                nf

            ## If hggroup children  were created by high level functions,
      ## copy only usefull properties.
            if (hilev):
                if (strcmp(s.type,'hggroup')):
                    nold=numel(s.children)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:597
                    nnew=numel(get(h).children)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:598
                    if (nold == nnew):
                        hnew=get(h).children
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:601
                        ii=1
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:602
                        while (ii <= nnew):

                            try:
                                set(hnew[ii],'displayname',s.children(ii).properties.displayname)
                            finally:
                                pass
                            ii

                    else:
                        error('struct2hdl: non-conformant number of children in hgggroup')
    else:
        set(h,s.properties)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def valcomp(x=None,hdls=None,*args,**kwargs):
    varargin = valcomp.varargin
    nargin = valcomp.nargin

    if (isfloat(x) and isscalar(x)):
        out=any(x == hdls)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:628
    else:
        out=0
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:630
    
    return out
    
if __name__ == '__main__':
    pass
    
    
@function
def addmissingprops(h=None,props=None,*args,**kwargs):
    varargin = addmissingprops.varargin
    nargin = addmissingprops.nargin

    hid=cellarray(['autopos_tag','looseinset'])
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:635
    oldfields=fieldnames(props)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:636
    curfields=fieldnames(get(h))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:637
    missing=logical_not(ismember(oldfields,curfields))
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:638
    idx=find(missing)
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:639
    for ii in arange(1,length(idx)).reshape(-1):
        prop=oldfields[idx[ii]]
# /home/lei/octave-4.0.2/scripts/plot/util/struct2hdl.m:641
        if (logical_not(any(strcmp(prop,hid)))):
            addproperty(prop,h,'any')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Need validation tests
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{res} =} isprop (@var{obj}, "@var{prop}")
## Return true if @var{prop} is a property of the object @var{obj}.
##
## @var{obj} may also be an array of objects in which case @var{res} will be a
## logical array indicating whether each handle has the property @var{prop}.
##
## For plotting, @var{obj} is a handle to a graphics object.  Otherwise,
## @var{obj} should be an instance of a class.
## @seealso{get, set, ismethod, isobject}
## @end deftypefn
    
    ## Author: Ben Abbott  <bpabbott@mac.com>
    
    
@function
def isprop(h=None,prop=None,*args,**kwargs):
    varargin = isprop.varargin
    nargin = isprop.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(all(ishandle(h)))):
        error('isprop: H must be a graphics handle or vector of handles')
    else:
        if (logical_not(ischar(prop))):
            error('isprop: PROP name must be a string')
    
    res=false(size(h))
# /home/lei/octave-4.0.2/scripts/plot/util/isprop.m:45
    for i in arange(1,numel(res)).reshape(-1):
        try:
            v=get(h[i],prop)
# /home/lei/octave-4.0.2/scripts/plot/util/isprop.m:48
            res[i]=true
# /home/lei/octave-4.0.2/scripts/plot/util/isprop.m:49
        finally:
            pass
    
    return res
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} figure
## @deftypefnx {Command} {} figure @var{n}
## @deftypefnx {Function File} {} figure (@var{n})
## @deftypefnx {Function File} {} figure (@dots{}, "@var{property}", @var{value}, @dots{})
## @deftypefnx {Function File} {@var{h} =} figure (@dots{})
## Create a new figure window for plotting.
##
## If no arguments are specified, a new figure with the next available number
## is created.
##
## If called with an integer @var{n}, and no such numbered figure exists, then
## a new figure with the specified number is created.  If the figure already
## exists then it is made visible and becomes the current figure for plotting.
##
## Multiple property-value pairs may be specified for the figure object, but
## they must appear in pairs.
##
## The optional return value @var{h} is a graphics handle to the created figure
## object.
## @seealso{axes, gcf, clf, close}
## @end deftypefn
    
    ## Author: jwe, Bill Denney
    
    
@function
def figure(varargin=None,*args,**kwargs):
    varargin = figure.varargin
    nargin = figure.nargin

    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:46
    if (mod(nargs,2) == 0):
        f=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:49
        init_new_figure=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:50
    else:
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:52
        if (ischar(arg)):
            arg=str2double(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:54
        if (isscalar(arg) and isfigure(arg)):
            f=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:57
            init_new_figure=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:58
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:59
            nargs
        else:
            if (isscalar(arg) and isnumeric(arg) and arg > 0 and arg == fix(arg)):
                f=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:62
                init_new_figure=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:63
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:64
                nargs
            else:
                error('figure: N must be figure handle or figure number')
    
    if (rem(nargs,2) == 1):
        error('figure: PROPERTY/VALUE arguments must be in pairs')
    
    ## Check to see if we already have a figure on the screen.  If we do,
  ## then update it if it is different from the figure we are creating
  ## or switching to.
    cf=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:78
    
    if (logical_not(isempty(cf)) and cf != 0):
        if (init_new_figure or cf != f):
            drawnow()
    
    if (init_new_figure):
        f=__go_figure__(f,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:86
        __add_default_menu__(f)
        __add_default_mouse_modes__(f)
    else:
        if (nargs > 0):
            set(f,varargin[:])
    
    set(0,'currentfigure',f)
    
    ## unless visibility is explicitly switched off
    if (logical_not(init_new_figure) and logical_not(any(strcmpi(varargin[1:2:end()],'visible') and strcmpi(varargin[2:2:end()],'off')))):
        set(f,'visible','on')
    
    if (nargout > 0):
        h=copy(f)
# /home/lei/octave-4.0.2/scripts/plot/util/figure.m:102
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def __add_default_mouse_modes__(fig=None,*args,**kwargs):
    varargin = __add_default_mouse_modes__.varargin
    nargin = __add_default_mouse_modes__.nargin

    set(fig,'__pan_mode__',struct('Enable','off','Motion','both','FigureHandle',fig))
    set(fig,'__rotate_mode__',struct('Enable','off','RotateStyle','box','FigureHandle',fig))
    set(fig,'__zoom_mode__',struct('Enable','off','Motion','both','Direction','in','FigureHandle',fig))
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Loadable Function} {[@var{prog}, @var{args}] =} gnuplot_binary ()
## @deftypefnx {Loadable Function} {[@var{old_prog}, @var{old_args}] =} gnuplot_binary (@var{new_prog}, @var{arg1}, @dots{})
## Query or set the name of the program invoked by the plot command when the
## graphics toolkit is set to "gnuplot".
##
## Additional arguments to pass to the external plotting program may also be
## given.  The default value is @qcode{"gnuplot"} with no additional arguments.
## @xref{Installation}.
## @seealso{graphics_toolkit}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def gnuplot_binary(new_prog=None,varargin=None,*args,**kwargs):
    varargin = gnuplot_binary.varargin
    nargin = gnuplot_binary.nargin

    
    
    if (nargout > 0 or nargin == 0):
        prog=copy(gp_binary)
# /home/lei/octave-4.0.2/scripts/plot/util/gnuplot_binary.m:39
        args=copy(gp_args)
# /home/lei/octave-4.0.2/scripts/plot/util/gnuplot_binary.m:40
    
    if (nargin == 1):
        if (logical_not(ischar(new_prog)) or isempty(new_prog)):
            error('gnuplot_binary: NEW_PROG must be a non-empty string')
        gp_binary=copy(new_prog)
# /home/lei/octave-4.0.2/scripts/plot/util/gnuplot_binary.m:47
    
    if (nargin > 1):
        if (logical_not(iscellstr(varargin))):
            error('gnuplot_binary: arguments must be character strings')
        gp_args=copy(varargin)
# /home/lei/octave-4.0.2/scripts/plot/util/gnuplot_binary.m:54
    
    return prog,args
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hggroup ()
## @deftypefnx {Function File} {} hggroup (@var{hax})
## @deftypefnx {Function File} {} hggroup (@dots{}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{h} =} hggroup (@dots{})
## Create handle graphics group object with axes parent @var{hax}.
##
## If no parent is specified, the group is created in the current axes.
##
## Multiple property/value pairs may be specified for the hggroup, but they
## must appear in pairs.
##
## The optional return value @var{h} is a graphics handle to the created
## hggroup object.
##
## Programming Note: An hggroup is a way to group base graphics objects such
## as line objects or patch objects into a single unit which can react
## appropriately.  For example, the individual lines of a contour plot are
## collected into a single hggroup so that they can be made visible/invisible
## with a single command, @code{set (hg_handle, "visible", "off")}.
##
## @seealso{addproperty, addlistener}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def hggroup(varargin=None,*args,**kwargs):
    varargin = hggroup.varargin
    nargin = hggroup.nargin

    hax,varargin=__plt_get_axis_arg__('hggroup',varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/hggroup.m:47
    if (isempty(hax)):
        hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/hggroup.m:50
    
    htmp=__go_hggroup__(hax,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/hggroup.m:53
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/util/hggroup.m:56
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} findall ()
## @deftypefnx {Function File} {@var{h} =} findall (@var{prop_name}, @var{prop_value}, @dots{})
## @deftypefnx {Function File} {@var{h} =} findall (@var{prop_name}, @var{prop_value}, "-@var{logical_op}", @var{prop_name}, @var{prop_value})
## @deftypefnx {Function File} {@var{h} =} findall ("-property", @var{prop_name})
## @deftypefnx {Function File} {@var{h} =} findall ("-regexp", @var{prop_name}, @var{pattern})
## @deftypefnx {Function File} {@var{h} =} findall (@var{hlist}, @dots{})
## @deftypefnx {Function File} {@var{h} =} findall (@var{hlist}, "flat", @dots{})
## @deftypefnx {Function File} {@var{h} =} findall (@var{hlist}, "-depth", @var{d}, @dots{})
## Find graphics object, including hidden ones, with specified property values.
##
## The return value @var{h} is a list of handles to the found graphic objects.
##
## @code{findall} performs the same search as @code{findobj}, but it
## includes hidden objects (HandleVisibility = @qcode{"off"}).  For full
## documentation, @pxref{XREFfindobj,,findobj}.
## @seealso{findobj, allchild, get, set}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
    
    
@function
def findall(varargin=None,*args,**kwargs):
    varargin = findall.varargin
    nargin = findall.nargin

    try:
        shh=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/util/findall.m:43
        set(0,'showhiddenhandles','on')
        h=findobj(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/findall.m:45
    finally:
        set(0,'showhiddenhandles',shh)
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} im2frame (@var{rgb})
## @deftypefnx {Function File} {} im2frame (@var{x}, @var{map})
## Convert image to movie frame.
##
## A movie frame is simply a struct with the fields @qcode{"cdata"} and
## @qcode{"colormap"}.
##
## Support for N-dimensional images is given when each image projection,
## matrix sizes of @nospell{MxN and MxNx3} for RGB images, is concatenated
## along the fourth dimension.  In such cases, the returned value is a struct
## array.
##
## @seealso{frame2im}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug@octave.org>
    
    
@function
def im2frame(x=None,map=[],*args,**kwargs):
    varargin = im2frame.varargin
    nargin = im2frame.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (ndims(x) > 4):
            error('im2frame: X and RGB must be a single image')
    
    ## Matlab documentation is incorrect.  Singleton 3rd dimension will error
  ## without cmap (no use of default cmap), and cmap is added to the frame
  ## even when image is RGB.
    
    nchannels=size(x,3)
# /home/lei/octave-4.0.2/scripts/plot/util/im2frame.m:49
    if (nchannels == 3):
        ## RGB image, do nothing
        pass
    else:
        if (nchannels == 1):
            if (nargin < 2):
                error('im2frame: MAP required for indexed images')
            x,map=ind2x('im2frame',x,map,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/im2frame.m:56
        else:
            error('im2frame: first argument must be indexed or RGB image')
    
    ## support N dimensional images and return a struct array
    if (ndims(x) == 4):
        x=reshape(num2cell(x,cat(1,2,3)),1,size(x,4))
# /home/lei/octave-4.0.2/scripts/plot/util/im2frame.m:63
    
    frame=struct('cdata',x,'colormap',map)
# /home/lei/octave-4.0.2/scripts/plot/util/im2frame.m:66
    return frame
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Carl Osterwisch
## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{rgb} =} __next_line_color__ (@var{reset})
## Undocumented internal function.
## @end deftypefn
    
    ## Return the next line color in the rotation.
    
    ## Author: Carl Osterwisch
## Author: jwe
    
    
@function
def __next_line_color__(reset=None,*args,**kwargs):
    varargin = __next_line_color__.varargin
    nargin = __next_line_color__.nargin

    
    if (nargin == 1):
        ## Indicates whether the next call will increment or not
        reset_colors=copy(reset)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:36
    else:
        ## Find and return the next line color
        ca=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:39
        colororder=get(ca,'colororder')
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:40
        if (reset_colors):
            color_index=1
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:42
            reset_colors=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:43
        else:
            ## Executed when "hold all" is active
            n_kids=length(get(ca,'children'))
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:46
            n_colors=rows(colororder)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:47
            color_index=mod(n_kids,n_colors) + 1
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:48
        rgb=colororder[color_index,:]
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_color__.m:50
    
    return rgb
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __gnuplot_drawnow__ (@var{h}, @var{term}, @var{file}, @var{mono}, @var{debug_file})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __gnuplot_drawnow__(h=None,term=None,file=None,mono=false,debug_file=None,*args,**kwargs):
    varargin = __gnuplot_drawnow__.varargin
    nargin = __gnuplot_drawnow__.nargin

    if (nargin < 1 or nargin > 5 or nargin == 2):
        print_usage()
    
    if (nargin >= 3 and nargin <= 5):
        ## Produce various output formats, or redirect gnuplot stream to a
    ## debug file.
        plot_stream=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:35
        fid=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:36
        default_plot_stream=get(h,'__plot_stream__')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:37
        try:
            plot_stream=__gnuplot_open_stream__(2,h)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:39
            gnuplot_supports_term=__gnuplot_has_terminal__(term,plot_stream)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:40
            if (gnuplot_supports_term):
                enhanced=gnuplot_set_term(plot_stream[1],true,h,term,file)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:42
                __go_draw_figure__(h,plot_stream[1],enhanced,mono)
                if (nargin == 5):
                    fid=fopen(debug_file,'wb')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:45
                    enhanced=gnuplot_set_term(fid,true,h,term,file)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:46
                    __go_draw_figure__(h,fid,enhanced,mono)
            else:
                error('__gnuplot_drawnow__: the gnuplot terminal, "%s", is not available',gnuplot_trim_term(term))
        finally:
            set(h,'__plot_stream__',default_plot_stream)
            if (logical_not(isempty(plot_stream))):
                pclose(plot_stream(1))
                if (numel(plot_stream) > 1):
                    pclose(plot_stream(2))
                if (numel(plot_stream) > 2):
                    waitpid(plot_stream(3))
            if (logical_not(isempty(fid))):
                fclose(fid)
    else:
        ##  Graphics terminal for display.
        plot_stream=get(h,'__plot_stream__')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:70
        if (isempty(plot_stream)):
            plot_stream=__gnuplot_open_stream__(2,h)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:72
            new_stream=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:73
        else:
            new_stream=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:75
        term=gnuplot_default_term(plot_stream)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:77
        if (strcmp(term,'dumb')):
            ## popen2 eats stdout of gnuplot, use temporary file instead
            dumb_tmp_file=tempname()
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:80
            enhanced=gnuplot_set_term(plot_stream[1],new_stream,h,term,dumb_tmp_file)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:81
        else:
            enhanced=gnuplot_set_term(plot_stream[1],new_stream,h,term)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:84
        __go_draw_figure__(h,plot_stream[1],enhanced,mono)
        fflush(plot_stream[1])
        if (strcmp(term,'dumb')):
            fid=- 1
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:89
            while (fid < 0):

                pause(0.1)
                fid=fopen(dumb_tmp_file,'r')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:92

            ## reprint the plot on screen
            a,count=fscanf(fid,'%c',Inf,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:95
            fclose(fid)
            if (count > 0):
                if (a[1] == 12):
                    a=a[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:99
                puts(a)
            unlink(dumb_tmp_file)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def gnuplot_set_term(plot_stream=None,new_stream=None,h=None,term=None,file=None,*args,**kwargs):
    varargin = gnuplot_set_term.varargin
    nargin = gnuplot_set_term.nargin

    ## Generate the gnuplot "set terminal <term> ..." command.
  ## When "term" originates from print.m, it may include other options.
    if (nargin < 4):
        ## This supports the gnuplot graphics toolkit.
        term=gnuplot_default_term(plot_stream)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:114
        opts_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:115
    else:
        ## Get the one word terminal id and save the remaining as options to be
    ## passed on to gnuplot.  The terminal may respect the graphics toolkit.
        term,opts_str=gnuplot_trim_term(term,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:119
        term=lower(term)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:120
        if (strcmp(term,'lua')):
            ## Replace "lua tikz" with just "tikz"
            term='tikz'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:123
            opts_str=strrep(opts_str,'tikz','')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:124
    
    if (strfind(opts_str,'noenhanced')):
        enhanced=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:129
    else:
        enhanced=gnuplot_is_enhanced_term(plot_stream,term)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:131
    
    ## Set the terminal.
    if (logical_not(isempty(term))):
        if (enhanced):
            enh_str='enhanced'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:138
        else:
            enh_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:140
        if (logical_not(isempty(h)) and isfigure(h)):
            ## Generate gnuplot title string for plot windows.
            if (output_to_screen(term) and logical_not(strcmp(term,'dumb'))):
                fig.numbertitle = copy(get(h,'numbertitle'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:147
                fig.name = copy(strrep(get(h,'name'),'"','\\"'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:148
                if (strcmp(get(h,'numbertitle'),'on')):
                    title_str=sprintf('Figure %d',h)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:150
                else:
                    title_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:152
                if (logical_not(isempty(fig.name)) and logical_not(isempty(title_str))):
                    title_str=sprintf('%s: %s',title_str,fig.name)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:155
                else:
                    if (logical_not(isempty(fig.name)) and isempty(title_str)):
                        title_str=fig.name
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:157
                if (logical_not(isempty(title_str))):
                    title_str=sprintf('title "%s"',title_str)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:160
                if (strcmp(term,'aqua')):
                    ## Adjust axes-label and tick-label spacing.
                    opts_str=sprintf('%s font "%s,%d"',opts_str,get(0,'defaultaxesfontname'),get(0,'defaultaxesfontsize') / 1.5)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:164
            else:
                title_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:169
            if (logical_not((any(strfind(opts_str,' size ') > 0) or any(strfind(opts_str,'size ') == 1)))):
                ## Get figure size in pixels.  Rely on listener to handle coversion.
                units=get(h,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:175
                try:
                    set(h,'units','pixels')
                    position_in_pixels=get(h,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:178
                finally:
                    set(h,'units',units)
                gnuplot_pos=position_in_pixels[1:2]
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:182
                gnuplot_size=position_in_pixels[3:4]
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:183
                if (logical_not((output_to_screen(term) or any(strcmp(term,cellarray(['canvas','emf','gif','jpeg','pbm','png','pngcairo','svg'])))))):
                    ## Convert to inches
                    gnuplot_pos=gnuplot_pos / 72
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:188
                    gnuplot_size=gnuplot_size / 72
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:189
                if (all(gnuplot_size > 0)):
                    terminals_with_size=cellarray(['canvas','emf','epslatex','fig','gif','jpeg','latex','pbm','pdf','pdfcairo','postscript','png','pngcairo','pstex','pslatex','svg','tikz'])
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:192
                    if (__gnuplot_has_feature__('windows_figure_position')):
                        terminals_with_size[end() + 1]='windows'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:197
                    if (__gnuplot_has_feature__('x11_figure_position')):
                        terminals_with_size[end() + 1]='x11'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:200
                    if (__gnuplot_has_feature__('wxt_figure_size')):
                        terminals_with_size[end() + 1]='wxt'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:203
                    if terminals_with_size == (term):
                        size_str=sprintf('size %.12g,%.12g',gnuplot_size)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:207
                    else:
                        if 'tikz' == (term):
                            size_str=sprintf('size %gin,%gin',gnuplot_size)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:209
                        else:
                            if 'dumb' == (term):
                                new_stream=1
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:211
                                if (logical_not(isempty(getenv('COLUMNS'))) and logical_not(isempty(getenv('LINES')))):
                                    ## Let dumb use full text screen size (minus prompt lines).
                                    n=sprintf('%i',- 2 - length(find(sprintf('%s',PS1) == '\n')))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:215
                                    size_str=matlabarray(cat('size ',getenv('COLUMNS'),',',getenv('LINES'),n))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:218
                                else:
                                    ## Use the gnuplot default.
                                    size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:221
                            else:
                                if cellarray(['aqua','fig','corel']) == (term):
                                    size_str=sprintf('size %g %g',gnuplot_size)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:224
                                else:
                                    if 'dxf' == (term):
                                        size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:226
                                    else:
                                        size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:228
                    if ((strcmp(term,'x11') and __gnuplot_has_feature__('x11_figure_position')) or (strcmpi(term,'windows') and __gnuplot_has_feature__('windows_figure_position'))):
                        ## X11/Windows allows the window to be positioned as well.
                        units=get(0,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:235
                        try:
                            set(0,'units','pixels')
                            screen_size=get(0,'screensize')(arange(3,4))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:238
                        finally:
                            set(0,'units',units)
                        if (all(screen_size > 0)):
                            ## For X11/Windows, set the figure positon as well as the size
              ## gnuplot position is UL, Octave's is LL (same for screen/window)
                            gnuplot_pos[2]=screen_size[2] - gnuplot_pos[2] - gnuplot_size[2]
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:245
                            gnuplot_pos=max(gnuplot_pos,1)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:246
                            size_str=sprintf('%s position %d,%d',size_str,gnuplot_pos[1],gnuplot_pos[2])
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:247
                else:
                    size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:252
                    warning('gnuplot_set_term: size is zero')
            else:
                ## A specified size take priority over the figure properies.
                size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:257
        else:
            if (isempty(h)):
                disp('gnuplot_set_term: figure handle is empty')
            else:
                if (logical_not(isfigure(h))):
                    disp('gnuplot_set_term: not a figure handle')
            title_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:265
            size_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:266
        ## Set the gnuplot terminal (type, enhanced, title, options & size).
        term_str=matlabarray(cat('set terminal ',term))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:270
        if (__gnuplot_has_feature__('needs_color_with_postscript') and strcmp(term,'postscript')):
            term_str=matlabarray(cat(term_str,' color'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:273
        if (logical_not(isempty(enh_str))):
            term_str=matlabarray(cat(term_str,' ',enh_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:276
        if (logical_not(isempty(title_str))):
            term_str=matlabarray(cat(term_str,' ',title_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:279
        if (isempty(strfind(term,'corel'))):
            if (logical_not(isempty(size_str)) and new_stream):
                ## size_str comes after other options to permit specification of
        ## the canvas size for terminals cdr/corel.
                term_str=matlabarray(cat(term_str,' ',size_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:285
            if (nargin > 3 and ischar(opts_str)):
                ## Options must go last.
                term_str=matlabarray(cat(term_str,' ',opts_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:289
        else:
            if (nargin > 3 and ischar(opts_str)):
                ## Options must go last.
                term_str=matlabarray(cat(term_str,' ',opts_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:294
            if (logical_not(isempty(size_str)) and new_stream):
                ## size_str comes after other options to permit specification of
        ## the canvas size for terminals cdr/corel.
                term_str=matlabarray(cat(term_str,' ',size_str))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:299
        if (logical_not(__gnuplot_has_feature__('has_termoption_dashed'))):
            ## If "set termoption dashed" isn't available add "dashed" option
      ## to the "set terminal ..." command, if it is supported.
            if (any(strcmp(term,cellarray(['aqua','cgm','eepic','emf','epslatex','fig','pcl5','mp','next','openstep','pdf','pdfcairo','pngcairo','postscript','pslatex','pstext','svg','tgif','x11'])))):
                term_str=matlabarray(cat(term_str,' dashed'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:309
        if (any(strcmp(term,cellarray(['aqua','wxt'])))):
            term_str=matlabarray(cat(term_str,' ','dashlength 1'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:313
        else:
            if (any(strcmp(term,cellarray(['epslatex','postscript','pslatex'])))):
                term_str=matlabarray(cat(term_str,' ','dashlength 2'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:315
        ## Work around the gnuplot feature of growing the x11 window and
    ## flickering window (x11, windows, & wxt) when the mouse and
    ## multiplot are set in gnuplot.
        fputs(plot_stream,'unset multiplot;\n')
        flickering_terms=cellarray(['x11','windows','wxt','dumb'])
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:322
        if (logical_not(any(strcmp(term,flickering_terms))) or have_non_legend_axes(h) or numel(findall(h,'type','image')) > 0):
            fprintf(plot_stream,'%s\n',term_str)
            if (nargin == 5):
                if (logical_not(isempty(file))):
                    fprintf(plot_stream,'set output \'%s\';\n',file)
            fputs(plot_stream,'set multiplot;\n')
        else:
            if (any(strcmp(term,flickering_terms))):
                fprintf(plot_stream,'%s\n',term_str)
                if (nargin == 5):
                    if (logical_not(isempty(file))):
                        fprintf(plot_stream,'set output \'%s\';\n',file)
        if (__gnuplot_has_feature__('has_termoption_dashed')):
            fprintf(plot_stream,'set termoption dashed\n')
    else:
        ## gnuplot will pick up the GNUTERM environment variable itself
    ## so no need to set the terminal type if not also setting the
    ## figure title, enhanced mode, or position.
        pass
    
    return enhanced
    
if __name__ == '__main__':
    pass
    
    
@function
def gnuplot_default_term(plot_stream=None,*args,**kwargs):
    varargin = gnuplot_default_term.varargin
    nargin = gnuplot_default_term.nargin

    term=lower(getenv('GNUTERM'))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:353
    
    if (isempty(term) or logical_not(__gnuplot_has_terminal__(term,plot_stream))):
        if (isguirunning() and __gnuplot_has_terminal__('qt',plot_stream)):
            term='qt'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:357
        else:
            if (ismac()):
                term='aqua'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:359
            else:
                if (logical_not(isunix())):
                    term='windows'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:361
                else:
                    if (logical_not(isempty(getenv('DISPLAY')))):
                        term='x11'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:363
                    else:
                        term='dumb'
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:365
    
    return term
    
if __name__ == '__main__':
    pass
    
    
@function
def gnuplot_trim_term(string=None,*args,**kwargs):
    varargin = gnuplot_trim_term.varargin
    nargin = gnuplot_trim_term.nargin

    ## Extract the terminal type and terminal options (from print.m)
    string=strtrim(string)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:372
    term,opts=strtok(string,' ',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:373
    if (logical_not(isempty(opts))):
        opts[1]=''
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:375
    
    return term,opts
    
if __name__ == '__main__':
    pass
    
    
@function
def gnuplot_is_enhanced_term(plot_stream=None,term=None,*args,**kwargs):
    varargin = gnuplot_is_enhanced_term.varargin
    nargin = gnuplot_is_enhanced_term.nargin

    ## Don't include pstex, pslatex or epslatex here as the TeX commands
  ## should not be interpreted in that case.
    
    if (nargin < 2):
        ## Determine the default gnuplot terminal.
        term=gnuplot_default_term(plot_stream)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:389
    
    have_enhanced=any(strcmp(term,enhanced_terminals))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:391
    return have_enhanced
    
if __name__ == '__main__':
    pass
    
    
@function
def output_to_screen(term=None,*args,**kwargs):
    varargin = output_to_screen.varargin
    nargin = output_to_screen.nargin

    ret=any(strcmpi(term,cellarray(['aqua','dumb','pm','qt','windows','wxt','x11'])))
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:395
    return ret
    
if __name__ == '__main__':
    pass
    
    
@function
def have_non_legend_axes(h=None,*args,**kwargs):
    varargin = have_non_legend_axes.varargin
    nargin = have_non_legend_axes.nargin

    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:400
    all_axes=findall(h,'type','axes')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:401
    if (logical_not(isempty(all_axes))):
        n_all_axes=numel(all_axes)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:403
        all_axes_tags=get(all_axes,'tag')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:404
        legend_axes=strcmp(all_axes_tags,'legend')
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:405
        if (logical_not(isempty(legend_axes))):
            n_legend_axes=sum(legend_axes)
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:407
            retval=(n_all_axes - n_legend_axes) > 1
# /home/lei/octave-4.0.2/scripts/plot/util/__gnuplot_drawnow__.m:408
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ishghandle (@var{h})
## Return true if @var{h} is a graphics handle and false otherwise.
##
## This function is equivalent to @code{ishandle} and is provided for
## compatibility with @sc{matlab}.
## @seealso{ishandle}
## @end deftypefn
    
    
@function
def ishghandle(h=None,*args,**kwargs):
    varargin = ishghandle.varargin
    nargin = ishghandle.nargin

    ## This function is just included for compatibility as Octave has
  ## no simulink equivalent.
    retval=ishandle(h)
# /home/lei/octave-4.0.2/scripts/plot/util/ishghandle.m:31
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{parent} =} ancestor (@var{h}, @var{type})
## @deftypefnx {Function File} {@var{parent} =} ancestor (@var{h}, @var{type}, "toplevel")
## Return the first ancestor of handle object @var{h} whose type matches
## @var{type}, where @var{type} is a character string.
##
## If @var{type} is a cell array of strings, return the first parent whose
## type matches any of the given type strings.
##
## If the handle object @var{h} itself is of type @var{type}, return @var{h}.
##
## If @qcode{"toplevel"} is given as a third argument, return the highest
## parent in the object hierarchy that matches the condition, instead
## of the first (nearest) one.
## @seealso{findobj, findall, allchild}
## @end deftypefn
    
    
@function
def ancestor(h=None,type_=None,toplevel=None,*args,**kwargs):
    varargin = ancestor.varargin
    nargin = ancestor.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (ischar(type_)):
        type_=cellarray([type_])
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:43
    else:
        if (logical_not(iscellstr(type_))):
            error('ancestor: TYPE must be a string or cell array of strings')
    
    find_first=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:48
    if (nargin == 3):
        if (ischar(toplevel) and strcmpi(toplevel,'toplevel')):
            find_first=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:51
        else:
            error('ancestor: third argument must be "toplevel"')
    
    if (isempty(h)):
        p=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:58
    else:
        p=cell(numel(h),1)
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:60
        h=num2cell(h)
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:61
        for nh in arange(1,numel(h)).reshape(-1):
            while (true):

                if (isempty(h[nh]) or logical_not(ishandle(h[nh]))):
                    break
                if (any(strcmpi(get(h[nh],'type'),type_))):
                    p[nh]=h[nh]
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:68
                    if (find_first):
                        break
                h[nh]=get(h[nh],'parent')
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:73

        if (nh == 1):
            p=p[1]
# /home/lei/octave-4.0.2/scripts/plot/util/ancestor.m:77
    
    return p
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} gcbo ()
## @deftypefnx {Function File} {[@var{h}, @var{fig}] =} gcbo ()
## Return a handle to the object whose callback is currently executing.
##
## If no callback is executing, this function returns the empty matrix.  This
## handle is obtained from the root object property @qcode{"CallbackObject"}.
##
## When called with a second output argument, return the handle of the figure
## containing the object whose callback is currently executing.  If no callback
## is executing the second output is also set to the empty matrix.
##
## @seealso{gcbf, gco, gca, gcf, get, set}
## @end deftypefn
    
    
@function
def gcbo(*args,**kwargs):
    varargin = gcbo.varargin
    nargin = gcbo.nargin

    h=get(0,'callbackobject')
# /home/lei/octave-4.0.2/scripts/plot/util/gcbo.m:36
    fig=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/gcbo.m:37
    if (logical_not(isempty(h)) and nargout > 1):
        fig=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/gcbo.m:40
    
    return h,fig
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2014-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{x}, @var{map}] =} frame2im (@var{f})
## Convert movie frame to indexed image.
##
## A movie frame is simply a struct with the fields @qcode{"cdata"} and
## @qcode{"colormap"}.
##
## Support for N-dimensional images or movies is given when @var{f} is a
## struct array.  In such cases, @var{x} will be a @nospell{MxNx1xK or MxNx3xK}
## for indexed and RGB movies respectively, with each frame concatenated
## along the 4th dimension.
##
## @seealso{im2frame}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug@octave.org>
    
    
@function
def frame2im(frame=None,*args,**kwargs):
    varargin = frame2im.varargin
    nargin = frame2im.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(all(isfield(frame,cellarray(['cdata','colormap']))))):
            error('frame2im: F must be a struct with the fields colormap and cdata')
    
    n=numel(frame)
# /home/lei/octave-4.0.2/scripts/plot/util/frame2im.m:44
    if (n == 0):
        error('frame2im: FRAME is empty')
    else:
        x=matlabarray(cat(frame.cdata))
# /home/lei/octave-4.0.2/scripts/plot/util/frame2im.m:48
        map=frame[1].colormap
# /home/lei/octave-4.0.2/scripts/plot/util/frame2im.m:49
    
    ## support for N dimensional images if we receive a struct array
    if (n > 1):
        x=reshape(x,rows(x),columns(x) / n,n,size(frame[1].cdata,3))
# /home/lei/octave-4.0.2/scripts/plot/util/frame2im.m:54
        x=permute(x,cat(1,2,4,3))
# /home/lei/octave-4.0.2/scripts/plot/util/frame2im.m:55
    
    return x,map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} zoom
## @deftypefnx {Command} {} zoom (@var{factor})
## @deftypefnx {Command} {} zoom on
## @deftypefnx {Command} {} zoom off
## @deftypefnx {Command} {} zoom xon
## @deftypefnx {Command} {} zoom yon
## @deftypefnx {Command} {} zoom out
## @deftypefnx {Command} {} zoom reset
## @deftypefnx {Command} {} zoom (@var{hfig}, @var{option})
## Zoom the current axes object or control the interactive zoom mode of a
## figure in the GUI.
##
## Given a numeric argument greater than zero, zoom by the given factor.  If
## the zoom factor is greater than one, zoom in on the plot.  If the factor
## is less than one, zoom out.  If the zoom factor is a two- or three-element
## vector, then the elements specify the zoom factors for the x, y, and z
## axes respectively.
##
## Given the option @qcode{"on"} or @qcode{"off"}, set the interactive zoom
## mode on or off.
##
## With no arguments, toggle the current zoom mode on or off.
##
## Given the option @qcode{"xon"} or @qcode{"yon"}, enable zoom mode for the
## x or y-axis only.
##
## Given the option @qcode{"out"}, zoom to the initial zoom setting.
##
## Given the option @qcode{"reset"}, store the current zoom setting so that
## @code{zoom out} will return to this zoom level.
##
## If the first argument @var{hfig} is a figure, then operate on the given
## figure rather than the current figure as returned by @code{gcf}.
##
## @seealso{pan, rotate3d}
## @end deftypefn
    
    ## Eventually we need to also support these features:
## @deftypefnx {Command} {zoom_object_handle =} zoom (@var{hfig})
    
    
@function
def zoom(varargin=None,*args,**kwargs):
    varargin = zoom.varargin
    nargin = zoom.nargin

    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:62
    if (nargs > 2):
        print_usage()
    
    if (nargs == 1 and nargout > 0 and isfigure(varargin[1])):
        error('zoom_object_handle = zoom (hfig): not implemented')
    
    hfig=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:71
    if (nargs == 2):
        hfig=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:73
        if (isfigure(hfig)):
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:75
            nargs
        else:
            error('zoom: expecting figure handle as first argument')
    
    if (isnan(hfig)):
        hfig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:83
    
    if (nargs == 0):
        zm=get(hfig,'__zoom_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:87
        if (strcmp(zm.Enable,'on')):
            zm.Enable = copy('off')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:89
        else:
            zm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:91
        set(hfig,'__zoom_mode__',zm)
        update_mouse_mode(hfig,zm.Enable)
    else:
        if (nargs == 1):
            arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:96
            if (isnumeric(arg)):
                factor=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:98
                if 2 == (numel(factor)):
                    xfactor=factor[1]
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:101
                    yfactor=factor[2]
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:102
                else:
                    if 1 == (numel(factor)):
                        xfactor=yfactor=copy(factor)
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:104
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:104
                    else:
                        error('zoom: invalid factor')
                if (xfactor < 0 or yfactor < 0):
                    error('zoom: factor must be greater than 1')
                else:
                    if (xfactor == 1 and yfactor == 1):
                        return
                cax=get(hfig,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:113
                if (logical_not(isempty(cax))):
                    if (xfactor != 1):
                        if (yfactor != 1):
                            mode='both'
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:117
                        else:
                            mode='horizontal'
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:119
                    else:
                        if (yfactor != 1):
                            mode='vertical'
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:123
                    __zoom__(cax,mode,factor)
            else:
                if (ischar(arg)):
                    if cellarray(['on','off','xon','yon']) == (arg):
                        zm=get(hfig,'__zoom_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:131
                        if cellarray(['on','off']) == (arg):
                            zm.Enable = copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:134
                            zm.Motion = copy('both')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:135
                        else:
                            if 'xon' == (arg):
                                zm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:137
                                zm.Motion = copy('horizontal')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:138
                            else:
                                if 'yon' == (arg):
                                    zm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:140
                                    zm.Motion = copy('vertical')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:141
                        set(hfig,'__zoom_mode__',zm)
                        update_mouse_mode(hfig,arg)
                    else:
                        if 'out' == (arg):
                            cax=get(hfig,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:146
                            if (logical_not(isempty(cax))):
                                __zoom__(cax,'out')
                        else:
                            if 'reset' == (arg):
                                cax=get(hfig,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/zoom.m:151
                                if (logical_not(isempty(cax))):
                                    __zoom__(cax,'reset')
                            else:
                                error('zoom: unrecognized option \'%s\'',arg)
                else:
                    error('zoom: wrong type argument \'%s\'',class_(arg))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_mouse_mode(hfig=None,arg=None,*args,**kwargs):
    varargin = update_mouse_mode.varargin
    nargin = update_mouse_mode.nargin

    if (strcmp(arg,'off')):
        set(hfig,'__mouse_mode__','none')
    else:
        ## FIXME: Is there a better way other than calling these
    ## functions to set the other mouse mode Enable fields to
    ## "off"?
        pan('off')
        rotate3d('off')
        set(hfig,'__mouse_mode__','zoom')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} refresh ()
## @deftypefnx {Function File} {} refresh (@var{h})
## Refresh a figure, forcing it to be redrawn.
##
## When called without an argument the current figure is redrawn.  Otherwise,
## the figure with graphic handle @var{h} is redrawn.
## @seealso{drawnow}
## @end deftypefn
    
    
@function
def refresh(h=None,*args,**kwargs):
    varargin = refresh.varargin
    nargin = refresh.nargin

    if (nargin > 1):
        print_usage()
    else:
        if (nargin == 1):
            if (logical_not(isfigure(h))):
                error('refresh: H must be a valid figure handle')
        else:
            h=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/refresh.m:38
    
    set(h,'__modified__','on')
    drawnow()
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{name} =} graphics_toolkit ()
## @deftypefnx {Function File} {@var{name} =} graphics_toolkit (@var{hlist})
## @deftypefnx {Function File} {} graphics_toolkit (@var{name})
## @deftypefnx {Function File} {} graphics_toolkit (@var{hlist}, @var{name})
## Query or set the default graphics toolkit which is assigned to new figures.
##
## With no inputs, return the current default graphics toolkit.  If the input
## is a list of figure graphic handles, @var{hlist}, then return the name
## of the graphics toolkit in use for each figure.
##
## When called with a single input @var{name} set the default graphics toolkit
## to @var{name}.  If the toolkit is not already loaded, it is initialized by
## calling the function @code{__init_@var{name}__}.  If the first input
## is a list of figure handles, @var{hlist}, then the graphics toolkit is set
## to @var{name} for these figures only.
##
## @seealso{available_graphics_toolkits}
## @end deftypefn
    
    
@function
def graphics_toolkit(name=None,hlist=[],*args,**kwargs):
    varargin = graphics_toolkit.varargin
    nargin = graphics_toolkit.nargin

    if (nargin > 2):
        print_usage()
    
    if (nargout > 0 or nargin == 0):
        retval=get(0,'defaultfigure__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:46
        if (isempty(retval)):
            toolkits=available_graphics_toolkits()
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:49
            if (any(strcmp('qt',toolkits))):
                retval='qt'
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:51
            else:
                if (any(strcmp('fltk',toolkits))):
                    retval='fltk'
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:53
                else:
                    if (logical_not(isempty(toolkits))):
                        retval=toolkits[1]
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:55
    
    if (nargin == 0):
        return retval
    else:
        if (nargin == 1):
            if (all(isfigure(name))):
                hlist=copy(name)
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:64
                retval=get(hlist,'__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:65
                return retval
            else:
                if (logical_not(ischar(name))):
                    error('graphics_toolkit: invalid graphics toolkit NAME')
        else:
            if (nargin == 2):
                ## Swap input arguments
                hlist,name=deal(name,hlist,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/graphics_toolkit.m:72
                if (logical_not(all(isfigure(hlist)))):
                    error('graphics_toolkit: invalid figure handle list HLIST')
                else:
                    if (logical_not(ischar(name))):
                        error('graphics_toolkit: invalid graphics toolkit NAME')
    
    if (logical_not(any(strcmp(available_graphics_toolkits(),name)))):
        error('graphics_toolkit: %s toolkit is not available',name)
    
    if (logical_not(any(strcmp(loaded_graphics_toolkits(),name)))):
        feval(cat('__init_',name,'__'))
        if (logical_not(any(strcmp(loaded_graphics_toolkits(),name)))):
            error('graphics_toolkit: %s toolkit was not correctly loaded',name)
    
    if (isempty(hlist)):
        set(0,'defaultfigure__graphics_toolkit__',name)
    else:
        set(hlist,'__graphics_toolkit__',name)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008 Bill Denney
## Copyright (C) 2012-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} findfigs ()
## Find all visible figures that are currently off the screen and move them
## onto the screen.
## @seealso{allchild, figure, get, set}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
## Modified by: Carn Draug <carandraug+dev@gmail.com>
    
    
@function
def findfigs(*args,**kwargs):
    varargin = findfigs.varargin
    nargin = findfigs.nargin

    hfigs=allchild(0)
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:32
    units=get(0,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:33
    try:
        set(0,'units','pixels')
        screensize=get(0,'screensize')
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:36
    finally:
        set(0,'units',units)
    
    ## give the monitor a margin so that the figure must not just
  ## marginally be on the monitor.
    margin=30
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:43
    screensize[1:2] += margin
    screensize[3:4] -= margin
    hfigs=hfigs[strcmp(get(hfigs,'visible'),'on')]
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:47
    for hf in hfigs.T.reshape(-1):
        units=get(hf,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:49
        try:
            set(hf,'units','pixels')
            pos=get(hf,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:52
            ## The left side is outside the right side of the screen
      ## The bottom is above the top of the screen
      ## The right side is outside the left of the screen
      ## the top is below the bottom of the screen
            if (pos[1] > screensize[3] or pos[2] > screensize[4] or pos[1] + pos[3] < screensize[1] or pos[2] + pos[4] < screensize[2]):
                ## the new position will be at the top left of the screen
        ## (all moved figures will overlap).  The bottom left is chosen
        ## instead of the top left because that allows for the unknown
        ## amount of space for the menu bar and the title bar.
                pos[1]=screensize[1]
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:67
                pos[2]=screensize[2]
# /home/lei/octave-4.0.2/scripts/plot/util/findfigs.m:68
                set(hf,'position',pos)
        finally:
            set(hf,'units',units)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{style} =} __next_line_style__ (@var{reset})
## Undocumented internal function.
## @end deftypefn
    
    ## Return the next line style in the rotation.
    
    
@function
def __next_line_style__(reset=None,*args,**kwargs):
    varargin = __next_line_style__.varargin
    nargin = __next_line_style__.nargin

    
    if (nargin == 1):
        ## Indicates whether the next call will increment or not
        reset_style=copy(reset)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:33
    else:
        ## Find and return the next line style
        ca=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:36
        style_rotation=get(ca,'linestyleorder')
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:37
        if (ischar(style_rotation)):
            style_rotation=strsplit(style_rotation,'|')
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:39
        nStyles=length(style_rotation)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:41
        if (reset_style or (nStyles < 2)):
            style_index=1
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:43
            reset_style=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:44
        else:
            ## Executed when "hold all" is active
            nChildren=length(get(ca,'Children'))
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:47
            nColors=rows(get(ca,'ColorOrder'))
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:48
            style_index=mod(floor(nChildren / nColors),nStyles) + 1
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:49
        options=__pltopt__('__next_line_style__',style_rotation[style_index])
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:51
        linestyle=options.linestyle
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:53
        marker=options.marker
# /home/lei/octave-4.0.2/scripts/plot/util/__next_line_style__.m:54
    
    return linestyle,marker
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} axes ()
## @deftypefnx {Function File} {} axes (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} axes (@var{hax})
## @deftypefnx {Function File} {@var{h} =} axes (@dots{})
## Create an axes object and return a handle to it, or set the current axes
## to @var{hax}.
##
## Called without any arguments, or with @var{property}/@var{value} pairs,
## construct a new axes.  For accepted properties and corresponding
## values, @pxref{XREFset,,set}.
##
## Called with a single axes handle argument @var{hax}, the function makes
## @var{hax} the current axis.  It also restacks the axes in the
## corresponding figure so that @var{hax} is the first entry in the list
## of children.  This causes @var{hax} to be displayed on top of any other
## axes objects (Z-order stacking).
##
## @seealso{gca, set, get}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def axes(varargin=None,*args,**kwargs):
    varargin = axes.varargin
    nargin = axes.nargin

    if (nargin == 0 or nargin > 1):
        ## Parent figure
        idx=find(strcmpi(varargin[1:2:end()],'parent'),1,'first')
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:46
        if (logical_not(isempty(idx)) and length(varargin) >= dot(2,idx)):
            cf=varargin[dot(2,idx)]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:48
            varargin[cat(dot(2,idx) - 1,dot(2,idx))]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:49
        else:
            cf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:51
        ## If there is an annotation axes currently on top of the figure
    ## children stack, we will put it back on top
        do_restack=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:56
        ch=allchild(cf)
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:57
        hax=ch[isaxes(ch)]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:58
        idx=find(strcmp(get(hax,'tag'),'scribeoverlay'))
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:59
        if (idx == 1):
            hover=hax[idx]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:61
            do_restack=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:62
        ## Create an axes object.
        htmp=__go_axes__(cf,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:66
        if (__is_handle_visible__(htmp)):
            set(ancestor(cf,'figure'),'currentaxes',htmp)
        ## Restack if necessary
        if (do_restack):
            restack_axes(hover,cf)
    else:
        ## ARG is axes handle.
        htmp=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:77
        if (isscalar(htmp) and isaxes(htmp)):
            cf=ancestor(htmp,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:79
            if (__is_handle_visible__(htmp)):
                set(0,'currentfigure',cf)
                set(cf,'currentaxes',htmp)
            ## restack
            restack_axes(htmp,cf)
        else:
            error('axes: H must be a scalar axes handle')
    
    if (nargout > 0):
        h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:93
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def restack_axes(h=None,cf=None,*args,**kwargs):
    varargin = restack_axes.varargin
    nargin = restack_axes.nargin

    show=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:99
    set(0,'showhiddenhandles','on')
    try:
        ch=get(cf,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:102
        hax=ch[isaxes(ch)]
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:103
        ch[isaxes(ch)]=cat([h],[hax[hax != h]])
# /home/lei/octave-4.0.2/scripts/plot/util/axes.m:104
        set(cf,'children',ch)
    finally:
        set(0,'showhiddenhandles',show)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} refreshdata ()
## @deftypefnx {Function File} {} refreshdata (@var{h})
## @deftypefnx {Function File} {} refreshdata (@var{h}, @var{workspace})
## Evaluate any @samp{datasource} properties of the current figure and update
## the plot if the corresponding data has changed.
##
## If the first argument @var{h} is a list of graphic handles, then operate
## on these objects rather than the current figure returned by @code{gcf}.
##
## The optional second argument @var{workspace} can take the following values:
##
## @table @asis
## @item @qcode{"base"}
## Evaluate the datasource properties in the base workspace.  (default).
##
## @item @qcode{"caller"}
## Evaluate the datasource properties in the workspace of the function
## that called @code{refreshdata}.
## @end table
##
## An example of the use of @code{refreshdata} is:
##
## @example
## @group
## x = 0:0.1:10;
## y = sin (x);
## plot (x, y, "ydatasource", "y");
## for i = 1 : 100
##   pause (0.1);
##   y = sin (x + 0.1*i);
##   refreshdata ();
## endfor
## @end group
## @end example
## @end deftypefn
    
    
@function
def refreshdata(h=None,workspace=None,*args,**kwargs):
    varargin = refreshdata.varargin
    nargin = refreshdata.nargin

    if (nargin == 0):
        h=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:59
        workspace='base'
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:60
    else:
        if (iscell(h)):
            h=matlabarray(cat(h[:]))
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:63
        if (logical_not(all(isfigure(h)))):
            error('refreshdata: H must be a list of figure handles')
        if (nargin == 1):
            workspace='base'
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:69
        else:
            if (nargin == 2):
                if (logical_not(ischar(workspace)) or logical_not(any(strcmpi(workspace,cellarray(['base','caller']))))):
                    error('refreshdata: WORKSPACE must be "base" or "caller"')
                workspace=tolower(workspace)
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:75
            else:
                print_usage()
    
    h=findall(h)
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:81
    objs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:82
    props=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:83
    for i in arange(1,numel(h)).reshape(-1):
        obj=get(h[i])
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:86
        flds=fieldnames(obj)
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:87
        ## Pretty unlikely that people are going to be adding datasource
    ## properties that are not, in fact, datasources.
    ## m = regexp (flds, '^.+datasource$');
        m=strfind(flds,'datasource')
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:92
        m=flds[logical_not(cellfun(isempty,m))]
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:93
        for j in arange(1,numel(m)).reshape(-1):
            if (isempty(getattr(obj,(m[j])))):
                continue
            expr=getattr(obj,(m[j]))
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:98
            val=evalin(workspace,expr)
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:99
            pdname=m[j](arange(1,end() - 6))
# /home/lei/octave-4.0.2/scripts/plot/util/refreshdata.m:100
            set(h[i],pdname,val)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} allchild (@var{handles})
## Find all children, including hidden children, of a graphics object.
##
## This function is similar to @code{get (h, "children")}, but also returns
## hidden objects (HandleVisibility = @qcode{"off"}).
##
## If @var{handles} is a scalar, @var{h} will be a vector.  Otherwise,
## @var{h} will be a cell matrix of the same size as @var{handles} and each
## cell will contain a vector of handles.
## @seealso{findall, findobj, get, set}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
    
    
@function
def allchild(handles=None,*args,**kwargs):
    varargin = allchild.varargin
    nargin = allchild.nargin

    if (nargin != 1):
        print_usage()
    
    shh=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/util/allchild.m:40
    try:
        set(0,'showhiddenhandles','on')
        h=get(handles,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/allchild.m:43
    finally:
        set(0,'showhiddenhandles',shh)
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} hold
## @deftypefnx {Command} {} hold on
## @deftypefnx {Command} {} hold off
## @deftypefnx {Command} {} hold all
## @deftypefnx {Function File} {} hold (@var{hax}, @dots{})
## Toggle or set the @qcode{"hold"} state of the plotting engine which
## determines whether new graphic objects are added to the plot or replace
## the existing objects.
##
## @table @code
## @item hold on
## Retain plot data and settings so that subsequent plot commands are displayed
## on a single graph.
##
## @item hold all
## Retain plot line color, line style, data, and settings so that subsequent
## plot commands are displayed on a single graph with the next line color and
## style.
##
## @item hold off
## Restore default graphics settings which clear the graph and reset axis
## properties before each new plot command.  (default).
##
## @item hold
## Toggle the current hold state.
## @end table
##
## When given the additional argument @var{hax}, the hold state is modified
## for this axis rather than the current axes returned by @code{gca}.
##
## To query the current hold state use the @code{ishold} function.
## @seealso{ishold, cla, clf, newplot}
## @end deftypefn
    
    
@function
def hold(varargin=None,*args,**kwargs):
    varargin = hold.varargin
    nargin = hold.nargin

    if (nargin > 0 and isscalar(varargin[1]) and isaxes(varargin[1])):
        hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:57
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:58
        nargs=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:59
        hfig=ancestor(hax,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:60
    else:
        if (nargin > 0 and numel(varargin[1]) > 1 and ishandle(varargin[1])):
            print_usage()
        else:
            hax=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:64
            hfig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:65
            nargs=numel(varargin)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:66
    
    hold_all=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:69
    if (nargs == 0):
        turn_hold_off=ishold(hax)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:71
    else:
        if (nargs == 1):
            state=tolower(varargin[1])
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:73
            if 'off' == (state):
                turn_hold_off=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:76
            else:
                if 'all' == (state):
                    turn_hold_off=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:78
                    hold_all=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:79
                else:
                    if 'on' == (state):
                        turn_hold_off=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/hold.m:81
                    else:
                        error('hold: invalid hold STATE')
        else:
            print_usage()
    
    if (turn_hold_off):
        set(hax,'nextplot','replace')
    else:
        set(hax,'nextplot','add')
        set(hfig,'nextplot','add')
    
    set(hax,'__hold_all__',hold_all)
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## hold on test
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## hold off test
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hgsave (@var{filename})
## @deftypefnx {Function File} {} hgsave (@var{h}, @var{filename})
## @deftypefnx {Function File} {} hgsave (@var{h}, @var{filename}, @var{fmt})
## Save the graphics handle @var{h} to the file @var{filename} in the format
## @var{fmt}.
##
## If unspecified, @var{h} is the current figure as returned by @code{gcf}.
##
## When @var{filename} does not have an extension the default filename
## extension @file{.ofig} will be appended.
##
## If present, @var{fmt} should be one of the following:
##
## @itemize @bullet
## @item @option{-binary}, @option{-float-binary}
##
## @item @option{-hdf5}, @option{-float-hdf5}
##
## @item @option{-V7}, @option{-v7}, @code{-7}, @option{-mat7-binary}
##
## @item @option{-V6}, @option{-v6}, @code{-6}, @option{-mat6-binary}
##
## @item @option{-text}
##
## @item @option{-zip}, @option{-z}
## @end itemize
##
## When producing graphics for final publication use @code{print} or
## @code{saveas}.  When it is important to be able to continue to edit a
## figure as an Octave object, use @code{hgsave}/@code{hgload}.
## @seealso{hgload, hdl2struct, saveas, print}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def hgsave(h=None,filename=None,fmt='-binary',*args,**kwargs):
    varargin = hgsave.varargin
    nargin = hgsave.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    ## Check input arguments
    if (nargin == 1 and ischar(h)):
        filename=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hgsave.m:63
        h=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/hgsave.m:64
        if (isempty(h)):
            error('hgsave: No current figure to save')
    else:
        if (logical_not((ishandle(h) and ischar(filename)))):
            print_usage()
    
    ## Check file extension
    __,__,ext=fileparts(filename,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/hgsave.m:73
    if (isempty(ext)):
        filename=matlabarray(cat(filename,'.ofig'))
# /home/lei/octave-4.0.2/scripts/plot/util/hgsave.m:75
    
    s_oct40=hdl2struct(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hgsave.m:78
    save(fmt,filename,'s_oct40')
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 pdiribarne
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{s} =} hdl2struct (@var{h})
## Return a structure, @var{s}, whose fields describe the properties
## of the object, and its children, associated with the handle, @var{h}.
##
## The fields of the structure @var{s} are @qcode{"type"}, @qcode{"handle"},
## @qcode{"properties"}, @qcode{"children"}, and @qcode{"special"}.
## @seealso{struct2hdl, hgsave, findobj}
## @end deftypefn
    
    ## Author: pdiribarne <pdiribarne@new-host.home>
## Created: 2012-03-04
    
    
@function
def hdl2struct(h=None,*args,**kwargs):
    varargin = hdl2struct.varargin
    nargin = hdl2struct.nargin

    if (nargin != 1 or logical_not(ishandle(h))):
        print_usage()
    
    hiddenh=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:38
    if (strcmp(hiddenh,'on')):
        set(0,'showhiddenhandles','off')
    
    ## main object
    main=get(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:44
    s.handle = copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:45
    s.type = copy(main.type)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:46
    s.properties = copy(getprops(h))
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:47
    s.children = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:48
    s.special = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:49
    
    ## in reverse order
    kids=main.children
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:53
    lg=findobj(h,'-depth',1,'tag','legend')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:54
    cb=findobj(h,'-depth',1,'tag','colorbar')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:55
    ui=findobj(h,'-depth',1,'type','uimenu')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:56
    nkids=length(kids)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:57
    ii=0
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:58
    while (nkids):

        if (logical_not(any(kids[nkids] == lg)) and logical_not(any(kids[nkids] == cb)) and logical_not(any(kids[nkids] == ui)) and logical_not(strcmp(main.type,'hggroup'))):
            ii
            s.children[ii]=hdl2struct(kids[nkids])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:63
        nkids

    
    ## add non "children" children objects (title, xlabel, ...) and
  ## hggroup children and tag theim in "special"
    special=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:70
    if (strcmp(main.type,'hggroup')):
        special=main.children
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:72
    
    special=matlabarray(cat(special,getspecial(h)))
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:74
    nsp=length(special)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:75
    while (nsp):

        ii
        s.children[ii]=hdl2struct(special[nsp])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:78
        s.special[nsp]=ii
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:79
        nsp

    
    ## look for legends and colorbars among "main"'s brothers and add them
  ## to the children list
    if (strcmp(main.type,'axes')):
        par=main.parent
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:86
        lg=findobj(par,'-depth',1,'tag','legend')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:87
        if (logical_not(isempty(lg))):
            idx=arrayfun(lambda x=None: get(x).userdata.handle(end()) == h,lg)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:89
            lg=lg[find(idx)]
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:90
        nlg=length(lg)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:92
        if (nlg == 1):
            ii
            s.children[ii]=hdl2struct(lg)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:95
        else:
            if (nlg > 1):
                error('hdl2struct: more than one legend found')
        cb=findobj(par,'-depth',1,'tag','colorbar')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:100
        if (logical_not(isempty(cb))):
            idx=arrayfun(lambda x=None: get(x).axes == h,cb)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:102
            cb=cb[find(idx)]
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:103
        ncb=length(cb)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:106
        if (ncb == 1):
            ii
            s.children[ii]=hdl2struct(cb)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:109
        else:
            if (nlg > 1):
                error('hdl2struct: more than one colorbar found')
    
    set(0,'showhiddenhandles',hiddenh)
    return s
    
if __name__ == '__main__':
    pass
    
    
@function
def getspecial(h=None,*args,**kwargs):
    varargin = getspecial.varargin
    nargin = getspecial.nargin

    obj=get(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:120
    
    fields=fieldnames(obj)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:122
    hdlist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:123
    regkids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:125
    set(0,'showhiddenhandles','on')
    allkids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:127
    set(0,'showhiddenhandles','off')
    speckids=arrayfun(lambda x=None: logical_not(any(x == regkids)),allkids)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:129
    hdlist=allkids[find(speckids)]
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:130
    hdlist=reshape(hdlist,1,numel(hdlist))
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:131
    return hdlist
    
if __name__ == '__main__':
    pass
    
    
@function
def getprops(h=None,*args,**kwargs):
    varargin = getprops.varargin
    nargin = getprops.nargin

    obj=get(h)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:136
    
    fields=fieldnames(obj)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:138
    hdlist=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:139
    forbid=cellarray(['beingdeleted','busyaction','buttondownfcn','children','clipping','createfcn','deletefcn','handlevisibility','hittest','interruptible','parent','selected','selectionhighlight','type','__modified__','uicontextmenu','__graphics_toolkit__','currentaxes','currentcharacter','currentobject','tightinset','currentpoint','extent'])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:141
    nflds=length(fields)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:150
    ii=0
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:151
    while (nflds):

        prop=fields[nflds]
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:153
        val=getattr(obj,(fields[nflds]))
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:154
        ii
        if (logical_not(any(strcmp(prop,forbid)))):
            setattr(prpstr,prop,val)
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:157
        nflds

    
    ## hidden properties
    hidden=cellarray(['autopos_tag','looseinset'])
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:163
    for ii in arange(1,numel(hidden)).reshape(-1):
        if (isprop(h,hidden[ii])):
            setattr(prpstr,hidden[ii],get(h,hidden[ii]))
# /home/lei/octave-4.0.2/scripts/plot/util/hdl2struct.m:166
    
    return prpstr
    
if __name__ == '__main__':
    pass
    
    ## FIXME: need validation tests
    
    ## Copyright (C) 2012-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{style}, @var{color}, @var{marker}, @var{msg}] =} colstyle (@var{linespec})
## Parse @var{linespec} and return the line style, color, and markers given.
##
## In the case of an error, the string @var{msg} will return the text of the
## error.
## @end deftypefn
    
    
@function
def colstyle(style=None,*args,**kwargs):
    varargin = colstyle.varargin
    nargin = colstyle.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(ischar(style))):
        error('colstyle: STYLE must be a string')
    
    try:
        opt=__pltopt__('colstyle',style)
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:38
        l=opt.linestyle
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:39
        if cat(0,0,0) == (opt.color):
            c='k'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:42
        else:
            if cat(1,0,0) == (opt.color):
                c='r'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:44
            else:
                if cat(0,1,0) == (opt.color):
                    c='g'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:46
                else:
                    if cat(0,0,1) == (opt.color):
                        c='b'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:48
                    else:
                        if cat(1,1,0) == (opt.color):
                            c='y'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:50
                        else:
                            if cat(1,0,1) == (opt.color):
                                c='m'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:52
                            else:
                                if cat(0,1,1) == (opt.color):
                                    c='c'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:54
                                else:
                                    if cat(0,1,1) == (opt.color):
                                        c='w'
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:56
                                    else:
                                        c=opt.color
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:58
        m=opt.marker
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:60
        msg=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/colstyle.m:61
    finally:
        pass
    
    return l,c,m,msg
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} gcf ()
## Return a handle to the current figure.
##
## The current figure is the default target for graphics output.  If multiple
## figures exist, @code{gcf} returns the last created figure or the last figure
## that was clicked on with the mouse.
##
## If a current figure does not exist, create one and return its handle.  The
## handle may then be used to examine or set properties of the figure.  For
## example,
##
## @example
## @group
## fplot (@@sin, [-10, 10]);
## fig = gcf ();
## set (fig, "numbertitle", "off", "name", "sin plot")
## @end group
## @end example
##
## @noindent
## plots a sine wave, finds the handle of the current figure, and then
## renames the figure window to describe the contents.
##
## Note: To find the current figure without creating a new one if it does not
## exist, query the @qcode{"CurrentFigure"} property of the root graphics
## object.
##
## @example
## get (0, "currentfigure");
## @end example
##
## @seealso{gca, gco, gcbf, gcbo, get, set}
## @end deftypefn
    
    ## Author: jwe, Bill Denney
    
    
@function
def gcf(*args,**kwargs):
    varargin = gcf.varargin
    nargin = gcf.nargin

    if (nargin == 0):
        h=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/gcf.m:59
        if (isempty(h) or h == 0):
            ## We only have a root figure object, so create a new figure
      ## object and make it the current figure.
            h=figure()
# /home/lei/octave-4.0.2/scripts/plot/util/gcf.m:63
    else:
        print_usage()
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{has_terminal} =} __gnuplot_has_terminal__ (@var{terminal})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-09-13
    
    
@function
def __gnuplot_has_terminal__(term=None,plot_stream=None,*args,**kwargs):
    varargin = __gnuplot_has_terminal__.varargin
    nargin = __gnuplot_has_terminal__.nargin

    term=strtrim(term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:29
    term=lower(strtok(term,' '))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:30
    if (__gnuplot_has_feature__('variable_GPVAL_TERMINALS')):
        if (nargin < 2):
            plot_stream=__gnuplot_open_stream__(2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:34
        available_terminals=__gnuplot_get_var__(plot_stream,'GPVAL_TERMINALS')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:36
        available_terminals=regexp(available_terminals,'\\w+','match')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:37
        if (nargin < 2 and logical_not(isempty(plot_stream))):
            pclose(plot_stream[1])
            if (numel(plot_stream) > 1):
                pclose(plot_stream[2])
            if (numel(plot_stream) > 2):
                waitpid(plot_stream[3])
    else:
        ## Gnuplot 4.0 terminals. No new terminals were added until 4.4 which
    ## allows the list of terminals to be obtained from GPVAL_TERMINALS.
        available_terminals=cellarray(['aifm','aqua','canvas','cgm','corel','dumb','dxf','eepic','emf','epslatex','epson_180dpi','fig','gif','gnugraph','gpic','hp2623A','hp2648','hp500c','hpgl','hpljii','hppj','imagen','jpeg','latex','mf','mif','mp','pbm','pdf','pm','png','postscript','pslatex','pstex','pstricks','qms','regis','rgip','svg','texdraw','tgif','tkcanvas','tpic','windows','x11','xlib','xterm'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:50
    
    gnuplot_supports_term=any(strcmp(term,available_terminals))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_terminal__.m:62
    return gnuplot_supports_term
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __go_draw_axes__ (@var{h}, @var{plot_stream}, @var{enhanced}, @var{mono})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __go_draw_axes__(h=None,plot_stream=None,enhanced=None,mono=None,bg_is_set=None,fg_is_set=None,hlgnd=None,*args,**kwargs):
    varargin = __go_draw_axes__.varargin
    nargin = __go_draw_axes__.nargin

    showhiddenhandles=get(0,'showhiddenhandles')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:29
    try:
        set(0,'showhiddenhandles','on')
        axis_obj=__get__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:32
    finally:
        set(0,'showhiddenhandles',showhiddenhandles)
    
    parent_figure_obj=get(axis_obj.parent)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:37
    gnuplot_term=__gnuplot_get_var__(axis_obj.parent,'GPVAL_TERM')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:38
    
    ymirror=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:41
    if (isfield(axis_obj,'__plotyy_axes__')):
        if (all(ishandle(axis_obj.__plotyy_axes__))):
            ymirror=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:44
        else:
            h=axis_obj.__plotyy_axes__
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:46
            h=h[ishandle(h)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:47
            h=h[isprop(h,'__plotyy_axes__')]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:48
            rmappdata(h,'__plotyy_axes__')
    
    nd=__calc_dimensions__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:53
    if (strcmp(axis_obj.dataaspectratiomode,'manual') and strcmp(axis_obj.xlimmode,'manual') and strcmp(axis_obj.ylimmode,'manual')):
        ## All can't be "manual"
        axis_obj.plotboxaspectratiomode = copy('auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:59
    
    if (strcmp(axis_obj.dataaspectratiomode,'manual') and strcmp(axis_obj.xlimmode,'manual') and strcmp(axis_obj.ylimmode,'manual') and (nd == 2 or all(mod(axis_obj.view,90) == 0))):
        ## FIXME: adjust plotboxaspectratio to respect other
        fpos=get(axis_obj.parent,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:67
        apos=axis_obj.position
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:68
    
    pos=__actual_axis_position__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:71
    if (strcmpi(axis_obj.dataaspectratiomode,'manual')):
        dr=axis_obj.dataaspectratio
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:74
        if (nd == 2 or all(mod(axis_obj.view,90) == 0)):
            dr=dr[1] / dr[2]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:76
        else:
            ## FIXME: need to properly implement 3D
            dr=mean(dr[1:2]) / dr[3]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:79
    else:
        dr=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:82
    
    if (strcmp(axis_obj.activepositionproperty,'position')):
        if (__gnuplot_has_feature__('screen_coordinates_for_{lrtb}margin')):
            if (nd == 2 or all(mod(axis_obj.view,90) == 0)):
                x=matlabarray(cat(1,1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:88
            else:
                ## 3D plots need to be sized down to fit in the window.
                x=1.0 / sqrt(cat(2,2.5))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:91
            fprintf(plot_stream,'set tmargin screen %.15g;\n',pos[2] + pos[4] / 2 + dot(x[2],pos[4]) / 2)
            fprintf(plot_stream,'set bmargin screen %.15g;\n',pos[2] + pos[4] / 2 - dot(x[2],pos[4]) / 2)
            fprintf(plot_stream,'set lmargin screen %.15g;\n',pos[1] + pos[3] / 2 - dot(x[1],pos[3]) / 2)
            fprintf(plot_stream,'set rmargin screen %.15g;\n',pos[1] + pos[3] / 2 + dot(x[1],pos[3]) / 2)
            sz_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:101
        else:
            fprintf(plot_stream,'set tmargin 0;\n')
            fprintf(plot_stream,'set bmargin 0;\n')
            fprintf(plot_stream,'set lmargin 0;\n')
            fprintf(plot_stream,'set rmargin 0;\n')
            if (nd == 3 and all(axis_obj.view == cat(0,90))):
                ## FIXME: Kludge to allow colorbar to be added to a pcolor() plot
                pos[3:4]=dot(pos[3:4],1.4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:110
                pos[1:2]=pos[1:2] - dot(pos[3:4],0.125)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:111
            fprintf(plot_stream,'set origin %.15g, %.15g;\n',pos[1],pos[2])
            if (strcmpi(axis_obj.dataaspectratiomode,'manual')):
                sz_str=sprintf('set size ratio %.15g',- dr)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:117
            else:
                sz_str='set size noratio'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:119
            sz_str=sprintf('%s %.15g, %.15g;\n',sz_str,pos[3],pos[4])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:121
    else:
        fprintf(plot_stream,'unset tmargin;\n')
        fprintf(plot_stream,'unset bmargin;\n')
        fprintf(plot_stream,'unset lmargin;\n')
        fprintf(plot_stream,'unset rmargin;\n')
        fprintf(plot_stream,'set origin %g, %g;\n',pos[1:2])
        sz_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:129
        if (strcmpi(axis_obj.dataaspectratiomode,'manual')):
            sz_str=sprintf('ratio %g',- dr)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:131
        else:
            sz_str='noratio'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:133
        sz_str=sprintf('set size %s %g, %g;\n',sz_str,pos[3:4])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:135
    
    if (logical_not(isempty(sz_str))):
        fputs(plot_stream,sz_str)
    
    ## Reset all labels, axis-labels, tick-labels, and title
  ## FIXME: We should have an function to initialize the axis.
  ##        Presently, this is dispersed in this function.
    fputs(plot_stream,'unset label;\n')
    fputs(plot_stream,'unset xtics;\n')
    fputs(plot_stream,'unset ytics;\n')
    fputs(plot_stream,'unset ztics;\n')
    fputs(plot_stream,'unset x2tics;\n')
    fputs(plot_stream,'unset y2tics;\n')
    if (logical_not(isempty(axis_obj.title))):
        t=get(axis_obj.title)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:152
        if (isempty(t.string)):
            fputs(plot_stream,'unset title;\n')
        else:
            colorspec=get_text_colorspec(t.color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:156
            tt,f,s=__maybe_munge_text__(enhanced,t,'string',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:157
            fontspec=create_fontspec(f,s,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:158
            fprintf(plot_stream,'set title "%s" %s %s %s;\n',undo_string_escapes(tt),fontspec,colorspec,__do_enhanced_option__(enhanced,t))
    
    if (logical_not(isempty(axis_obj.xlabel))):
        t=get(axis_obj.xlabel)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:166
        angle=t.rotation
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:167
        colorspec=get_text_colorspec(t.color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:168
        if (isempty(t.string)):
            fprintf(plot_stream,'unset xlabel;\n')
            fprintf(plot_stream,'unset x2label;\n')
        else:
            tt,f,s=__maybe_munge_text__(enhanced,t,'string',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:173
            fontspec=create_fontspec(f,s,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:174
            if (strcmpi(axis_obj.xaxislocation,'top')):
                fprintf(plot_stream,'set x2label "%s" %s %s %s',undo_string_escapes(tt),colorspec,fontspec,__do_enhanced_option__(enhanced,t))
            else:
                fprintf(plot_stream,'set xlabel "%s" %s %s %s',undo_string_escapes(tt),colorspec,fontspec,__do_enhanced_option__(enhanced,t))
            fprintf(plot_stream,' rotate by %f;\n',angle)
            if (strcmpi(axis_obj.xaxislocation,'top')):
                fprintf(plot_stream,'unset xlabel;\n')
            else:
                fprintf(plot_stream,'unset x2label;\n')
    
    if (logical_not(isempty(axis_obj.ylabel))):
        t=get(axis_obj.ylabel)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:194
        angle=t.rotation
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:195
        colorspec=get_text_colorspec(t.color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:196
        if (isempty(t.string)):
            fprintf(plot_stream,'unset ylabel;\n')
            fprintf(plot_stream,'unset y2label;\n')
        else:
            tt,f,s=__maybe_munge_text__(enhanced,t,'string',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:201
            fontspec=create_fontspec(f,s,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:202
            if (strcmpi(axis_obj.yaxislocation,'right')):
                fprintf(plot_stream,'set y2label "%s" %s %s %s',undo_string_escapes(tt),colorspec,fontspec,__do_enhanced_option__(enhanced,t))
            else:
                fprintf(plot_stream,'set ylabel "%s" %s %s %s',undo_string_escapes(tt),colorspec,fontspec,__do_enhanced_option__(enhanced,t))
            fprintf(plot_stream,' rotate by %f;\n',angle)
            if (strcmpi(axis_obj.yaxislocation,'right')):
                fprintf(plot_stream,'unset ylabel;\n')
            else:
                fprintf(plot_stream,'unset y2label;\n')
    
    if (logical_not(isempty(axis_obj.zlabel))):
        t=get(axis_obj.zlabel)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:222
        angle=t.rotation
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:223
        colorspec=get_text_colorspec(t.color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:224
        if (isempty(t.string)):
            fputs(plot_stream,'unset zlabel;\n')
        else:
            tt,f,s=__maybe_munge_text__(enhanced,t,'string',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:228
            fontspec=create_fontspec(f,s,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:229
            fprintf(plot_stream,'set zlabel "%s" %s %s %s',undo_string_escapes(tt),colorspec,fontspec,__do_enhanced_option__(enhanced,t))
            fprintf(plot_stream,' rotate by %f;\n',angle)
    
    if (strcmpi(axis_obj.xaxislocation,'top')):
        xaxisloc='x2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:238
        xaxisloc_using='x2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:239
    else:
        xaxisloc='x'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:241
        xaxisloc_using='x1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:242
        if (strcmpi(axis_obj.xaxislocation,'zero')):
            fputs(plot_stream,'set xzeroaxis;\n')
    
    if (strcmpi(axis_obj.yaxislocation,'right')):
        yaxisloc='y2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:248
        yaxisloc_using='y2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:249
    else:
        yaxisloc='y'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:251
        yaxisloc_using='y1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:252
        if (strcmpi(axis_obj.yaxislocation,'zero')):
            fputs(plot_stream,'set yzeroaxis;\n')
    
    have_grid=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:258
    if (strcmpi(axis_obj.xgrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:261
        fprintf(plot_stream,'set grid %stics;\n',xaxisloc)
    else:
        fprintf(plot_stream,'set grid no%stics;\n',xaxisloc)
    
    if (strcmpi(axis_obj.ygrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:268
        fprintf(plot_stream,'set grid %stics;\n',yaxisloc)
    else:
        fprintf(plot_stream,'set grid no%stics;\n',yaxisloc)
    
    if (strcmpi(axis_obj.zgrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:275
        fputs(plot_stream,'set grid ztics;\n')
    else:
        fputs(plot_stream,'set grid noztics;\n')
    
    if (strcmpi(axis_obj.xminorgrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:282
        if (strcmp(axis_obj.xscale,'log')):
            m=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:284
        else:
            m=5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:286
        fprintf(plot_stream,'set m%stics %d;\n',xaxisloc,m)
        fprintf(plot_stream,'set grid m%stics;\n',xaxisloc)
    else:
        fprintf(plot_stream,'set grid nom%stics;\n',xaxisloc)
    
    if (strcmpi(axis_obj.yminorgrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:295
        if (strcmp(axis_obj.yscale,'log')):
            m=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:297
        else:
            m=5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:299
        fprintf(plot_stream,'set m%stics %d;\n',yaxisloc,m)
        fprintf(plot_stream,'set grid m%stics;\n',yaxisloc)
    else:
        fprintf(plot_stream,'set grid nom%stics;\n',yaxisloc)
    
    if (strcmpi(axis_obj.zminorgrid,'on')):
        have_grid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:308
        if (strcmp(axis_obj.zscale,'log')):
            m=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:310
        else:
            m=5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:312
        fprintf(plot_stream,'set mztics %d;\n',m)
        fputs(plot_stream,'set grid mztics;\n')
    else:
        fputs(plot_stream,'set grid nomztics;\n')
    
    ## The grid front/back/layerdefault option also controls the
  ## appearance of tics, so it is used even if the grid is absent.
    if (strcmpi(axis_obj.layer,'top')):
        fputs(plot_stream,'set grid front;\n')
        fputs(plot_stream,'set border front;\n')
    else:
        fputs(plot_stream,'set grid layerdefault;\n')
        ##        for set border too, but it fails for me with gnuplot 4.2.5.
    ##        So, use "back" instead.
        fputs(plot_stream,'set border back;\n')
    
    fprintf(plot_stream,'set grid linewidth %f, linewidth %f;\n',axis_obj.linewidth,axis_obj.linewidth)
    if (logical_not(have_grid)):
        fputs(plot_stream,'unset grid;\n')
    
    xlogscale=strcmpi(axis_obj.xscale,'log')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:340
    ylogscale=strcmpi(axis_obj.yscale,'log')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:341
    zlogscale=strcmpi(axis_obj.zscale,'log')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:342
    
    if (xlogscale and all(axis_obj.xlim < 0)):
        axis_obj.xsgn = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:346
        if (strcmp(axis_obj.xdir,'reverse')):
            axis_obj.xdir = copy('normal')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:348
        else:
            if (strcmp(axis_obj.xdir,'normal')):
                axis_obj.xdir = copy('reverse')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:350
        axis_obj.xtick = copy(- flip(axis_obj.xtick))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:352
        axis_obj.xticklabel = copy(flip(axis_obj.xticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:353
        axis_obj.xlim = copy(- flip(axis_obj.xlim))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:354
    else:
        axis_obj.xsgn = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:356
    
    if (ylogscale and all(axis_obj.ylim < 0)):
        axis_obj.ysgn = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:359
        if (strcmp(axis_obj.ydir,'reverse')):
            axis_obj.ydir = copy('normal')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:361
        else:
            if (strcmp(axis_obj.ydir,'normal')):
                axis_obj.ydir = copy('reverse')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:363
        axis_obj.ytick = copy(- flip(axis_obj.ytick))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:365
        axis_obj.yticklabel = copy(flip(axis_obj.yticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:366
        axis_obj.ylim = copy(- flip(axis_obj.ylim))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:367
    else:
        axis_obj.ysgn = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:369
    
    if (zlogscale and all(axis_obj.zlim < 0)):
        axis_obj.zsgn = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:372
        if (strcmp(axis_obj.zdir,'reverse')):
            axis_obj.zdir = copy('normal')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:374
        else:
            if (strcmp(axis_obj.zdir,'normal')):
                axis_obj.zdir = copy('reverse')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:376
        axis_obj.ztick = copy(- flip(axis_obj.ztick))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:378
        axis_obj.zticklabel = copy(flip(axis_obj.zticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:379
        axis_obj.zlim = copy(- flip(axis_obj.zlim))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:380
    else:
        axis_obj.zsgn = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:382
    
    xlim=axis_obj.xlim
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:385
    ylim=axis_obj.ylim
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:386
    zlim=axis_obj.zlim
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:387
    clim=axis_obj.clim
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:388
    do_tics(axis_obj,plot_stream,ymirror,mono,gnuplot_term)
    fputs(plot_stream,'unset logscale;\n')
    if (xlogscale):
        fprintf(plot_stream,'set logscale %s;\n',xaxisloc)
    
    if (ylogscale):
        fprintf(plot_stream,'set logscale %s;\n',yaxisloc)
    
    if (zlogscale):
        fputs(plot_stream,'set logscale z;\n')
    
    xautoscale=strcmpi(axis_obj.xlimmode,'auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:403
    yautoscale=strcmpi(axis_obj.ylimmode,'auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:404
    zautoscale=strcmpi(axis_obj.zlimmode,'auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:405
    cautoscale=strcmpi(axis_obj.climmode,'auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:406
    cdatadirect=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:407
    truecolor=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:408
    fputs(plot_stream,'set clip two;\n')
    kids=axis_obj.children
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:412
    
    ## preserved the original order.
    jnk,k=setdiff(kids,cat([axis_obj.xlabel],[axis_obj.ylabel],[axis_obj.zlabel],[axis_obj.title]),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:415
    kids=kids[sort(k)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:417
    if (nd == 3):
        fputs(plot_stream,'set parametric;\n')
        fputs(plot_stream,'set style data lines;\n')
        fputs(plot_stream,'set surface;\n')
        fputs(plot_stream,'unset contour;\n')
    
    data_idx=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:426
    data=cell()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:427
    is_image_data=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:428
    hidden_removal=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:429
    view_map=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:430
    if (logical_not(cautoscale) and clim[1] == clim[2]):
        clim[2]
    
    addedcmap=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:435
    ximg_data=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:437
    ximg_data_idx=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:438
    while (logical_not(isempty(kids))):

        obj=get(kids[end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:442
        if (isfield(obj,'xdata')):
            obj.xdata = copy(double(obj.xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:445
        if (isfield(obj,'ydata')):
            obj.ydata = copy(double(obj.ydata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:448
        if (isfield(obj,'zdata')):
            obj.zdata = copy(double(obj.zdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:451
        if (isfield(obj,'units')):
            units=obj.units
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:455
            try:
                set(kids[end()],'units','data')
                obj=get(kids[end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:458
            finally:
                set(kids(end()),'units',units)
        kids=kids[1:(end() - 1)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:463
        if (strcmp(obj.visible,'off')):
            continue
        if (xlogscale and isfield(obj,'xdata')):
            obj.xdata = copy(dot(axis_obj.xsgn,obj.xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:470
            obj.xdata[obj.xdata <= 0]=NaN
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:471
        if (ylogscale and isfield(obj,'ydata')):
            obj.ydata = copy(dot(axis_obj.ysgn,obj.ydata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:474
            obj.ydata[obj.ydata <= 0]=NaN
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:475
        if (zlogscale and isfield(obj,'zdata')):
            obj.zdata = copy(dot(axis_obj.zsgn,obj.zdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:478
            obj.zdata[obj.zdata <= 0]=NaN
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:479
        ## Check for facecolor interpolation for surfaces.
        doing_interp_color=isfield(obj,'facecolor') and strcmp(obj.facecolor,'interp')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:483
        if 'image' == (obj.type):
            img_data=obj.cdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:488
            img_xdata=obj.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:489
            img_ydata=obj.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:490
            if (ndims(img_data) == 3):
                truecolor=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:493
            else:
                if (strcmpi(obj.cdatamapping,'direct')):
                    cdatadirect=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:495
            data_idx
            is_image_data[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:498
            parametric[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:499
            have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:500
            have_3d_patch[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:501
            if (img_xdata[2] < img_xdata[1]):
                img_xdata=img_xdata[2:- 1:1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:504
                img_data=img_data[:,end():- 1:1,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:505
            else:
                if (img_xdata[1] == img_xdata[2]):
                    img_xdata=img_xdata[1] + cat(0,columns(img_data) - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:507
            if (img_ydata[2] < img_ydata[1]):
                img_ydata=img_ydata[2:- 1:1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:510
                img_data=img_data[end():- 1:1,:,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:511
            else:
                if (img_ydata[1] == img_ydata[2]):
                    img_ydata=img_ydata[1] + cat(0,rows(img_data) - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:513
            x_origin=min(img_xdata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:516
            y_origin=min(img_ydata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:517
            y_dim,x_dim=size(img_data[:,:,1],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:519
            if (x_dim > 1):
                dx=abs(img_xdata[2] - img_xdata[1]) / (x_dim - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:521
            else:
                x_dim=2
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:523
                img_data=matlabarray(cat(img_data,img_data))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:524
                dx=abs(img_xdata[2] - img_xdata[1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:525
                if (dx < 1):
                    ## Correct gnuplot string for 1-D images
                    dx=0.5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:528
                    x_origin=0.75
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:529
            if (y_dim > 1):
                dy=abs(img_ydata[2] - img_ydata[1]) / (y_dim - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:533
            else:
                y_dim=2
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:535
                img_data=matlabarray(cat([img_data],[img_data]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:536
                dy=abs(img_ydata[2] - img_ydata[1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:537
                if (dy < 1):
                    ## Correct gnuplot string for 1-D images
                    dy=0.5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:540
                    y_origin=0.75
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:541
            if (ndims(img_data) == 3):
                data[data_idx]=ravel(permute(img_data,cat(3,1,2)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:546
                format='1:2:3'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:547
                imagetype='rgbimage'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:548
            else:
                data[data_idx]=ravel(img_data)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:550
                format='1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:551
                imagetype='image'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:552
            titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:555
            usingclause[data_idx]=sprintf('binary array=%dx%d scan=yx origin=(%.15g,%.15g) dx=%.15g dy=%.15g using %s',x_dim,y_dim,x_origin,y_origin,dx,dy,format)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:556
            withclause[data_idx]=sprintf('with %s;',imagetype)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:558
        else:
            if 'line' == (obj.type):
                if (strcmp(obj.linestyle,'none') and (logical_not(isfield(obj,'marker')) or (isfield(obj,'marker') and strcmp(obj.marker,'none')))):
                    continue
                data_idx
                is_image_data[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:568
                parametric[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:569
                have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:570
                have_3d_patch[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:571
                if (isempty(obj.displayname)):
                    titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:573
                else:
                    tmp=undo_string_escapes(__maybe_munge_text__(enhanced,obj,'displayname'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:575
                    titlespec[data_idx]=cat('title "',tmp,'"')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:578
                usingclause[data_idx]=sprintf('record=%d',numel(obj.xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:580
                errbars=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:581
                if (nd == 3):
                    xdat=ravel(obj.xdata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:583
                    ydat=ravel(obj.ydata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:584
                    if (logical_not(isempty(obj.zdata))):
                        zdat=ravel(obj.zdata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:586
                    else:
                        zdat=zeros(size(xdat))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:588
                    data[data_idx]=cat(xdat,ydat,zdat).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:590
                    usingclause[data_idx]=sprintf('record=%d using ($1):($2):($3)',numel(xdat))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:591
                    hidden_removal=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:593
                else:
                    xdat=ravel(obj.xdata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:596
                    ydat=ravel(obj.ydata)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:597
                    data[data_idx]=cat(xdat,ydat).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:598
                    usingclause[data_idx]=sprintf('record=%d using ($1):($2) axes %s%s',rows(xdat),xaxisloc_using,yaxisloc_using)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:599
                style=do_linestyle_command(obj,obj.color,data_idx,mono,plot_stream,errbars)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:604
                withclause[data_idx]=sprintf('with %s linestyle %d',style[1],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:607
                if (length(style) > 1):
                    data_idx
                    is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:612
                    parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:613
                    have_cdata[data_idx]=have_cdata[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:614
                    have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:615
                    titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:616
                    usingclause[data_idx]=usingclause[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:617
                    data[data_idx]=data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:618
                    withclause[data_idx]=sprintf('with %s linestyle %d',style[2],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:619
                if (length(style) > 2):
                    data_idx
                    is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:624
                    parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:625
                    have_cdata[data_idx]=have_cdata[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:626
                    have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:627
                    titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:628
                    usingclause[data_idx]=usingclause[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:629
                    data[data_idx]=data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:630
                    withclause[data_idx]=sprintf('with %s linestyle %d',style[3],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:631
            else:
                if 'patch' == (obj.type):
                    cmap=parent_figure_obj.colormap
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:636
                    nr,nc=size(obj.xdata,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:637
                    if (logical_not(isempty(obj.cdata))):
                        cdat=obj.cdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:640
                        if (strcmpi(obj.cdatamapping,'direct')):
                            cdatadirect=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:642
                    else:
                        cdat=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:645
                    data_3d_idx=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:648
                    for i in arange(1,nc).reshape(-1):
                        xcol=obj.xdata(arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:650
                        ycol=obj.ydata(arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:651
                        if (nd == 3):
                            if (logical_not(isempty(obj.zdata))):
                                zcol=obj.zdata(arange(),i)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:654
                            else:
                                zcol=zeros(size(xcol))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:656
                        if (logical_not(isnan(xcol)) and logical_not(isnan(ycol))):
                            ## Is the patch closed or not
                            if (strcmp(obj.facecolor,'none')):
                                hidden_removal=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:663
                            else:
                                if (isnan(hidden_removal)):
                                    hidden_removal=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:667
                                if (nd == 3):
                                    if (numel(xcol) > 3):
                                        error('__go_draw_axes__: gnuplot (as of v4.2) only supports 3-D filled triangular patches')
                                    else:
                                        if (isnan(data_3d_idx)):
                                            data_idx
                                            data_3d_idx=copy(data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:675
                                            is_image_data[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:676
                                            parametric[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:677
                                            have_cdata[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:678
                                            have_3d_patch[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:679
                                            withclause[data_3d_idx]=sprintf('with pm3d')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:680
                                            usingclause[data_3d_idx]='using 1:2:3:4'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:681
                                            data[data_3d_idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:682
                                        local_idx=copy(data_3d_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:684
                                        ccdat=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:685
                                else:
                                    data_idx
                                    local_idx=copy(data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:689
                                    is_image_data[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:690
                                    parametric[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:691
                                    have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:692
                                    have_3d_patch[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:693
                                if (i > 1 or isempty(obj.displayname)):
                                    titlespec[local_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:697
                                else:
                                    tmp=undo_string_escapes(__maybe_munge_text__(enhanced,obj,'displayname'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:699
                                    titlespec[local_idx]=cat('title "',tmp,'"')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:702
                                if (isfield(obj,'facecolor')):
                                    if ((strcmp(obj.facecolor,'flat') or strcmp(obj.facecolor,'interp')) and isfield(obj,'cdata')):
                                        if (ndims(obj.cdata) == 2 and (columns(obj.cdata) == nc and (rows(obj.cdata) == 1 or rows(obj.cdata) == 3))):
                                            ccol=cdat[:,i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:712
                                        else:
                                            if (ndims(obj.cdata) == 2 and (rows(obj.cdata) == nc and (columns(obj.cdata) == 1 or columns(obj.cdata) == 3))):
                                                ccol=cdat[i,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:717
                                            else:
                                                if (ndims(obj.cdata) == 3):
                                                    ccol=permute(cdat[:,i,:],cat(1,3,2))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:719
                                                else:
                                                    ccol=copy(cdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:721
                                        if (strcmp(obj.facecolor,'flat')):
                                            if (isequal(size(ccol),cat(1,3))):
                                                ## RGB Triplet
                                                color=copy(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:726
                                            else:
                                                if (nd == 3 and numel(xcol) == 3):
                                                    ccdat=copy(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:728
                                                else:
                                                    if (cdatadirect):
                                                        r=round(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:731
                                                    else:
                                                        r=1 + round(dot((rows(cmap) - 1),(ccol - clim[1])) / (clim[2] - clim[1]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:733
                                                    r=max(1,min(r,rows(cmap)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:736
                                                    color=cmap[r,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:737
                                        else:
                                            if (strcmp(obj.facecolor,'interp')):
                                                if (nd == 3 and numel(xcol) == 3):
                                                    ccdat=copy(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:741
                                                    if (logical_not(isvector(ccdat))):
                                                        tmp=rows(cmap) + rows(addedcmap) + cat(arange(1,rows(ccdat)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:743
                                                        addedcmap=matlabarray(cat([addedcmap],[ccdat]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:745
                                                        ccdat=ravel(tmp)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:746
                                                    else:
                                                        ccdat=ravel(ccdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:748
                                                else:
                                                    if (sum(diff(ccol))):
                                                        warning('"interp" not supported, using 1st entry of cdata')
                                                    if (cdatadirect):
                                                        r=round(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:755
                                                    else:
                                                        r=1 + round(dot((rows(cmap) - 1),(ccol - clim[1])) / (clim[2] - clim[1]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:757
                                                    r=max(1,min(r,rows(cmap)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:760
                                                    color=cmap[r[1],:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:761
                                    else:
                                        if (isnumeric(obj.facecolor)):
                                            color=obj.facecolor
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:765
                                        else:
                                            color=matlabarray(cat(0,1,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:767
                                else:
                                    color=matlabarray(cat(0,1,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:770
                                if (nd == 3 and numel(xcol) == 3):
                                    if (isnan(ccdat)):
                                        ccdat=dot((rows(cmap) + rows(addedcmap) + 1),ones(3,1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:775
                                        addedcmap=matlabarray(cat([addedcmap],[reshape(color,1,3)]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:776
                                    else:
                                        if (numel(ccdat) <= 1):
                                            ccdat=copy(zcol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:778
                                    data[data_3d_idx]=cat(data[data_3d_idx],cat(cat([xcol],[xcol[end()]]),cat([ycol],[ycol[end()]]),cat([zcol],[zcol[end()]]),cat([ccdat],[ccdat[end()]])).T)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:780
                                else:
                                    if (mono):
                                        colorspec=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:785
                                    else:
                                        if (__gnuplot_has_feature__('transparent_patches') and isscalar(obj.facealpha)):
                                            colorspec=sprintf('lc rgb "#%02x%02x%02x" fillstyle transparent solid %f',round(dot(255,color)),obj.facealpha)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:788
                                        else:
                                            colorspec=sprintf('lc rgb "#%02x%02x%02x"',round(dot(255,color)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:791
                                    withclause[data_idx]=sprintf('with filledcurve %s',colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:795
                                    data[data_idx]=cat(xcol,ycol).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:797
                                    usingclause[data_idx]=sprintf('record=%d using ($1):($2)',numel(xcol))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:798
                        ## patch outline
                        if (logical_not((strcmp(obj.edgecolor,'none') and (strcmp(obj.marker,'none') or (strcmp(obj.markeredgecolor,'none') and strcmp(obj.markerfacecolor,'none')))))):
                            data_idx
                            is_image_data[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:811
                            parametric[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:812
                            have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:813
                            have_3d_patch[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:814
                            titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:815
                            usingclause[data_idx]=sprintf('record=%d',numel(obj.xdata))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:816
                            if (isfield(obj,'markersize')):
                                mdat=obj.markersize / 3
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:819
                            if (isfield(obj,'edgecolor')):
                                ## FIXME: This is the wrong thing to do as edgecolor,
             ## markeredgecolor and markerfacecolor can have different values
             ## and we should treat them seperately. However, the code below
             ## allows the scatter functions to work as expected, where only
             ## one of these values is set.
                                if (strcmp(obj.edgecolor,'none')):
                                    if (strcmp(obj.markeredgecolor,'none')):
                                        ec=obj.markerfacecolor
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:830
                                    else:
                                        ec=obj.markeredgecolor
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:832
                                else:
                                    ec=obj.edgecolor
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:835
                                if ((strcmp(ec,'flat') or strcmp(ec,'interp')) and isfield(obj,'cdata')):
                                    if (ndims(obj.cdata) == 2 and (columns(obj.cdata) == nc and (rows(obj.cdata) == 1 or rows(obj.cdata) == 3))):
                                        ccol=cdat[:,i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:845
                                    else:
                                        if (ndims(obj.cdata) == 2 and (rows(obj.cdata) == nc and (columns(obj.cdata) == 1 or columns(obj.cdata) == 3))):
                                            ccol=cdat[i,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:850
                                        else:
                                            if (ndims(obj.cdata) == 3):
                                                ccol=permute(cdat[:,i,:],cat(1,3,2))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:852
                                            else:
                                                ccol=copy(cdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:854
                                    if (strcmp(ec,'flat')):
                                        if (numel(ccol) == 3):
                                            color=copy(ccol)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:858
                                        else:
                                            if (isscalar(ccol)):
                                                ccol=repmat(ccol,numel(xcol),1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:861
                                            color='flat'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:863
                                            have_cdata[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:864
                                    else:
                                        if (strcmp(ec,'interp')):
                                            if (numel(ccol) == 3):
                                                warning('"interp" not supported, using 1st entry of cdata')
                                                color=ccol[1,:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:869
                                            else:
                                                if (isscalar(ccol)):
                                                    ccol=repmat(ccol,numel(xcol),1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:872
                                                color='interp'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:874
                                                have_cdata[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:875
                                else:
                                    if (isnumeric(ec)):
                                        color=copy(ec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:879
                                    else:
                                        color=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:881
                            else:
                                color=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:884
                            if (isfield(obj,'linestyle')):
                                if '-' == (obj.linestyle):
                                    lt='lt 1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:890
                                else:
                                    if '--' == (obj.linestyle):
                                        lt='lt 2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:892
                                    else:
                                        if ':' == (obj.linestyle):
                                            lt='lt 3'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:894
                                        else:
                                            if '-.' == (obj.linestyle):
                                                lt='lt 6'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:896
                                            else:
                                                if 'none' == (obj.linestyle):
                                                    lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:898
                                                else:
                                                    lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:900
                            else:
                                lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:903
                            if (isfield(obj,'linewidth')):
                                lw=sprintf('linewidth %f',obj.linewidth)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:907
                            else:
                                lw=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:909
                            pt,pt2,obj=gnuplot_pointtype(obj,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:912
                            if (logical_not(isempty(pt))):
                                pt=sprintf('pointtype %s',pt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:914
                            if (logical_not(isempty(pt2))):
                                pt2=sprintf('pointtype %s',pt2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:917
                            if (mono):
                                colorspec=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:921
                            else:
                                if (ischar(color)):
                                    colorspec='palette'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:924
                                else:
                                    colorspec=sprintf('lc rgb "#%02x%02x%02x"',round(dot(255,color)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:926
                            sidx=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:931
                            if (isempty(lt)):
                                style=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:933
                            else:
                                style='lines'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:935
                            tmpwith=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:937
                            facesame=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:939
                            if (logical_not(isequal(pt,pt2)) and isfield(obj,'markerfacecolor') and logical_not(strcmp(obj.markerfacecolor,'none'))):
                                if (strcmp(obj.markerfacecolor,'auto') or logical_not(isnumeric(obj.markerfacecolor)) or (isnumeric(obj.markerfacecolor) and isequal(color,obj.markerfacecolor))):
                                    style=strcat(style,'points')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:946
                                    if (isfield(obj,'markersize')):
                                        if (length(mdat) == nc):
                                            m=mdat[i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:949
                                        else:
                                            m=copy(mdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:951
                                        ps=sprintf('pointsize %f',m / 3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:953
                                    else:
                                        ps=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:955
                                    tmpwith[sidx]=sprintf('with %s %s %s %s %s %s',style,lw,pt2,lt,ps,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:958
                                else:
                                    facesame=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:962
                                    if (logical_not(isempty(style))):
                                        tmpwith[sidx]=sprintf('with %s %s %s %s',style,lw,lt,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:964
                                        sidx
                                    if (isnumeric(obj.markerfacecolor) and logical_not(mono)):
                                        colorspec=sprintf('lc rgb "#%02x%02x%02x"',round(dot(255,obj.markerfacecolor)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:970
                                    style='points'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:973
                                    if (isfield(obj,'markersize')):
                                        if (length(mdat) == nc):
                                            m=mdat[i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:976
                                        else:
                                            m=copy(mdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:978
                                        ps=sprintf('pointsize %f',m / 3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:980
                                    else:
                                        ps=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:982
                                    tmpwith[sidx]=sprintf('with %s %s %s %s %s %s',style,lw,pt2,lt,ps,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:984
                            if (isfield(obj,'markeredgecolor') and logical_not(strcmp(obj.markeredgecolor,'none'))):
                                if (facesame and logical_not(isempty(pt)) and (strcmp(obj.markeredgecolor,'auto') or logical_not(isnumeric(obj.markeredgecolor)) or (isnumeric(obj.markeredgecolor) and isequal(color,obj.markeredgecolor)))):
                                    if (sidx == 1 and ((length(style) == 5 and strncmp(style,'lines',5)) or isempty(style))):
                                        style=strcat(style,'points')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1000
                                        if (isfield(obj,'markersize')):
                                            if (length(mdat) == nc):
                                                m=mdat[i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1003
                                            else:
                                                m=copy(mdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1005
                                            ps=sprintf('pointsize %f',m / 3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1007
                                        else:
                                            ps=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1009
                                        tmpwith[sidx]=sprintf('with %s %s %s %s %s %s',style,lw,pt,lt,ps,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1011
                                else:
                                    if (logical_not(isempty(style))):
                                        if (length(tmpwith) < sidx or isempty(tmpwith[sidx])):
                                            tmpwith[sidx]=sprintf('with %s %s %s %s',style,lw,lt,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1018
                                        sidx
                                    if (logical_not(isempty(pt))):
                                        if (logical_not(mono)):
                                            if (strcmp(obj.markeredgecolor,'auto')):
                                                colorspec=sprintf('lc rgb "#%02x%02x%02x"',round(dot(255,color)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1028
                                            else:
                                                if (isnumeric(obj.markeredgecolor) and logical_not(mono)):
                                                    colorspec=sprintf('lc rgb "#%02x%02x%02x"',round(dot(255,obj.markeredgecolor)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1031
                                        style='points'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1035
                                        if (isfield(obj,'markersize')):
                                            if (length(mdat) == nc):
                                                m=mdat[i]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1038
                                            else:
                                                m=copy(mdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1040
                                            ps=sprintf('pointsize %f',m / 3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1042
                                        else:
                                            ps=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1044
                                        tmpwith[sidx]=sprintf('with %s %s %s %s %s %s',style,lw,pt,lt,ps,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1046
                            if (isempty(tmpwith)):
                                withclause[data_idx]=sprintf('with %s %s %s %s %s',style,lw,pt,lt,colorspec)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1054
                            else:
                                withclause[data_idx]=tmpwith[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1058
                            if (nd == 3):
                                if (ischar(color)):
                                    if (logical_not(isnan(xcol)) and logical_not(isnan(ycol)) and logical_not(isnan(zcol))):
                                        data[data_idx]=cat(cat([xcol],[xcol[1]]),cat([ycol],[ycol[1]]),cat([zcol],[zcol[1]]),cat([ccol],[ccol[1]])).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1063
                                    else:
                                        data[data_idx]=cat(xcol,ycol,zcol,ccol).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1066
                                    usingclause[data_idx]=sprintf('record=%d using ($1):($2):($3):($4)',columns(data[data_idx]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1068
                                else:
                                    if (logical_not(isnan(xcol)) and logical_not(isnan(ycol)) and logical_not(isnan(zcol))):
                                        data[data_idx]=cat(cat([xcol],[xcol[1]]),cat([ycol],[ycol[1]]),cat([zcol],[zcol[1]])).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1071
                                    else:
                                        data[data_idx]=cat(xcol,ycol,zcol).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1074
                                    usingclause[data_idx]=sprintf('record=%d using ($1):($2):($3)',columns(data[data_idx]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1076
                            else:
                                if (ischar(color)):
                                    if (logical_not(isnan(xcol)) and logical_not(isnan(ycol))):
                                        data[data_idx]=cat(cat([xcol],[xcol[1]]),cat([ycol],[ycol[1]]),cat([ccol],[ccol[1]])).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1081
                                    else:
                                        data[data_idx]=cat(xcol,ycol,ccol).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1084
                                    usingclause[data_idx]=sprintf('record=%d using ($1):($2):($3)',columns(data[data_idx]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1086
                                else:
                                    if (logical_not(isnan(xcol)) and logical_not(isnan(ycol))):
                                        data[data_idx]=cat(cat([xcol],[xcol[1]]),cat([ycol],[ycol[1]])).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1089
                                    else:
                                        data[data_idx]=cat(xcol,ycol).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1091
                                    usingclause[data_idx]=sprintf('record=%d using ($1):($2)',columns(data[data_idx]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1093
                            if (length(tmpwith) > 1):
                                data_idx
                                is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1099
                                parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1100
                                have_cdata[data_idx]=have_cdata[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1101
                                have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1102
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1103
                                usingclause[data_idx]=usingclause[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1104
                                data[data_idx]=data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1105
                                withclause[data_idx]=tmpwith[2]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1106
                            if (length(tmpwith) > 2):
                                data_idx
                                is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1110
                                parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1111
                                have_cdata[data_idx]=have_cdata[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1112
                                have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1113
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1114
                                usingclause[data_idx]=usingclause[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1115
                                data[data_idx]=data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1116
                                withclause[data_idx]=tmpwith[3]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1117
                else:
                    if 'surface' == (obj.type):
                        view_map=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1123
                        if (logical_not((strcmp(obj.edgecolor,'none') and strcmp(obj.facecolor,'none')))):
                            data_idx
                            is_image_data[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1127
                            parametric[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1128
                            have_cdata[data_idx]=true
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1129
                            have_3d_patch[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1130
                            style=do_linestyle_command(obj,obj.edgecolor,data_idx,mono,plot_stream)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1131
                            if (isempty(obj.displayname)):
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1136
                            else:
                                tmp=undo_string_escapes(__maybe_munge_text__(enhanced,obj,'displayname'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1138
                                titlespec[data_idx]=cat('title "',tmp,'"')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1141
                            withclause[data_idx]=sprintf('with pm3d linestyle %d',data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1143
                            withpm3d=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1145
                            pm3didx=copy(data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1146
                            xdat=obj.xdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1148
                            ydat=obj.ydata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1149
                            zdat=obj.zdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1150
                            cdat=obj.cdata
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1151
                            err=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1153
                            if (logical_not(size_equal(zdat,cdat))):
                                err=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1155
                            if (isvector(xdat) and isvector(ydat) and ismatrix(zdat)):
                                if (rows(zdat) == length(ydat) and columns(zdat) == length(xdat)):
                                    xdat,ydat=meshgrid(xdat,ydat,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1160
                                else:
                                    err=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1162
                            else:
                                if (ismatrix(xdat) and ismatrix(ydat) and ismatrix(zdat)):
                                    if (logical_not(size_equal(xdat,ydat,zdat))):
                                        err=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1166
                                else:
                                    err=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1169
                            if (err):
                                error('__go_draw_axes__: invalid grid data')
                            xlen=columns(zdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1174
                            ylen=rows(zdat)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1175
                            if (xlen == columns(xdat) and xlen == columns(ydat) and ylen == rows(xdat) and ylen == rows(ydat)):
                                len_=dot(4,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1178
                                zz=zeros(ylen,len_)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1179
                                k=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1180
                                for kk in arange(1,len_,4).reshape(-1):
                                    zz[:,kk]=xdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1182
                                    zz[:,kk + 1]=ydat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1183
                                    zz[:,kk + 2]=zdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1184
                                    zz[:,kk + 3]=cdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1185
                                    k
                                data[data_idx]=zz.T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1188
                            if (doing_interp_color):
                                interp_str='interpolate 0, 0'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1192
                            else:
                                ## No interpolation of facecolors.
                                interp_str=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1195
                            usingclause[data_idx]=sprintf('record=%dx%d using ($1):($2):($3):($4)',ylen,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1197
                            flat_interp_face=(strcmp(obj.facecolor,'flat') or strcmp(obj.facecolor,'interp'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1199
                            flat_interp_edge=(strcmp(obj.edgecolor,'flat') or strcmp(obj.edgecolor,'interp'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1201
                            facecolor_none_or_white=(strcmp(obj.facecolor,'none') or (isnumeric(obj.facecolor) and all(obj.facecolor == 1)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1204
                            hidden_removal=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1207
                            fputs(plot_stream,'set style increment default;\n')
                            if (flat_interp_edge and facecolor_none_or_white):
                                withpm3d=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1210
                                withclause[data_idx]=sprintf('with %s palette',style[1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1211
                                fputs(plot_stream,'unset pm3d\n')
                                if (all(obj.facecolor == 1)):
                                    hidden_removal=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1214
                            else:
                                if (facecolor_none_or_white):
                                    if (all(obj.facecolor == 1)):
                                        hidden_removal=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1218
                                    fputs(plot_stream,'unset pm3d;\n')
                                    fputs(plot_stream,'set style increment user;\n')
                                    withpm3d=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1222
                                    withclause[data_idx]=sprintf('with %s linestyle %d',style[1],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1223
                                    fputs(plot_stream,'unset pm3d\n')
                            if (doing_interp_color):
                                ## "depthorder" interferes with interpolation of colors.
                                dord='scansautomatic'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1230
                            else:
                                dord='depthorder'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1232
                            if (flat_interp_face and strcmp(obj.edgecolor,'flat')):
                                fprintf(plot_stream,'set pm3d explicit at s %s %s corners2color c3;\n',interp_str,dord)
                            else:
                                if (logical_not(facecolor_none_or_white)):
                                    if (strcmp(obj.edgecolor,'none')):
                                        if (__gnuplot_has_feature__('transparent_surface') and isscalar(obj.facealpha)):
                                            fprintf(plot_stream,'set style fill transparent solid %f;\n',obj.facealpha)
                                        fprintf(plot_stream,'set pm3d explicit at s %s corners2color c3;\n',interp_str,dord)
                                    else:
                                        fprintf(plot_stream,'set pm3d explicit at s hidden3d %d %s %s corners2color c3;\n',data_idx,interp_str,dord)
                                        if (__gnuplot_has_feature__('transparent_surface') and isscalar(obj.facealpha)):
                                            fprintf(plot_stream,'set style fill transparent solid %f;\n',obj.facealpha)
                            zz=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1264
                            if (length(style) > 1):
                                len_=dot(3,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1266
                                zz=zeros(ylen,len_)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1267
                                k=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1268
                                for kk in arange(1,len_,3).reshape(-1):
                                    zz[:,kk]=xdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1270
                                    zz[:,kk + 1]=ydat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1271
                                    zz[:,kk + 2]=zdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1272
                                    k
                                zz=zz.T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1275
                                data_idx
                                is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1278
                                parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1279
                                have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1280
                                have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1281
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1282
                                usingclause[data_idx]=sprintf('record=%dx%d using ($1):($2):($3)',ylen,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1283
                                data[data_idx]=zz
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1284
                                withclause[data_idx]=sprintf('with %s linestyle %d',style[2],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1285
                            if (length(style) > 2):
                                data_idx
                                is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1291
                                parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1292
                                have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1293
                                have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1294
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1295
                                usingclause[data_idx]=sprintf('record=%dx%d using ($1):($2):($3)',ylen,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1296
                                data[data_idx]=zz
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1297
                                withclause[data_idx]=sprintf('with %s linestyle %d',style[3],data_idx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1298
                            if (withpm3d and strcmp(style[1],'linespoints')):
                                if (isempty(zz)):
                                    len_=dot(3,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1303
                                    zz=zeros(ylen,len_)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1304
                                    k=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1305
                                    for kk in arange(1,len_,3).reshape(-1):
                                        zz[:,kk]=xdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1307
                                        zz[:,kk + 1]=ydat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1308
                                        zz[:,kk + 2]=zdat[:,k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1309
                                        k
                                    zz=zz.T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1312
                                data_idx
                                is_image_data[data_idx]=is_image_data[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1315
                                parametric[data_idx]=parametric[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1316
                                have_cdata[data_idx]=false
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1317
                                have_3d_patch[data_idx]=have_3d_patch[data_idx - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1318
                                titlespec[data_idx]='title ""'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1319
                                usingclause[data_idx]=sprintf('record=%dx%d using ($1):($2):($3)',ylen,xlen)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1320
                                data[data_idx]=zz
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1321
                                withclause[data_idx]=sprintf('with points linestyle %d',pm3didx)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1322
                    else:
                        if 'text' == (obj.type):
                            label,f,s=__maybe_munge_text__(enhanced,obj,'string',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1328
                            fontspec=create_fontspec(f,s,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1329
                            lpos=obj.position
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1330
                            halign=obj.horizontalalignment
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1331
                            valign=obj.verticalalignment
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1332
                            angle=obj.rotation
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1333
                            units=obj.units
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1334
                            color=obj.color
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1335
                            if (strcmpi(units,'normalized')):
                                units='graph'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1337
                            else:
                                if (strcmp(axis_obj.yaxislocation,'right') and strcmp(units,'data')):
                                    units='second'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1340
                                else:
                                    units=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1342
                            if (isnumeric(color)):
                                colorspec=get_text_colorspec(color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1346
                            if (ischar(obj.string)):
                                num_lines=rows(obj.string)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1350
                                num_lines += numel(strfind(obj.string,'\n'))
                            else:
                                num_lines=numel(obj.string)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1353
                            if 'top' == (valign):
                                dy=- 0.5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1358
                            else:
                                if 'cap' == (valign):
                                    dy=- 0.5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1360
                                else:
                                    if 'middle' == (valign):
                                        dy=dot(0.5,(num_lines - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1362
                                    else:
                                        if 'baseline' == (valign):
                                            dy=0.5 + (num_lines - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1364
                                        else:
                                            if 'bottom' == (valign):
                                                dy=0.5 + (num_lines - 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1366
                            ## Gnuplot's Character units are different for x/y and vary with
        ## fontsize. The aspect ratio of 1:1.7 was determined by experiment
        ## to work for eps/ps/etc. For the MacOS aqua terminal a value of 2.5
        ## is needed. However, the difference is barely noticable.
                            dx_and_dy=multiply(cat((dot(- dy,sind(angle))),(dot(dy,cosd(angle)))),cat(1.7,1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1372
                            ##        "warning: ft_render: skipping glyph"
                            if (nd == 3):
                                ## This produces the desired vertical alignment in 3D.
                                fprintf(plot_stream,'set label "%s" at %s %.15e,%.15e,%.15e %s rotate by %f offset character %f,%f %s %s front %s;\n',undo_string_escapes(label),units,lpos[1],lpos[2],lpos[3],halign,angle,dx_and_dy,fontspec,__do_enhanced_option__(enhanced,obj),colorspec)
                            else:
                                fprintf(plot_stream,'set label "%s" at %s %.15e,%.15e %s rotate by %f offset character %f,%f %s %s front %s;\n',undo_string_escapes(label),units,lpos[1],lpos[2],halign,angle,dx_and_dy,fontspec,__do_enhanced_option__(enhanced,obj),colorspec)
                        else:
                            if 'hggroup' == (obj.type):
                                ## Push group children into the kid list.
                                if (isempty(kids)):
                                    kids=obj.children
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1394
                                else:
                                    if (logical_not(isempty(obj.children))):
                                        kids=matlabarray(cat([kids],[obj.children]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1396
                            else:
                                error('__go_draw_axes__: unknown object class, %s',obj.type)

    
    ## This is need to prevent warnings for rotations in 3D plots, while
  ## allowing colorbars with contours.
    if (nd == 2 or (data_idx > 1 and logical_not(view_map))):
        fputs(plot_stream,'set pm3d implicit;\n')
    else:
        fputs(plot_stream,'set pm3d explicit;\n')
    
    if (isnan(hidden_removal) or hidden_removal):
        fputs(plot_stream,'set hidden3d;\n')
    else:
        fputs(plot_stream,'unset hidden3d;\n')
    
    have_data=(logical_not((isempty(data) or all(cellfun('isempty',data)))))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1420
    
    ## dual axis plotting features of gnuplot.
    if (isempty(xlim)):
        return
    
    if (strcmpi(axis_obj.xdir,'reverse')):
        xdir='reverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1428
    else:
        xdir='noreverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1430
    
    fprintf(plot_stream,'set xrange [%.15e:%.15e] %s;\n',xlim,xdir)
    if (strcmpi(axis_obj.xaxislocation,'top')):
        fprintf(plot_stream,'set x2range [%.15e:%.15e] %s;\n',xlim,xdir)
    
    if (isempty(ylim)):
        return
    
    if (strcmpi(axis_obj.ydir,'reverse')):
        ydir='reverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1441
    else:
        ydir='noreverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1443
    
    fprintf(plot_stream,'set yrange [%.15e:%.15e] %s;\n',ylim,ydir)
    if (strcmpi(axis_obj.yaxislocation,'right')):
        fprintf(plot_stream,'set y2range [%.15e:%.15e] %s;\n',ylim,ydir)
    
    if (nd == 3):
        if (isempty(zlim)):
            return
        if (strcmpi(axis_obj.zdir,'reverse')):
            zdir='reverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1455
        else:
            zdir='noreverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1457
        fprintf(plot_stream,'set zrange [%.15e:%.15e] %s;\n',zlim,zdir)
    
    cmap=parent_figure_obj.colormap
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1462
    cmap_sz=rows(cmap)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1463
    if (logical_not(any(isinf(clim)))):
        if (truecolor or logical_not(cdatadirect)):
            if (rows(addedcmap) > 0):
                for i in arange(1,data_idx).reshape(-1):
                    if (have_3d_patch[i]):
                        data[i][end(),:]=dot(clim[2],(data[i](end(),arange()) - 0.5)) / cmap_sz
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1469
                fprintf(plot_stream,'set cbrange [%.15e:%.15e];\n',clim[1],dot(clim[2],(cmap_sz + rows(addedcmap))) / cmap_sz)
            else:
                fprintf(plot_stream,'set cbrange [%.15e:%.15e];\n',clim)
        else:
            fprintf(plot_stream,'set cbrange [1:%d];\n',cmap_sz + rows(addedcmap))
    
    if (strcmpi(axis_obj.box,'on')):
        if (nd == 3):
            fputs(plot_stream,'set border 4095;\n')
        else:
            fputs(plot_stream,'set border 431;\n')
    else:
        if (nd == 3):
            fputs(plot_stream,'set border 895;\n')
        else:
            if (logical_not(isempty(axis_obj.ytick))):
                if (strcmpi(axis_obj.yaxislocation,'right')):
                    fprintf(plot_stream,'unset ytics; set y2tics %s nomirror\n',axis_obj.tickdir)
                    if (strcmpi(axis_obj.xaxislocation,'top')):
                        maybe_do_x2tick_mirror(plot_stream,axis_obj)
                        fputs(plot_stream,'set border 12;\n')
                    else:
                        if (strcmpi(axis_obj.xaxislocation,'bottom')):
                            maybe_do_xtick_mirror(plot_stream,axis_obj)
                            fputs(plot_stream,'set border 9;\n')
                        else:
                            fprintf(plot_stream,'unset x2tics; set xtics %s nomirror\n',axis_obj.tickdir)
                            fputs(plot_stream,'set border 8;\n')
                            fprintf(plot_stream,'set xzeroaxis lt -1 lw %f;\n',axis_obj.linewidth)
                else:
                    if (strcmpi(axis_obj.yaxislocation,'left')):
                        fprintf(plot_stream,'unset y2tics; set ytics %s nomirror\n',axis_obj.tickdir)
                        if (strcmpi(axis_obj.xaxislocation,'top')):
                            maybe_do_x2tick_mirror(plot_stream,axis_obj)
                            fputs(plot_stream,'set border 6;\n')
                        else:
                            if (strcmpi(axis_obj.xaxislocation,'bottom')):
                                maybe_do_xtick_mirror(plot_stream,axis_obj)
                                fputs(plot_stream,'set border 3;\n')
                            else:
                                maybe_do_xtick_mirror(plot_stream,axis_obj)
                                fputs(plot_stream,'set border 2;\n')
                                fprintf(plot_stream,'set xzeroaxis lt -1 lw %f;\n',axis_obj.linewidth)
                    else:
                        fprintf(plot_stream,'unset y2tics; set ytics %s nomirror\n',axis_obj.tickdir)
                        if (strcmpi(axis_obj.xaxislocation,'top')):
                            maybe_do_x2tick_mirror(plot_stream,axis_obj)
                            fputs(plot_stream,'set border 4;\n')
                        else:
                            if (strcmpi(axis_obj.xaxislocation,'bottom')):
                                maybe_do_xtick_mirror(plot_stream,axis_obj)
                                fputs(plot_stream,'set border 1;\n')
                            else:
                                maybe_do_xtick_mirror(plot_stream,axis_obj)
                                fprintf(plot_stream,'unset y2tics; set ytics %s nomirror\n',axis_obj.tickdir)
                                fputs(plot_stream,'unset border;\n')
                                fprintf(plot_stream,'set xzeroaxis lt -1 lw %f;\n',axis_obj.linewidth)
                        fprintf(plot_stream,'set yzeroaxis lt -1 lw %f;\n',axis_obj.linewidth)
    
    if (strcmpi(axis_obj.visible,'off')):
        fputs(plot_stream,'unset border; unset tics\n')
    else:
        fprintf(plot_stream,'set border lw %f;\n',axis_obj.linewidth)
    
    if (logical_not(isempty(hlgnd)) and logical_not(isempty(hlgnd.children)) and any(strcmpi(get(hlgnd.children,'visible'),'on'))):
        if (strcmpi(hlgnd.box,'on')):
            box='box'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1556
        else:
            box='nobox'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1558
        if (strcmpi(hlgnd.orientation,'vertical')):
            horzvert='vertical'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1561
        else:
            horzvert='horizontal'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1563
        if (strcmpi(hlgnd.textposition,'right')):
            reverse='reverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1566
        else:
            reverse='noreverse'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1568
        inout='inside'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1570
        keypos=hlgnd.location
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1571
        if (ischar(keypos)):
            keypos=lower(keypos)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1573
            keyout=strfind(keypos,'outside')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1574
            if (logical_not(isempty(keyout))):
                inout='outside'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1576
                keypos=keypos[1:keyout - 1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1577
        if 'north' == (keypos):
            pos='center top'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1582
        else:
            if 'south' == (keypos):
                pos='center bottom'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1584
            else:
                if 'east' == (keypos):
                    pos='right center'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1586
                else:
                    if 'west' == (keypos):
                        pos='left center'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1588
                    else:
                        if 'northeast' == (keypos):
                            pos='right top'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1590
                        else:
                            if 'northwest' == (keypos):
                                pos='left top'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1592
                            else:
                                if 'southeast' == (keypos):
                                    pos='right bottom'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1594
                                else:
                                    if 'southwest' == (keypos):
                                        pos='left bottom'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1596
                                    else:
                                        if 'best' == (keypos):
                                            pos=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1598
                                            warning('legend: \'Best\' not yet implemented for location specifier.\n')
                                            ## Least unused space outside plot.
                                        else:
                                            pos=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1603
        if (__gnuplot_has_feature__('key_has_font_properties')):
            fontname,fontsize=get_fontname_and_size(hlgnd,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1606
            fontspacespec=matlabarray(cat(create_spacingspec(fontname,fontsize,gnuplot_term),create_fontspec(fontname,fontsize,gnuplot_term)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1607
        else:
            fontspacespec=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1610
        textcolors=get(findobj(hlgnd.children,'type','text'),'color')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1612
        if (iscell(textcolors)):
            textcolors=cell2mat(textcolors)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1614
            textcolors=unique(textcolors,'rows')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1615
        if (rows(textcolors) > 1):
            ## Gnuplot is unable to assign arbitrary colors to each text entry
      ## for the key/legend.  But, the text color can be set to match the
      ## color of the plot object.
            colorspec='textcolor variable'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1621
        else:
            colorspec=get_text_colorspec(textcolors,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1623
        fprintf(plot_stream,'set key %s %s;\nset key %s %s %s %s %s %s;\n',inout,pos,box,reverse,horzvert,fontspacespec,colorspec,__do_enhanced_option__(enhanced,hlgnd))
    else:
        fputs(plot_stream,'unset key;\n')
    
    fputs(plot_stream,'set style data lines;\n')
    cmap=matlabarray(cat([cmap],[addedcmap]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1633
    cmap_sz=cmap_sz + rows(addedcmap)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1634
    if (mono == false and length(cmap) > 0):
        fprintf(plot_stream,'set palette positive color model RGB maxcolors %i;\n',cmap_sz)
        fprintf(plot_stream,'set palette file "-" binary record=%d using 1:2:3:4;\n',cmap_sz)
        fwrite(plot_stream,cat([arange(1,cmap_sz)],[cmap.T]),'float32')
        fwrite(plot_stream,'\n')
    
    fputs(plot_stream,'unset colorbox;\n')
    if (have_data):
        if (nd == 2):
            plot_cmd='plot'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1650
        else:
            plot_cmd='splot'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1652
            rot_x=90 - axis_obj.view(2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1653
            rot_z=axis_obj.view(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1654
            while (rot_z < 0):

                rot_z += 360

            fputs(plot_stream,'set ticslevel 0;\n')
            if (view_map and rot_x == 0 and rot_z == 0):
                fputs(plot_stream,'set view map;\n')
            else:
                fprintf(plot_stream,'set view %.15g, %.15g;\n',rot_x,rot_z)
        if (have_3d_patch[1]):
            fputs(plot_stream,'set pm3d depthorder\n')
            fprintf(plot_stream,'%s "-" %s %s %s \\\n',plot_cmd,usingclause[1],titlespec[1],withclause[1])
        else:
            if (is_image_data[1]):
                if (numel(is_image_data) > 1 and is_image_data[2]):
                    ## Remove terminating semicolon
                    n=max(strfind(withclause[1],';'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1672
                    if (logical_not(isempty(n))):
                        withclause[1]=withclause[1](arange(1,n - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1674
                fprintf(plot_stream,'%s "-" %s %s %s \\\n',plot_cmd,usingclause[1],titlespec[1],withclause[1])
            else:
                fprintf(plot_stream,'%s "-" binary format=\'%%float64\' %s %s %s \\\n',plot_cmd,usingclause[1],titlespec[1],withclause[1])
        for i in arange(2,data_idx).reshape(-1):
            if (have_3d_patch[i]):
                fprintf(plot_stream,', "-" %s %s %s \\\n',usingclause[i],titlespec[i],withclause[i])
            else:
                if (is_image_data[i]):
                    if (logical_not(is_image_data[i - 1])):
                        fputs(plot_stream,'; ')
                        if (bg_is_set):
                            fputs(plot_stream,'unset obj 1; \\\n')
                            bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1692
                        if (fg_is_set):
                            fputs(plot_stream,'unset obj 2; \\\n')
                            fg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1696
                        if (numel(is_image_data) > i and is_image_data[i + 1]):
                            ## Remove terminating semicolon
                            n=max(strfind(withclause[i],';'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1700
                            if (logical_not(isempty(n))):
                                withclause[i]=withclause[i](arange(1,n - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1702
                        fprintf(plot_stream,'%s "-" %s %s %s \\\n',plot_cmd,usingclause[i],titlespec[i],withclause[i])
                    else:
                        ## For consecutive images continue with the same plot command
                        fprintf(plot_stream,'%s "-" %s %s %s \\\n',',',usingclause[i],titlespec[i],withclause[i])
                else:
                    if (is_image_data[i - 1]):
                        if (bg_is_set):
                            fputs(plot_stream,'unset obj 1; \\\n')
                            bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1715
                        if (fg_is_set):
                            fputs(plot_stream,'unset obj 2; \\\n')
                            fg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1719
                        fprintf(plot_stream,'%s "-" binary format=\'%%float64\' %s %s %s \\\n',plot_cmd,usingclause[i],titlespec[i],withclause[i])
                    else:
                        fprintf(plot_stream,', "-" binary format=\'%%float64\' %s %s %s \\\n',usingclause[i],titlespec[i],withclause[i])
        fputs(plot_stream,';\n')
        for i in arange(1,data_idx).reshape(-1):
            if (have_3d_patch[i]):
                ## Can't write 3d patch data as binary as can't plot more than
        ## a single patch at a time and have to plot all patches together
        ## so that the gnuplot depth ordering is done correctly
                for j in arange(1,columns(data[i]),4).reshape(-1):
                    if (j != 1):
                        fputs(plot_stream,'\n\n')
                    fprintf(plot_stream,'%.15g %.15g %.15g %.15g\n',data[i](arange(),j).T)
                    fprintf(plot_stream,'%.15g %.15g %.15g %.15g\n\n',data[i](arange(),j + 1).T)
                    fprintf(plot_stream,'%.15g %.15g %.15g %.15g\n',data[i](arange(),j + 2).T)
                    fprintf(plot_stream,'%.15g %.15g %.15g %.15g\n',data[i](arange(),j + 3).T)
                fputs(plot_stream,'e\n')
            else:
                if (is_image_data[i]):
                    fwrite(plot_stream,data[i],'float32')
                else:
                    __gnuplot_write_data__(plot_stream,data[i],nd,parametric[i],have_cdata[i])
    else:
        fputs(plot_stream,'plot "-";\nInf Inf\ne\n')
    
    ## Needed to allow mouse rotation with pcolor.
    if (view_map):
        fputs(plot_stream,'unset view;\n')
    
    if (bg_is_set):
        fputs(plot_stream,'unset obj 1;\n')
        bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1762
    
    fflush(plot_stream)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def flip(x=None,*args,**kwargs):
    varargin = flip.varargin
    nargin = flip.nargin

    if (rows(x) == 1):
        x=fliplr(x)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1771
    else:
        if (columns(x) == 1 or ischar(x)):
            x=flipud(x)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1773
        else:
            x=flipud(fliplr(x))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1775
    
    return x
    
if __name__ == '__main__':
    pass
    
    
@function
def create_spacingspec(f=None,s=None,gp_term=None,*args,**kwargs):
    varargin = create_spacingspec.varargin
    nargin = create_spacingspec.nargin

    ## The gnuplot default font size is 10, and default spacing is 1.25.
  ## gnuplot has a concept of a figure global font, and sizes everything
  ## appropriate to that, including the legend spacing.
  ##
  ## This means that if an alternative size is used, gnuplot will use an
  ## inappropriate spacing in the legend by default.
  ##
  ## FIXME: Are fractional spacing specifications allowed?  Or should this
  ##        number be rounded?
    spc=dot(s / 10,1.25)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1789
    spacing_spec=sprintf('spacing %d',spc)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1790
    return spacing_spec
    
if __name__ == '__main__':
    pass
    
    
@function
def create_fontspec(f=None,s=None,gp_term=None,*args,**kwargs):
    varargin = create_fontspec.varargin
    nargin = create_fontspec.nargin

    if (strcmp(f,'*') or strcmp(gp_term,'tikz')):
        fontspec=sprintf('font ",%d"',s)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1796
    else:
        fontspec=sprintf('font "%s,%d"',f,s)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1798
    
    return fontspec
    
if __name__ == '__main__':
    pass
    
    
@function
def do_linestyle_command(obj=None,linecolor=None,idx=None,mono=None,plot_stream=None,errbars='',*args,**kwargs):
    varargin = do_linestyle_command.varargin
    nargin = do_linestyle_command.nargin

    style=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1804
    fprintf(plot_stream,'set style line %d default;\n',idx)
    fprintf(plot_stream,'set style line %d',idx)
    found_style=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1809
    if (isnumeric(linecolor)):
        color=copy(linecolor)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1811
        if (logical_not(mono)):
            fprintf(plot_stream,' linecolor rgb "#%02x%02x%02x"',round(dot(255,color)))
    else:
        color=matlabarray(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1817
    
    if (isfield(obj,'linestyle')):
        if '-' == (obj.linestyle):
            lt='1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1823
        else:
            if '--' == (obj.linestyle):
                lt='2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1825
            else:
                if ':' == (obj.linestyle):
                    lt='3'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1827
                else:
                    if '-.' == (obj.linestyle):
                        lt='6'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1829
                    else:
                        if 'none' == (obj.linestyle):
                            lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1831
                        else:
                            lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1833
        if (logical_not(isempty(lt))):
            fprintf(plot_stream,' linetype %s',lt)
    else:
        lt=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1841
    
    if (logical_not(isempty(errbars))):
        found_style=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1844
    
    if (isfield(obj,'linewidth')):
        fprintf(plot_stream,' linewidth %f',obj.linewidth)
        found_style=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1849
    
    pt,pt2,obj=gnuplot_pointtype(obj,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1852
    if (logical_not(isempty(pt))):
        found_style=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1855
    
    sidx=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1858
    if (isempty(errbars)):
        if (isempty(lt)):
            style[sidx]=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1861
        else:
            style[sidx]='lines'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1863
        facesame=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1866
        if (logical_not(isequal(pt,pt2)) and isfield(obj,'markerfacecolor') and logical_not(strcmp(obj.markerfacecolor,'none'))):
            if (strcmp(obj.markerfacecolor,'auto') or logical_not(isnumeric(obj.markerfacecolor)) or (isnumeric(obj.markerfacecolor) and isequal(color,obj.markerfacecolor))):
                if (logical_not(isempty(pt2))):
                    fprintf(plot_stream,' pointtype %s',pt2)
                    style[sidx]=strcat(style[sidx],'points')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1875
                if (isfield(obj,'markersize')):
                    fprintf(plot_stream,' pointsize %f',obj.markersize / 3)
            else:
                facesame=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1881
                if (logical_not(found_style)):
                    fputs(plot_stream,' default')
                fputs(plot_stream,';\n')
                if (logical_not(isempty(style[sidx]))):
                    sidx
                    idx
                else:
                    fputs(plot_stream,';\n')
                fprintf(plot_stream,'set style line %d default;\n',idx)
                fprintf(plot_stream,'set style line %d',idx)
                if (isnumeric(obj.markerfacecolor) and logical_not(mono)):
                    fprintf(plot_stream,' linecolor rgb "#%02x%02x%02x"',round(dot(255,obj.markerfacecolor)))
                if (logical_not(isempty(pt2))):
                    style[sidx]='points'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1899
                    fprintf(plot_stream,' pointtype %s',pt2)
                if (isfield(obj,'markersize')):
                    fprintf(plot_stream,' pointsize %f',obj.markersize / 3)
        if (isfield(obj,'markeredgecolor') and logical_not(strcmp(obj.markeredgecolor,'none'))):
            if (facesame and logical_not(isempty(pt)) and (strcmp(obj.markeredgecolor,'auto') or logical_not(isnumeric(obj.markeredgecolor)) or (isnumeric(obj.markeredgecolor) and isequal(color,obj.markeredgecolor)))):
                if (sidx == 1 and ((length(style[sidx]) == 5 and strncmp(style[sidx],'lines',5)) or isempty(style[sidx]))):
                    if (logical_not(isempty(pt))):
                        style[sidx]=strcat(style[sidx],'points')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1917
                        fprintf(plot_stream,' pointtype %s',pt)
                    if (isfield(obj,'markersize')):
                        fprintf(plot_stream,' pointsize %f',obj.markersize / 3)
            else:
                if (logical_not(found_style)):
                    fputs(plot_stream,' default')
                fputs(plot_stream,';\n')
                if (logical_not(isempty(style[sidx]))):
                    sidx
                    idx
                else:
                    fputs(plot_stream,';\n')
                fprintf(plot_stream,'set style line %d default;\n',idx)
                fprintf(plot_stream,'set style line %d',idx)
                if (logical_not(mono)):
                    if (strcmp(obj.markeredgecolor,'auto')):
                        fprintf(plot_stream,' linecolor rgb "#%02x%02x%02x"',round(dot(255,color)))
                    else:
                        if (isnumeric(obj.markeredgecolor) and logical_not(mono)):
                            fprintf(plot_stream,' linecolor rgb "#%02x%02x%02x"',round(dot(255,obj.markeredgecolor)))
                if (logical_not(isempty(pt))):
                    style[sidx]='points'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1947
                    fprintf(plot_stream,' pointtype %s',pt)
                if (isfield(obj,'markersize')):
                    fprintf(plot_stream,' pointsize %f',obj.markersize / 3)
    else:
        style[1]=errbars
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1956
        fputs(plot_stream,' pointtype 0')
    
    if (logical_not(found_style) and isempty(style[1])):
        fputs(plot_stream,' default')
    
    fputs(plot_stream,';\n')
    return style
    
if __name__ == '__main__':
    pass
    
    
@function
def gnuplot_pointtype(obj=None,*args,**kwargs):
    varargin = gnuplot_pointtype.varargin
    nargin = gnuplot_pointtype.nargin

    if (isfield(obj,'marker')):
        if '+' == (obj.marker):
            pt=pt2='1'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1972
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1972
        else:
            if 'o' == (obj.marker):
                pt='6'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1974
                pt2='7'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1975
            else:
                if '*' == (obj.marker):
                    pt=pt2='3'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1977
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1977
                else:
                    if '.' == (obj.marker):
                        pt='6'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1979
                        pt2='7'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1980
                        if (isfield(obj,'markerfacecolor') or strcmp(obj.markerfacecolor,'none')):
                            obj.markerfacecolor = copy('auto')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1983
                        if (isfield(obj,'markersize')):
                            obj.markersize /= 3
                        else:
                            obj.markersize = copy(5)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1988
                    else:
                        if 'x' == (obj.marker):
                            pt=pt2='2'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1991
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1991
                        else:
                            if cellarray(['square','s']) == (obj.marker):
                                pt='4'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1993
                                pt2='5'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1994
                            else:
                                if cellarray(['diamond','d']) == (obj.marker):
                                    pt='12'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1996
                                    pt2='13'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1997
                                else:
                                    if '^' == (obj.marker):
                                        pt='8'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:1999
                                        pt2='9'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2000
                                    else:
                                        if 'v' == (obj.marker):
                                            pt='10'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2002
                                            pt2='11'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2003
                                        else:
                                            if '>' == (obj.marker):
                                                ## FIXME: Should be triangle pointing right, use triangle pointing up
                                                pt='8'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2006
                                                pt2='9'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2007
                                            else:
                                                if '<' == (obj.marker):
                                                    ## FIXME: Should be triangle pointing left, use triangle pointing down
                                                    pt='10'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2010
                                                    pt2='11'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2011
                                                else:
                                                    if cellarray(['pentagram','p']) == (obj.marker):
                                                        ## FIXME: Should be pentagram, using pentagon
                                                        pt='14'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2014
                                                        pt2='15'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2015
                                                    else:
                                                        if cellarray(['hexagram','h']) == (obj.marker):
                                                            ## FIXME: Should be 6 pt start, using "*" instead
                                                            pt=pt2='3'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2018
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2018
                                                        else:
                                                            if 'none' == (obj.marker):
                                                                pt=pt2=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2020
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2020
                                                            else:
                                                                pt=pt2=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2022
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2022
    else:
        pt=pt2=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2025
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2025
    
    return pt,pt2,obj
    
if __name__ == '__main__':
    pass
    
    
@function
def __gnuplot_write_data__(plot_stream=None,data=None,nd=None,parametric=None,cdata=None,*args,**kwargs):
    varargin = __gnuplot_write_data__.varargin
    nargin = __gnuplot_write_data__.nargin

    ## DATA is already transposed.
    
    ## FIXME: this may need to be converted to C++ for speed.
    
    ## Convert NA elements to normal NaN values because fprintf writes
  ## "NA" and that confuses gnuplot.
    idx=find(isna(data))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2037
    if (any(idx)):
        data[idx]=NaN
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2039
    
    if (nd == 2):
        fwrite(plot_stream,data,'float64')
    else:
        if (nd == 3):
            if (parametric):
                fwrite(plot_stream,data,'float64')
            else:
                nr=rows(data)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2048
                if (cdata):
                    for j in arange(1,nr,4).reshape(-1):
                        fwrite(plot_stream,data[j:j + 3,:],'float64')
                else:
                    for j in arange(1,nr,3).reshape(-1):
                        fwrite(plot_stream,data[j:j + 2,:],'float64')
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def do_tics(obj=None,plot_stream=None,ymirror=None,mono=None,gnuplot_term=None,*args,**kwargs):
    varargin = do_tics.varargin
    nargin = do_tics.nargin

    obj.xticklabel = copy(ticklabel_to_cell(obj.xticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2065
    obj.yticklabel = copy(ticklabel_to_cell(obj.yticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2066
    obj.zticklabel = copy(ticklabel_to_cell(obj.zticklabel))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2067
    if (strcmp(obj.xminorgrid,'on')):
        obj.xminortick = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2070
    
    if (strcmp(obj.yminorgrid,'on')):
        obj.yminortick = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2073
    
    if (strcmp(obj.zminorgrid,'on')):
        obj.zminortick = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2076
    
    fontname,fontsize=get_fontname_and_size(obj,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2079
    fontspec=create_fontspec(fontname,fontsize,gnuplot_term)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2080
    
    ticklength=sprintf('scale %4.1f',dot((69 / 0.5),obj.ticklength(1)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2083
    if (strcmpi(obj.xaxislocation,'top')):
        do_tics_1(obj.xtickmode,obj.xtick,obj.xminortick,obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x2',plot_stream,true,mono,'border',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
        do_tics_1('manual',[],'off',obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x',plot_stream,true,mono,'border','','',fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
    else:
        if (strcmpi(obj.xaxislocation,'zero')):
            do_tics_1(obj.xtickmode,obj.xtick,obj.xminortick,obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x',plot_stream,true,mono,'axis',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
            do_tics_1('manual',[],'off',obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x2',plot_stream,true,mono,'axis','','',fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
        else:
            do_tics_1(obj.xtickmode,obj.xtick,obj.xminortick,obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x',plot_stream,true,mono,'border',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
            do_tics_1('manual',[],'off',obj.xticklabelmode,obj.xticklabel,obj.xcolor,'x2',plot_stream,true,mono,'border','','',fontname,fontspec,obj.interpreter,obj.xscale,obj.xsgn,gnuplot_term)
    
    if (strcmpi(obj.yaxislocation,'right')):
        do_tics_1(obj.ytickmode,obj.ytick,obj.yminortick,obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y2',plot_stream,ymirror,mono,'border',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
        do_tics_1('manual',[],'off',obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y',plot_stream,ymirror,mono,'border','','',fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
    else:
        if (strcmpi(obj.yaxislocation,'zero')):
            do_tics_1(obj.ytickmode,obj.ytick,obj.yminortick,obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y',plot_stream,ymirror,mono,'axis',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
            do_tics_1('manual',[],'off',obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y2',plot_stream,ymirror,mono,'axis','','',fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
        else:
            do_tics_1(obj.ytickmode,obj.ytick,obj.yminortick,obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y',plot_stream,ymirror,mono,'border',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
            do_tics_1('manual',[],'off',obj.yticklabelmode,obj.yticklabel,obj.ycolor,'y2',plot_stream,ymirror,mono,'border','','',fontname,fontspec,obj.interpreter,obj.yscale,obj.ysgn,gnuplot_term)
    
    do_tics_1(obj.ztickmode,obj.ztick,obj.zminortick,obj.zticklabelmode,obj.zticklabel,obj.zcolor,'z',plot_stream,true,mono,'border',obj.tickdir,ticklength,fontname,fontspec,obj.interpreter,obj.zscale,obj.zsgn,gnuplot_term)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def do_tics_1(ticmode=None,tics=None,mtics=None,labelmode=None,labels=None,color=None,ax=None,plot_stream=None,mirror=None,mono=None,axispos=None,tickdir=None,ticklength=None,fontname=None,fontspec=None,interpreter=None,scale=None,sgn=None,gnuplot_term=None,*args,**kwargs):
    varargin = do_tics_1.varargin
    nargin = do_tics_1.nargin

    
    
    ## effect of the previous unset xtics and thereby adds back in the tics.
    if (isempty(tics)):
        return
    
    if (mirror):
        mirror='mirror'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2159
    else:
        mirror='nomirror'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2161
    
    if (strcmpi(interpreter,'tex')):
        for n in arange(1,numel(labels)).reshape(-1):
            labels[n]=__tex2enhanced__(labels[n],fontname,false,false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2165
    else:
        if (strcmpi(interpreter,'latex')):
            if (logical_not(warned_latex)):
                warning('latex markup not supported for tick marks')
                warned_latex=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2170
    
    if (strcmp(scale,'log')):
        num_mtics=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2174
        if (any(strcmp(gnuplot_term,cellarray(['tikz','pstex','pslatex','epslatex'])))):
            fmt='$10^{%T}$'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2176
        else:
            fmt='10^{%T}'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2178
        if (sgn < 0):
            fmt=strcat('-',fmt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2181
    else:
        fmt='%g'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2184
        num_mtics=5
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2185
    
    colorspec=get_text_colorspec(color,mono)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2187
    fprintf(plot_stream,'set format %s "%s";\n',ax,fmt)
    if (strcmpi(ticmode,'manual')):
        if (isempty(tics)):
            fprintf(plot_stream,'unset %stics;\nunset m%stics;\n',ax,ax)
            return
        fprintf(plot_stream,'set %stics %s %s %s %s (',ax,tickdir,ticklength,axispos,mirror)
        fprintf(plot_stream,' %.15g,',tics[1:end() - 1])
        fprintf(plot_stream,' %.15g) %s;\n',tics[end()],fontspec)
    else:
        fprintf(plot_stream,'set %stics %s %s %s %s %s %s;\n',ax,tickdir,ticklength,axispos,mirror,colorspec,fontspec)
    
    if (strcmpi(labelmode,'manual')):
        k=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2203
        ntics=numel(tics)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2204
        nlabels=numel(labels)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2205
        fprintf(plot_stream,'set %stics add %s %s %s %s (',ax,tickdir,ticklength,axispos,mirror)
        labels=strrep(labels,'%','%%')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2208
        for i in arange(1,ntics).reshape(-1):
            fprintf(plot_stream,' "%s" %.15g',labels[k],tics[i])
            if (i < ntics):
                fputs(plot_stream,', ')
            if (k > nlabels):
                k=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2215
        fprintf(plot_stream,') %s %s;\n',colorspec,fontspec)
    
    if (strcmp(mtics,'on')):
        fprintf(plot_stream,'set m%stics %d;\n',ax,num_mtics)
    else:
        fprintf(plot_stream,'unset m%stics;\n',ax)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def ticklabel_to_cell(ticklabel=None,*args,**kwargs):
    varargin = ticklabel_to_cell.varargin
    nargin = ticklabel_to_cell.nargin

    if (ischar(ticklabel)):
        ticklabel=cellstr(ticklabel)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2229
    else:
        if (iscellstr(ticklabel)):
            ticklabel=copy(ticklabel)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2231
        else:
            error('__go_draw_axes__: unsupported type of ticklabel')
    
    return ticklabel
    
if __name__ == '__main__':
    pass
    
    
@function
def get_text_colorspec(color=None,mono=None,*args,**kwargs):
    varargin = get_text_colorspec.varargin
    nargin = get_text_colorspec.nargin

    if (mono):
        colorspec=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2239
    else:
        colorspec=sprintf('textcolor rgb "#%02x%02x%02x"',round(dot(255,color)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2241
    
    return colorspec
    
if __name__ == '__main__':
    pass
    
    
@function
def get_fontname_and_size(t=None,*args,**kwargs):
    varargin = get_fontname_and_size.varargin
    nargin = get_fontname_and_size.nargin

    if (isempty(t.fontname) or strcmp(t.fontname,'*')):
        fnt='{}'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2248
    else:
        fnt=t.fontname
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2250
    
    f=copy(fnt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2252
    it=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2253
    bld=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2254
    if (logical_not(isempty(t.fontweight)) and strcmpi(t.fontweight,'bold')):
        if (logical_not(isempty(t.fontangle)) and (strcmpi(t.fontangle,'italic') or strcmpi(t.fontangle,'oblique'))):
            f=matlabarray(cat(f,'-bolditalic'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2259
            it=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2260
            bld=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2261
        else:
            f=matlabarray(cat(f,'-bold'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2263
            bld=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2264
    else:
        if (logical_not(isempty(t.fontangle)) and (strcmpi(t.fontangle,'italic') or strcmpi(t.fontangle,'oblique'))):
            f=matlabarray(cat(f,'-italic'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2269
            it=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2270
    
    if (isempty(t.fontsize)):
        s=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2273
    else:
        s=t.fontsize
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2275
    
    return f,s,fnt,it,bld
    
if __name__ == '__main__':
    pass
    
    
@function
def __maybe_munge_text__(enhanced=None,obj=None,fld=None,*args,**kwargs):
    varargin = __maybe_munge_text__.varargin
    nargin = __maybe_munge_text__.nargin

    
    if (strcmp(fld,'string')):
        f,s,fnt,it,bld=get_fontname_and_size(obj,nargout=5)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2284
    else:
        f='Helvetica'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2286
        s=10
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2287
        fnt=copy(f)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2288
        it=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2289
        bld=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2290
    
    ## The text object may be multiline, and may be of any class
    str=getfield(obj,fld)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2294
    if (ischar(str) and rows(str) > 1):
        str=cellstr(str)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2296
    else:
        if (isnumeric(str)):
            str=cellstr(num2str(ravel(str)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2298
    
    if (iscellstr(str)):
        for n in arange(1,numel(str)).reshape(-1):
            if (isnumeric(str[n])):
                str[n]=num2str(str[n])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2303
        str=sprintf('%s\n',str[:])(arange(1,end() - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2306
    
    if (enhanced):
        str=regexprep(str,'(?<!\\\\)@','\\@')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2310
    
    if (enhanced):
        if (strcmpi(obj.interpreter,'tex')):
            if (iscellstr(str)):
                for n in arange(1,numel(str)).reshape(-1):
                    str[n]=__tex2enhanced__(str[n],fnt,it,bld)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2317
            else:
                str=__tex2enhanced__(str,fnt,it,bld)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2320
        else:
            if (strcmpi(obj.interpreter,'latex')):
                if (logical_not(warned_latex)):
                    warning('latex markup not supported for text objects')
                    warned_latex=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2325
    
    return str,f,s
    
if __name__ == '__main__':
    pass
    
    
@function
def __tex2enhanced__(str=None,fnt=None,it=None,bld=None,*args,**kwargs):
    varargin = __tex2enhanced__.varargin
    nargin = __tex2enhanced__.nargin

    
    
    s,e,m=regexp(str,'\\\\([a-zA-Z]+|0)','start','end','matches',nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2335
    for i in arange(length(s),1,- 1).reshape(-1):
        ## special case for "\0"  and replace with empty set "{/Symbol \306}'
        if (strncmp(m[i],'\\0',2)):
            str=matlabarray(cat(str[1:s[i] - 1],'{/Symbol \\306}',str[s[i] + 2:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2340
        else:
            f=m[i](arange(2,end()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2342
            if (isfield(sym,f)):
                g=getfield(sym,f)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2344
                ##if (bld)
        ##  if (it)
        ##    g = regexprep (g, '/Symbol', '/Symbol-bolditalic');
        ##  else
        ##    g = regexprep (g, '/Symbol', '/Symbol-bold');
        ##  endif
        ##elseif (it)
        ##  g = regexprep (g, '/Symbol', '/Symbol-italic');
        ##endif
                str=matlabarray(cat(str[1:s[i] - 1],g,str[e[i] + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2355
            else:
                if (strncmp(f,'rm',2)):
                    bld=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2357
                    it=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2358
                    str=matlabarray(cat(str[1:s[i] - 1],'/',fnt,' ',str[s[i] + 3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2359
                else:
                    if (strncmp(f,'it',2) or strncmp(f,'sl',2)):
                        it=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2361
                        if (bld):
                            str=matlabarray(cat(str[1:s[i] - 1],'/',fnt,'-bolditalic ',str[s[i] + 3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2363
                        else:
                            str=matlabarray(cat(str[1:s[i] - 1],'/',fnt,'-italic ',str[s[i] + 3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2365
                    else:
                        if (strncmp(f,'bf',2)):
                            bld=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2368
                            if (it):
                                str=matlabarray(cat(str[1:s[i] - 1],'/',fnt,'-bolditalic ',str[s[i] + 3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2370
                            else:
                                str=matlabarray(cat(str[1:s[i] - 1],'/',fnt,'-bold ',str[s[i] + 3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2372
                        else:
                            if (strcmpi(f,'color')):
                                ## FIXME: Ignore \color but remove trailing {} block as well
                                d=strfind(str[e[i] + 1:end()],'}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2376
                                if (isempty(d)):
                                    warning('syntax error in \\color argument')
                                else:
                                    str=matlabarray(cat(str[1:s[i] - 1],str[e[i] + d + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2380
                            else:
                                if (strcmpi(f,'fontname')):
                                    b1=strfind(str[e[i] + 1:end()],'{')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2383
                                    b2=strfind(str[e[i] + 1:end()],'}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2384
                                    if (isempty(b1) or isempty(b2)):
                                        warning('syntax error in \\fontname argument')
                                    else:
                                        str=matlabarray(cat(str[1:s[i] - 1],'/',str[e[i] + b1[1] + 1:e[i] + b2[1] - 1],'{}',str[e[i] + b2[1] + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2388
                                else:
                                    if (strcmpi(f,'fontsize')):
                                        b1=strfind(str[e[i] + 1:end()],'{')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2392
                                        b2=strfind(str[e[i] + 1:end()],'}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2393
                                        if (isempty(b1) or isempty(b2)):
                                            warning('syntax error in \\fontname argument')
                                        else:
                                            str=matlabarray(cat(str[1:s[i] - 1],'/=',str[e[i] + b1[1] + 1:e[i] + b2[1] - 1],'{}',str[e[i] + b2[1] + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2397
                                    else:
                                        ## Last desperate attempt to treat the symbol. Look for things
        ## like \pix, that should be translated to the symbol Pi and x
                                        for j in arange(1,length(flds)).reshape(-1):
                                            if (strncmp(flds[j],f,length(flds[j]))):
                                                g=getfield(sym,flds[j])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2405
                                                ##if (bld)
            ##  if (it)
            ##    g = regexprep (g, '/Symbol', '/Symbol-bolditalic');
            ##  else
            ##    g = regexprep (g, '/Symbol', '/Symbol-bold');
            ##  endif
            ##elseif (it)
            ##  g = regexprep (g, '/Symbol', '/Symbol-italic');
            ##endif
                                                str=matlabarray(cat(str[1:s[i] - 1],g,str[s[i] + length(flds[j]) + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2416
                                                break
    
    ## Prepend @ to things like _0^x or _{-100}^{100} for alignment.
  ## But need to put the shorter of the two arguments first.
  ## Careful of nested {} and unprinted characters when defining
  ## shortest..  Don't have to worry about things like ^\theta as they
  ## are already converted to ^{/Symbol q}.
    
    ## FIXME: This is a mess... Is it worth it just for a "@" character?
    
    s,m=regexp(str,'[_\\^]','start','matches',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2432
    i=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2433
    p=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2434
    while (i < length(s)):

        if (i < length(s)):
            if (str[s[i] + p + 1] == '{'):
                s1=strfind(str[s[i] + p + 2:end()],'{')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2438
                si=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2439
                l1=strfind(str[s[i] + p + 1:end()],'}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2440
                li=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2441
                while (li <= length(l1) and si <= length(s1)):

                    if (l1[li] < s1[si]):
                        if (li == si):
                            break
                        li
                    else:
                        si

                l1=l1[min(length(l1),si)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2452
                if (s[i] + l1 + 1 == s[i + 1]):
                    if (str[s[i + 1] + p + 1] == '{'):
                        s2=strfind(str[s[i + 1] + p + 2:end()],'{')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2455
                        si=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2456
                        l2=strfind(str[s[i + 1] + p + 1:end()],'}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2457
                        li=1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2458
                        while (li <= length(l2) and si <= length(s2)):

                            if (l2[li] < s2[si]):
                                if (li == si):
                                    break
                                li
                            else:
                                si

                        l2=l2[min(length(l2),si)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2469
                        if (length_string(str[s[i] + p + 2:s[i] + p + l1 - 1]) <= length_string(str[s[i + 1] + p + 2:s[i + 1] + p + l2 - 1])):
                            ## Shortest already first!
                            str=matlabarray(cat(str[1:s[i] + p - 1],'@',str[s[i] + p:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2473
                        else:
                            ## Have to swap sub/super-script to get shortest first.
                            str=matlabarray(cat(str[1:s[i] + p - 1],'@',str[s[i + 1] + p:s[i + 1] + p + l2],str[s[i] + p:s[i] + p + l1],str[s[i + 1] + p + l2 + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2476
                    else:
                        ## Have to swap sub/super-script to get shortest first.
                        str=matlabarray(cat(str[1:s[i] + p - 1],'@',str[s[i + 1] + p:s[i + 1] + p + 1],str[s[i] + p:s[i] + p + l1],str[s[i + 1] + p + 2:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2481
                    i += 2
                    p
                else:
                    i
            else:
                if (s[i + 1] == s[i] + 2):
                    ## Shortest already first!
                    str=matlabarray(cat(str[1:s[i] + p - 1],'@',str[s[i] + p:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2492
                    p
                    i += 2
                else:
                    i
        else:
            i

    
    return str
    
if __name__ == '__main__':
    pass
    
    
@function
def length_string(s=None,*args,**kwargs):
    varargin = length_string.varargin
    nargin = length_string.nargin

    l=length(s) - length(strfind(s,'{')) - length(strfind(s,'}'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2507
    m=regexp(s,'/([\\w-]+|[\\w-]+=\\d+)','matches')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2508
    if (logical_not(isempty(m))):
        l=l - sum(cellfun('length',m))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2510
    
    return l
    
if __name__ == '__main__':
    pass
    
    
@function
def __setup_sym_table__(*args,**kwargs):
    varargin = __setup_sym_table__.varargin
    nargin = __setup_sym_table__.nargin

    ## Setup the translation table for TeX to gnuplot enhanced mode.
    sym.forall = copy('{/Symbol \\042}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2516
    sym.exists = copy('{/Symbol \\044}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2517
    sym.ni = copy('{/Symbol \\047}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2518
    sym.cong = copy('{/Symbol \\100}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2519
    sym.Delta = copy('{/Symbol D}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2520
    sym.Phi = copy('{/Symbol F}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2521
    sym.Gamma = copy('{/Symbol G}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2522
    sym.vartheta = copy('{/Symbol J}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2523
    sym.Lambda = copy('{/Symbol L}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2524
    sym.Pi = copy('{/Symbol P}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2525
    sym.Theta = copy('{/Symbol Q}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2526
    sym.Sigma = copy('{/Symbol S}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2527
    sym.varsigma = copy('{/Symbol V}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2528
    sym.Omega = copy('{/Symbol W}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2529
    sym.Xi = copy('{/Symbol X}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2530
    sym.Psi = copy('{/Symbol Y}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2531
    sym.perp = copy('{/Symbol \\136}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2532
    sym.alpha = copy('{/Symbol a}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2533
    sym.beta = copy('{/Symbol b}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2534
    sym.chi = copy('{/Symbol c}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2535
    sym.delta = copy('{/Symbol d}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2536
    sym.epsilon = copy('{/Symbol e}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2537
    sym.phi = copy('{/Symbol f}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2538
    sym.gamma = copy('{/Symbol g}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2539
    sym.eta = copy('{/Symbol h}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2540
    sym.iota = copy('{/Symbol i}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2541
    sym.varphi = copy('{/Symbol j}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2542
    
    sym.kappa = copy('{/Symbol k}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2543
    sym.lambda = copy('{/Symbol l}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2544
    sym.mu = copy('{/Symbol m}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2545
    sym.nu = copy('{/Symbol n}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2546
    sym.o = copy('{/Symbol o}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2547
    sym.pi = copy('{/Symbol p}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2548
    sym.theta = copy('{/Symbol q}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2549
    sym.rho = copy('{/Symbol r}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2550
    sym.sigma = copy('{/Symbol s}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2551
    sym.tau = copy('{/Symbol t}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2552
    sym.upsilon = copy('{/Symbol u}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2553
    sym.varpi = copy('{/Symbol v}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2554
    sym.omega = copy('{/Symbol w}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2555
    sym.xi = copy('{/Symbol x}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2556
    sym.psi = copy('{/Symbol y}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2557
    sym.zeta = copy('{/Symbol z}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2558
    sym.sim = copy('{/Symbol \\176}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2559
    sym.Upsilon = copy('{/Symbol \\241}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2560
    sym.prime = copy('{/Symbol \\242}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2561
    sym.leq = copy('{/Symbol \\243}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2562
    sym.infty = copy('{/Symbol \\245}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2563
    sym.clubsuit = copy('{/Symbol \\247}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2564
    sym.diamondsuit = copy('{/Symbol \\250}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2565
    sym.heartsuit = copy('{/Symbol \\251}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2566
    sym.spadesuit = copy('{/Symbol \\252}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2567
    sym.leftrightarrow = copy('{/Symbol \\253}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2568
    sym.leftarrow = copy('{/Symbol \\254}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2569
    sym.uparrow = copy('{/Symbol \\255}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2570
    sym.rightarrow = copy('{/Symbol \\256}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2571
    sym.downarrow = copy('{/Symbol \\257}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2572
    sym.circ = copy('{/Symbol \\260}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2573
    
    sym.deg = copy('{/Symbol \\260}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2574
    sym.ast = copy('{/Symbol *}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2575
    sym.pm = copy('{/Symbol \\261}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2576
    sym.geq = copy('{/Symbol \\263}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2577
    sym.times = copy('{/Symbol \\264}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2578
    sym.propto = copy('{/Symbol \\265}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2579
    sym.partial = copy('{/Symbol \\266}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2580
    sym.bullet = copy('{/Symbol \\267}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2581
    sym.div = copy('{/Symbol \\270}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2582
    sym.neq = copy('{/Symbol \\271}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2583
    sym.equiv = copy('{/Symbol \\272}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2584
    sym.approx = copy('{/Symbol \\273}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2585
    sym.ldots = copy('{/Symbol \\274}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2586
    sym.mid = copy('{/Symbol \\275}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2587
    sym.aleph = copy('{/Symbol \\300}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2588
    sym.Im = copy('{/Symbol \\301}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2589
    sym.Re = copy('{/Symbol \\302}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2590
    sym.wp = copy('{/Symbol \\303}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2591
    sym.otimes = copy('{/Symbol \\304}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2592
    sym.oplus = copy('{/Symbol \\305}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2593
    
    sym.oslash = copy('{/Symbol \\306}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2595
    sym.cap = copy('{/Symbol \\307}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2596
    sym.cup = copy('{/Symbol \\310}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2597
    sym.supset = copy('{/Symbol \\311}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2598
    sym.supseteq = copy('{/Symbol \\312}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2599
    sym.subset = copy('{/Symbol \\314}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2600
    sym.subseteq = copy('{/Symbol \\315}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2601
    sym.in = copy('{/Symbol \\316}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2602
    sym.notin = copy('{/Symbol \\317}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2603
    
    sym.angle = copy('{/Symbol \\320}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2604
    sym.bigtriangledown = copy('{/Symbol \\321}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2605
    
    sym.langle = copy('{/Symbol \\341}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2606
    sym.rangle = copy('{/Symbol \\361}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2607
    sym.nabla = copy('{/Symbol \\321}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2608
    sym.prod = copy('{/Symbol \\325}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2609
    
    sym.surd = copy('{/Symbol \\326}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2610
    sym.cdot = copy('{/Symbol \\327}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2611
    sym.neg = copy('{/Symbol \\330}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2612
    sym.wedge = copy('{/Symbol \\331}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2613
    sym.vee = copy('{/Symbol \\332}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2614
    sym.Leftrightarrow = copy('{/Symbol \\333}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2615
    
    sym.Leftarrow = copy('{/Symbol \\334}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2616
    sym.Uparrow = copy('{/Symbol \\335}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2617
    
    sym.Rightarrow = copy('{/Symbol \\336}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2618
    sym.Downarrow = copy('{/Symbol \\337}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2619
    
    sym.diamond = copy('{/Symbol \\340}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2620
    
    sym.copyright = copy('{/Symbol \\343}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2621
    sym.lfloor = copy('{/Symbol \\353}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2622
    sym.lceil = copy('{/Symbol \\351}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2623
    sym.rfloor = copy('{/Symbol \\373}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2624
    sym.rceil = copy('{/Symbol \\371}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2625
    sym.int = copy('{/Symbol \\362}')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2626
    return sym
    
if __name__ == '__main__':
    pass
    
    
@function
def __do_enhanced_option__(enhanced=None,obj=None,*args,**kwargs):
    varargin = __do_enhanced_option__.varargin
    nargin = __do_enhanced_option__.nargin

    retval=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2630
    if (enhanced):
        if (strcmpi(obj.interpreter,'none')):
            retval='noenhanced'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2633
        else:
            retval='enhanced'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_axes__.m:2635
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def maybe_do_xtick_mirror(plot_stream=None,axis_obj=None,*args,**kwargs):
    varargin = maybe_do_xtick_mirror.varargin
    nargin = maybe_do_xtick_mirror.nargin

    if (logical_not(isempty(axis_obj.xtick))):
        fprintf(plot_stream,'unset x2tics; set xtics %s nomirror\n',axis_obj.tickdir)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def maybe_do_x2tick_mirror(plot_stream=None,axis_obj=None,*args,**kwargs):
    varargin = maybe_do_x2tick_mirror.varargin
    nargin = maybe_do_x2tick_mirror.nargin

    if (logical_not(isempty(axis_obj.xtick))):
        fprintf(plot_stream,'unset xtics; set x2tics %s nomirror\n',axis_obj.tickdir)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{args} =} __print_parse_opts__ (@var{propname}, @var{propvalue})
## @deftypefnx {Function File} {@var{args} =} __print_parse_opts__ (@var{struct})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __print_parse_opts__(varargin=None,*args,**kwargs):
    varargin = __print_parse_opts__.varargin
    nargin = __print_parse_opts__.nargin

    
    arg_st.append_to_file = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:29
    arg_st.canvas_size = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:30
    arg_st.debug = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:31
    arg_st.debug_file = copy('octave-print-commands.log')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:32
    arg_st.devopt = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:33
    arg_st.epstool_binary = copy(__quote_path__(__find_binary__('epstool')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:34
    arg_st.figure = copy(get(0,'currentfigure'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:35
    arg_st.fig2dev_binary = copy(__quote_path__(__find_binary__('fig2dev')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:36
    arg_st.fontsize = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:37
    arg_st.font = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:38
    arg_st.scalefontsize = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:39
    arg_st.force_solid = copy(0)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:40
    
    arg_st.formatted_for_printing = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:41
    arg_st.ghostscript.binary = copy(__quote_path__(__ghostscript_binary__()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:42
    arg_st.ghostscript.debug = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:43
    arg_st.ghostscript.device = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:44
    arg_st.ghostscript.epscrop = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:45
    arg_st.ghostscript.level = copy(2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:46
    arg_st.ghostscript.output = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:47
    arg_st.ghostscript.papersize = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:48
    arg_st.ghostscript.pageoffset = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:49
    arg_st.ghostscript.resolution = copy(150)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:50
    arg_st.ghostscript.antialiasing = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:51
    arg_st.ghostscript.antialiasing_textalphabits = copy(4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:52
    arg_st.ghostscript.antialiasing_graphicsalphabits = copy(4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:53
    arg_st.loose = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:54
    arg_st.lpr_binary = copy(__quote_path__(__find_binary__('lpr')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:55
    arg_st.name = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:56
    arg_st.orientation = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:57
    arg_st.pstoedit_binary = copy(__quote_path__(__find_binary__('pstoedit')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:58
    arg_st.preview = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:59
    arg_st.printer = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:60
    arg_st.send_to_printer = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:61
    arg_st.special_flag = copy('textnormal')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:62
    arg_st.tight_flag = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:63
    arg_st.use_color = copy(0)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:64
    
    if (isunix()):
        arg_st.lpr_options = copy('-l')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:67
    else:
        if (ispc()):
            arg_st.lpr_options = copy('-o l')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:69
        else:
            arg_st.lpr_options = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:71
    
    arg_st.unlink = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:73
    if (nargin > 0 and isfigure(varargin[1])):
        arg_st.figure = copy(varargin[1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:76
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:77
    
    for i in arange(1,numel(varargin)).reshape(-1):
        arg=strtrim(varargin[i])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:81
        if (ischar(arg)):
            if (strcmp(arg,'-color')):
                arg_st.use_color = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:84
            else:
                if (strcmp(arg,'-append')):
                    arg_st.append_to_file = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:86
                else:
                    if (strcmp(arg,'-mono')):
                        arg_st.use_color = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:88
                    else:
                        if (strcmp(arg,'-solid')):
                            arg_st.force_solid = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:90
                        else:
                            if (strcmp(arg,'-dashed')):
                                arg_st.force_solid = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:92
                            else:
                                if (strncmp(arg,'-portrait',length(arg))):
                                    arg_st.orientation = copy('portrait')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:94
                                else:
                                    if (strncmp(arg,'-landscape',length(arg))):
                                        arg_st.orientation = copy('landscape')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:96
                                    else:
                                        if (strcmp(arg,'-loose')):
                                            arg_st.loose = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:98
                                            arg_st.tight_flag = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:99
                                        else:
                                            if (strcmp(arg,'-tight')):
                                                arg_st.loose = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:101
                                                arg_st.tight_flag = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:102
                                            else:
                                                if (strcmp(arg,'-textspecial')):
                                                    arg_st.special_flag = copy('textspecial')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:104
                                                else:
                                                    if (any(strcmp(arg,cellarray(['-interchange','-metafile','-pict','-tiff'])))):
                                                        arg_st.preview = copy(arg[2:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:106
                                                    else:
                                                        if (strncmp(arg,'-debug',6)):
                                                            arg_st.debug = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:108
                                                            arg_st.ghostscript.debug = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:109
                                                            if (length(arg) > 7):
                                                                arg_st.debug_file = copy(arg[8:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:111
                                                        else:
                                                            if (length(arg) > 2 and arg[1:2] == '-d'):
                                                                arg_st.devopt = copy(tolower(arg[3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:114
                                                            else:
                                                                if (length(arg) > 2 and arg[1:2] == '-P'):
                                                                    arg_st.printer = copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:116
                                                                else:
                                                                    if (strncmp(arg,'-EPSTOOL:',9)):
                                                                        arg_st.epstool_binary = copy(arg[10:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:118
                                                                    else:
                                                                        if (strncmp(arg,'-FIG2DEV:',9)):
                                                                            arg_st.fig2dev_binary = copy(arg[10:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:120
                                                                        else:
                                                                            if (strncmp(arg,'-PSTOEDIT:',9)):
                                                                                arg_st.pstoedit_binary = copy(arg[10:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:122
                                                                            else:
                                                                                if (strncmpi(arg,'-textalphabits=',15)):
                                                                                    n=find(arg == '=')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:124
                                                                                    if (logical_not(isempty(n)) and n == numel(arg) - 1 and any(arg[end()] == '124')):
                                                                                        arg_st.ghostscript.antialiasing_textalphabits = copy(str2num(arg[end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:126
                                                                                    else:
                                                                                        error('print: improper syntax, or value, for TextAlphaBits')
                                                                                else:
                                                                                    if (strncmpi(arg,'-graphicsalphabits=',19)):
                                                                                        n=find(arg == '=')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:131
                                                                                        if (logical_not(isempty(n)) and n == numel(arg) - 1 and any(arg[end()] == '124')):
                                                                                            arg_st.ghostscript.antialiasing_graphicsalphabits = copy(str2num(arg[end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:133
                                                                                        else:
                                                                                            error('print: improper syntax, or value, for GraphicsAlphaBits')
                                                                                    else:
                                                                                        if ((length(arg) > 2) and arg[1:2] == '-G'):
                                                                                            arg_st.ghostscript.binary = copy(file_in_path(getenv('PATH'),arg[3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:138
                                                                                            if (isempty(arg_st.ghostscript.binary)):
                                                                                                error('print: Ghostscript binary ""%s"" could not be located',arg[3:end()])
                                                                                            else:
                                                                                                arg_st.ghostscript.binary = copy(__quote_path__(arg_st.ghostscript.binary))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:143
                                                                                        else:
                                                                                            if (length(arg) > 2 and arg[1:2] == '-F'):
                                                                                                idx=rindex(arg,':')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:146
                                                                                                if (idx):
                                                                                                    arg_st.font = copy(arg[3:idx - 1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:148
                                                                                                    arg_st.fontsize = copy(str2num(arg[idx + 1:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:149
                                                                                                else:
                                                                                                    arg_st.font = copy(arg[3:end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:151
                                                                                            else:
                                                                                                if (length(arg) > 2 and arg[1:2] == '-S'):
                                                                                                    arg_st.canvas_size = copy(str2num(arg[3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:154
                                                                                                else:
                                                                                                    if (length(arg) > 2 and arg[1:2] == '-r'):
                                                                                                        arg_st.ghostscript.resolution = copy(str2double(arg[3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:156
                                                                                                    else:
                                                                                                        if (length(arg) > 2 and arg[1:2] == '-f'):
                                                                                                            arg_st.figure = copy(str2num(arg[3:end()]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:158
                                                                                                        else:
                                                                                                            if (any(strcmp(arg,cellarray(['-painters','-opengl'])))):
                                                                                                                warning('print: \'%s\' accepted for Matlab compatibility, but is ignored',arg)
                                                                                                            else:
                                                                                                                if (strcmp(arg,'-noui')):
                                                                                                                    warning('print: option \'-noui\' not yet implemented')
                                                                                                                else:
                                                                                                                    if (length(arg) >= 1 and arg[1] == '-'):
                                                                                                                        error('print: unknown option \'%s\'',arg)
                                                                                                                    else:
                                                                                                                        if (length(arg) > 0):
                                                                                                                            arg_st.name = copy(tilde_expand(arg))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:166
        else:
            if (isfigure(arg)):
                arg_st.figure = copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:169
            else:
                error('print: expecting inputs to be character string options or a figure handle')
    
    if (arg_st.ghostscript.resolution == 0):
        ## Do as Matlab does.
        arg_st.ghostscript.resolution = copy(get(0,'screenpixelsperinch'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:177
    
    if (isempty(arg_st.orientation)):
        if (isfigure(arg_st.figure)):
            arg_st.orientation = copy(get(arg_st.figure,'paperorientation'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:182
        else:
            ## Allows tests to be run without error.
            arg_st.orientation = copy('portrait')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:185
    
    if (isempty(arg_st.ghostscript.binary)):
        arg_st.ghostscript.binary = copy(__ghostscript_binary__())
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:190
    
    dot=rindex(arg_st.name,'.')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:193
    if (isempty(arg_st.devopt)):
        if (dot == 0):
            arg_st.devopt = copy('psc')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:196
        else:
            arg_st.devopt = copy(tolower(arg_st.name(arange(dot + 1,end()))))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:198
    
    if (arg_st.use_color == 0):
        if (any(strcmp(cellarray(['ps','ps2','eps','eps2']),arg_st.devopt))):
            arg_st.use_color = copy(- 1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:204
        else:
            arg_st.use_color = copy(1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:206
    
    if (strcmp(arg_st.devopt,'tex')):
        arg_st.devopt = copy('epslatex')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:211
    else:
        if (strcmp(arg_st.devopt,'ill')):
            arg_st.devopt = copy('aifm')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:213
        else:
            if (strcmp(arg_st.devopt,'cdr')):
                arg_st.devopt = copy('corel')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:215
            else:
                if (strcmp(arg_st.devopt,'meta')):
                    arg_st.devopt = copy('emf')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:217
                else:
                    if (strcmp(arg_st.devopt,'jpg')):
                        arg_st.devopt = copy('jpeg')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:219
    
    dev_list=cellarray(['aifm','corel','fig','png','jpeg','gif','pbm','pbmraw','dxf','mf','svg','hpgl','ps','ps2','psc','psc2','eps','eps2','epsc','epsc2','emf','pdf','pslatex','epslatex','epslatexstandalone','pslatexstandalone','pdflatexstandalone','pstex','tiff','tiffn','tikz','pcxmono','pcx24b','pcx256','pcx16','pgm','pgmraw','ppm','ppmraw','pdflatex','texdraw','pdfcairo','pngcairo','pstricks','epswrite','eps2write','pswrite','ps2write','pdfwrite'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:222
    suffixes=cellarray(['ai','cdr','fig','png','jpg','gif','pbm','pbm','dxf','mf','svg','hpgl','ps','ps','ps','ps','eps','eps','eps','eps','emf','pdf','tex','tex','tex','tex','tex','ps','tiff','tiff','tikz','pcx','pcx','pcx','pcx','pgm','pgm','ppm','ppm','tex','tex','pdf','png','tex','eps','eps','ps','ps','pdf'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:234
    if (isfigure(arg_st.figure)):
        __graphics_toolkit__=get(arg_st.figure,'__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:247
    else:
        ## Allow tests when no figures are present.
        __graphics_toolkit__=get(0,'defaultfigure__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:250
    
    if (strcmp(__graphics_toolkit__,'gnuplot') and __gnuplot_has_feature__('epslatex_implies_eps_filesuffix')):
        suffixes[strncmp(dev_list,'epslatex',8)]=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:255
    
    match=strcmpi(dev_list,arg_st.devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:258
    if (any(match)):
        default_suffix=suffixes[match]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:260
    else:
        default_suffix=arg_st.devopt
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:262
    
    if (dot == 0 and logical_not(isempty(arg_st.name))):
        arg_st.name = copy(strcat(arg_st.name,'.',default_suffix))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:266
    
    if (arg_st.append_to_file):
        if (isempty(arg_st.name)):
            arg_st.append_to_file = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:271
        else:
            if (any(strcmpi(arg_st.devopt,cellarray(['eps','eps2','epsc','epsc2','ps','ps2','psc','psc2','pdf'])))):
                have_ghostscript=logical_not(isempty(__ghostscript_binary__()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:274
                if (have_ghostscript):
                    file_exists=((numel(dir(arg_st.name)) == 1) and (logical_not(isdir(arg_st.name))))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:276
                    if (logical_not(file_exists)):
                        arg_st.append_to_file = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:279
                else:
                    arg_st.append_to_file = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:282
                    warning('print.m: appended output requires ghostscript to be installed')
            else:
                warning('print.m: appended output is not supported for device \'%s\'',arg_st.devopt)
                arg_st.append_to_file = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:288
    
    if (logical_not(isempty(arg_st.printer)) or isempty(arg_st.name)):
        arg_st.send_to_printer = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:293
    
    if (any(strcmp(arg_st.devopt,cellarray(['ps','ps2','psc','psc2','pdf'])))):
        arg_st.formatted_for_printing = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:297
    
    aliases=gs_aliases()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:300
    if (any(strcmp(arg_st.devopt,fieldnames(aliases)))):
        arg_st.devopt = copy(getattr(aliases,(arg_st.devopt)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:302
    
    if ((any(strcmp(arg_st.devopt,gs_device_list)) and logical_not(arg_st.formatted_for_printing)) or any(strcmp(arg_st.devopt,cellarray(['pswrite','ps2write','pdfwrite'])))):
        ## Use ghostscript for graphic formats
        arg_st.ghostscript.device = copy(arg_st.devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:309
        arg_st.ghostscript.output = copy(arg_st.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:310
        arg_st.ghostscript.antialiasing = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:311
        if (arg_st.formatted_for_printing):
            arg_st.ghostscript.epscrop = copy(logical_not(arg_st.loose))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:313
        else:
            ## pstoedit throws errors if the EPS file isn't cropped
            arg_st.ghostscript.epscrop = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:316
    else:
        if (all(logical_not(strcmp(arg_st.devopt,dev_list)))):
            ## Assume we are formating output for a printer
            arg_st.formatted_for_printing = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:320
            arg_st.ghostscript.device = copy(arg_st.devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:321
            arg_st.ghostscript.output = copy(arg_st.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:322
            arg_st.ghostscript.antialiasing = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:323
            arg_st.ghostscript.epscrop = copy(logical_not(arg_st.loose))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:324
    
    if (arg_st.send_to_printer):
        if (isempty(arg_st.name)):
            ## Pipe the ghostscript output
            arg_st.name = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:330
        else:
            error('print: a file name may not specified when spooling to a printer')
        if (logical_not(any(strcmp(arg_st.devopt,gs_device_list)))):
            ## Only supported ghostscript devices
            error('print: format must be a valid Ghostscript format for spooling to a printer')
    else:
        if (isempty(arg_st.name)):
            error('print: an output file name must be specified')
    
    if (isempty(arg_st.canvas_size)):
        if (isfigure(arg_st.figure)):
            arg_st.ghostscript.papersize,paperposition=gs_papersize(arg_st.figure,arg_st.orientation,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:344
        else:
            ## allows tests to be run
            arg_st.ghostscript.papersize = copy('letter')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:348
            paperposition=dot(cat(0.25,2.5,8.0,6.0),72)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:349
        arg_st.canvas_size = copy(paperposition[3:4])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:351
        if (strcmp(__graphics_toolkit__,'gnuplot') and logical_not(arg_st.ghostscript.epscrop)):
            arg_st.ghostscript.pageoffset = copy(paperposition[1:2] - 50)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:354
        else:
            arg_st.ghostscript.pageoffset = copy(paperposition[1:2])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:356
    else:
        ## Convert canvas size to points from pixels.
        if (logical_not(isempty(arg_st.fontsize))):
            ## Work around the eps bbox having whole numbers (both gnuplot & gl2ps).
            arg_st.scalefontsize = copy(arg_st.ghostscript.resolution / 72)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:362
        arg_st.ghostscript.resolution = copy(72)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:364
        arg_st.ghostscript.papersize = copy(arg_st.canvas_size)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:365
        arg_st.ghostscript.epscrop = copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:366
        arg_st.ghostscript.pageoffset = copy(cat(0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:367
    
    if (arg_st.formatted_for_printing):
        arg_st.ghostscript.resolution = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:371
    else:
        arg_st.ghostscript.papersize = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:373
        arg_st.ghostscript.pageoffset = copy(cat(0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:374
    
    if (warn_on_missing_binary):
        if (isempty(arg_st.ghostscript.binary)):
            warning('print:missing_gs','print.m: Ghostscript binary is not available.\nOnly eps output is available.')
        else:
            if (isempty(arg_st.epstool_binary)):
                warning('print:missing_epstool','print.m: epstool binary is not available.\nSome output formats are not available.')
            if (isempty(arg_st.fig2dev_binary)):
                warning('print:missing_fig2dev','print.m: fig2dev binary is not available.\nSome output formats are not available.')
            if (isempty(arg_st.pstoedit_binary)):
                warning('print:missing_pstoedit','print.m: pstoedit binary is not available.\nSome output formats are not available.')
        warn_on_missing_binary=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:391
    
    return arg_st
    
if __name__ == '__main__':
    pass
    
    ## Test blocks are not allowed (and not needed) for private functions
##!test
    
    
    
    
    
    
    ##!test
    
    
    ##!test
    
    
    
    
    
    
    
    ##!test
    
    
    
    
    
    ##!test
    
    
    
    
    
    
    
    
    
    
    ##!test
    
    
    
    
    
    
    
    ##!test
    
    
    
    
    
    
    
@function
def __quote_path__(cmd=None,*args,**kwargs):
    varargin = __quote_path__.varargin
    nargin = __quote_path__.nargin

    if (logical_not(isempty(cmd))):
        is_quoted=all(cmd[cat(1,end())] == '\'')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:456
        if (logical_not(is_quoted)):
            dos_shell=logical_not(isunix()) and ispc()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:458
            if (dos_shell and any(cmd == '/')):
                cmd=strrep(cmd,'/','\\')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:460
            if (any(cmd == ' ')):
                cmd=strcat('"',strrep(cmd,'"','""'),'"')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:463
    
    return cmd
    
if __name__ == '__main__':
    pass
    
    
@function
def __ghostscript_binary__(*args,**kwargs):
    varargin = __ghostscript_binary__.varargin
    nargin = __ghostscript_binary__.nargin

    
    
    
    if (isempty(ghostscript_binary)):
        GSC=getenv('GSC')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:476
        if (exist(GSC,'file') or (logical_not(isempty(GSC)) and file_in_path(getenv('PATH'),GSC))):
            gs_binaries=cellarray([GSC])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:479
        else:
            if (logical_not(isempty(GSC)) and warn_on_bad_gsc):
                warning('print:badgscenv','print.m: GSC environment variable not set properly')
                warn_on_bad_gsc=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:483
                gs_binaries=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:484
            else:
                gs_binaries=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:486
        if (isunix()):
            ## Unix - Includes Mac OSX and Cygwin.
            gs_binaries=matlabarray(cat(gs_binaries,cellarray(['gs','gs.exe'])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:490
        else:
            ## pc - Includes Win32 and mingw.
            gs_binaries=matlabarray(cat(gs_binaries,cellarray(['gs.exe','gswin32c.exe','gswin64c.exe','mgs.exe'])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:493
        n=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:496
        while (n < numel(gs_binaries) and isempty(ghostscript_binary)):

            n=n + 1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:498
            ghostscript_binary=file_in_path(getenv('PATH'),gs_binaries[n])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:499

        if (warn_on_no_ghostscript and isempty(ghostscript_binary)):
            warning('print:noghostscript','print.m: ghostscript not found in PATH')
            warn_on_no_ghostscript=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:504
    
    gs=copy(ghostscript_binary)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:508
    return gs
    
if __name__ == '__main__':
    pass
    
    
@function
def __find_binary__(binary=None,*args,**kwargs):
    varargin = __find_binary__.varargin
    nargin = __find_binary__.nargin

    
    if (logical_not(isfield(data,binary))):
        ## Reinitialize when 'user_binaries' is present.
        getattr(data,(binary)).bin = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:518
        getattr(data,(binary)).warn_on_absence = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:519
    
    if (isempty(getattr(data,(binary)).bin)):
        if (isunix()):
            ## Unix - Includes Mac OSX and Cygwin.
            binaries=strcat(binary,cellarray(['','.exe']))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:525
        else:
            ## pc - Includes Win32 and mingw.
            binaries=strcat(binary,cellarray(['.exe']))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:528
        n=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:530
        while (n < numel(binaries) and isempty(getattr(data,(binary)).bin)):

            n=n + 1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:532
            getattr(data,(binary)).bin = copy(file_in_path(getenv('PATH'),binaries[n]))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:533

        if (isempty(getattr(data,(binary)).bin) and getattr(data,(binary)).warn_on_absence):
            warning(sprintf('print:no%s',binary),'print.m: \'%s\' not found in PATH',binary)
            getattr(data,(binary)).warn_on_absence = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:538
    
    bin=getattr(data,(binary)).bin
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:542
    return bin
    
if __name__ == '__main__':
    pass
    
    
@function
def gs_papersize(hfig=None,paperorientation=None,*args,**kwargs):
    varargin = gs_papersize.varargin
    nargin = gs_papersize.nargin

    
    if (isempty(papertypes)):
        papertypes=cellarray(['usletter','uslegal','a0','a1','a2','a3','a4','a5','b0','b1','b2','b3','b4','b5','arch-a','arch-b','arch-c','arch-d','arch-e','a','b','c','d','e','tabloid'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:550
        papersizes=dot(cat([8.5,11.0],[8.5,14.0],[33.1,46.8],[23.4,33.1],[16.5,23.4],[11.7,16.5],[8.3,11.7],[5.8,8.3],[39.4,55.7],[27.8,39.4],[19.7,27.8],[13.9,19.7],[9.8,13.9],[6.9,9.8],[9.0,12.0],[12.0,18.0],[18.0,24.0],[24.0,36.0],[36.0,48.0],[8.5,11.0],[11.0,17.0],[18.0,24.0],[24.0,36.0],[36.0,48.0],[11.0,17.0]),72)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:557
    
    papertype=get(hfig,'papertype')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:566
    paperunits=get(hfig,'paperunits')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:567
    paperposition=get(hfig,'paperposition')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:568
    if (strcmp(papertype,'<custom>')):
        papersize=get(hfig,'papersize')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:570
        papersize=convert2points(papersize,paperunits)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:571
    else:
        papersize=papersizes[strcmp(papertypes,papertype),:]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:573
    
    if (strcmp(paperunits,'normalized')):
        paperposition=multiply(paperposition,papersize[cat(1,2,1,2)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:577
    else:
        paperposition=convert2points(paperposition,paperunits)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:579
    
    ## FIXME: This will be obsoleted by listeners for paper properties.
  ##        Papersize is tall when portrait,and wide when landscape.
    if ((papersize[1] > papersize[2] and strcmpi(paperorientation,'portrait')) or (papersize[1] < papersize[2] and strcmpi(paperorientation,'landscape'))):
        papersize=papersize[cat(2,1)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:586
        paperposition=paperposition[cat(2,1,4,3)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:587
    
    if (logical_not(strcmp(papertype,'<custom>')) and (strcmp(paperorientation,'portrait'))):
        ## For portrait use the ghostscript name
        papersize=copy(papertype)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:593
        papersize[papersize == '-']=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:594
        papersize=strrep(papersize,'us','')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:595
        if 'a' == (papersize):
            papersize='letter'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:598
        else:
            if cellarray(['b','tabloid']) == (papersize):
                papersize='11x17'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:600
            else:
                if cellarray(['c','d','e']) == (papersize):
                    papersize=strcat('arch',papersize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:602
        if (strncmp(papersize,'arch',4)):
            papersize[end()]=upper(papersize[end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:605
    
    return papersize,paperposition
    
if __name__ == '__main__':
    pass
    
    
@function
def convert2points(value=None,units=None,*args,**kwargs):
    varargin = convert2points.varargin
    nargin = convert2points.nargin

    if 'inches' == (units):
        value=dot(value,72)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:614
    else:
        if 'centimeters' == (units):
            value=dot[value,72] / 2.54
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:616
        else:
            if 'normalized' == (units):
                error('print:customnormalized','print.m: papersize==\'<custom>\' and paperunits=\'normalized\' may not be combined')
    
    return value
    
if __name__ == '__main__':
    pass
    
    
@function
def gs_device_list(*args,**kwargs):
    varargin = gs_device_list.varargin
    nargin = gs_device_list.nargin

    
    device_list=cellarray([['bmp16'],['bmp16m'],['bmp256'],['bmp32b'],['bmpgray'],['epswrite'],['eps2write'],['jpeg'],['jpegcymk'],['jpeggray'],['pbm'],['pbmraw'],['pcx16'],['pcx24b'],['pcx256'],['pcx2up'],['pcxcmyk'],['pcxgray'],['pcxmono'],['pdfwrite'],['pgm'],['pgmraw'],['pgnm'],['pgnmraw'],['png16'],['png16m'],['png256'],['png48'],['pngalpha'],['pnggray'],['pngmono'],['pnm'],['pnmraw'],['ppm'],['ppmraw'],['pswrite'],['ps2write'],['tiff12nc'],['tiff24nc'],['tiff32nc'],['tiffcrle'],['tiffg3'],['tiffg32d'],['tiffg4'],['tiffgray'],['tifflzw'],['tiffpack'],['tiffsep']])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:625
    return device_list
    
if __name__ == '__main__':
    pass
    
    
@function
def gs_aliases(*args,**kwargs):
    varargin = gs_aliases.varargin
    nargin = gs_aliases.nargin

    
    ##                            "ps", "ps2", "psc", "psc2"
  ##
  ## eps, epsc, eps2, epsc2 are not included here because those are
  ## are generated by the graphics toolkit.
    aliases.bmp = copy('bmp32b')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:643
    aliases.pdf = copy('pdfwrite')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:644
    aliases.png = copy('png16m')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:645
    aliases.ps = copy('ps2write')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:646
    aliases.ps2 = copy('ps2write')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:647
    aliases.psc = copy('ps2write')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:648
    aliases.psc2 = copy('ps2write')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:649
    aliases.tiff = copy('tiff24nc')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:650
    aliases.tiffn = copy('tiff24nc')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__print_parse_opts__.m:651
    return aliases
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2004-2015 Petr Mikulik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{x}, @var{y}, @var{buttons}] =} __gnuplot_ginput__ (@var{f}, @var{n})
## Undocumented internal function.
## @end deftypefn
    
    ## This is ginput.m implementation for gnuplot and X11.
## It requires gnuplot 4.1 and later.
    
    ## This file initially bore the copyright statement
## Petr Mikulik
## History: June 2006; August 2005; June 2004; April 2004
## License: public domain
    
    
@function
def __gnuplot_ginput__(f=None,n=None,*args,**kwargs):
    varargin = __gnuplot_ginput__.varargin
    nargin = __gnuplot_ginput__.nargin

    if (compare_versions(__gnuplot_version__(),'4.0','<=')):
        error('ginput: version %s of gnuplot not supported',gnuplot_version())
    
    ostream=get(f,'__plot_stream__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:38
    if (numel(ostream) < 1):
        error('ginput: stream to gnuplot not open')
    else:
        if (ispc()):
            if (numel(ostream) == 1):
                error('ginput: Need mkfifo that is not implemented under Windows')
            use_mkfifo=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:45
            istream=ostream[2]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:46
            ostream=ostream[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:47
        else:
            use_mkfifo=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:49
            ostream=ostream[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:50
    
    if (nargin == 1):
        x=zeros(100,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:54
        y=zeros(100,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:55
        button=zeros(100,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:56
    else:
        x=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:58
        y=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:59
        button=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:60
    
    if (use_mkfifo):
        gpin_name=tempname()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:64
        err,msg=mkfifo(gpin_name,dot(dot(6,8),8),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:67
        if (err):
            error('ginput: Can not open fifo (%s)',msg)
    
    try:
        k=0
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:76
        while (true):

            k
            ## or Alt-F4. Further, this abrupt close also requires the leading
      ## "\n" on the next line.
            if (use_mkfifo):
                fprintf(ostream,'set print "%s";\n',gpin_name)
                fflush(ostream)
                gpin,err=fopen(gpin_name,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:86
                if (err):
                    error('ginput: Can not open FIFO (%s)',msg)
                fputs(ostream,'pause mouse any;\n\n')
                fputs(ostream,'\nif (exists("MOUSE_KEY") && exists("MOUSE_X")) print MOUSE_X, MOUSE_Y, MOUSE_KEY; else print "0 0 -1"\n')
                fputs(ostream,'set print;\n')
                fflush(ostream)
                x[k],y[k],button[k],count=fscanf(gpin,'%f %f %d','C',nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:98
                fclose(gpin)
            else:
                fputs(ostream,'set print "-";\n')
                fflush(ostream)
                fputs(ostream,'pause mouse any;\n\n')
                fputs(ostream,'\nif (exists("MOUSE_KEY") && exists("MOUSE_X")) key = (MOUSE_KEY==1063 ? 1 : MOUSE_KEY); print "OCTAVE: ", MOUSE_X, MOUSE_Y, key; else print "0 0 -1"\n')
                fputs(ostream,'set print;\n')
                fflush(ostream)
                str=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:110
                while (isempty(str)):

                    str=fread(istream,'*char').T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:112
                    if (isempty(str)):
                        sleep(0.05)
                    else:
                        str=regexp(str,'OCTAVE:\\s+[-+.\\d]+\\s+[-+.\\d]+\\s+\\d*','match')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:116
                    fclear(istream)

                x[k],y[k],button[k],count=sscanf(str[end()](arange(8,end())),'%f %f %d','C',nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:120
            if (cat(x[k],y[k],button[k]) == cat(0,0,- 1)):
                ## Mousing not active (no plot yet).
                break
            if (button[k] == 13 or button[k] == 10):
                ## Stop when hitting a RETURN or ENTER key.
                x[k:end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:131
                y[k:end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:132
                button[k:end()]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_ginput__.m:133
                break
            if (nargin > 1 and k == n):
                ## Input argument n was given, stop when k == n.
                break

    finally:
        if (use_mkfifo):
            unlink(gpin_name)
    
    return x,y,button
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __go_draw_figure__ (@var{h}, @var{plot_stream}, @var{enhanced}, @var{mono})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __go_draw_figure__(h=None,plot_stream=None,enhanced=None,mono=None,*args,**kwargs):
    varargin = __go_draw_figure__.varargin
    nargin = __go_draw_figure__.nargin

    htype=get(h,'type')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:28
    if (strcmp(htype,'figure')):
        ## Get complete list of children.
        kids=allchild(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:31
        nkids=length(kids)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:32
        if (nkids > 0):
            fputs(plot_stream,'\nreset;\n')
            fputs(plot_stream,'set autoscale keepfix;\n')
            fputs(plot_stream,'set origin 0, 0\n')
            fputs(plot_stream,'set size 1, 1\n')
            bg=get(h,'color')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:39
            if (isnumeric(bg)):
                fprintf(plot_stream,'set obj 1 rectangle from screen 0,0 to screen 1,1 behind fc rgb "#%02x%02x%02x" fs solid noborder\n',round(dot(255,bg)))
                bg_is_set=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:42
            else:
                bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:44
            fg_was_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:46
            for i in arange(nkids,1,- 1).reshape(-1):
                type_=get(kids[i],'type')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:49
                if 'axes' == (type_):
                    if (strcmpi(get(kids[i],'tag'),'legend')):
                        ## This is so ugly. If there was a way of getting
              ## gnuplot to give us the text extents of strings
              ## then we could get rid of this mess.
                        lh=getfield(get(kids[i],'userdata'),'handle')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:56
                        if (isscalar(lh)):
                            ## We have a legend with a single parent. It'll be handled
                ## below as a gnuplot key to the axis it corresponds to
                            continue
                        else:
                            ca=lh[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:62
                            ## to "normalized" units.
                            legend_axes_units=get(kids[i],'units')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:65
                            legend_axes_position=get(kids[i],'position')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:66
                            legend_axes_outerposition=get(kids[i],'outerposition')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:67
                            legend_axes_box=get(kids[i],'box')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:68
                            legend_axes_ylim=get(kids[i],'ylim')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:69
                            orig_axes_units=get(ca,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:70
                            hlgnd=get(kids[i])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:71
                            try:
                                set(ca,'units','normalized')
                                set(kids[i],'units','normalized','box','off','ylim',cat(- 2,- 1),'position',get(ca[1],'position'),'outerposition',get(ca[1],'outerposition'))
                                ## displaynames, etc
                                toberm=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:81
                                hobj=get(kids[i],'children')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:82
                                for j in arange(numel(hobj),1,- 1).reshape(-1):
                                    if (logical_not(strcmp(get(hobj[j],'type'),'text'))):
                                        continue
                                    displayname=get(hobj[j],'string')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:87
                                    ll=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:88
                                    lm=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:89
                                    for k in arange(numel(hobj),1,- 1).reshape(-1):
                                        if (logical_not(strcmp(get(hobj[k],'type'),'line'))):
                                            continue
                                        if (get(hobj[j],'userdata') != get(hobj[k],'userdata')):
                                            continue
                                        if (logical_not(strcmp(get(hobj[k],'linestyle'),'none'))):
                                            ll=hobj[k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:99
                                        if (logical_not(strcmp(get(hobj[k],'marker'),'none'))):
                                            lm=hobj[k]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:102
                                    if (logical_not(isempty(ll))):
                                        if (logical_not(isempty(lm))):
                                            toberm=matlabarray(cat(toberm,line('xdata',cat(0,0),'ydata',cat(0,0),'color',get(lm,'color'),'linestyle',get(ll,'linestyle'),'marker',get(lm,'marker'),'markeredgecolor',get(lm,'markeredgecolor'),'markerfacecolor',get(lm,'markerfacecolor'),'markersize',get(lm,'markersize'),'displayname',displayname,'parent',kids[i])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:108
                                        else:
                                            toberm=matlabarray(cat(toberm,line('xdata',cat(0,0),'ydata',cat(0,0),'color',get(ll,'color'),'linestyle',get(ll,'linestyle'),'marker','none','displayname',displayname,'parent',kids[i])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:110
                                    else:
                                        if (logical_not(isempty(lm))):
                                            toberm=matlabarray(cat(toberm,line('xdata',cat(0,0),'ydata',cat(0,0),'color',get(lm,'color'),'linestyle','none','marker',get(lm,'marker'),'markeredgecolor',get(lm,'markeredgecolor'),'markerfacecolor',get(lm,'markerfacecolor'),'markersize',get(lm,'markersize'),'displayname',displayname,'parent',kids[i])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:113
                                if (bg_is_set):
                                    fprintf(plot_stream,'set border linecolor rgb "#%02x%02x%02x"\n',round(dot(255,(1 - bg))))
                                __go_draw_axes__(kids[i],plot_stream,enhanced,mono,bg_is_set,false,hlgnd)
                            finally:
                                ## Return axes "units" and "position" back to
                  ## their original values.
                                set(ca,'units',orig_axes_units)
                                set(kids(i),'units',legend_axes_units,'box',legend_axes_box,'ylim',legend_axes_ylim,'position',legend_axes_position,'outerposition',legend_axes_outerposition)
                                delete(toberm)
                                bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:131
                    else:
                        ## Rely upon listener to convert axes position
              ## to "normalized" units.
                        orig_axes_units=get(kids[i],'units')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:137
                        orig_axes_position=get(kids[i],'position')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:138
                        try:
                            set(kids[i],'units','normalized')
                            fg=get(kids[i],'color')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:141
                            if (isnumeric(fg) and strcmp(get(kids[i],'visible'),'on')):
                                fprintf(plot_stream,'set obj 2 rectangle from graph 0,0 to graph 1,1 behind fc rgb "#%02x%02x%02x" fs solid noborder\n',round(dot(255,fg)))
                                fg_is_set=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:144
                                fg_was_set=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:145
                            else:
                                if (fg_was_set):
                                    fprintf(plot_stream,'unset obj 2\n')
                                    fg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:148
                                    fg_was_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:149
                                else:
                                    fg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:151
                            if (bg_is_set):
                                fprintf(plot_stream,'set border linecolor rgb "#%02x%02x%02x"\n',round(dot(255,(1 - bg))))
                            ## Find if this axes has an associated legend axes and pass it
                ## to __go_draw_axes__
                            hlegend=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:158
                            fkids=get(h,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:159
                            for j in arange(1,numel(fkids)).reshape(-1):
                                if (ishandle(fkids[j]) and strcmp(get(fkids[j],'type'),'axes') and (strcmp(get(fkids[j],'tag'),'legend'))):
                                    udata=get(fkids[j],'userdata')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:164
                                    if (isscalar(udata.handle) and logical_not(isempty(intersect(udata.handle,kids[i])))):
                                        hlegend=get(fkids[j])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:167
                                        break
                            __go_draw_axes__(kids[i],plot_stream,enhanced,mono,bg_is_set,fg_is_set,hlegend)
                        finally:
                            ## Return axes "units" and "position" back to
                ## their original values.
                            set(kids(i),'units',orig_axes_units)
                            set(kids(i),'position',orig_axes_position)
                            bg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:179
                            fg_is_set=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:180
                else:
                    if 'uimenu' == (type_):
                        ## ignore uimenu objects
                        kids[i]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__go_draw_figure__.m:185
                    else:
                        error('__go_draw_figure__: unknown object class, %s',type_)
            if (isempty(kids)):
                fputs(plot_stream,'\nreset; clear;\n')
                fflush(plot_stream)
            else:
                fputs(plot_stream,'\nunset multiplot;\n')
        else:
            fputs(plot_stream,'\nreset; clear;\n')
            fflush(plot_stream)
    else:
        error('__go_draw_figure__: expecting figure object, found \'%s\'',htype)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2006-2015 Daniel Sebald
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{version} =} __gnuplot_version__ ()
## Undocumented internal function.
## @end deftypefn
    
    ## Return the version of gnuplot we are using.  Note that we do not
## attempt to handle the case of the user switching to different
## versions of gnuplot during the same session.
    
    
@function
def __gnuplot_version__(*args,**kwargs):
    varargin = __gnuplot_version__.varargin
    nargin = __gnuplot_version__.nargin

    
    if (isempty(__version__)):
        status,output=system(sprintf('"%s" --version',gnuplot_binary()),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:33
        if (status != 0):
            ## This message ends in a newline so that the traceback messages
      ## are skipped and people might actually see the message, read it,
      ## comprehend it, take the advice it gives, and stop asking us
      ## why plotting fails when gnuplot is not found.
            error('you must have gnuplot installed to display graphics; if you have gnuplot installed in a non-standard location, see the \'gnuplot_binary\' function\n')
        output=strrep(output,'gnuplot','')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:41
        output=strrep(output,'patchlevel','.')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:42
        output=strrep(output,'\n','')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:43
        output=strrep(output,'\r','')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:44
        __version__=strrep(output,' ','')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:45
    
    version=copy(__version__)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_version__.m:48
    return version
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1999-2015 Daniel Heiserer
## Copyright (C) 2001 Laurent Mazet
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __gnuplot_print__ (@var{@dots{}})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Daniel Heiserer <Daniel.heiserer@physik.tu-muenchen.de>
## Adapted-By: jwe
    
    
@function
def __gnuplot_print__(opts=None,*args,**kwargs):
    varargin = __gnuplot_print__.varargin
    nargin = __gnuplot_print__.nargin

    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:30
    if (isempty(opts.fontsize)):
        ## If no fontsize, determine the nominal axes fontsize.
        defaultfontsize=get(0,'defaultaxesfontsize')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:34
        axesfontsize=get(findobj(opts.figure,'type','axes'),'fontsize')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:35
        if (iscell(axesfontsize)):
            axesfontsize=round(median(cell2mat(axesfontsize)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:37
        if (isempty(axesfontsize)):
            opts.fontsize = copy(defaultfontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:40
        else:
            opts.fontsize = copy(axesfontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:42
    
    ## The axes-label and tick-label spacing is determined by
  ## the font spec given in "set terminal ..."
    gp_opts=font_spec(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:47
    pipeline=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:49
    if cellarray(['eps','eps2','epsc','epsc2']) == (lower(opts.devopt)):
        if (any(strcmp(opts.devopt,cellarray(['eps','epsc'])))):
            gp_opts=matlabarray(cat(gp_opts,' level1'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:54
        if (opts.tight_flag or logical_not(isempty(opts.preview))):
            tmp_file=matlabarray(cat(tempname(),'.eps'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:57
            eps_drawnow(opts,tmp_file,gp_opts)
            if (dos_shell):
                cleanup=matlabarray(cat(' & del ',strrep(tmp_file,'/','\\')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:60
            else:
                cleanup=matlabarray(cat(' ; rm ',tmp_file))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:62
            pipeline=cellarray([sprintf('%s %s',opts.epstool_cmd(opts,tmp_file,opts.name),cleanup)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:64
        else:
            eps_drawnow(opts,opts.name,gp_opts)
    else:
        if cellarray(['epslatex','pslatex','pstex','epslatexstandalone']) == (lower(opts.devopt)):
            dot=find(opts.name == '.',1,'last')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:71
            n=find(opts.devopt == 'l',1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:72
            suffix=opts.devopt(arange(1,n - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:73
            if (logical_not(isempty(dot))):
                if (any(strcmpi(opts.name(arange(dot,end())),cellarray([cat('.',suffix),'.tex','.'])))):
                    name=opts.name(arange(1,dot - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:76
                else:
                    error('print:invalid-suffix','invalid suffix \'%s\' for device \'%s\'.',opts.name(arange(dot,end())),lower(opts.devopt))
            if (strfind(opts.devopt,'standalone')):
                term=sprintf('%s ',strrep(opts.devopt,'standalone',' standalone'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:84
            else:
                term=sprintf('%s ',opts.devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:87
            if (__gnuplot_has_feature__('epslatex_implies_eps_filesuffix')):
                suffix='tex'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:90
            else:
                ## Gnuplot 4.0 wants a ".eps" suffix.
                suffix='eps'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:93
            local_drawnow(cat(term,' ',gp_opts),strcat(name,'.',suffix),opts)
        else:
            if 'tikz' == (lower(opts.devopt)):
                if (__gnuplot_has_terminal__('tikz')):
                    local_drawnow(cat('lua tikz ',gp_opts),opts.name,opts)
                else:
                    error(sprintf('print:no%soutput',opts.devopt),'print.m: \'%s\' output is not available for gnuplot-%s',upper(opts.devopt),__gnuplot_version__())
            else:
                if 'svg' == (lower(opts.devopt)):
                    local_drawnow(cat('svg dynamic ',gp_opts),opts.name,opts)
                else:
                    if cellarray(['aifm','corel','eepic','emf','fig']) == (lower(opts.devopt)):
                        local_drawnow(cat(opts.devopt,' ',gp_opts),opts.name,opts)
                    else:
                        if cellarray(['pdfcairo','pngcairo']) == (lower(opts.devopt)):
                            if (__gnuplot_has_terminal__(opts.devopt)):
                                local_drawnow(cat(opts.devopt,' ',gp_opts),opts.name,opts)
                            else:
                                error(sprintf('print:no%soutput',opts.devopt),'print.m: \'%s\' output is not available for gnuplot-%s',upper(opts.devopt),__gnuplot_version__())
                        else:
                            if cellarray(['canvas','dxf','hpgl','mf','gif','pstricks','texdraw']) == (lower(opts.devopt)):
                                local_drawnow(cat(opts.devopt,' ',gp_opts),opts.name,opts)
                            else:
                                if opts.ghostscript.device == (lower(opts.devopt)):
                                    gp_opts=font_spec(opts,'devopt','eps')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:120
                                    opts.ghostscript.output = copy(opts.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:121
                                    opts.ghostscript.source = copy(cat(tempname(),'.eps'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:122
                                    eps_drawnow(opts,opts.ghostscript.source,gp_opts)
                                    cmd_gs,cmd_cleanup=__ghostscript__(opts.ghostscript,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:124
                                    if (opts.send_to_printer or isempty(opts.name)):
                                        cmd_lpr=opts.lpr_cmd(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:126
                                        cmd=matlabarray(cat(cmd_gs,' | ',cmd_lpr))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:127
                                    else:
                                        cmd=copy(cmd_gs)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:129
                                    if (dos_shell):
                                        cmd=sprintf('%s & del %s',cmd,strrep(opts.ghostscript.source,'/','\\'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:132
                                    else:
                                        cmd=sprintf('%s ; rm %s',cmd,opts.ghostscript.source)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:135
                                    if (logical_not(isempty(cmd_cleanup))):
                                        if (dos_shell):
                                            pipeline=cellarray([cat(cmd,' & ',cmd_cleanup)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:139
                                        else:
                                            pipeline=cellarray([cat(cmd,' ; ',cmd_cleanup)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:141
                                    else:
                                        pipeline=cellarray([cmd])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:144
                                else:
                                    error(sprintf('print:no%soutput',opts.devopt),'print.m: %s output is not available for the Gnuplot graphics toolkit',upper(opts.devopt))
    
    opts.pipeline = copy(pipeline)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:153
    for n in arange(1,numel(pipeline)).reshape(-1):
        if (opts.debug):
            fprintf('gnuplot-pipeline: \'%s\'\n',pipeline[n])
        status,output=system(pipeline[n],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:159
        if (status):
            fprintf('%s\n%s\n%s\n','---------- output begin ----------',output,'----------- output end -----------')
            error('gnuplot:failedpipe','print: failed to print')
    
    return opts
    
if __name__ == '__main__':
    pass
    
    
@function
def eps_drawnow(opts=None,epsfile=None,gp_opts=None,*args,**kwargs):
    varargin = eps_drawnow.varargin
    nargin = eps_drawnow.nargin

    h,fontsize=get_figure_text_objs(opts,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:172
    try:
        fontsize_2x=cellfun(times,cellarray([2]),fontsize,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:174
        set(h,cellarray(['fontsize']),fontsize_2x)
        local_drawnow(cat('postscript eps ',gp_opts),epsfile,opts)
    finally:
        set(h,cellarray(['fontsize']),fontsize)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def local_drawnow(term=None,file=None,opts=None,*args,**kwargs):
    varargin = local_drawnow.varargin
    nargin = local_drawnow.nargin

    if (opts.use_color < 0):
        mono=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:184
    else:
        mono=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:186
    
    set(0,'currentfigure',opts.figure)
    if (isempty(opts.debug_file) or logical_not(opts.debug)):
        drawnow(term,file,mono)
    else:
        drawnow(term,file,mono,opts.debug_file)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def font_spec(opts=None,varargin=None,*args,**kwargs):
    varargin = font_spec.varargin
    nargin = font_spec.nargin

    for n in arange(1,numel(varargin),2).reshape(-1):
        setattr(opts,varargin[n],varargin[n + 1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:198
    
    f=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:200
    if 'cgm' == (opts.devopt):
        if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
            f=sprintf('font "%s,%d"',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:204
        else:
            if (logical_not(isempty(opts.font))):
                f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:206
            else:
                if (logical_not(isempty(opts.fontsize))):
                    f=sprintf('%d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:208
    else:
        if cellarray(['eps','eps2','epsc','epsc2']) == (opts.devopt):
            ## Gnuplot renders fonts as half their specification, which
      ## results in a tight spacing for the axes-labels and tick-labels.
      ## Compensate for the half scale. This will produce the proper
      ## spacing for the requested fontsize.
            if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                f=sprintf('font "%s,%d"',opts.font,dot(2,opts.fontsize))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:216
            else:
                if (logical_not(isempty(opts.font))):
                    f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:218
                else:
                    if (logical_not(isempty(opts.fontsize))):
                        f=sprintf('%d',dot(2,opts.fontsize))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:220
        else:
            if 'svg' == (opts.devopt):
                ## FIXME: Why does svg format use round on the fontsize while
      ##        other terminals don't?
                if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                    fontsize=round(dot(opts.fontsize,0.75))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:226
                    f=sprintf('fname "%s" fsize %d',opts.font,fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:227
                else:
                    if (logical_not(isempty(opts.font))):
                        f=sprintf('fname "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:229
                    else:
                        if (logical_not(isempty(opts.fontsize))):
                            fontsize=round(dot[opts.fontsize,0.75])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:231
                            f=sprintf('%s fsize %d',f,fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:232
            else:
                if 'pdf' == (opts.devopt):
                    if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                        f=sprintf('font "%s,%d"',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:236
                    else:
                        if (logical_not(isempty(opts.font))):
                            f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:238
                        else:
                            if (logical_not(isempty(opts.fontsize))):
                                f=sprintf('fsize %d',f,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:240
                else:
                    if cellarray(['pdfcairo','pngcairo']) == (opts.devopt):
                        if (logical_not(isempty(opts.font))):
                            f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:244
                    else:
                        if cellarray(['epslatex','epslatexstandalone']) == (opts.devopt):
                            if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                                f=sprintf('font "%s,%d"',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:248
                            else:
                                if (logical_not(isempty(opts.font))):
                                    f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:250
                                else:
                                    if (logical_not(isempty(opts.fontsize))):
                                        f=sprintf('%d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:252
                        else:
                            if 'pslatex' == (opts.devopt):
                                if (logical_not(isempty(opts.fontsize))):
                                    f=sprintf('%d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:256
                            else:
                                if cellarray(['gif','jpeg','png']) == (opts.devopt):
                                    if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                                        f=sprintf('font "%s ,%d"',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:260
                                    else:
                                        if (logical_not(isempty(opts.font))):
                                            f=sprintf('font "%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:262
                                        else:
                                            if (logical_not(isempty(opts.fontsize))):
                                                f=sprintf('font "%d"',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:264
                                else:
                                    if 'emf' == (opts.devopt):
                                        if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                                            f=sprintf('"%s" %d',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:268
                                        else:
                                            if (logical_not(isempty(opts.font))):
                                                f=sprintf('"%s"',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:270
                                            else:
                                                if (logical_not(isempty(opts.fontsize))):
                                                    f=sprintf('%d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:272
                                    else:
                                        if 'canvas' == (opts.devopt):
                                            if (logical_not(isempty(opts.fontsize))):
                                                f=sprintf('fsize %d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:276
                                        else:
                                            if cellarray(['aifm','corel']) == (opts.devopt):
                                                if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                                                    f=sprintf('%s %d',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:280
                                                else:
                                                    if (logical_not(isempty(opts.font))):
                                                        f=sprintf('%s',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:282
                                                    else:
                                                        if (logical_not(isempty(opts.fontsize))):
                                                            f=sprintf('%d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:284
                                            else:
                                                if 'fig' == (opts.devopt):
                                                    if (logical_not(isempty(opts.font)) and logical_not(isempty(opts.fontsize))):
                                                        f=sprintf('font %s fontsize %d',opts.font,opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:288
                                                    else:
                                                        if (logical_not(isempty(opts.font))):
                                                            f=sprintf('font %s',opts.font)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:290
                                                        else:
                                                            if (logical_not(isempty(opts.fontsize))):
                                                                f=sprintf('fontsize %d',opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:292
    
    return f
    
if __name__ == '__main__':
    pass
    
    
@function
def get_figure_text_objs(opts=None,*args,**kwargs):
    varargin = get_figure_text_objs.varargin
    nargin = get_figure_text_objs.nargin

    h=findall(opts.figure,'-property','fontsize')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:298
    hp=get(h,'parent')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:299
    if (iscell(hp)):
        hp=cell2mat(hp)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:301
    
    ## Do not change the text objects fontsizes for the children of a
  ## legend axes.  These will be handled by the fontsize listener.
    is_legend_key_string=logical_and(logical_and(logical_and(strcmp(get(hp,'tag'),'legend'),isprop(hp,'string')),isprop(hp,'location')),strcmp(get(hp,'type'),'axes'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:305
    h[is_legend_key_string]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:309
    fontsize=get(h,'fontsize')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:310
    if 0 == (numel(fontsize)):
        fontsize=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:313
    else:
        if 1 == (numel(fontsize)):
            fontsize=cellarray([fontsize])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_print__.m:315
    
    return h,fontsize
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __opengl_print__ (@var{@dots{}})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __opengl_print__(opts=None,*args,**kwargs):
    varargin = __opengl_print__.varargin
    nargin = __opengl_print__.nargin

    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:26
    set(0,'currentfigure',opts.figure)
    drawnow('expose')
    if (logical_not(isempty(opts.fig2dev_binary))):
        ## fig2dev is prefered for conversion to emf
        fig2dev_devices=cellarray(['pstex','mf','emf'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:33
    else:
        fig2dev_devices=cellarray(['pstex','mf'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:35
    
    gl2ps_device=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:38
    pipeline=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:39
    if cellarray(['eps','eps2','epsc','epsc2']) == (lower(opts.devopt)):
        ## format GL2PS_EPS
        gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:43
        pipeline=cellarray([opts.epstool_cmd(opts,'-',opts.name)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:45
    else:
        if cellarray(['epslatex','pslatex','pdflatex','epslatexstandalone','pslatexstandalone','pdflatexstandalone']) == (lower(opts.devopt)):
            ## format GL2PS_TEX
            n=find(opts.devopt == 'l',1)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:49
            suffix=opts.devopt(arange(1,n - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:50
            dot=find(opts.name == '.',1,'last')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:51
            if ((logical_not(isempty(dot))) and any(strcmpi(opts.name(arange(dot,end())),cellarray([strcat('.',suffix),'.tex','.'])))):
                name=opts.name(arange(1,dot - 1))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:55
                if (dot < numel(opts.name) and any(strcmpi(opts.name(arange(dot + 1,end())),cellarray(['eps','ps','pdf'])))):
                    ## If user provides eps/ps/pdf suffix, use it.
                    suffix=opts.name(arange(dot + 1,end()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:59
            else:
                error('print:invalid-suffix','invalid suffix \'%s\' for device \'%s\'.',opts.name(arange(dot,end())),lower(opts.devopt))
            gl2ps_device=cellarray([sprintf('%snotxt',lower(suffix))])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:66
            gl2ps_device[2]='tex'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:67
            if (dos_shell):
                ## FIXME: this will only work on MinGW with the MSYS shell
                pipeline=cellarray([sprintf('cat > %s-inc.%s',name,suffix)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:70
                pipeline[2]=sprintf('cat > %s.tex',name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:71
            else:
                pipeline=cellarray([sprintf('cat > %s-inc.%s',name,suffix)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:73
                pipeline[2]=sprintf('cat > %s.tex',name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:74
        else:
            if 'tikz' == (lower(opts.devopt)):
                ## format GL2PS_PGF
                gl2ps_device=cellarray(['pgf'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:78
                pipeline=cellarray([sprintf('cat > %s',opts.name)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:79
            else:
                if 'svg' == (lower(opts.devopt)):
                    ## format GL2PS_SVG
                    gl2ps_device=cellarray(['svg'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:82
                    pipeline=cellarray([sprintf('cat > %s',opts.name)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:83
                else:
                    if fig2dev_devices == (lower(opts.devopt)):
                        cmd_pstoedit=opts.pstoedit_cmd(opts,'fig')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:85
                        cmd_fig2dev=opts.fig2dev_cmd(opts,opts.devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:86
                        if (strcmp(opts.devopt,'pstex')):
                            __,__,ext=fileparts(opts.name,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:88
                            if (any(strcmpi(ext,cellarray(['.ps','.tex','.'])))):
                                opts.name = copy(opts.name(arange(1,end() - numel(ext))))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:90
                            opts.name = copy(strcat(opts.name,'.ps'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:92
                            cmd=sprintf('%s | %s > %s',cmd_pstoedit,cmd_fig2dev,opts.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:93
                            gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:94
                            pipeline=cellarray([cmd])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:95
                            cmd_fig2dev=opts.fig2dev_cmd(opts,'pstex_t')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:96
                            gl2ps_device[2]='eps'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:97
                            pipeline[2]=sprintf('%s | %s > %s',cmd_pstoedit,cmd_fig2dev,strrep(opts.name,'.ps','.tex'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:98
                        else:
                            cmd=sprintf('%s | %s > %s',cmd_pstoedit,cmd_fig2dev,opts.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:101
                            gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:102
                            pipeline=cellarray([cmd])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:103
                    else:
                        if 'aifm' == (lower(opts.devopt)):
                            cmd=opts.pstoedit_cmd(opts,'ps2ai')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:106
                            gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:107
                            pipeline=cellarray([sprintf('%s > %s',cmd,opts.name)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:108
                        else:
                            if cellarray(['dxf','emf','fig','hpgl']) == (lower(opts.devopt)):
                                cmd=opts.pstoedit_cmd(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:110
                                gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:111
                                pipeline=cellarray([sprintf('%s > %s',cmd,opts.name)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:112
                            else:
                                if cellarray(['corel','gif']) == (lower(opts.devopt)):
                                    error('print:unsupporteddevice','print.m: %s output is not available for the FLTK graphics toolkit',upper(opts.devopt))
                                else:
                                    if opts.ghostscript.device == (lower(opts.devopt)):
                                        opts.ghostscript.source = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:118
                                        opts.ghostscript.output = copy(opts.name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:119
                                        if (opts.send_to_printer):
                                            opts.unlink[strcmp(opts.unlink,opts.ghostscript.output)]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:121
                                            opts.ghostscript.output = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:122
                                        cmd_gs,cmd_cleanup=__ghostscript__(opts.ghostscript,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:124
                                        if (opts.send_to_printer or isempty(opts.name)):
                                            cmd_lpr=opts.lpr_cmd(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:126
                                            cmd=sprintf('%s | %s',cmd_gs,cmd_lpr)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:127
                                        else:
                                            cmd=sprintf('%s',cmd_gs)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:129
                                        if (logical_not(isempty(cmd_cleanup))):
                                            gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:132
                                            if (dos_shell):
                                                pipeline=cellarray([sprintf('%s & %s',cmd,cmd_cleanup)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:134
                                            else:
                                                pipeline=cellarray([sprintf('%s ; %s',cmd,cmd_cleanup)])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:136
                                        else:
                                            gl2ps_device=cellarray(['eps'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:139
                                            pipeline=cellarray([cmd])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:140
                                    else:
                                        error(sprintf('print:no%soutput',opts.devopt),'print.m: %s output is not available for GL2PS output',upper(opts.devopt))
    
    opts.pipeline = copy(pipeline)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:148
    
    haxes=findall(opts.figure,'type','axes')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:151
    vw=get(haxes,'view')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:152
    if (iscell(vw)):
        vw=vertcat(vw[:])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:154
    
    is2D=all(abs(vw[:,2]) == 90)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:156
    if (is2D):
        gl2ps_device[end()]=cat(gl2ps_device[end()],'is2D')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__opengl_print__.m:158
    
    for n in arange(1,numel(pipeline)).reshape(-1):
        if (opts.debug):
            fprintf('opengl-pipeline: \'%s\'\n',pipeline[n])
        if (strcmp(get(opts.figure,'visible'),'on')):
            ## Use toolkits "print_figure" method
            drawnow(gl2ps_device[n],cat('|',pipeline[n]))
        else:
            ## Use OpenGL offscreen rendering with OSMesa
            __osmesa_print__(opts.figure,cat('|',pipeline[n]),gl2ps_device[n])
    
    if (logical_not(isempty(strfind(opts.devopt,'standalone')))):
        opts.latex_standalone(opts)
    
    return opts
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{has_feature} =} __gnuplot_has_feature__ (@var{feature})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2009-01-27
    
    
@function
def __gnuplot_has_feature__(feature=None,*args,**kwargs):
    varargin = __gnuplot_has_feature__.varargin
    nargin = __gnuplot_has_feature__.nargin

    
    
    if (isempty(has_features)):
        try:
            gnuplot_version=__gnuplot_version__()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:44
        finally:
            pass
        versions=cellarray(['4.2.5','4.4','4.4','4.4','4.2','4.2','4.4','4.4','4.4','4.4','4.3','5.0'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:49
        operators=cellarray(['>=','>=','>=','>=','>=','>=','>=','>=','>=','>=','>=','>='])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:50
        have_features=false(size(features))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:51
        for n in arange(1,numel(have_features)).reshape(-1):
            has_features[n]=compare_versions(gnuplot_version,versions[n],operators[n])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:53
    
    n=find(strcmpi(feature,features))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:57
    if (isempty(n)):
        res=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:59
    else:
        res=has_features[n]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_has_feature__.m:61
    
    return res
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{bbox} =} __tight_eps_bbox__ (@var{@dots{}})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-26
    
    
@function
def __tight_eps_bbox__(opts=None,eps_file_name=None,*args,**kwargs):
    varargin = __tight_eps_bbox__.varargin
    nargin = __tight_eps_bbox__.nargin

    box_string='%%BoundingBox:'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:29
    cmd=sprintf('"%s" "%s" 2>&1','head',eps_file_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:31
    status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:32
    if (status == 0):
        orig_bbox_line=get_bbox(output)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:35
    else:
        error('print:noboundingbox','print.m: no bounding box found in \'%s\'',eps_file_name)
    
    ghostscript_options='-q -dBATCH -dSAFER -dNOPAUSE -dTextAlphaBits=4 -sDEVICE=bbox'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:41
    cmd=sprintf('"%s" %s "%s" 2>&1',opts.ghostscript.binary,ghostscript_options,eps_file_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:42
    status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:44
    if (status == 0):
        tight_bbox_line=get_bbox(output)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:47
    else:
        warning('print:nogsboundingbox','print.m: ghostscript failed to determine the bounding for \'%s\'',eps_file_name)
    
    ## Attempt to fix the bbox in place.
    fid=fopen(eps_file_name,'r+')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:55
    try:
        bbox_replaced=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:57
        looking_for_bbox=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:58
        while (looking_for_bbox):

            current_line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:60
            if (strncmpi(current_line,box_string,length(box_string))):
                line_length=numel(current_line)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:62
                num_spaces=line_length - numel(tight_bbox_line)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:63
                if (numel(current_line) >= numel(tight_bbox_line)):
                    new_line=copy(tight_bbox_line)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:65
                    new_line[end() + 1:numel(current_line)]=' '
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:66
                    bbox_replaced=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:67
                    if (ispc()):
                        fseek(fid,- line_length - 2,'cof')
                    else:
                        fseek(fid,- line_length - 1,'cof')
                    count=fprintf(fid,'%s',new_line)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:74
                looking_for_bbox=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:76
            else:
                if (logical_not(ischar(current_line))):
                    looking_for_bbox=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:78

    finally:
        fclose(fid)
    
    ## If necessary load the eps-file and replace the bbox (can be slow).
    if (logical_not(bbox_replaced)):
        fid=fopen(eps_file_name,'r')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:87
        try:
            data=char(fread(fid,Inf)).T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:89
        finally:
            fclose(fid)
        n=strfind(data,box_string)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:93
        if (numel(n) > 1):
            ## Only replace one instance.
            n=n[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:96
        else:
            if (isempty(n)):
                error('print:noboundingbox','print.m: no bounding box found in \'%s\'.',eps_file_name)
        m=numel(orig_bbox_line)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:101
        data=horzcat(data[1:(n - 1)],tight_bbox_line,data[(n + m):end()])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:102
        fid=fopen(eps_file_name,'w')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:103
        try:
            fprintf(fid,'%s',data)
        finally:
            fclose(fid)
    
    return bb
    
if __name__ == '__main__':
    pass
    
    
@function
def get_bbox(lines=None,*args,**kwargs):
    varargin = get_bbox.varargin
    nargin = get_bbox.nargin

    box_string='%%BoundingBox:'
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:114
    pattern=strcat(box_string,'[^%]*')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:115
    pattern=pattern[1:find(double(pattern) > 32,1,'last')]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:116
    bbox_line=regexp(lines,pattern,'match')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:117
    if (iscell(bbox_line)):
        bbox_line=bbox_line[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:119
    
    ## Remove the EOL characters.
    bbox_line[double(bbox_line) < 32]=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__tight_eps_bbox__.m:122
    return bbox_line
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{value} =} __gnuplot_get_var__ (@var{h}, @var{name}, @var{fmt})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2009-02-07
    
    
@function
def __gnuplot_get_var__(h=None,gp_var_name=None,fmt='',*args,**kwargs):
    varargin = __gnuplot_get_var__.varargin
    nargin = __gnuplot_get_var__.nargin

    if (numel(h) == 1 and isfigure(h)):
        if (isempty(get(h,'__plot_stream__'))):
            ostream=__gnuplot_open_stream__(2,h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:31
        else:
            ostream=get(h,'__plot_stream__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:33
    else:
        ostream=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:36
    
    if (numel(ostream) < 1):
        error('__gnuplot_get_var__: stream to gnuplot not open')
    else:
        if (ispc()):
            if (numel(ostream) == 1):
                error('__gnuplot_get_var__: Need mkfifo that is not implemented under Windows')
            use_mkfifo=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:44
            istream=ostream[2]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:45
            ostream=ostream[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:46
        else:
            use_mkfifo=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:48
            ostream=ostream[1]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:49
    
    if (use_mkfifo):
        gpin_name=tempname()
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:53
        err,msg=mkfifo(gpin_name,dot(dot(6,8),8),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:56
        if (err):
            error('__gnuplot_get_var__: Can not make FIFO (%s)',msg)
    
    gp_var_name=strtrim(gp_var_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:63
    n=min(strfind(gp_var_name,' '),strfind(gp_var_name,',')) - 1
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:64
    if (isempty(n)):
        n=numel(gp_var_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:66
    
    try:
        ## Notes: Variables may be undefined if user closes gnuplot by "q"
    ## or Alt-F4.  Further, this abrupt close also requires the leading
    ## "\n" on the next line.
        if (use_mkfifo):
            fprintf(ostream,'\nset print "%s";\n',gpin_name)
            fflush(ostream)
            gpin,err=fopen(gpin_name,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:77
            if (err):
                ## Try a second time, and then give an error.
                gpin,err=fopen(gpin_name,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:80
            if (err):
                error('__gnuplot_get_var__: can not open FIFO')
            gp_cmd=sprintf('\nif (exists("%s")) print %s; else print NaN\n',gp_var_name[1:n],gp_var_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:85
            fputs(ostream,gp_cmd)
            fputs(ostream,'set print;\n')
            fflush(ostream)
            reading=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:94
            str=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:95
            while (reading):

                str[end() + 1]=fgets(gpin)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:97
                if (isnumeric(str[end()]) and (str[end()] == - 1)):
                    reading=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:99
                    str=str[1:(end() - 1)]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:100

            str=strcat(str[:])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:103
            fclose(gpin)
        else:
            ## Direct gnuplot to print to <STDOUT>
            fprintf(ostream,'set print "-";\n')
            fflush(ostream)
            gp_cmd=sprintf('\nif (exists("%s")) print "OCTAVE: ", %s; else print NaN\n',gp_var_name[1:n],gp_var_name)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:109
            fputs(ostream,gp_cmd)
            fflush(ostream)
            fputs(ostream,'set print;\n')
            fflush(ostream)
            str=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:117
            while (isempty(str)):

                str=fread(istream,'*char').T
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:119
                if (isempty(str)):
                    sleep(0.05)
                else:
                    str=regexp(str,'OCTAVE:.*','match')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:123
                    str=str[end()](arange(8,end()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:124
                fclear(istream)

        ## Strip out EOLs and the continuation character "|"
        str[str == logical_or('\n',str) == '\r']=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:131
        n_continue=strfind(str,' \\ ')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:132
        if (logical_not(isempty(n_continue))):
            str[n_continue + 1]=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:134
        if (isempty(fmt)):
            gp_var_value=strtrim(str)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:138
        else:
            gp_var_value=sscanf(str,fmt)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_get_var__.m:140
    finally:
        if (use_mkfifo):
            unlink(gpin_name)
    
    return gp_var_value
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{stream} =} __gnuplot_open_stream__ (@var{npipes}, @var{h})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2009-04-11
    
    
@function
def __gnuplot_open_stream__(npipes=None,h=None,*args,**kwargs):
    varargin = __gnuplot_open_stream__.varargin
    nargin = __gnuplot_open_stream__.nargin

    prog,args=gnuplot_binary(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_open_stream__.m:28
    if (npipes > 1):
        plot_stream(1),plot_stream[2],pid=popen2(prog,args[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_open_stream__.m:30
        if (pid < 0):
            error('__gnuplot_open_stream__: failed to open connection to gnuplot')
        else:
            plot_stream[3]=pid
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_open_stream__.m:34
    else:
        plot_stream=popen(sprintf('%s ',prog,args[:]),'w')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__gnuplot_open_stream__.m:37
        if (plot_stream < 0):
            error('__gnuplot_open_stream__: failed to open connection to gnuplot')
    
    if (nargin > 1):
        set(h,'__plot_stream__',plot_stream)
    
    return plot_stream
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __ghostscript__ (@var{@dots{}})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-07-26
    
    
@function
def __ghostscript__(varargin=None,*args,**kwargs):
    varargin = __ghostscript__.varargin
    nargin = __ghostscript__.nargin

    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:29
    opts.binary = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:31
    opts.source = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:32
    opts.output = copy('-')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:33
    opts.device = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:34
    opts.epscrop = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:35
    opts.antialiasing = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:36
    opts.antialiasing_textalphabits = copy(4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:37
    
    opts.antialiasing_graphicsalphabits = copy(4)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:38
    opts.resolution = copy(150)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:39
    opts.papersize = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:40
    opts.pageoffset = copy(cat(0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:41
    opts.debug = copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:42
    opts.level = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:43
    opts.prepend = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:44
    offsetfile=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:46
    offset_ps=cellarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:47
    cleanup_cmd=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:48
    args=copy(varargin)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:50
    n=find(cellfun('isclass',args,'struct'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:51
    if (logical_not(isempty(n))):
        f=fieldnames(args[n])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:53
        for m in arange(1,numel(f)).reshape(-1):
            setattr(opts,f[m],getattr(args[n],(f[m])))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:55
        args[n]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:57
    
    for n in arange(1,numel(args),2).reshape(-1):
        setattr(opts,args[n],args[n + 1])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:60
    
    if (isempty(opts.papersize)):
        format_for_printer=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:64
    else:
        format_for_printer=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:66
    
    gs_opts=matlabarray(cat('-dQUIET -dNOPAUSE -dBATCH -dSAFER -dAutoRotatePages=/None -sDEVICE=',opts.device))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:69
    if (logical_not(isempty(opts.level)) and ismember(opts.level,cat(1,2,3))):
        gs_opts=sprintf('%s -dLanguageLevel=%d',gs_opts,opts.level)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:72
    
    if (opts.antialiasing and isempty(strfind(opts.device,'write'))):
        ## Apply anti-aliasing to all bitmap formats/devices
        gs_opts=sprintf('%s -dTextAlphaBits=%d -dGraphicsAlphaBits=%d',gs_opts,fix(opts.antialiasing_textalphabits),fix(opts.antialiasing_graphicsalphabits))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:77
        gs_opts=sprintf('%s -r%dx%d',gs_opts,fix(dot(cat(1,1),opts.resolution)))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:80
    else:
        if (any(strcmp(opts.device,cellarray(['pswrite','ps2write','pdfwrite'])))):
            gs_opts=sprintf('%s -dEmbedAllFonts=true',gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:82
            if (strcmp(opts.device,'pdfwrite')):
                ## Optimize for loading
                gs_opts=sprintf('%s -dOptimize=true',gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:85
    
    if (opts.epscrop):
        ## papersize is specified by the eps bbox
        gs_opts=sprintf('%s -dEPSCrop',gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:91
    
    if (format_for_printer):
        if (ischar(opts.papersize)):
            gs_opts=sprintf('%s -sPAPERSIZE=%s',gs_opts,opts.papersize)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:95
        else:
            if (isnumeric(opts.papersize) and numel(opts.papersize) == 2):
                gs_opts=sprintf('%s -dDEVICEWIDTHPOINTS=%d -dDEVICEHEIGHTPOINTS=%d',gs_opts,fix(opts.papersize))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:97
                if (opts.papersize(1) > opts.papersize(2)):
                    ## Lanscape mode: This option will result in automatic rotation of the
        ##                document page if the requested page size matches one
        ##                of the default page sizes
                    gs_opts=sprintf('%s -dNORANGEPAGESIZE',gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:103
            else:
                error('print:badpapersize','__ghostscript__.m: invalid \'papersize\'')
        gs_opts=sprintf('%s -dFIXEDMEDIA',gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:108
        str=sprintf('%s [%d %d] %s','<< /Margins [0 0] /.HWMargins [0 0 0 0] /PageOffset',fix(opts.pageoffset),'>> setpagedevice')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:110
        offset_ps=cellarray(['%!PS-Adobe-3.0',str,'%%EOF'])
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:112
        if (isfield(opts,'offsetfile')):
            offsetfile=opts.offsetfile
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:114
            cleanup_cmd=''
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:115
        else:
            offsetfile=matlabarray(cat(tempname(),'.ps'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:117
            if (dos_shell):
                cleanup_cmd=matlabarray(cat('del ',strrep(offsetfile,'/','\\')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:119
            else:
                cleanup_cmd=matlabarray(cat('rm ',offsetfile))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:121
        try:
            fid=fopen(offsetfile,'w')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:125
            if (fid == - 1):
                error('print:fopenfailed','__ghostscript__.m: fopen () failed')
            fprintf(fid,'%s\n',offset_ps[:])
        finally:
            status=fclose(fid)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:131
            if (status == - 1):
                error('print:fclosefailed','__ghostscript__.m: fclose () failed')
        if (opts.debug):
            fprintf('---- begin %s ----\n',offsetfile)
            fprintf('%s\n',offset_ps[:])
            fprintf('----- end %s -----\n',offsetfile)
    
    if (isempty(opts.binary)):
        error('print:no_ghostscript','__ghostscript__.m: ghostscript is required.')
    else:
        if (isempty(opts.output)):
            cmd=sprintf('%s %s',opts.binary,gs_opts)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:146
        else:
            cmd=sprintf('%s %s -sOutputFile="%s"',opts.binary,gs_opts,opts.output)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:148
    
    if (logical_not(isempty(opts.prepend)) and any(strcmpi(opts.device,cellarray(['pswrite','ps2write','pdfwrite'])))):
        ## FIXME: Fonts get may be mangled when appending ps/ps2.
    ##        See "How to concatenate several PS files" at the link,
    ##        http://en.wikibooks.org/wiki/PostScript_FAQ
        cmd=sprintf('%s %s',cmd,opts.prepend)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:155
        if (isempty(cleanup_cmd)):
            if (dos_shell):
                cleanup_cmd=matlabarray(cat('del ',strrep(opts.prepend,'/','\\')))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:158
            else:
                cleanup_cmd=matlabarray(cat('rm ',opts.prepend))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:160
        else:
            if (dos_shell):
                cleanup_cmd=sprintf('%s & del %s',cleanup_cmd,strrep(opts.prepend,'/','\\'))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:164
            else:
                cleanup_cmd=sprintf('%s ; rm %s',cleanup_cmd,opts.prepend)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:167
    
    if (logical_not(isempty(offsetfile)) and format_for_printer):
        cmd=sprintf('%s %s',cmd,offsetfile)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:172
    
    if (logical_not(isempty(opts.source))):
        cmd=sprintf('%s %s',cmd,opts.source)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:175
    
    if (opts.debug):
        fprintf('Ghostscript command: \'%s\'\n',cmd)
    
    gs_cmd=copy(cmd)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__ghostscript__.m:182
    return gs_cmd,cleanup_cmd
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __add_default_menu__ (@var{fig})
## Add default menu to figure.
##
## All uimenu handles have their @qcode{"HandleVisibility"} property set to
## @qcode{"off"}.
## @end deftypefn
    
    ## Author: Kai Habel
    
    
@function
def __add_default_menu__(fig=None,*args,**kwargs):
    varargin = __add_default_menu__.varargin
    nargin = __add_default_menu__.nargin

    ## Only FLTK toolkit currently provides menubar
    if (logical_not(strcmp(get(fig,'__graphics_toolkit__'),'fltk'))):
        return
    
    obj=findall(fig,'-depth',1,'tag','__default_menu__','label','&File')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:36
    if (isempty(obj)):
        __f=uimenu(fig,'label','&File','handlevisibility','off','tag','__default_menu__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:38
        uimenu(__f,'label','&Save','callback',save_cb)
        uimenu(__f,'label','Save &As','callback',save_cb)
        uimenu(__f,'label','&Close','callback','close (gcf)')
        __e=uimenu(fig,'label','&Edit','handlevisibility','off','tag','__default_menu__')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:44
        uimenu(__e,'label','Toggle &grid on all axes','tag','toggle','callback',grid_cb)
        uimenu(__e,'label','Show grid on all axes','tag','on','callback',grid_cb)
        uimenu(__e,'label','Hide grid on all axes','tag','off','callback',grid_cb)
        uimenu(__e,'label','Auto&scale all axes','callback',autoscale_cb)
        gm=uimenu(__e,'label','GUI &Mode (on all axes)')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:50
        uimenu(gm,'label','Pan x and y','tag','pan_on','callback',guimode_cb)
        uimenu(gm,'label','Pan x only','tag','pan_xon','callback',guimode_cb)
        uimenu(gm,'label','Pan y only','tag','pan_yon','callback',guimode_cb)
        uimenu(gm,'label','Disable pan and rotate','tag','no_pan_rotate','callback',guimode_cb)
        uimenu(gm,'label','Rotate on','tag','rotate3d','callback',guimode_cb)
        uimenu(gm,'label','Enable mousezoom','tag','zoom_on','callback',guimode_cb)
        uimenu(gm,'label','Disable mousezoom','tag','zoom_off','callback',guimode_cb)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def save_cb(h=None,e=None,*args,**kwargs):
    varargin = save_cb.varargin
    nargin = save_cb.nargin

    hcbo,hfig=gcbo(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:64
    lbl=get(hcbo,'label')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:65
    if (strcmp(lbl,'&Save')):
        fname=get(hfig,'filename')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:67
        if (isempty(fname)):
            __save_as__(hcbo)
        else:
            saveas(hcbo,fname)
    else:
        if (strcmp(lbl,'Save &As')):
            __save_as__(hcbo)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __save_as__(caller=None,*args,**kwargs):
    varargin = __save_as__.varargin
    nargin = __save_as__.nargin

    filename,filedir=uiputfile(cellarray(['*.pdf;*.ps;*.gif;*.png;*.jpg','Supported Graphic Formats']),'Save Figure',cat(pwd,filesep,'untitled.pdf'),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:79
    if (filename != 0):
        fname=matlabarray(cat(filedir,filesep(),filename))
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:84
        set(gcbf,'filename',fname)
        saveas(caller,fname)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def __get_axes__(h=None,*args,**kwargs):
    varargin = __get_axes__.varargin
    nargin = __get_axes__.nargin

    ## Get parent figure
    fig=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:93
    
    hax=findobj(fig,'type','axes','-not','tag','legend')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:96
    return hax,fig
    
if __name__ == '__main__':
    pass
    
    
@function
def grid_cb(h=None,e=None,*args,**kwargs):
    varargin = grid_cb.varargin
    nargin = grid_cb.nargin

    hax=__get_axes__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:100
    id=get(h,'tag')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:101
    if 'toggle' == (id):
        arrayfun(grid,hax)
    else:
        arrayfun(lambda h=None: grid(h,id),hax)
    
    drawnow()
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def autoscale_cb(h=None,e=None,*args,**kwargs):
    varargin = autoscale_cb.varargin
    nargin = autoscale_cb.nargin

    hax=__get_axes__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:112
    arrayfun(lambda h=None: axis(h,'auto'),hax)
    drawnow()
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def guimode_cb(h=None,e=None,*args,**kwargs):
    varargin = guimode_cb.varargin
    nargin = guimode_cb.nargin

    hax,fig=__get_axes__(h,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:118
    id=get(h,'tag')
# /home/lei/octave-4.0.2/scripts/plot/util/private/__add_default_menu__.m:119
    if 'pan_on' == (id):
        pan(fig,'on')
    else:
        if 'pan_xon' == (id):
            pan(fig,'xon')
        else:
            if 'pan_yon' == (id):
                pan(fig,'yon')
            else:
                if 'rotate3d' == (id):
                    rotate3d(fig,'on')
                else:
                    if 'no_pan_rotate' == (id):
                        pan(fig,'off')
                        rotate3d(fig,'off')
                    else:
                        if 'zoom_on' == (id):
                            arrayfun(lambda h=None: set(h,'mousewheelzoom',0.05),hax)
                        else:
                            if 'zoom_off' == (id):
                                arrayfun(lambda h=None: set(h,'mousewheelzoom',0.0),hax)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} newplot ()
## @deftypefnx {Function File} {} newplot (@var{hfig})
## @deftypefnx {Function File} {} newplot (@var{hax})
## @deftypefnx {Function File} {@var{hax} =} newplot (@dots{})
## Prepare graphics engine to produce a new plot.
##
## This function is called at the beginning of all high-level plotting
## functions.  It is not normally required in user programs.  @code{newplot}
## queries the @qcode{"NextPlot"} field of the current figure and axis to
## determine what to do.
##
## @multitable @columnfractions .25 .75
## @headitem Figure NextPlot @tab Action
## @item @qcode{"new"} @tab Create a new figure and make it the current figure.
##
## @item @qcode{"add"} (default) @tab Add new graphic objects to the current
## figure.
##
## @item @qcode{"replacechildren"} @tab Delete child objects whose
## HandleVisibility is set to @qcode{"on"}.  Set NextPlot property to
## @qcode{"add"}.  This typically clears a figure, but leaves in place hidden
## objects such as menubars.  This is equivalent to @code{clf}.
##
## @item @qcode{"replace"} @tab Delete all child objects of the figure and
## reset all figure properties to their defaults.  However, the following
## four properties are not reset: Position, Units, PaperPosition, PaperUnits.
## This is equivalent to @code{clf reset}.
## @end multitable
##
## @multitable @columnfractions .25 .75
## @headitem Axis NextPlot @tab Action
## @item @qcode{"add"} @tab Add new graphic objects to the current axes.  This
## is equivalent to @code{hold on}.
##
## @item @qcode{"replacechildren"} @tab Delete child objects whose
## HandleVisibility is set to @qcode{"on"}, but leave axis properties
## unmodified.  This typically clears a plot, but preserves special settings
## such as log scaling for axes.  This is equivalent to @code{cla}.
##
## @item @qcode{"replace"} (default) @tab Delete all child objects of the
## axis and reset all axis properties to their defaults.  However, the
## following properties are not reset: Position, Units.  This is equivalent
## to @code{cla reset}.
## @end multitable
##
## If the optional input @var{hfig} or @var{hax} is given then prepare the
## specified figure or axes rather than the current figure and axes.
##
## The optional return value @var{hax} is a graphics handle to the created
## axes object (not figure).
##
## @strong{Caution:} Calling @code{newplot} may change the current figure and
## current axis.
## @end deftypefn
    
    ## FIXME: The Matlab function takes an optional list of file handles, hsave,
##        which are not deleted when the figure and axes are prepared.
##        I'm sure there is a good reason for that, but coding such
##        compatibility is really tricky and doesn't serve much purpose since
##        newplot is nearly exclusively used by Octave's internal plotting
##        functions.  In Octave's case the argument is almost always null,
##        or occasionally the axis handle to plot into.
    
    
@function
def newplot(hsave=[],*args,**kwargs):
    varargin = newplot.varargin
    nargin = newplot.nargin

    if (nargin > 1):
        print_usage()
    
    cf=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:89
    ca=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:90
    if (logical_not(isempty(hsave))):
        ## Find the first valid axes
        ca=ancestor(hsave,'axes','toplevel')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:94
        if (iscell(ca)):
            ca=matlabarray(cat(ca[:]))
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:96
        ca=ca[find(ca,1)]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:98
        hsave[hsave == ca]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:99
        if (logical_not(isempty(ca))):
            cf=ancestor(ca,'figure','toplevel')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:102
        else:
            cf=ancestor(hsave,'figure','toplevel')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:104
            if (iscell(cf)):
                cf=matlabarray(cat(cf[:]))
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:106
            cf=cf[find(cf,1)]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:108
    
    if (isempty(cf)):
        ## get current figure, or create a new one if necessary
        cf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:114
    else:
        ## switch to figure provided without causing other updates
        set(0,'currentfigure',cf)
    
    fnp=get(cf,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:120
    if 'add' == (fnp):
        ## Default case.  Doesn't require action.
        pass
    else:
        if 'new' == (fnp):
            ## Ordinarily, create a new figure to hold plot.
      ## But, if user has requested preparing a specific axis, then
      ## use the existing figure to hold the requested axis.
            if (isempty(ca)):
                cf=figure()
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:129
        else:
            if 'replacechildren' == (fnp):
                kids=get(cf,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:132
                if (logical_not(isempty(ca))):
                    kids[kids == ca]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:134
                delete(kids)
            else:
                if 'replace' == (fnp):
                    kids=allchild(cf)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:138
                    if (logical_not(isempty(ca))):
                        kids[kids == ca]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:140
                    delete(kids)
                    reset(cf)
    
    set(cf,'nextplot','add')
    
    if (isempty(ca)):
        ca=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:148
        deleteall=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:149
    else:
        set(cf,'currentaxes',ca)
        deleteall=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:152
    
    ## FIXME: Is this necessary anymore?
  ##        It seems like a kluge that belongs somewhere else.
    if (strcmp(get(ca,'__hold_all__'),'off')):
        __next_line_color__(true)
        __next_line_style__(true)
    else:
        __next_line_color__(false)
        __next_line_style__(false)
    
    anp=get(ca,'nextplot')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:165
    if 'add' == (anp):
        ## Default case.  Doesn't require action.
        pass
    else:
        if 'replacechildren' == (anp):
            if (logical_not(deleteall) and ca != hsave):
                ## preserve hsave and its parents, uncles, ...
                kids=allchild(ca)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:172
                hkid=copy(hsave)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:173
                while (logical_not(any(hkid == kids))):

                    hkid=get(hkid,'parent')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:175

                kids[kids == hkid]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:177
                delete(kids)
            else:
                delete(get(ca,'children'))
        else:
            if 'replace' == (anp):
                if (logical_not(deleteall) and ca != hsave):
                    ## preserve hsave and its parents, uncles, ...
                    kids=allchild(ca)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:185
                    hkid=copy(hsave)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:186
                    while (logical_not(any(hkid == kids))):

                        hkid=get(hkid,'parent')
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:188

                    kids[kids == hkid]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:190
                    delete(kids)
                else:
                    if (isprop(ca,'__plotyy_axes__')):
                        ## Hack for bug #44246.  There is no way to reset or remove a
          ## property created with addproperty short of deleting the object.
                        delete(ca)
                        ca=axes()
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:197
                    else:
                        __go_axes_init__(ca,'replace')
                        __request_drawnow__()
                ## FIXME: The code above should perform the following:
      ###########################
      ## delete (allchild (ca));
      ## reset (ca);
      ###########################
      ## Actually, __go_axes_init__ does both less and more.
      ## It doesn't really remove all children since it re-instantiates
      ## xlabel, ylabel, zlabel, and title text objects.
      ## Also it preserves font properties like fontsize.
      ## For the time being, in order to have axis labels and title work,
      ## the above code is is required.
    
    if (nargout > 0):
        hax=copy(ca)
# /home/lei/octave-4.0.2/scripts/plot/util/newplot.m:217
    
    return hax
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{h}, @var{varargin}, @var{narg}] =} __plt_get_axis_arg__ (@var{caller}, @var{varargin})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __plt_get_axis_arg__(caller=None,varargin=None,*args,**kwargs):
    varargin = __plt_get_axis_arg__.varargin
    nargin = __plt_get_axis_arg__.nargin

    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:28
    parent=find(strcmpi(varargin,'parent'),1)
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:29
    
    ## Root Figure (0) or an ordinary figure (integer).
    if (numel(varargin) > 0 and numel(varargin[1]) == 1 and ishandle(varargin[1]) and varargin[1] != 0 and logical_not(isfigure(varargin[1]))):
        htmp=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:35
        if (logical_not(isaxes(htmp))):
            error('%s: expecting first argument to be axes handle',caller)
        if (logical_not(strcmp(get(htmp,'tag'),'legend'))):
            h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:40
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:41
        ## Look for "parent"/axis prop/value pair
    else:
        if (numel(varargin) > 1 and logical_not(isempty(parent))):
            if (parent < numel(varargin) and ishandle(varargin[parent + 1])):
                htmp=varargin[parent + 1]
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:46
                if (isaxes(htmp) and logical_not(strcmp(get(htmp,'tag'),'legend'))):
                    h=copy(htmp)
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:48
                    varargin[parent:parent + 1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:49
                else:
                    ## 'parent' property for some other type like hggroup
                    h=matlabarray(cat(ancestor(htmp,'axes'),htmp))
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:52
            else:
                error('%s: expecting parent value to be axes handle',caller)
    
    narg=length(varargin)
# /home/lei/octave-4.0.2/scripts/plot/util/__plt_get_axis_arg__.m:59
    return h,varargin,narg
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 2007-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{options} =} __default_plot_options__ ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def __default_plot_options__(*args,**kwargs):
    varargin = __default_plot_options__.varargin
    nargin = __default_plot_options__.nargin

    options.key = copy('')
# /home/lei/octave-4.0.2/scripts/plot/util/__default_plot_options__.m:28
    options.color = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/__default_plot_options__.m:29
    options.linestyle = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/__default_plot_options__.m:30
    options.marker = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/__default_plot_options__.m:31
    options.errorstyle = copy([])
# /home/lei/octave-4.0.2/scripts/plot/util/__default_plot_options__.m:32
    return options
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Michael D. Godfrey
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public
## License as published by the Free Software Foundation;
## either version 3 of the License, or (at your option) any
## later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied
## warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public
## License along with Octave; see the file COPYING. If not,
## see <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} printd (@var{obj}, @var{filename})
## @deftypefnx {Function File} {@var{out_file} =} printd (@dots{})
##
## Convert any object acceptable to @code{disp} into the format selected by
## the suffix of @var{filename}.
##
## If the return argument @var{out_file} is given, the name of the created
## file is returned.
##
## This function is intended to facilitate manipulation of the output of
## functions such as @code{stemleaf}.
## @seealso{stemleaf}
## @end deftypefn
    
    ## Author: Michael D. Godfrey <michaeldgodfrey@gmail.com>
## Description: Convert objects into other file formats.
    
    
@function
def printd(obj=None,filename=None,*args,**kwargs):
    varargin = printd.varargin
    nargin = printd.nargin

    ## Convert any object acceptable to disp() into various display formats.
  ## obj is the input object.
  ## filename is the output file (with required suffix).
    
    ## Extract .suffix from filename
    if ((sufix=rindex(filename,'.')
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:45) <= 0):
        error('The output filename: %s requires a suffix.\nOptions are: pdf ps eps txt jpg jpeg',filename)
    
    opt=substr(filename,sufix + 1)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:48
    pf,tempf,mag=mkstemp('oct-XXXXXX',1,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:49
    fprintf(pf,'%s',disp(obj))
    frewind(pf)
    
    ## are badly rendered.
    opt=lower(opt)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:55
    if 'pdf' == (opt):
        enscr=sprintf('enscript --no-header -o %s.ps %s ; ps2pdf %s.ps %s.pdf; mv %s.pdf %s;exit',tempf,tempf,tempf,tempf,tempf,filename)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:58
        system(enscr)
        delete(cat(tempf,'.ps'))
    else:
        if 'ps' == (opt):
            enscr=sprintf('enscript --no-header -o %s %s ; exit',filename,tempf)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:63
            system(enscr)
        else:
            if 'eps' == (opt):
                enscr=sprintf('enscript --no-header -o %s.ps %s ; ps2eps --ignoreBB %s.ps; mv %s.eps %s; exit',tempf,tempf,tempf,tempf,filename)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:66
                system(enscr)
                delete(cat(tempf,'.ps'))
            else:
                if 'txt' == (opt):
                    enscr=sprintf('cp %s %s',tempf,filename)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:71
                    system(enscr)
                else:
                    if cellarray(['jpg','jpeg']) == (opt):
                        enscr=sprintf('convert -trim txt:%s  jpg:%s',tempf,filename)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:74
                        system(enscr)
                    else:
                        fclose(pf)
                        delete(tempf)
                        error('Unknown conversion type: %s.\nOptions are: pdf ps eps txt jpg jpeg',opt)
    
    fclose(pf)
    delete(tempf)
    pr_out=sprintf('%s file %s written\n',opt,filename)
# /home/lei/octave-4.0.2/scripts/plot/util/printd.m:84
    return pr_out
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} gca ()
## Return a handle to the current axis object.
##
## The current axis is the default target for graphics output.  In the case
## of a figure with multiple axes, @code{gca} returns the last created axes
## or the last axes that was clicked on with the mouse.
##
## If no current axes object exists, create one and return its handle.  The
## handle may then be used to examine or set properties of the axes.  For
## example,
##
## @example
## @group
## ax = gca ();
## set (ax, "position", [0.5, 0.5, 0.5, 0.5]);
## @end group
## @end example
##
## @noindent
## creates an empty axes object and then changes its location and size in the
## figure window.
##
## Note: To find the current axis without creating a new axes object if it
## does not exist, query the @qcode{"CurrentAxes"} property of a figure.
##
## @example
## get (gcf, "currentaxes");
## @end example
## @seealso{gcf, gco, gcbf, gcbo, get, set}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def gca(*args,**kwargs):
    varargin = gca.varargin
    nargin = gca.nargin

    if (nargin == 0):
        h=get(gcf(),'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/gca.m:56
        if (isempty(h)):
            h=axes()
# /home/lei/octave-4.0.2/scripts/plot/util/gca.m:58
    else:
        print_usage()
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hlink} =} linkprop (@var{h}, "@var{prop}")
## @deftypefnx {Function File} {@var{hlink} =} linkprop (@var{h}, @{"@var{prop1}", "@var{prop2}", @dots{}@})
## Link graphic object properties, such that a change in one is propagated to
## the others.
##
## The input @var{h} is a vector of graphic handles to link.
##
## @var{prop} may be a string when linking a single property, or a cell array
## of strings for multiple properties.  During the linking process all
## properties in @var{prop} will initially be set to the values that exist on
## the first object in the list @var{h}.
##
## The function returns @var{hlink} which is a special object describing the
## link.  As long as the reference @var{hlink} exists the link between graphic
## objects will be active.  This means that @var{hlink} must be preserved in
## a workspace variable, a global variable, or otherwise stored using a
## function such as @code{setappdata}, @code{guidata}.  To unlink properties,
## execute @code{clear @var{hlink}}.
##
## An example of the use of @code{linkprop} is
##
## @example
## @group
## x = 0:0.1:10;
## subplot (1,2,1);
## h1 = plot (x, sin (x));
## subplot (1,2,2);
## h2 = plot (x, cos (x));
## hlink = linkprop ([h1, h2], @{"color","linestyle"@});
## set (h1, "color", "green");
## set (h2, "linestyle", "--");
## @end group
## @end example
##
## @seealso{linkaxes}
## @end deftypefn
    
    
@function
def linkprop(h=None,prop=None,*args,**kwargs):
    varargin = linkprop.varargin
    nargin = linkprop.nargin

    if (nargin != 2):
        print_usage()
    
    if (numel(h) < 2):
        error('linkprop: H must contain at least 2 handles')
    else:
        if (logical_not(all(ishandle(ravel(h))))):
            error('linkprop: invalid graphic handle in input H')
    
    if (ischar(prop)):
        prop=cellarray([prop])
# /home/lei/octave-4.0.2/scripts/plot/util/linkprop.m:70
    else:
        if (logical_not(iscellstr(prop))):
            error('linkprop: PROP must be a string or cell string array')
    
    h=ravel(h).T
# /home/lei/octave-4.0.2/scripts/plot/util/linkprop.m:75
    
    ## Match all objects to the first one in the list before linking
    for j in arange(1,numel(prop)).reshape(-1):
        set(h[2:end()],prop[j],get(h[1],prop[j]))
    
    ## Add listeners to all objects
    for i in arange(1,numel(h)).reshape(-1):
        for j in arange(1,numel(prop)).reshape(-1):
            addlistener(h[i],prop[j],cellarray([update_prop,cat(h[1:i - 1],h[i + 1:end()]),prop[j]]))
    
    hlink=onCleanup(lambda : delete_linkprop(h,prop))
# /home/lei/octave-4.0.2/scripts/plot/util/linkprop.m:89
    return hlink
    
if __name__ == '__main__':
    pass
    
    
@function
def update_prop(h=None,__=None,hlist=None,prop=None,*args,**kwargs):
    varargin = update_prop.varargin
    nargin = update_prop.nargin

    
    
    if (logical_not(recursion)):
        try:
            recursion=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/linkprop.m:99
            set(hlist[ishandle(hlist)],prop,get(h,prop))
        finally:
            recursion=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/linkprop.m:102
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def delete_linkprop(hlist=None,prop=None,*args,**kwargs):
    varargin = delete_linkprop.varargin
    nargin = delete_linkprop.nargin

    for i in arange(1,numel(hlist)).reshape(-1):
        if (ishandle(hlist[i])):
            for j in arange(1,numel(prop)).reshape(-1):
                dellistener(hlist[i],prop[j])
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} subplot (@var{rows}, @var{cols}, @var{index})
## @deftypefnx {Function File} {} subplot (@var{rcn})
## @deftypefnx {Function File} {} subplot (@var{hax})
## @deftypefnx {Function File} {} subplot (@dots{}, "align")
## @deftypefnx {Function File} {} subplot (@dots{}, "replace")
## @deftypefnx {Function File} {} subplot (@dots{}, "position", @var{pos})
## @deftypefnx {Function File} {} subplot (@dots{}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {@var{hax} =} subplot (@dots{})
## Set up a plot grid with @var{rows} by @var{cols} subwindows and set the
## current axes for plotting (@code{gca}) to the location given by @var{index}.
##
## If only one numeric argument is supplied, then it must be a three digit
## value specifying the number of rows in digit 1, the number of columns in
## digit 2, and the plot index in digit 3.
##
## The plot index runs row-wise; First, all columns in a row are numbered
## and then the next row is filled.
##
## For example, a plot with 2x3 grid will have plot indices running as follows:
## @tex
## \vskip 10pt
## \hfil\vbox{\offinterlineskip\hrule
## \halign{\vrule#&&\qquad\hfil#\hfil\qquad\vrule\cr
## height13pt&1&2&3\cr height12pt&&&\cr\noalign{\hrule}
## height13pt&4&5&6\cr height12pt&&&\cr\noalign{\hrule}}}
## \hfil
## \vskip 10pt
## @end tex
## @ifnottex
##
## @example
## @group
## +-----+-----+-----+
## |  1  |  2  |  3  |
## +-----+-----+-----+
## |  4  |  5  |  6  |
## +-----+-----+-----+
## @end group
## @end example
##
## @end ifnottex
##
## @var{index} may also be a vector.  In this case, the new axis will enclose
## the grid locations specified.  The first demo illustrates this:
##
## @example
## demo ("subplot", 1)
## @end example
##
## The index of the subplot to make active may also be specified by its axes
## handle, @var{hax}, returned from a previous @code{subplot} command.
##
## If the option @qcode{"align"} is given then the plot boxes of the subwindows
## will align, but this may leave no room for axis tick marks or labels.
##
## If the option @qcode{"replace"} is given then the subplot axis will be
## reset, rather than just switching the current axis for plotting to the
## requested subplot.
##
## The @qcode{"position"} property can be used to exactly position the subplot
## axes within the current figure.  The option @var{pos} is a 4-element vector
## [x, y, width, height] that determines the location and size of the axes.
## The values in @var{pos} are normalized in the range [0,1].
##
## Any property/value pairs are passed directly to the underlying axes object.
##
## If the output @var{hax} is requested, subplot returns the axis handle for
## the subplot.  This is useful for modifying the properties of a subplot
## using @code{set}.
## @seealso{axes, plot, gca, set}
## @end deftypefn
    
    ## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
## Adapted-By: jwe
    
    
@function
def subplot(varargin=None,*args,**kwargs):
    varargin = subplot.varargin
    nargin = subplot.nargin

    align_axes=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:97
    replace_axes=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:98
    have_position=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:99
    initial_args_decoded=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:100
    if (nargin >= 3):
        ## R, C, N?
        arg1=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:104
        arg2=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:105
        arg3=varargin[3]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:106
        if (isnumeric(arg1) and isscalar(arg1) and isnumeric(arg2) and isscalar(arg2) and isnumeric(arg3)):
            rows=copy(arg1)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:110
            cols=copy(arg2)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:111
            index=copy(arg3)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:112
            varargin[1:3]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:113
            initial_args_decoded=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:114
    
    if (logical_not(initial_args_decoded) and nargin > 1):
        ## check for "position", pos, ...
        if (strcmpi(varargin[1],'position')):
            arg=varargin[2]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:121
            if (isnumeric(arg) and numel(arg) == 4):
                pos=copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:123
                varargin[1:2]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:124
                have_position=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:125
                initial_args_decoded=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:126
            else:
                error('subplot: POSITION must be a 4-element numeric array')
    
    if (logical_not(initial_args_decoded) and nargin > 0):
        arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:134
        if (nargin == 1 and isaxes(arg)):
            ## Axes handle
            axes(arg)
            cf=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:138
            set(cf,'nextplot','add')
            return h
        else:
            if (isscalar(arg) and arg >= 0):
                ## RCN?
                index=rem(arg,10)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:143
                arg=(arg - index) / 10
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:144
                cols=rem(arg,10)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:145
                arg=(arg - cols) / 10
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:146
                rows=rem(arg,10)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:147
                varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:148
                initial_args_decoded=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:149
            else:
                error('subplot: expecting axes handle or RCN argument')
    
    if (logical_not(initial_args_decoded)):
        print_usage()
    
    if (logical_not(have_position)):
        cols=round(cols)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:160
        rows=round(rows)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:161
        index=round(index)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:162
        if (any(index < 1) or any(index > dot(rows,cols))):
            error('subplot: INDEX value must be >= 1 and <= ROWS*COLS')
        if (rows < 1 or cols < 1 or index < 1):
            error('subplot: ROWS, COLS, and INDEX must be be positive')
    
    ## Process "align" and "replace" options
    idx=strcmpi(varargin,'align')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:174
    if (any(idx)):
        align_axes=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:176
        varargin[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:177
    
    idx=strcmpi(varargin,'replace')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:180
    if (any(idx)):
        replace_axes=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:182
        varargin[idx]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:183
    
    axesunits=get(0,'defaultaxesunits')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:186
    cf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:187
    figureunits=get(cf,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:188
    try:
        set(0,'defaultaxesunits','normalized')
        set(cf,'units','pixels')
        ##        which will set "activepositionproperty" to "position".
    ##        This can yield to text overlap between labels and titles.
    ##        See bug #31610.
        if (strcmp(get(cf,'__graphics_toolkit__'),'gnuplot')):
            align_axes=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:198
        if (logical_not(have_position)):
            ## Subplots that cover more that one base subplot are not updated
            align_axes=(align_axes or (logical_not(isscalar(index))))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:203
            pos,opos,li=subplot_position(cf,rows,cols,index,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:205
        else:
            ## Position is specified by the user.
            li=zeros(1,4)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:208
            align_axes=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:209
        set(cf,'nextplot','add')
        found=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:214
        kids=get(cf,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:215
        for child in ravel(kids).T.reshape(-1):
            ## Check whether this child is still valid; this might not be the
      ## case anymore due to the deletion of previous children (due to
      ## "deletefcn" callback or for legends/colorbars that are deleted
      ## with their corresponding axes).
            if (logical_not(ishandle(child))):
                continue
            if (strcmp(get(child,'type'),'axes')):
                ## Skip legend and colorbar objects.
                if (any(strcmp(get(child,'tag'),cellarray(['legend','colorbar'])))):
                    continue
                if (isappdata(child,'__subplotposition__')):
                    objpos=getappdata(child,'__subplotposition__')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:231
                else:
                    objpos=get(child,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:233
                if (all(abs(objpos - pos) < eps) and logical_not(replace_axes)):
                    ## If the new axes are in exactly the same position
          ## as an existing axes object, or if they share the same
          ## appdata "__subplotposition__", use the existing axes.
                    found=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:239
                    hsubplot=copy(child)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:240
                else:
                    ## If the new axes overlap an old axes object, delete the old axes.
                    objpos=get(child,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:243
                    x0=pos[1]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:245
                    x1=x0 + pos[3]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:246
                    y0=pos[2]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:247
                    y1=y0 + pos[4]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:248
                    objx0=objpos[1]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:249
                    objx1=objx0 + objpos[3]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:250
                    objy0=objpos[2]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:251
                    objy1=objy0 + objpos[4]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:252
                    if (logical_not((x0 >= objx1 or x1 <= objx0 or y0 >= objy1 or y1 <= objy0))):
                        delete(child)
        if (found):
            ## Switch to existing subplot and set requested properties
            set(cf,'currentaxes',hsubplot)
            if (logical_not(isempty(varargin))):
                set(hsubplot,varargin[:])
        else:
            hsubplot=axes('box','off','activepositionproperty','position','position',pos,'looseinset',li,varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:267
            if (logical_not(align_axes)):
                ## base position (no ticks, no annotation, no cumbersome neighbor)
                setappdata(hsubplot,'__subplotposition__',pos)
                setappdata(hsubplot,'__subplotouterposition__',opos)
                addlistener(hsubplot,'outerposition',subplot_align)
                addlistener(hsubplot,'xaxislocation',subplot_align)
                addlistener(hsubplot,'yaxislocation',subplot_align)
                addlistener(hsubplot,'position',cellarray([subplot_align,true]))
                subplot_align(hsubplot)
    finally:
        set(0,'defaultaxesunits',axesunits)
        set(cf,'units',figureunits)
    
    if (nargout > 0):
        h=copy(hsubplot)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:291
    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def subplot_position(hf=None,nrows=None,ncols=None,idx=None,*args,**kwargs):
    varargin = subplot_position.varargin
    nargin = subplot_position.nargin

    if (nrows == 1 and ncols == 1):
        ## Trivial result for subplot (1,1,1)
        pos=get(0,'defaultaxesposition')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:300
        opos=get(0,'defaultaxesouterposition')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:301
        li=get(0,'defaultaxeslooseinset')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:302
        return pos,opos,li
    
    ## Row/Column inside the axes array
    row=ceil(idx / ncols)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:307
    col=dot(idx- (row - 1),ncols)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:308
    row=matlabarray(cat(min(row),max(row)))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:309
    col=matlabarray(cat(min(col),max(col)))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:310
    
    fig_units=get(hf,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:313
    set(hf,'units','points')
    pts_size=get(gcf,'position')(arange(3,4))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:315
    xbasemargin=6 / pts_size[1]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:316
    ybasemargin=6 / pts_size[2]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:317
    
    margin.column = copy(0.2 / ncols + dot(2,xbasemargin))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:320
    margin.row = copy(0.2 / nrows + dot(2,ybasemargin))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:321
    set(hf,'units',fig_units)
    margin.left = copy(xbasemargin)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:324
    margin.right = copy(xbasemargin)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:325
    margin.bottom = copy(ybasemargin)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:326
    margin.top = copy(ybasemargin)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:327
    
    borders=get(0,'defaultaxesposition')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:330
    if (col[1] == 1):
        margin.left = copy(borders[1])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:332
    else:
        margin.left = copy(margin.column - margin.right)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:334
    
    if (col[2] == ncols):
        margin.right = copy(1 - borders[1] - borders[3])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:337
    
    if (row[2] == nrows):
        margin.bottom = copy(borders[2])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:342
    else:
        margin.bottom = copy(margin.row - margin.top)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:344
    
    if (row[1] == 1):
        margin.top = copy(1 - borders[2] - borders[4])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:347
    
    ## Compute base width and height
    width=(borders[3] - dot((ncols - 1),margin.column)) / ncols
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:352
    height=(borders[4] - dot((nrows - 1),margin.row)) / nrows
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:353
    
    x0=borders[1] + dot((col[1] - 1),(width + margin.column))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:356
    y0=borders[2] + dot((nrows - row[2]),(height + margin.row))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:357
    width += dot(diff(col),(width + margin.column))
    height += dot(diff(row),(height + margin.row))
    pos=matlabarray(cat(x0,y0,width,height))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:361
    opos=matlabarray(cat((x0 - margin.left),(y0 - margin.bottom),(width + margin.left + margin.right),(height + margin.bottom + margin.top)))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:362
    li=matlabarray(cat(margin.left,margin.bottom,margin.right,margin.top))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:365
    return pos,opos,li
    
if __name__ == '__main__':
    pass
    
    
@function
def subplot_align(h=None,d=None,rmupdate=false,*args,**kwargs):
    varargin = subplot_align.varargin
    nargin = subplot_align.nargin

    
    if (logical_not(updating)):
        if (rmupdate):
            ## The "position" property has been changed from outside this
      ## routine. Don't update anymore.
            if (isappdata(h,'__subplotposition__')):
                rmappdata(h,'__subplotposition__')
                rmappdata(h,'__subplotouterposition__')
            return
        try:
            updating=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:383
            hf=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:384
            children=get(hf,'children')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:385
            pos=getappdata(children,'__subplotposition__')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:388
            if (iscell(pos)):
                do_align=logical_not(cellfun(isempty,pos))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:391
                pos=cell2mat(pos[do_align])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:392
            else:
                return
            hsubplots=children[do_align]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:396
            ## the same figure. Only subplots that have the same width and
      ## height as this one are updated.
            if (any(h == hsubplots)):
                width=pos[h == hsubplots,3]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:403
                height=pos[h == hsubplots,4]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:404
                do_align=logical_and((pos[:,3] == width),(pos[:,4] == height))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:405
                hsubplots[logical_not(do_align)]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:406
                pos[logical_not(do_align),:]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:407
            else:
                return
            ## Reset outerpositions to their default value
            opos=getappdata(hsubplots,'__subplotouterposition__')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:413
            if (iscell(opos)):
                opos=cell2mat(opos)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:415
            for ii in arange(1,numel(hsubplots)).reshape(-1):
                set(hsubplots[ii],'outerposition',opos[ii,:],'activepositionproperty','position')
            ## Compare current positions to default and compute the new ones
            curpos=get(hsubplots,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:423
            if (iscell(curpos)):
                curpos=cell2mat(curpos)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:425
            dx0=max(curpos[:,1] - pos[:,1])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:427
            dx0[dx0 < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:428
            dx1=max((pos[:,1] + pos[:,3]) - (curpos[:,1] + curpos[:,3]))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:429
            dx1[dx1 < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:430
            dy0=max(curpos[:,2] - pos[:,2])
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:431
            dy0[dy0 < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:432
            dy1=max((pos[:,2] + pos[:,4]) - (curpos[:,2] + curpos[:,4]))
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:433
            dy1[dy1 < 0]=0
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:434
            pos[:,1] += dx0
            pos[:,2] += dy0
            pos[:,3] -= dx0 + dx1
            pos[:,4] -= dy0 + dy1
            for ii in arange(1,numel(hsubplots)).reshape(-1):
                set(hsubplots[ii],'position',pos[ii,:])
        finally:
            updating=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/subplot.m:446
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test recognition/deletion of previous axes
## Default mode
    
    
    
    
    
    
    
    
    
    
    
    
    ## Position mode
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Align mode
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isaxes (@var{h})
## Return true if @var{h} is an axes graphics handle and false otherwise.
##
## If @var{h} is a matrix then return a logical array which is true where the
## elements of @var{h} are axes graphics handles and false where they are not.
## @seealso{isaxes, ishandle}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def isaxes(h=None,*args,**kwargs):
    varargin = isaxes.varargin
    nargin = isaxes.nargin

    if (nargin != 1):
        print_usage()
    
    hlist=ishandle(h)
# /home/lei/octave-4.0.2/scripts/plot/util/isaxes.m:36
    retval=copy(hlist)
# /home/lei/octave-4.0.2/scripts/plot/util/isaxes.m:37
    if (any(hlist)):
        retval[hlist]=strcmp(get(h[hlist],'type'),'axes')
# /home/lei/octave-4.0.2/scripts/plot/util/isaxes.m:40
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} closereq ()
## Close the current figure and delete all graphics objects associated with it.
##
## By default, the @qcode{"closerequestfcn"} property of a new plot figure
## points to this function.
## @seealso{close, delete}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def closereq(*args,**kwargs):
    varargin = closereq.varargin
    nargin = closereq.nargin

    if (nargin != 0):
        print_usage()
    
    cf=gcbf()
# /home/lei/octave-4.0.2/scripts/plot/util/closereq.m:36
    if (isempty(cf)):
        warning('closereq: calling closereq from octave prompt is not supported, use \'close\' instead')
        cf=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/closereq.m:39
    
    if (logical_not(isempty(cf)) and isfigure(cf)):
        delete(cf)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Command} {} shg
## Show the graph window.
##
## Currently, this is the same as executing @code{drawnow}.
## @seealso{drawnow, figure}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def shg(*args,**kwargs):
    varargin = shg.varargin
    nargin = shg.nargin

    if (nargin != 0):
        warning('shg: ignoring extra arguments')
    
    drawnow()
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Andreas Weber
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} rotate3d
## @deftypefnx {Command} {} rotate3d on
## @deftypefnx {Command} {} rotate3d off
## @deftypefnx {Function File} {} rotate3d (@var{hfig}, @var{option})
## Control the interactive 3-D rotation mode of a figure in the GUI.
##
## Given the option @qcode{"on"} or @qcode{"off"}, set the interactive
## rotate mode on or off.
##
## With no arguments, toggle the current rotate mode on or off.
##
## If the first argument @var{hfig} is a figure, then operate on the given
## figure rather than the current figure as returned by @code{gcf}.
##
## @seealso{pan, zoom}
## @end deftypefn
    
    
@function
def rotate3d(varargin=None,*args,**kwargs):
    varargin = rotate3d.varargin
    nargin = rotate3d.nargin

    hfig=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:39
    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:41
    if (nargs > 2):
        print_usage()
    
    if (nargin == 1 and nargout > 0 and isfigure(varargin[1])):
        error('rotate_object_handle = rotate3d (hfig): not implemented')
    
    if (nargs == 2):
        hfig=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:52
        if (isfigure(hfig)):
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:54
            nargs
        else:
            error('rotate3d: expecting figure handle as first argument')
    
    if (isnan(hfig)):
        hfig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:62
    
    if (nargs == 0):
        rm=get(hfig,'__rotate_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:66
        if (strcmp(rm.Enable,'on')):
            rm.Enable = copy('off')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:68
        else:
            rm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:70
        set(hfig,'__rotate_mode__',rm)
        update_mouse_mode(hfig,rm.Enable)
    else:
        if (nargs == 1):
            arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:75
            if (ischar(arg)):
                if cellarray(['on','off']) == (arg):
                    rm=get(hfig,'__rotate_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:79
                    if cellarray(['on','off']) == (arg):
                        rm.Enable = copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:82
                        rm.Motion = copy('both')
# /home/lei/octave-4.0.2/scripts/plot/util/rotate3d.m:83
                    set(hfig,'__rotate_mode__',rm)
                    update_mouse_mode(hfig,arg)
                else:
                    error('rotate3d: unrecognized option \'%s\'',arg)
            else:
                error('rotate3d: wrong type argument \'%s\'',class_(arg))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_mouse_mode(hfig=None,arg=None,*args,**kwargs):
    varargin = update_mouse_mode.varargin
    nargin = update_mouse_mode.nargin

    if (strcmp(arg,'off')):
        set(hfig,'__mouse_mode__','none')
    else:
        ## FIXME: Is there a better way other than calling these
    ## functions to set the other mouse mode Enable fields to
    ## "off"?
        pan('off')
        zoom('off')
        set(hfig,'__mouse_mode__','rotate')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Andreas Weber
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} pan
## @deftypefnx {Command} {} pan on
## @deftypefnx {Command} {} pan off
## @deftypefnx {Command} {} pan xon
## @deftypefnx {Command} {} pan yon
## @deftypefnx {Function File} {} pan (@var{hfig}, @var{option})
## Control the interactive panning mode of a figure in the GUI.
##
## Given the option @qcode{"on"} or @qcode{"off"}, set the interactive
## pan mode on or off.
##
## With no arguments, toggle the current pan mode on or off.
##
## Given the option @qcode{"xon"} or @qcode{"yon"}, enable pan mode
## for the x or y axis only.
##
## If the first argument @var{hfig} is a figure, then operate on the given
## figure rather than the current figure as returned by @code{gcf}.
##
## @seealso{rotate3d, zoom}
## @end deftypefn
    
    
@function
def pan(varargin=None,*args,**kwargs):
    varargin = pan.varargin
    nargin = pan.nargin

    hfig=copy(NaN)
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:44
    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:46
    if (nargs > 2):
        print_usage()
    
    if (nargin == 1 and nargout > 0 and isfigure(varargin[1])):
        error('pan_object_handle = pan (hfig): not implemented')
    
    if (nargs == 2):
        hfig=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:57
        if (isfigure(hfig)):
            varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:59
            nargs
        else:
            error('pan: expecting figure handle as first argument')
    
    if (isnan(hfig)):
        hfig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:67
    
    if (nargs == 0):
        pm=get(hfig,'__pan_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:71
        if (strcmp(pm.Enable,'on')):
            pm.Enable = copy('off')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:73
        else:
            pm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:75
        set(hfig,'__pan_mode__',pm)
        update_mouse_mode(hfig,pm.Enable)
    else:
        if (nargs == 1):
            arg=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:80
            if (ischar(arg)):
                if cellarray(['on','off','xon','yon']) == (arg):
                    pm=get(hfig,'__pan_mode__')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:84
                    if cellarray(['on','off']) == (arg):
                        pm.Enable = copy(arg)
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:87
                        pm.Motion = copy('both')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:88
                    else:
                        if 'xon' == (arg):
                            pm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:90
                            pm.Motion = copy('horizontal')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:91
                        else:
                            if 'yon' == (arg):
                                pm.Enable = copy('on')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:93
                                pm.Motion = copy('vertical')
# /home/lei/octave-4.0.2/scripts/plot/util/pan.m:94
                    set(hfig,'__pan_mode__',pm)
                    update_mouse_mode(hfig,arg)
                else:
                    error('pan: unrecognized option \'%s\'',arg)
            else:
                error('pan: wrong type argument \'%s\'',class_(arg))
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def update_mouse_mode(hfig=None,arg=None,*args,**kwargs):
    varargin = update_mouse_mode.varargin
    nargin = update_mouse_mode.nargin

    if (strcmp(arg,'off')):
        set(hfig,'__mouse_mode__','none')
    else:
        ## FIXME: Is there a better way other than calling these
    ## functions to set the other mouse mode Enable fields to
    ## "off"?
        rotate3d('off')
        zoom('off')
        set(hfig,'__mouse_mode__','pan')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2006-2015 Alexander Barth
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{y1}, @var{y2}, @dots{}, @var{y}n] =} ndgrid (@var{x1}, @var{x2}, @dots{}, @var{x}n)
## @deftypefnx {Function File} {[@var{y1}, @var{y2}, @dots{}, @var{y}n] =} ndgrid (@var{x})
## Given n vectors @var{x1}, @dots{}, @var{x}n, @code{ndgrid} returns n
## arrays of dimension n.
##
## The elements of the i-th output argument contains the elements of the
## vector @var{x}i repeated over all dimensions different from the i-th
## dimension.  Calling ndgrid with only one input argument @var{x} is
## equivalent to calling ndgrid with all n input arguments equal to @var{x}:
##
## [@var{y1}, @var{y2}, @dots{}, @var{y}n] = ndgrid (@var{x}, @dots{}, @var{x})
##
## Programming Note: @code{ndgrid} is very similar to the function
## @code{meshgrid} except that the first two dimensions are transposed in
## comparison to @code{meshgrid}.  Some core functions expect @code{meshgrid}
## input and others expect @code{ndgrid} input.  Check the documentation for
## the function in question to determine the proper input format.
## @seealso{meshgrid}
## @end deftypefn
    
    ## Author: Alexander Barth <abarth@marine.usf.edu>
    
    
@function
def ndgrid(varargin=None,*args,**kwargs):
    varargin = ndgrid.varargin
    nargin = ndgrid.nargin

    if (nargin == 0):
        print_usage()
    else:
        if (nargin == 1):
            nd=max(nargout,1)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:47
            varargin[1:nd]=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:49
        else:
            if (nargin >= nargout):
                nd=max(nargin,1)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:51
            else:
                error('ndgrid: wrong number of input arguments')
    
    ## Determine the size of the output arguments
    shape=zeros(1,nd)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:57
    for i in arange(1,nd).reshape(-1):
        if (logical_not(isvector(varargin[i])) and logical_not(isempty(varargin[i]))):
            error('ndgrid: arguments must be vectors')
        shape[i]=length(varargin[i])
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:62
    
    if (nd == 1):
        ## Special case, single input vector
        varargout[1]=ravel(varargin[1])
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:67
    else:
        for i in arange(1,nd).reshape(-1):
            ## size for reshape
            r=ones(1,nd + 1)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:71
            r[i]=shape[i]
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:72
            s=copy(shape)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:75
            s[i]=1
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:76
            varargout[i]=repmat(reshape(varargin[i],r),s)
# /home/lei/octave-4.0.2/scripts/plot/util/ndgrid.m:78
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 Willem Atsma
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} linkaxes (@var{hax})
## @deftypefnx {Function File} {} linkaxes (@var{hax}, @var{optstr})
## Link the axis limits of 2-D plots such that a change in one is propagated
## to the others.
##
## The axes handles to be linked are passed as the first argument @var{hax}.
##
## The optional second argument is a string which defines which axis limits
## will be linked.  The possible values for @var{optstr} are:
##
## @table @asis
## @item @qcode{"x"}
## Link x-axes
##
## @item @qcode{"y"}
## Link y-axes
##
## @item @qcode{"xy"} (default)
## Link both axes
##
## @item @qcode{"off"}
## Turn off linking
## @end table
##
## If unspecified the default is to link both X and Y axes.
##
## When linking, the limits from the first axes in @var{hax} are applied to the
## other axes in the list.  Subsequent changes to any one of the axes will be
## propagated to the others.
##
## @seealso{linkprop, addproperty}
## @end deftypefn
    
    ## Author: Willem Atsma willem.atsma at tanglebridge.com
## Created: 2014-03-18
    
    
@function
def linkaxes(hax=None,optstr='xy',*args,**kwargs):
    varargin = linkaxes.varargin
    nargin = linkaxes.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (numel(hax) < 2):
        error('linkaxes: HAX must contain at least 2 handles')
    else:
        if (logical_not(all(isaxes(ravel(hax))))):
            error('linkaxes: HAX must be a vector of axes handles')
    
    ## Check if axes are linked already and clear if found.
  ## Otherwise, add the necessary linkaxes_data property.
    for i in arange(1,length(hax)).reshape(-1):
        if (isprop(hax[i],'linkaxes_data')):
            hld=get(hax[i],'linkaxes_data')
# /home/lei/octave-4.0.2/scripts/plot/util/linkaxes.m:72
            try:
                rmappdata(hld,'linkprop_data')
            finally:
                pass
        else:
            addproperty('linkaxes_data',hax[i],'any')
    
    if 'x' == (optstr):
        hlink=linkprop(hax,'xlim')
# /home/lei/octave-4.0.2/scripts/plot/util/linkaxes.m:83
    else:
        if 'y' == (optstr):
            hlink=linkprop(hax,'ylim')
# /home/lei/octave-4.0.2/scripts/plot/util/linkaxes.m:85
        else:
            if 'xy' == (optstr):
                hlink=linkprop(hax,cellarray(['xlim','ylim']))
# /home/lei/octave-4.0.2/scripts/plot/util/linkaxes.m:87
            else:
                if 'off' == (optstr):
                    ## do nothing - link already deleted
                    hlink=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/linkaxes.m:90
                else:
                    error('linkaxes: unrecognized OPTSTR \'%s\'',optstr)
    
    if (logical_not(isempty(hlink))):
        setappdata(hax[1],'linkprop_data',hlink)
        set(hax,'linkaxes_data',hax[1])
    else:
        set(hax,'linkaxes_data',[])
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} ishold
## @deftypefnx {Function File} {} ishold (@var{hax})
## @deftypefnx {Function File} {} ishold (@var{hfig})
## Return true if the next plot will be added to the current plot, or
## false if the plot device will be cleared before drawing the next plot.
##
## If the first argument is an axes handle @var{hax} or figure handle
## @var{hfig} then operate on this plot rather than the current one.
## @seealso{hold, newplot}
## @end deftypefn
    
    
@function
def ishold(h=None,*args,**kwargs):
    varargin = ishold.varargin
    nargin = ishold.nargin

    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        fig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:38
        ax=get(fig,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:39
    else:
        if (ishandle(h)):
            if (strcmp(get(h,'type'),'figure')):
                fig=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:43
                ax=get(fig,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:44
            else:
                if (strcmp(get(h,'type'),'axes')):
                    ax=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:46
                    fig=ancestor(ax,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:47
                else:
                    error('ishold: H must be an axes or figure graphics handle')
        else:
            error('ishold: H must be an axes or figure graphics handle')
    
    retval=(strcmp(get(fig,'nextplot'),'add') and logical_not(isempty(ax)) and strcmp(get(ax,'nextplot'),'add'))
# /home/lei/octave-4.0.2/scripts/plot/util/ishold.m:56
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} __actual_axis_position__ (@var{h})
## @deftypefnx {Function File} {} __actual_axis_position__ (@var{axis_struct})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Ben Abbott
    
    
@function
def __actual_axis_position__(h=None,*args,**kwargs):
    varargin = __actual_axis_position__.varargin
    nargin = __actual_axis_position__.nargin

    if (ishandle(h)):
        axis_obj=get(h)
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:30
    else:
        if (isstruct(h)):
            axis_obj=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:32
            h=axis_obj.__cbar_hax__
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:33
    
    ## Get figure size in pixels
    orig_fig_units=get(axis_obj.parent,'units')
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:37
    orig_fig_position=get(axis_obj.parent,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:38
    try:
        set(axis_obj.parent,'units','pixels')
        fig_position=get(axis_obj.parent,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:41
    finally:
        set(axis_obj.parent,'units',orig_fig_units)
        set(axis_obj.parent,'position',orig_fig_position)
    
    ## Get axes size in pixels
    if (strcmp(get(axis_obj.parent,'__graphics_toolkit__'),'gnuplot') and strcmp(axis_obj.activepositionproperty,'outerposition')):
        pos_in_pixels=multiply(axis_obj.outerposition,fig_position[cat(3,4,3,4)])
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:49
    else:
        pos_in_pixels=multiply(axis_obj.position,fig_position[cat(3,4,3,4)])
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:51
    
    nd=__calc_dimensions__(h)
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:54
    if (strcmp(axis_obj.plotboxaspectratiomode,'manual') or strcmp(axis_obj.dataaspectratiomode,'manual')):
        ## When using {rltb}margin, Gnuplot does not handle the specified
    ## aspect ratio properly, so handle it here.
        if (nd == 2 or all(mod(axis_obj.view,90) == 0)):
            aspect_ratio_2d=axis_obj.plotboxaspectratio(arange(1,2))
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:61
        else:
            ## FIXME: This works for "axis square", but has not been
      ##        thoroughly tested for other aspect ratios.
            aspect_ratio_2d=matlabarray(cat(max(axis_obj.plotboxaspectratio(arange(1,2))),axis_obj.plotboxaspectratio(3) / sqrt(2)))
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:65
        orig_aspect_ratio_2d=pos_in_pixels[3:4]
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:68
        rel_aspect_ratio_2d=aspect_ratio_2d / orig_aspect_ratio_2d
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:69
        rel_aspect_ratio_2d=rel_aspect_ratio_2d / max(rel_aspect_ratio_2d)
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:70
        if (rel_aspect_ratio_2d[1] < rel_aspect_ratio_2d[2]):
            dx=dot((1.0 - rel_aspect_ratio_2d[1]),pos_in_pixels[3])
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:72
            pos_in_pixels=pos_in_pixels + dot(dx,cat(0.5,0.0,- 1.0,0.0))
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:73
        else:
            if (rel_aspect_ratio_2d[1] > rel_aspect_ratio_2d[2]):
                dy=dot((1.0 - rel_aspect_ratio_2d[2]),pos_in_pixels[4])
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:75
                pos_in_pixels=pos_in_pixels + dot(dy,cat(0.0,0.5,0.0,- 1.0))
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:76
        pos=pos_in_pixels / fig_position[cat(3,4,3,4)]
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:78
    else:
        if (strcmp(get(axis_obj.parent,'__graphics_toolkit__'),'gnuplot') and strcmp(axis_obj.activepositionproperty,'outerposition')):
            pos=axis_obj.outerposition
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:81
        else:
            pos=axis_obj.position
# /home/lei/octave-4.0.2/scripts/plot/util/__actual_axis_position__.m:83
    
    return pos
    
if __name__ == '__main__':
    pass
    
    ## No test coverage for internal function.  It is tested through calling fcn.
    
    ## Copyright (C) 2010-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} saveas (@var{h}, @var{filename})
## @deftypefnx {Function File} {} saveas (@var{h}, @var{filename}, @var{fmt})
## Save graphic object @var{h} to the file @var{filename} in graphic format
## @var{fmt}.
##
## @var{fmt} should be one of the following formats:
##
## @table @code
##   @item ps
##     PostScript
##
##   @item eps
##     Encapsulated PostScript
##
##   @item jpg
##     JPEG Image
##
##   @item png
##     PNG Image
##
##   @item emf
##     Enhanced Meta File
##
##   @item pdf
##     Portable Document Format
## @end table
##
## All device formats specified in @code{print} may also be used.  If
## @var{fmt} is omitted it is extracted from the extension of @var{filename}.
## The default format is @qcode{"pdf"}.
##
## @example
## @group
## clf ();
## surf (peaks);
## saveas (1, "figure1.png");
## @end group
## @end example
##
## @seealso{print, hgsave, orient}
## @end deftypefn
    
    ## Author: Kai Habel
    
    
@function
def saveas(h=None,filename=None,fmt='pdf',*args,**kwargs):
    varargin = saveas.varargin
    nargin = saveas.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    if (ishandle(h)):
        if (isfigure(h)):
            fig=copy(h)
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:72
        else:
            fig=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:74
    else:
        error('saveas: first argument H must be a graphics handle')
    
    if (logical_not(ischar(filename))):
        error('saveas: FILENAME must be a string')
    
    if (nargin == 2):
        __,__,ext=fileparts(filename,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:85
        if (logical_not(isempty(ext))):
            fmt=ext[2:end()]
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:87
    
    if (nargin == 3):
        if (logical_not(ischar(filename))):
            error('saveas: EXT must be a string')
        __,__,ext=fileparts(filename,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:96
        if (isempty(ext)):
            filename=strcat(filename,'.',fmt)
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:99
    
    prt_opt=strcat('-d',tolower(fmt))
# /home/lei/octave-4.0.2/scripts/plot/util/saveas.m:103
    print_(fig,filename,prt_opt)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{fig} =} gcbf ()
## Return a handle to the figure containing the object whose callback is
## currently executing.
##
## If no callback is executing, this function returns the empty matrix.  The
## handle returned by this function is the same as the second output argument
## of @code{gcbo}.
##
## @seealso{gcbo, gcf, gco, gca, get, set}
## @end deftypefn
    
    
@function
def gcbf(*args,**kwargs):
    varargin = gcbf.varargin
    nargin = gcbf.nargin

    __,fig=gcbo(nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/gcbf.m:33
    return fig
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isfigure (@var{h})
## Return true if @var{h} is a figure graphics handle and false otherwise.
##
## If @var{h} is a matrix then return a logical array which is true where the
## elements of @var{h} are figure graphics handles and false where they are not.
## @seealso{isaxes, ishandle}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def isfigure(h=None,*args,**kwargs):
    varargin = isfigure.varargin
    nargin = isfigure.nargin

    if (nargin != 1):
        print_usage()
    
    hlist=ishandle(h)
# /home/lei/octave-4.0.2/scripts/plot/util/isfigure.m:36
    if (any(hlist)):
        retval[hlist]=strcmp(get(h[hlist],'type'),'figure')
# /home/lei/octave-4.0.2/scripts/plot/util/isfigure.m:38
    else:
        retval=copy(hlist)
# /home/lei/octave-4.0.2/scripts/plot/util/isfigure.m:40
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{y}, @var{buttons}] =} ginput (@var{n})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{buttons}] =} ginput ()
## Return the position and type of mouse button clicks and/or key strokes
## in the current figure window.
##
## If @var{n} is defined, then capture @var{n} events before returning.
## When @var{n} is not defined @code{ginput} will loop until the return key
## @key{RET} is pressed.
##
## The return values @var{x}, @var{y} are the coordinates where the mouse
## was clicked in the units of the current axes.  The return value @var{button}
## is 1, 2, or 3 for the left, middle, or right button.  If a key is pressed
## the ASCII value is returned in @var{button}.
##
## Implementation Note: @code{ginput} is intenteded for 2-D plots.  For 3-D
## plots see the @var{currentpoint} property of the current axes which can be
## transformed with knowledge of the current @code{view} into data units.
## @seealso{gtext, waitforbuttonpress}
## @end deftypefn
    
    
@function
def ginput(n=- 1,*args,**kwargs):
    varargin = ginput.varargin
    nargin = ginput.nargin

    if (nargin > 1):
        print_usage()
    
    ## Create an axis, if necessary.
    fig=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:47
    ax=gca()
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:48
    drawnow()
    if (isempty(ax)):
        error('ginput: must have at least one axes')
    
    toolkit=get(fig,'__graphics_toolkit__')
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:55
    toolkit_fcn=sprintf('__%s_ginput__',toolkit)
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:56
    if (exist(toolkit_fcn)):
        varargout=cell(1,nargout)
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:59
        if (nargin == 0):
            varargout[:]=feval(toolkit_fcn,fig)
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:61
        else:
            varargout[:]=feval(toolkit_fcn,fig,n)
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:63
        return varargout
    
    x=y=button=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:68
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:68
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:68
    ginput_accumulator(0,0,0,0)
    
    orig_windowbuttondownfcn=get(fig,'windowbuttondownfcn')
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:71
    orig_ginput_keypressfcn=get(fig,'keypressfcn')
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:72
    try:
        set(fig,'windowbuttondownfcn',ginput_windowbuttondownfcn)
        set(fig,'keypressfcn',ginput_keypressfcn)
        do
        if (strcmp(toolkit,'fltk')):
            __fltk_check__()
        ## Release CPU.
        sleep(0.01)
        x,y,n0,button=ginput_accumulator(- 1,0,0,0,nargout=4)
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:87
        until((n > - 1 and n0 >= n) or n0 < 0)
        if (n0 > n):
            ## More clicks than requested due to double-click or too fast clicking
            x=x[1:n]
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:92
            y=y[1:n]
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:93
            button=button[1:n]
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:94
    finally:
        set(fig,'windowbuttondownfcn',orig_windowbuttondownfcn)
        set(fig,'keypressfcn',orig_ginput_keypressfcn)
    
    varargout=cellarray([x,y,button])
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:102
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def ginput_accumulator(mode=None,xn=None,yn=None,btn=None,*args,**kwargs):
    varargin = ginput_accumulator.varargin
    nargin = ginput_accumulator.nargin

    
    if (mode == 0):
        ## Initialize.
        x=y=button=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:111
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:111
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:111
        n=0
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:112
    else:
        if (mode == 1):
            ## Append mouse button or key press.
            x=matlabarray(cat([x],[xn]))
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:115
            y=matlabarray(cat([y],[yn]))
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:116
            button=matlabarray(cat([button],[btn]))
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:117
            n += 1
        else:
            if (mode == 2):
                ## The end due to Enter.
                n=- 1
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:121
    
    return x,y,n,button
    
if __name__ == '__main__':
    pass
    
    
@function
def ginput_windowbuttondownfcn(src=None,button=None,*args,**kwargs):
    varargin = ginput_windowbuttondownfcn.varargin
    nargin = ginput_windowbuttondownfcn.nargin

    point=get(gca(),'currentpoint')
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:127
    ginput_accumulator(1,point[1,1],point[1,2],button)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def ginput_keypressfcn(src=None,evt=None,*args,**kwargs):
    varargin = ginput_keypressfcn.varargin
    nargin = ginput_keypressfcn.nargin

    point=get(gca(),'currentpoint')
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:132
    if (strcmp(evt.Key,'return')):
        ## Enter key stops ginput.
        ginput_accumulator(2,NaN,NaN,NaN)
    else:
        character=evt.Character
# /home/lei/octave-4.0.2/scripts/plot/util/ginput.m:137
        if (logical_not(isempty(character))):
            ginput_accumulator(1,point[1,1],point[1,2],uint8(character[1]))
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Remove from test statistics.  No real tests possible.
    
    ## Copyright (C) 2002-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} close
## @deftypefnx {Command} {} close (@var{h})
## @deftypefnx {Command} {} close @var{h}
## @deftypefnx {Command} {} close all
## @deftypefnx {Command} {} close all hidden
## @deftypefnx {Command} {} close all force
## Close figure window(s).
##
## When called with no arguments, close the current figure.  This is equivalent
## to @code{close (gcf)}.  If the input @var{h} is a graphic handle, or vector
## of graphics handles, then close each figure in @var{h}.
##
## If the argument @qcode{"all"} is given then all figures with visible handles
## (HandleVisibility = @qcode{"on"}) are closed.
##
## If the argument @qcode{"all hidden"} is given then all figures, including
## hidden ones, are closed.
##
## If the argument @qcode{"all force"} is given then all figures are closed
## even when @qcode{"closerequestfcn"} has been altered to prevent closing
## the window.
##
## Implementation Note: @code{close} operates by calling the function specified
## by the @qcode{"closerequestfcn"} property for each figure.  By default, the
## function @code{closereq} is used.  It is possible that the function invoked
## will delay or abort removing the figure.  To remove a figure without
## executing any callback functions use @code{delete}.  When writing a callback
## function to close a window do not use @code{close} to avoid recursion.
##
## @seealso{closereq, delete}
## @end deftypefn
    
    ## Author: jwe
## 2010-05-02   PBig    allow empty argument
    
    
@function
def close_(arg1=None,arg2=None,*args,**kwargs):
    varargin = close_.varargin
    nargin = close_.nargin

    figs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:57
    if (nargin > 2):
        print_usage()
    else:
        if (nargin == 0):
            ## Close current figure.
    ## Can't use gcf because it opens a new plot window if one does not exist.
            figs=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:64
            if (figs == 0):
                figs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:66
        else:
            if (nargin == 1):
                if (ischar(arg1) and strcmpi(arg1,'all')):
                    figs=(get(0,'children')).T
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:70
                    figs=figs[isfigure(figs)]
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:71
                else:
                    if (any(isfigure(arg1))):
                        figs=arg1[isfigure(arg1)]
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:73
                    else:
                        if (isempty(arg1)):
                            figs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:75
                        else:
                            error('close: first argument must be "all" or a figure handle')
            else:
                if (ischar(arg2) and (strcmpi(arg2,'hidden') or strcmpi(arg2,'force'))):
                    if (ischar(arg1) and strcmpi(arg1,'all')):
                        figs=(allchild(0)).T
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:82
                        figs=figs[isfigure(figs)]
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:83
                    else:
                        error('close: first argument must be "all" with "hidden" or "force"')
                    if (strcmpi(arg2,'force')):
                        delete(figs)
                        return retval
                else:
                    error('close: second argument must be "hidden" or "force"')
    
    for h in figs.reshape(-1):
        __go_execute_callback__(h,'closerequestfcn')
    
    if (nargout > 0):
        retval=1
# /home/lei/octave-4.0.2/scripts/plot/util/close.m:100
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 pdiribarne
##
## This file is part of Octave.
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hnew} =} copyobj (@var{horig})
## @deftypefnx {Function File} {@var{hnew} =} copyobj (@var{horig}, @var{hparent})
## Construct a copy of the graphic object associated with handle @var{horig}
## and return a handle @var{hnew} to the new object.
##
## If a parent handle @var{hparent} (root, figure, axes, or hggroup) is
## specified, the copied object will be created as a child of @var{hparent}.
## @seealso{struct2hdl, hdl2struct, findobj}
## @end deftypefn
    
    ## Author: pdiribarne <pdiribarne@new-host.home>
## Created: 2012-04-01
    
    
@function
def copyobj(horig=None,hparent=0,*args,**kwargs):
    varargin = copyobj.varargin
    nargin = copyobj.nargin

    partypes=cellarray(['root','figure','axes','hggroup'])
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:35
    othertypes=cellarray(['line','patch','surface','image','text'])
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:36
    alltypes=matlabarray(cat(partypes,othertypes))
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:37
    if (logical_not(ishandle(horig)) or nargin > 2):
        print_usage()
    else:
        if (logical_not(ishandle(hparent))):
            hparent=figure(fix(hparent))
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:42
        else:
            if (logical_not(any(strcmpi(get(hparent).type,partypes)))):
                print_usage()
    
    ## current figure and axes
    cf=gcf()
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:48
    ca=get(cf,'currentaxes')
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:49
    
    kididx=find(strcmp(alltypes,get(horig).type))
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:52
    paridx=find(strcmp(alltypes,get(hparent).type))
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:53
    if (kididx <= paridx):
        error('copyobj: %s object can\'t be children to %s.',alltypes[kididx],alltypes[paridx])
    else:
        if (nargin == 1):
            str=hdl2struct(horig)
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:59
            hnew=struct2hdl(str)
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:60
        else:
            str=hdl2struct(horig)
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:62
            hnew=struct2hdl(str,hparent)
# /home/lei/octave-4.0.2/scripts/plot/util/copyobj.m:63
    
    ## reset current figure (and eventually axes) to original
    set(0,'currentfigure',cf)
    if (ancestor(hnew,'figure') == cf and logical_not(isempty(ca))):
        set(cf,'currentaxes',ca)
    
    return hnew
    
if __name__ == '__main__':
    pass
    
    ## Absurd number of drawnow() function calls in demos is due to problem
## with FLTK backend which is not respecting the set ('position') call.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} print ()
## @deftypefnx {Function File} {} print (@var{options})
## @deftypefnx {Function File} {} print (@var{filename}, @var{options})
## @deftypefnx {Function File} {} print (@var{h}, @var{filename}, @var{options})
## Print a plot, or save it to a file.
##
## Both output formatted for printing (PDF and PostScript), and many bitmapped
## and vector image formats are supported.
##
## @var{filename} defines the name of the output file.  If the file name has
## no suffix, one is inferred from the specified device and appended to the
## file name.  If no filename is specified, the output is sent to the
## printer.
##
## @var{h} specifies the handle of the figure to print.  If no handle is
## specified the current figure is used.
##
## For output to a printer, PostScript file, or PDF file, the paper size is
## specified by the figure's @code{papersize} property.  The location and
## size of the image on the page are specified by the figure's
## @code{paperposition} property.  The orientation of the page is specified
## by the figure's @code{paperorientation} property.
##
## The width and height of images are specified by the figure's
## @code{paperpositon(3:4)} property values.
##
## The @code{print} command supports many @var{options}:
##
## @table @code
## @item -f@var{h}
##   Specify the handle, @var{h}, of the figure to be printed.  The default
## is the current figure.
##
## @item -P@var{printer}
##   Set the @var{printer} name to which the plot is sent if no
## @var{filename} is specified.
##
## @item -G@var{ghostscript_command}
##   Specify the command for calling Ghostscript.  For Unix and Windows the
## defaults are @qcode{"gs"} and @qcode{"gswin32c"}, respectively.
##
## @item  -color
## @itemx -mono
##   Color or monochrome output.
##
## @item  -solid
## @itemx -dashed
##   Force all lines to be solid or dashed, respectively.
##
## @item  -portrait
## @itemx -landscape
##   Specify the orientation of the plot for printed output.
## For non-printed output the aspect ratio of the output corresponds to the
## plot area defined by the @qcode{"paperposition"} property in the
## orientation specified.  This option is equivalent to changing the figure's
## @qcode{"paperorientation"} property.
##
## @item  -TextAlphaBits=@var{n}
## @itemx -GraphicsAlphaBits=@var{n}
##   Octave is able to produce output for various printers, bitmaps, and
## vector formats by using Ghostscript.  For bitmap and printer output
## anti-aliasing is applied using Ghostscript's TextAlphaBits and
## GraphicsAlphaBits options.  The default number of bits for each is 4.
## Allowed values for @var{N} are 1, 2, or 4.
##
## @item -d@var{device}
##   The available output format is specified by the option @var{device}, and
## is one of:
##
##   @table @code
##   @item  ps
##   @itemx ps2
##   @itemx psc
##   @itemx psc2
##     PostScript (level 1 and 2, mono and color).  The FLTK graphics
## toolkit generates PostScript level 3.0.
##
##   @item  eps
##   @itemx eps2
##   @itemx epsc
##   @itemx epsc2
##     Encapsulated PostScript (level 1 and 2, mono and color).  The FLTK
## graphic toolkit generates PostScript level 3.0.
##
##   @item  pslatex
##   @itemx epslatex
##   @itemx pdflatex
##   @itemx pslatexstandalone
##   @itemx epslatexstandalone
##   @itemx pdflatexstandalone
##     Generate a @LaTeX{} file @file{@var{filename}.tex} for the text
## portions of a plot and a file @file{@var{filename}.(ps|eps|pdf)} for the
## remaining graphics.  The graphics file suffix .ps|eps|pdf is determined
## by the specified device type.  The @LaTeX{} file produced by the
## @samp{standalone} option can be processed directly by @LaTeX{}.  The file
## generated without the @samp{standalone} option is intended to be included
## from another @LaTeX{} document.  In either case, the @LaTeX{} file
## contains an @code{\includegraphics} command so that the generated graphics
## file is automatically included when the @LaTeX{} file is processed.  The
## text that is written to the @LaTeX{} file contains the strings
## @strong{exactly} as they were specified in the plot.  If any special
## characters of the @TeX{} mode interpreter were used, the file must be
## edited before @LaTeX{} processing.  Specifically, the special characters
## must be enclosed with dollar signs (@code{$ @dots{} $}), and other
## characters that are recognized by @LaTeX{} may also need editing (.e.g.,
## braces).  The @samp{pdflatex} device, and any of the @samp{standalone}
## formats, are not available with the Gnuplot toolkit.
##
##   @item tikz
##     Generate a @LaTeX{} file using PGF/TikZ@.  For the FLTK toolkit
## the result is PGF.
##
##   @item  ill
##   @itemx aifm
##     Adobe Illustrator (Obsolete for Gnuplot versions > 4.2)
##
##   @item  cdr
##   @itemx @nospell{corel}
##     CorelDraw
##
##   @item dxf
##     AutoCAD
##
##   @item  emf
##   @itemx meta
##     Microsoft Enhanced Metafile
##
##   @item fig
##     XFig.  For the Gnuplot graphics toolkit, the additional options
## @option{-textspecial} or @option{-textnormal} can be used to control whether the special flag should be set for the text in the figure.  (default is @option{-textnormal})
##
##   @item hpgl
##     HP plotter language
##
##   @item mf
##     Metafont
##
##   @item png
##     Portable network graphics
##
##   @item  jpg
##   @itemx jpeg
##     JPEG image
##
##   @item gif
##     GIF image (only available for the Gnuplot graphics toolkit)
##
##   @item pbm
##     PBMplus
##
##   @item svg
##     Scalable vector graphics
##
##   @item pdf
##     Portable document format
##   @end table
##
##   If the device is omitted, it is inferred from the file extension,
## or if there is no filename it is sent to the printer as PostScript.
##
## @item -d@var{ghostscript_device}
##   Additional devices are supported by Ghostscript.
## Some examples are;
##
##   @table @code
##   @item pdfwrite
##     Produces pdf output from eps
##
##   @item ljet2p
##     HP LaserJet @nospell{IIP}
##
##   @item pcx24b
##     24-bit color PCX file format
##
##   @item ppm
##     Portable Pixel Map file format
##   @end table
##
##   For a complete list, type @code{system ("gs -h")} to see what formats
## and devices are available.
##
##   When Ghostscript output is sent to a printer the size is determined by
## the figure's @qcode{"papersize"} property.  When the output is sent to a
## file the size is determined by the plot box defined by the figure's
## @qcode{"paperposition"} property.
##
## @item -append
##   Append PostScript or PDF output to a pre-existing file of the same type.
##
## @item -r@var{NUM}
##   Resolution of bitmaps in pixels per inch.  For both metafiles and SVG
## the default is the screen resolution; for other formats it is 150 dpi.  To
## specify screen resolution, use @qcode{"-r0"}.
##
## @item  -loose
## @itemx -tight
##   Force a tight or loose bounding box for eps files.  The default is loose.
##
## @item -@var{preview}
##   Add a preview to eps files.  Supported formats are:
##
##   @table @code
##   @item -interchange
##     Provide an interchange preview.
##
##   @item -metafile
##     Provide a metafile preview.
##
##   @item -pict
##     Provide pict preview.
##
##   @item -tiff
##     Provide a tiff preview.
##   @end table
##
## @item -S@var{xsize},@var{ysize}
##   Plot size in pixels for EMF, GIF, JPEG, PBM, PNG, and SVG@.
## For PS, EPS, PDF, and other vector formats the plot size is in points.
## This option is equivalent to changing the size of the plot box associated
## with the @qcode{"paperposition"} property.  When using the command form of
## the print function you must quote the @var{xsize},@var{ysize} option.  For
## example, by writing @w{"-S640,480"}.
##
## @item  -F@var{fontname}
## @itemx -F@var{fontname}:@var{size}
## @itemx -F:@var{size}
##   Use @var{fontname} and/or @var{fontsize} for all text.
## @var{fontname} is ignored for some devices: dxf, fig, hpgl, etc.
## @end table
##
## The filename and options can be given in any order.
##
## Example: Print to a file using the pdf device.
##
## @example
## @group
## figure (1);
## clf ();
## surf (peaks);
## print figure1.pdf
## @end group
## @end example
##
## Example: Print to a file using jpg device.
##
## @example
## @group
## clf ();
## surf (peaks);
## print -djpg figure2.jpg
## @end group
## @end example
##
## Example: Print to printer named PS_printer using ps format.
##
## @example
## @group
## clf ();
## surf (peaks);
## print -dpswrite -PPS_printer
## @end group
## @end example
##
## @seealso{saveas, hgsave, orient, figure}
## @end deftypefn
    
    
@function
def print_(varargin=None,*args,**kwargs):
    varargin = print_.varargin
    nargin = print_.nargin

    opts=__print_parse_opts__(varargin[:])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:288
    opts.pstoedit_cmd = copy(pstoedit)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:290
    opts.fig2dev_cmd = copy(fig2dev)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:291
    opts.latex_standalone = copy(latex_standalone)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:292
    opts.lpr_cmd = copy(lpr)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:293
    opts.epstool_cmd = copy(epstool)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:294
    if (isempty(opts.figure) or logical_not(isfigure(opts.figure))):
        error('print: no figure to print')
    
    if (isempty(findall(opts.figure,'-depth','1','type','axes'))):
        error('print: no axes object in figure to print')
    
    orig_figure=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:304
    set(0,'currentfigure',opts.figure)
    if (opts.append_to_file):
        __,__,ext=fileparts(opts.ghostscript.output,nargout=3)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:308
        opts.ghostscript.prepend = copy(cat(tempname(),ext))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:309
        copyfile(opts.ghostscript.output,opts.ghostscript.prepend)
    
    try:
        ## Modify properties as specified by options
        props=matlabarray([])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:316
        drawnow()
        props[1].h = copy(opts.figure)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:321
        props[1].name = copy('units')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:322
        props[1].value = copy(cellarray([get(opts.figure,'units')]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:323
        set(opts.figure,'units','pixels')
        fpos=get(opts.figure,'position')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:327
        props[2].h = copy(opts.figure)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:328
        props[2].name = copy('position')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:329
        props[2].value = copy(cellarray([fpos]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:330
        fpos[3:4]=opts.canvas_size
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:331
        set(opts.figure,'position',fpos)
        ## This is done both for consistency with Matlab and to eliminate
    ## the visible box along the figure's perimeter.
        props[3].h = copy(opts.figure)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:337
        props[3].name = copy('color')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:338
        props[3].value[1]=get(props[3].h,props[3].name)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:339
        set(props[3].h,'color','none')
        if (opts.force_solid != 0):
            h=findall(opts.figure,'-property','linestyle')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:343
            m=numel(props)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:344
            for n in arange(1,numel(h)).reshape(-1):
                props[m + n].h = copy(h[n])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:346
                props[m + n].name = copy('linestyle')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:347
                props[m + n].value = copy(cellarray([get(h[n],'linestyle')]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:348
            if (opts.force_solid > 0):
                linestyle='-'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:351
            else:
                linestyle='--'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:353
            set(h,'linestyle',linestyle)
        if (opts.use_color < 0 and logical_not(strcmp(get(opts.figure,'__graphics_toolkit__'),'gnuplot'))):
            color_props=cellarray(['color','facecolor','edgecolor','colormap'])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:360
            for c in arange(1,numel(color_props)).reshape(-1):
                h=findall(opts.figure,'-property',color_props[c])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:362
                hnone=findall(opts.figure,color_props[c],'none')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:363
                h=setdiff(h,hnone)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:364
                m=numel(props)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:365
                for n in arange(1,numel(h)).reshape(-1):
                    if (ishandle(h[n])):
                        ## Need to verify objects exist since callbacks may delete objects
            ## as the colors for others are modified.
                        rgb=get(h[n],color_props[c])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:370
                        props[end() + 1].h = copy(h[n])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:371
                        props[end()].name = copy(color_props[c])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:372
                        props[end()].value = copy(cellarray([get(h[n],color_props[c])]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:373
                        if (isnumeric(rgb)):
                            ## convert RGB color to RGB gray scale
                            xfer=repmat(cat(0.3,0.59,0.11),rows(rgb),1)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:376
                            ggg=repmat(sum(multiply(xfer,rgb),2),1,3)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:377
                            set(h[n],color_props[c],ggg)
        if (logical_not(isempty(opts.font)) or logical_not(isempty(opts.fontsize))):
            h=findall(opts.figure,'-property','fontname')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:386
            m=numel(props)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:387
            for n in arange(1,numel(h)).reshape(-1):
                if (ishandle(h[n])):
                    if (logical_not(isempty(opts.font))):
                        props[end() + 1].h = copy(h[n])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:391
                        props[end()].name = copy('fontname')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:392
                        props[end()].value = copy(cellarray([get(h[n],'fontname')]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:393
                if (ishandle(h[n])):
                    if (logical_not(isempty(opts.fontsize))):
                        props[end() + 1].h = copy(h[n])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:398
                        props[end()].name = copy('fontsize')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:399
                        props[end()].value = copy(cellarray([get(h[n],'fontsize')]))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:400
            if (logical_not(isempty(opts.font))):
                set(h[ishandle(h)],'fontname',opts.font)
            if (logical_not(isempty(opts.fontsize))):
                if (ischar(opts.fontsize)):
                    fontsize=str2double(opts.fontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:409
                else:
                    fontsize=opts.fontsize
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:411
                if (logical_not(isempty(opts.scalefontsize)) and logical_not(opts.scalefontsize) != 1):
                    ## This is done to work around the bbox being whole numbers.
                    fontsize=dot(fontsize,opts.scalefontsize)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:415
                ## FIXME: legend child objects need to be acted on first.
        ##        or legend fontsize callback will destroy them.
                hlist=h[ishandle(h)]
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:419
                haxes=strcmp(get(hlist,'type'),'axes')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:420
                set(hlist[logical_not(haxes)],'fontsize',fontsize)
                set(hlist[haxes],'fontsize',fontsize)
        ## call the graphics toolkit print script
        if 'gnuplot' == (get(opts.figure,'__graphics_toolkit__')):
            opts=__gnuplot_print__(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:429
        else:
            opts=__opengl_print__(opts)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:431
    finally:
        ## restore modified properties
        if (isstruct(props)):
            ## Restore figure position and units first
            for n in arange(2,1,- 1).reshape(-1):
                if (ishandle(props(n).h)):
                    set(props(n).h,props(n).name,props(n).value[1])
            for n in arange(numel(props),3,- 1).reshape(-1):
                if (ishandle(props(n).h)):
                    set(props(n).h,props(n).name,props(n).value[1])
        ## Unlink temporary files
        for n in arange(1,numel(opts.unlink)).reshape(-1):
            status,output=unlink(opts.unlink[n],nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:452
            if (status != 0):
                warning('print.m: %s, \'%s\'',output,opts.unlink[n])
    
    if (isfigure(orig_figure)):
        set(0,'currentfigure',orig_figure)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def epstool(opts=None,filein=None,fileout=None,*args,**kwargs):
    varargin = epstool.varargin
    nargin = epstool.nargin

    ## As epstool does not work with pipes, a subshell is used to
  ## permit piping. Since this solution does not work with the DOS
  ## command shell, the -tight and -preview options are disabled if
  ## output must be piped.
    
    ## DOS Shell:
  ##   gs.exe [...] -sOutputFile=<filein> - & epstool -bbox -preview-tiff <filein> <fileout> & del <filein>
  ## Unix Shell;
  ##   cat > <filein> ; epstool -bbox -preview-tiff <filein> <fileout> ; rm <filein>
    
    ## HACK: Keep track of whether ghostscript supports epswrite or eps2write.
    
    if (isempty(epsdevice)):
        status,devlist=system(sprintf('%s -h',opts.ghostscript.binary),nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:479
        if (isempty(strfind(devlist,'eps2write'))):
            epsdevice='epswrite'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:481
        else:
            epsdevice='eps2write'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:483
    
    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:487
    cleanup=''
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:489
    if (nargin < 3):
        fileout=opts.name
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:491
    else:
        if (isempty(fileout)):
            fileout='-'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:493
    
    if (nargin < 2 or strcmp(filein,'-') or isempty(filein)):
        pipein=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:497
        filein=matlabarray(cat(tempname(),'.eps'))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:498
        if (dos_shell):
            cleanup=sprintf('& del %s ',strrep(filein,'/','\\'))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:500
        else:
            cleanup=sprintf('; rm %s ',filein)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:502
    else:
        pipein=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:505
        filein=strcat('\'',strtrim(filein),'\'')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:506
    
    if (strcmp(fileout,'-')):
        pipeout=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:509
        fileout=matlabarray(cat(tempname(),'.eps'))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:510
        if (dos_shell):
            cleanup=matlabarray(cat(cleanup,sprintf('& del %s ',strrep(fileout,'/','\\'))))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:512
        else:
            cleanup=matlabarray(cat(cleanup,sprintf('; rm %s ',fileout)))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:514
    else:
        pipeout=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:517
        fileout=strcat('\'',strtrim(fileout),'\'')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:518
    
    if (logical_not(isempty(opts.preview)) and opts.tight_flag):
        warning('print:previewandtight','print.m: eps preview may not be combined with -tight')
    
    if (logical_not(isempty(opts.preview)) or opts.tight_flag):
        if (logical_not(isempty(opts.epstool_binary))):
            if (opts.tight_flag):
                cmd='--copy --bbox'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:528
            else:
                if (logical_not(isempty(opts.preview))):
                    if 'tiff' == (opts.preview):
                        cmd=sprintf('--add-%s-preview --device tiffg3',opts.preview)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:532
                    else:
                        if cellarray(['tiff6u','tiff6p','metafile']) == (opts.preview):
                            cmd=sprintf('--add-%s-preview --device bmpgray',opts.preview)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:534
                        else:
                            if cellarray(['tiff4','interchange']) == (opts.preview):
                                cmd=sprintf('--add-%s-preview',opts.preview)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:536
                            else:
                                if 'pict' == (opts.preview):
                                    cmd=sprintf('--add-%s-preview --mac-single',opts.preview)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:538
                                else:
                                    error('print:invalidpreview','print.m: epstool cannot include preview for format \'%s\'',opts.preview)
                    if (logical_not(isempty(opts.ghostscript.resolution))):
                        cmd=sprintf('%s --dpi %d',cmd,fix(opts.ghostscript.resolution))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:545
                else:
                    cmd=''
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:548
            if (logical_not(isempty(cmd))):
                cmd=sprintf('%s --quiet %s %s %s ',opts.epstool_binary,cmd,filein,fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:551
            if (pipein):
                if (dos_shell):
                    filein[filein == '\'']='"'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:556
                    gs_cmd=__ghostscript__('binary',opts.ghostscript.binary,'device',epsdevice,'source','-','output',filein)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:557
                    cmd=sprintf('%s %s & %s',gs_cmd,filein,cmd)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:561
                else:
                    cmd=sprintf('cat > %s ; %s',filein,cmd)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:563
            if (pipeout):
                if (dos_shell):
                    cmd=sprintf('%s & type %s',cmd,fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:568
                else:
                    cmd=sprintf('%s ; cat %s',cmd,fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:570
            if (logical_not(isempty(cleanup))):
                if (pipeout and dos_shell):
                    error('print:epstoolpipe','print.m: cannot pipe output of \'epstool\' for DOS shell')
                else:
                    if (pipeout):
                        cmd=sprintf('( %s %s )',cmd,cleanup)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:578
                    else:
                        cmd=sprintf('%s %s',cmd,cleanup)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:580
        else:
            if (isempty(opts.epstool_binary)):
                error('print:noepstool','print.m: \'epstool\' not found in PATH')
    else:
        if (pipein and pipeout):
            if (dos_shell):
                cmd=__ghostscript__('binary',opts.ghostscript.binary,'device',epsdevice,'source','-','output','-')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:589
            else:
                cmd=' cat '
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:594
        else:
            if (pipein and logical_not(pipeout)):
                if (dos_shell):
                    ## ghostscript expects double, not single, quotes
                    fileout[fileout == '\'']='"'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:599
                    cmd=__ghostscript__('binary',opts.ghostscript.binary,'device',epsdevice,'source','-','output',fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:600
                else:
                    cmd=sprintf(' cat > %s ',fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:605
            else:
                if (logical_not(pipein) and pipeout):
                    if (dos_shell):
                        cmd=sprintf(' type %s ',filein)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:609
                    else:
                        cmd=sprintf(' cat %s ',filein)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:611
                else:
                    if (dos_shell):
                        cmd=sprintf(' copy %s %s ',filein,fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:615
                    else:
                        cmd=sprintf(' cp %s %s ',filein,fileout)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:617
    
    if (opts.debug):
        fprintf('epstool command: \'%s\'\n',cmd)
    
    return cmd
    
if __name__ == '__main__':
    pass
    
    
@function
def fig2dev(opts=None,devopt=None,*args,**kwargs):
    varargin = fig2dev.varargin
    nargin = fig2dev.nargin

    if (nargin < 2):
        devopt=opts.devopt
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:628
    
    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:630
    if (logical_not(isempty(opts.fig2dev_binary))):
        if (dos_shell):
            ## FIXME: Is this the right thing to do for DOS?
            cmd=sprintf('%s -L %s 2> NUL',opts.fig2dev_binary,devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:634
        else:
            cmd=sprintf('%s -L %s 2> /dev/null',opts.fig2dev_binary,devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:636
    else:
        if (isempty(opts.fig2dev_binary)):
            error('print:nofig2dev','print.m: \'fig2dev\' not found in PATH')
    
    if (opts.debug):
        fprintf('fig2dev command: \'%s\'\n',cmd)
    
    return cmd
    
if __name__ == '__main__':
    pass
    
    
@function
def latex_standalone(opts=None,*args,**kwargs):
    varargin = latex_standalone.varargin
    nargin = latex_standalone.nargin

    n=find(opts.name == '.',1,'last')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:647
    if (logical_not(isempty(n))):
        opts.name = copy(opts.name(arange(1,n - 1)))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:649
    
    latexfile=strcat(opts.name,'.tex')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:651
    if cellarray(['pdflatexstandalone']) == (opts.devopt):
        packages='\\usepackage{graphicx,color}'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:654
        graphicsfile=strcat(opts.name,'-inc.pdf')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:655
    else:
        if cellarray(['pslatexstandalone']) == (opts.devopt):
            packages='\\usepackage{epsfig,color}'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:657
            graphicsfile=strcat(opts.name,'-inc.ps')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:658
        else:
            packages='\\usepackage{epsfig,color}'
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:660
            graphicsfile=strcat(opts.name,'-inc.eps')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:661
    
    papersize=sprintf('\\usepackage[papersize={%.2fbp,%.2fbp},text={%.2fbp,%.2fbp}]{geometry}',fix(opts.canvas_size),fix(opts.canvas_size))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:663
    prepend=cellarray([['\\documentclass{minimal}'],[packages],[papersize],['\\begin{document}'],['\\centering']])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:665
    postpend=cellarray(['\\end{document}'])
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:670
    fid=fopen(latexfile,'r')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:671
    if (fid >= 0):
        latex=fscanf(fid,'%c',Inf)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:673
        status=fclose(fid)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:674
        if (status != 0):
            error('print:errorclosingfile','print.m: error closing file \'%s\'',latexfile)
        ## TODO - should this be fixed in GL2PS?
        latex=strrep(latex,'\\includegraphics{}',sprintf('\\includegraphics{%s}',graphicsfile))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:680
    else:
        error('print:erroropeningfile','print.m: error opening file \'%s\'',latexfile)
    
    fid=fopen(latexfile,'w')
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:686
    if (fid >= 0):
        fprintf(fid,'%s\n',prepend[:])
        fprintf(fid,'%s',latex)
        fprintf(fid,'%s\n',postpend[:])
        status=fclose(fid)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:691
        if (status != 0):
            error('print:errorclosingfile','print.m: error closing file \'%s\'',latexfile)
    else:
        error('print:erroropeningfile','print.m: error opening file \'%s\'',latexfile)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def lpr(opts=None,*args,**kwargs):
    varargin = lpr.varargin
    nargin = lpr.nargin

    if (nargin < 2):
        devopt=opts.devopt
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:704
    
    if (logical_not(isempty(opts.lpr_binary))):
        cmd=opts.lpr_binary
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:707
        if (logical_not(isempty(opts.lpr_options))):
            cmd=sprintf('%s %s',cmd,opts.lpr_options)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:709
        if (logical_not(isempty(opts.printer))):
            cmd=sprintf('%s %s',cmd,opts.printer)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:712
    else:
        if (isempty(opts.lpr_binary)):
            error('print:nolpr','print.m: \'lpr\' not found in PATH')
    
    if (opts.debug):
        fprintf('lpr command: \'%s\'\n',cmd)
    
    return cmd
    
if __name__ == '__main__':
    pass
    
    
@function
def pstoedit(opts=None,devopt=None,*args,**kwargs):
    varargin = pstoedit.varargin
    nargin = pstoedit.nargin

    if (nargin < 2):
        devopt=opts.devopt
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:724
    
    dos_shell=(ispc() and logical_not(isunix()))
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:726
    if (logical_not(isempty(opts.pstoedit_binary))):
        if (dos_shell):
            cmd=sprintf('%s -f %s 2> NUL',opts.pstoedit_binary,devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:729
        else:
            ## FIXME: Is this the right thing to do for DOS?
            cmd=sprintf('%s -f %s 2> /dev/null',opts.pstoedit_binary,devopt)
# /home/lei/octave-4.0.2/scripts/plot/util/print.m:732
    else:
        if (isempty(opts.pstoedit_binary)):
            error('print:nopstoedit','print.m: \'pstoedit\' not found in PATH')
    
    if (opts.debug):
        fprintf('pstoedit command: \'%s\'\n',cmd)
    
    return cmd
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __pltopt__ (@var{caller}, @var{opt})
## Undocumented internal function.
## @end deftypefn
    
    ## @deftypefn {Function File} {} __pltopt__ (@var{caller}, @var{opt})
##
## Decode plot option strings.
##
## @var{opt} can currently be some combination of the following:
##
## @table @code
## @item "-"
## For solid linestyle (default).
##
## @item "--"
## For dashed line style.
##
## @item "-."
## For linespoints plot style.
##
## @item ":"
## For dots plot style.
##
## @item "r"
## Red line color.
##
## @item "g"
## Green line color.
##
## @item "b"
## Blue line color.
##
## @item "c"
## Cyan line color.
##
## @item "m"
## Magenta line color.
##
## @item "y"
## Yellow line color.
##
## @item "k"
## Black line color.
##
## @item "w"
## White line color.
##
## @item ";title;"
## Here @code{"title"} is the label for the key.
##
## @item "+"
## @itemx "o"
## @itemx "*"
## @itemx "."
## @itemx "x"
## @itemx "s"
## @itemx "d"
## @itemx "^"
## @itemx "v"
## @itemx ">"
## @itemx "<"
## @itemx "p"
## @itemx "h"
## Used in combination with the points or linespoints styles, set the point
## style.
## @end table
##
## The legend may be fixed to include the name of the variable
## plotted in some future version of Octave.
    
    ## Author: jwe
    
    
@function
def __pltopt__(caller=None,opt=None,err_on_invalid=true,*args,**kwargs):
    varargin = __pltopt__.varargin
    nargin = __pltopt__.nargin

    options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:94
    valid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:95
    if (ischar(opt)):
        opt=cellstr(opt)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:98
    else:
        if (logical_not(iscellstr(opt))):
            error('__pltopt__: argument must be a character string or cell array of character strings')
    
    nel=numel(opt)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:103
    for i in arange(nel,1,- 1).reshape(-1):
        options[i],valid=__pltopt1__(caller,opt[i],err_on_invalid,nargout=2)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:106
        if (logical_not(err_on_invalid) and logical_not(valid)):
            return options,valid
    
    return options,valid
    
if __name__ == '__main__':
    pass
    
    ## Really decode plot option strings.
    
    ## Author: Rick Niles <niles@axp745.gsfc.nasa.gov>
## Adapted-By: jwe
## Maintainer: jwe
    
    
@function
def __pltopt1__(caller=None,opt=None,err_on_invalid=None,*args,**kwargs):
    varargin = __pltopt1__.varargin
    nargin = __pltopt1__.nargin

    options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:122
    valid=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:123
    have_linestyle=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:125
    have_marker=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:126
    
    if (strcmp(caller,'__errplot__')):
        if (strncmp(opt,'#~>',3)):
            n=3
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:131
        else:
            if (strncmp(opt,'#~',2) or strncmp(opt,'~>',2)):
                n=2
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:133
            else:
                if (strncmp(opt,'~',1) or strncmp(opt,'>',1) or strncmp(opt,'#',1)):
                    n=1
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:136
                else:
                    n=0
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:138
        options.errorstyle = copy(opt[1:n])
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:140
        opt[1:n]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:141
    else:
        options.errorstyle = copy('~')
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:143
    
    while (logical_not(isempty(opt))):

        if (strncmp(opt,'--',2) or strncmp(opt,'-.',2)):
            options.linestyle = copy(opt[1:2])
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:148
            have_linestyle=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:149
            n=2
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:150
        else:
            topt=opt[1]
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:152
            n=1
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:153
            if (topt == '-' or topt == ':'):
                have_linestyle=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:155
                options.linestyle = copy(topt)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:156
            else:
                if (topt == '+' or topt == 'o' or topt == '*' or topt == '.' or topt == 'x' or topt == 's' or topt == 'd' or topt == '^' or topt == 'v' or topt == '>' or topt == '<' or topt == 'p' or topt == 'h' or topt == '@'):
                    have_marker=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:162
                    if (any(topt == 'sdhp')):
                        if (strncmp(opt,'square',6)):
                            n=6
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:166
                        else:
                            if (strncmp(opt,'diamond',7)):
                                n=7
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:168
                            else:
                                if (strncmp(opt,'hexagram',8)):
                                    n=8
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:170
                                else:
                                    if (strncmp(opt,'pentagram',9)):
                                        n=9
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:172
                    ## Backward compatibility.  Leave undocumented.
                    if (topt == '@'):
                        topt='+'
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:177
                    options.marker = copy(topt)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:179
                else:
                    if (topt == 'k' or topt == '0'):
                        options.color = copy(cat(0,0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:182
                    else:
                        if (topt == 'r' or topt == '1'):
                            options.color = copy(cat(1,0,0))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:184
                        else:
                            if (topt == 'g' or topt == '2'):
                                options.color = copy(cat(0,1,0))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:186
                            else:
                                if (topt == 'b' or topt == '3'):
                                    options.color = copy(cat(0,0,1))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:188
                                else:
                                    if (topt == 'y'):
                                        options.color = copy(cat(1,1,0))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:190
                                    else:
                                        if (topt == 'm' or topt == '4'):
                                            options.color = copy(cat(1,0,1))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:192
                                        else:
                                            if (topt == 'c' or topt == '5'):
                                                options.color = copy(cat(0,1,1))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:194
                                            else:
                                                if (topt == 'w' or topt == '6'):
                                                    options.color = copy(cat(1,1,1))
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:196
                                                else:
                                                    if (isspace(topt)):
                                                        ## Do nothing.
                                                        pass
                                                    else:
                                                        if (topt == ';'):
                                                            t=index(opt[2:end()],';')
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:200
                                                            if (t):
                                                                options.key = copy(opt[2:t])
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:202
                                                                n=t + 1
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:203
                                                            else:
                                                                if (err_on_invalid):
                                                                    error('%s: unfinished key label',caller)
                                                                else:
                                                                    valid=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:208
                                                                    options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:209
                                                                    return options,valid
                                                        else:
                                                            if (err_on_invalid):
                                                                error('%s: unrecognized format character: \'%s\'',caller,topt)
                                                            else:
                                                                valid=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:217
                                                                options=__default_plot_options__()
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:218
                                                                return options,valid
        opt[1:n]=[]
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:223

    
    if (logical_not(have_linestyle) and have_marker):
        options.linestyle = copy('none')
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:227
    
    if (have_linestyle and logical_not(have_marker)):
        options.marker = copy('none')
# /home/lei/octave-4.0.2/scripts/plot/util/__pltopt__.m:231
    
    return options,valid
    
if __name__ == '__main__':
    pass
    
    ## Only cursory testing.  Real testing done by appearance of plots.
#test
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} clf
## @deftypefnx {Command} {} clf reset
## @deftypefnx {Function File} {} clf (@var{hfig})
## @deftypefnx {Function File} {} clf (@var{hfig}, "reset")
## @deftypefnx {Function File} {@var{h} =} clf (@dots{})
## Clear the current figure window.
##
## @code{clf} operates by deleting child graphics objects with visible
## handles (HandleVisibility = @qcode{"on"}).
##
## If the optional argument @qcode{"reset"} is specified, delete all child
## objects including those with hidden handles and reset all figure
## properties to their defaults.  However, the following properties are not
## reset: Position, Units, PaperPosition, PaperUnits.
##
## If the first argument @var{hfig} is a figure handle, then operate on
## this figure rather than the current figure returned by @code{gcf}.
##
## The optional return value @var{h} is the graphics handle of the figure
## window that was cleared.
## @seealso{cla, close, delete, reset}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def clf(varargin=None,*args,**kwargs):
    varargin = clf.varargin
    nargin = clf.nargin

    if (nargin > 2):
        print_usage()
    else:
        if (nargin == 0):
            hfig=copy(gcf)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:50
            do_reset=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:51
        else:
            if (nargin == 1):
                if (isscalar(varargin[1]) and isfigure(varargin[1])):
                    hfig=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:54
                    do_reset=copy(false)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:55
                else:
                    if (ischar(varargin[1]) and strcmpi(varargin[1],'reset')):
                        hfig=copy(gcf)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:57
                        do_reset=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:58
                    else:
                        print_usage()
            else:
                if (isscalar(varargin[1]) and isfigure(varargin[1]) and ischar(varargin[2]) and strcmpi(varargin[2],'reset')):
                    hfig=varargin[1]
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:65
                    do_reset=copy(true)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:66
                else:
                    print_usage()
    
    if (do_reset):
        ## Select all the children, including the one with hidden handles.
        delete(allchild(hfig))
        reset(hfig)
    else:
        ## Select only the chilren with visible handles.
        delete(get(hfig,'children'))
        hover=findall(hfig,'-depth',1,'tag','scribeoverlay')
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:81
        delete(hover)
    
    if (nargout > 0):
        h=copy(hfig)
# /home/lei/octave-4.0.2/scripts/plot/util/clf.m:86
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __run_test_suite__ (@var{fcndirs}, @var{fixedtestdirs})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __run_test_suite__(fcndirs=None,fixedtestdirs=None,*args,**kwargs):
    varargin = __run_test_suite__.varargin
    nargin = __run_test_suite__.nargin

    testsdir=octave_config_info('octtestsdir')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:25
    libinterptestdir=fullfile(testsdir,'libinterp')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:26
    liboctavetestdir=fullfile(testsdir,'liboctave')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:27
    fixedtestdir=fullfile(testsdir,'fixed')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:28
    fcnfiledir=octave_config_info('fcnfiledir')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:29
    if (nargin == 0):
        fcndirs=cellarray([liboctavetestdir,libinterptestdir,fcnfiledir])
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:31
        fixedtestdirs=cellarray([fixedtestdir])
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:32
    
    global files_with_no_tests
    global files_with_tests
    files_with_no_tests=cellarray([])
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:36
    files_with_tests=cellarray([])
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:37
    
    ##        tests for an installed copy of Octave.
    global topsrcdir
    global topbuilddir
    pso=page_screen_output()
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:42
    orig_wstate=warning()
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:43
    logfile=make_absolute_filename('fntests.log')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:44
    try:
        page_screen_output(false)
        warning('on','quiet')
        warning('off','Octave:deprecated-function')
        try:
            fid=fopen(logfile,'wt')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:50
            if (fid < 0):
                error('could not open %s for writing',logfile)
            test('','explain',fid)
            dp=dn=dxf=dsk=0
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:55
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:55
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:55
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:55
            puts('\nIntegrated test scripts:\n\n')
            for i in arange(1,length(fcndirs)).reshape(-1):
                p,n,xf,sk=run_test_script(fid,fcndirs[i],nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:58
                dp += p
                dn += n
                dxf += xf
                dsk += sk
            puts('\nFixed test scripts:\n\n')
            for i in arange(1,length(fixedtestdirs)).reshape(-1):
                p,n,xf,sk=run_test_dir(fid,fixedtestdirs[i],nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:66
                dp += p
                dn += n
                dxf += xf
                dsk += sk
            puts('\nSummary:\n\n')
            nfail=dn - dp - dxf
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:73
            printf('  PASS    %6d\n',dp)
            printf('  FAIL    %6d\n',nfail)
            if (dxf > 0):
                printf('  XFAIL   %6d\n',dxf)
            if (dsk > 0):
                printf('  SKIPPED %6d\n',dsk)
            puts('\n')
            printf('See the file %s for additional details.\n',logfile)
            if (dxf > 0):
                puts('\n')
                puts('Expected failures (listed as XFAIL above) are known bugs.\n')
                puts('Please help improve Octave by contributing fixes for them.\n')
            if (dsk > 0):
                puts('\n')
                puts('Tests are most often skipped because the features they require\n')
                puts('have been disabled.  Features are most often disabled because\n')
                puts('they require dependencies that were not present when Octave\n')
                puts('was built.  The configure script should have printed a summary\n')
                puts('at the end of its run indicating which dependencies were not found.\n')
            ## Weed out deprecated and private functions
            weed_idx=cellfun(isempty,regexp(files_with_tests,'\\<deprecated\\>|\\<private\\>','once'))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:99
            files_with_tests=files_with_tests[weed_idx]
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:100
            weed_idx=cellfun(isempty,regexp(files_with_no_tests,'\\<deprecated\\>|\\<private\\>','once'))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:101
            files_with_no_tests=files_with_no_tests[weed_idx]
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:102
            report_files_with_no_tests(files_with_tests,files_with_no_tests,'.m')
            puts('\nPlease help improve Octave by contributing tests for these files\n')
            printf('(see the list in the file %s).\n\n',logfile)
            fprintf(fid,'\nFiles with no tests:\n\n%s',list_in_columns(files_with_no_tests,80))
            fclose(fid)
        finally:
            pass
    finally:
        warning('off','all')
        warning(orig_wstate)
        page_screen_output(pso)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def print_test_file_name(nm=None,*args,**kwargs):
    varargin = print_test_file_name.varargin
    nargin = print_test_file_name.nargin

    filler=repmat('.',1,60 - length(nm))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:123
    printf('  %s %s',nm,filler)
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def print_pass_fail(p=None,n=None,xf=None,sk=None,*args,**kwargs):
    varargin = print_pass_fail.varargin
    nargin = print_pass_fail.nargin

    if ((n + sk) > 0):
        printf(' PASS   %4d/%-4d',p,n)
        nfail=n - p - xf
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:130
        if (nfail > 0):
            printf('\n%71s %3d','FAIL ',nfail)
        if (sk > 0):
            printf('\n%71s %3d','SKIP ',sk)
        if (xf > 0):
            printf('\n%71s %3d','XFAIL',xf)
    
    puts('\n')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def has_functions(f=None,*args,**kwargs):
    varargin = has_functions.varargin
    nargin = has_functions.nargin

    n=length(f)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:145
    if (n > 3 and strcmpi(f[(end() - 2):end()],'.cc')):
        fid=fopen(f)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:147
        if (fid >= 0):
            str=fread(fid,'*char').T
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:149
            fclose(fid)
            retval=logical_not(isempty(regexp(str,'^(DEFUN|DEFUN_DLD)\\>','lineanchors','once')))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:151
        else:
            error('fopen failed: %s',f)
    else:
        if (n > 2 and strcmpi(f[(end() - 1):end()],'.m')):
            retval=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:157
        else:
            retval=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:159
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def has_tests(f=None,*args,**kwargs):
    varargin = has_tests.varargin
    nargin = has_tests.nargin

    fid=fopen(f)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:164
    if (fid >= 0):
        str=fread(fid,'*char').T
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:166
        fclose(fid)
        retval=logical_not(isempty(regexp(str,'^%!(assert|error|fail|test|xtest|warning)','lineanchors','once')))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:168
    else:
        error('fopen failed: %s',f)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def run_test_dir(fid=None,d=None,*args,**kwargs):
    varargin = run_test_dir.varargin
    nargin = run_test_dir.nargin

    global files_with_tests
    global files_with_no_tests
    lst=dir(d)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:179
    dp=dn=dxf=dsk=0
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:180
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:180
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:180
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:180
    for i in arange(1,length(lst)).reshape(-1):
        nm=lst[i].name
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:182
        if (lst[i].isdir and nm[1] != '.' and logical_not(strcmp(nm,'private')) and nm[1] != '@'):
            p,n,xf,sk=run_test_dir(fid,cat(d,filesep,nm),nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:185
            dp += p
            dn += n
            dxf += xf
            dsk += sk
    
    saved_dir=pwd()
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:192
    try:
        cd(d)
        for i in arange(1,length(lst)).reshape(-1):
            nm=lst[i].name
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:196
            if (length(nm) > 4 and strcmpi(nm[(end() - 3):end()],'.tst')):
                p=n=xf=sk=0
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:198
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:198
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:198
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:198
                ffnm=fullfile(d,nm)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:199
                if (has_tests(ffnm)):
                    print_test_file_name(nm)
                    p,n,xf,sk=test(nm,'quiet',fid,nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:202
                    print_pass_fail(p,n,xf,sk)
                    files_with_tests[end() + 1]=ffnm
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:204
                else:
                    files_with_no_tests[end() + 1]=ffnm
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:206
                dp += p
                dn += n
                dxf += xf
                dsk += sk
    finally:
        cd(saved_dir)
    
    return dp,dn,dxf,dsk
    
if __name__ == '__main__':
    pass
    
    
@function
def run_test_script(fid=None,d=None,*args,**kwargs):
    varargin = run_test_script.varargin
    nargin = run_test_script.nargin

    global files_with_tests
    global files_with_no_tests
    global topsrcdir
    global topbuilddir
    lst=dir(d)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:224
    dp=dn=dxf=dsk=0
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:225
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:225
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:225
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:225
    for i in arange(1,length(lst)).reshape(-1):
        nm=lst[i].name
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:227
        if (lst[i].isdir and nm[1] != '.'):
            p,n,xf,sk=run_test_script(fid,cat(d,filesep,nm),nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:229
            dp += p
            dn += n
            dxf += xf
            dsk += sk
    
    for i in arange(1,length(lst)).reshape(-1):
        nm=lst[i].name
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:237
        if (nm[1] == '.'):
            continue
        f=fullfile(d,nm)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:242
        if ((length(nm) > 2 and strcmpi(nm[(end() - 1):end()],'.m')) or (length(nm) > 4 and (strcmpi(nm[(end() - 3):end()],'-tst') or strcmpi(nm[(end() - 3):end()],'.tst')))):
            p=n=xf=0
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:247
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:247
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:247
            if (has_tests(f)):
                tmp=strrep(f,cat(topsrcdir,filesep),'')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:250
                tmp=strrep(tmp,cat(topbuilddir,filesep),'')
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:251
                print_test_file_name(tmp)
                p,n,xf,sk=test(f,'quiet',fid,nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:253
                print_pass_fail(p,n,xf,sk)
                dp += p
                dn += n
                dxf += xf
                dsk += sk
                files_with_tests[end() + 1]=f
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:259
            else:
                ## To reduce the list length, only mark .cc files that contain
        ## DEFUN definitions.
                files_with_no_tests[end() + 1]=f
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:263
    
    ##  printf("#s#s -> passes #d of #d tests\n", ident, d, dp, dn);
    return dp,dn,dxf,dsk
    
if __name__ == '__main__':
    pass
    
    
@function
def num_elts_matching_pattern(lst=None,pat=None,*args,**kwargs):
    varargin = num_elts_matching_pattern.varargin
    nargin = num_elts_matching_pattern.nargin

    n=sum(logical_not(cellfun('isempty',regexp(lst,pat,'once'))))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:271
    return n
    
if __name__ == '__main__':
    pass
    
    
@function
def report_files_with_no_tests(with_=None,without=None,typ=None,*args,**kwargs):
    varargin = report_files_with_no_tests.varargin
    nargin = report_files_with_no_tests.nargin

    pat=matlabarray(cat('\\',typ,'$'))
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:275
    n_with=num_elts_matching_pattern(with_,pat)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:276
    n_without=num_elts_matching_pattern(without,pat)
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:277
    n_tot=n_with + n_without
# /home/lei/octave-4.0.2/scripts/testfun/__run_test_suite__.m:278
    printf('\n%d (of %d) %s files have no tests.\n',n_without,n_tot,typ)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test coverage for internal function.  It is tested through calling fcn.
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} example @var{name}
## @deftypefnx {Command} {} example @var{name} @var{n}
## @deftypefnx {Function File} {} example ("@var{name}")
## @deftypefnx {Function File} {} example ("@var{name}", @var{n})
## @deftypefnx {Function File} {[@var{s}, @var{idx}] =} example (@dots{})
##
## Display the code for example @var{n} associated with the function
## @var{name}, but do not run it.
##
## If @var{n} is not specified, all examples are displayed.
##
## When called with output arguments, the examples are returned in the form of
## a string @var{s}, with @var{idx} indicating the ending position of the
## various examples.
##
## See @code{demo} for a complete explanation.
## @seealso{demo, test}
## @end deftypefn
    
    
@function
def example(name=None,n=0,*args,**kwargs):
    varargin = example.varargin
    nargin = example.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (ischar(n)):
        n=str2double(n)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:46
    
    if (logical_not((isreal(n) and isscalar(n) and n == fix(n)))):
        error('example: N must be a scalar integer')
    
    code,idx=test(name,'grabdemo',nargout=2)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:53
    if (idx == - 1):
        warning('example: no function %s found',name)
        return ex_code,ex_idx
    else:
        if (isempty(idx)):
            warning('example: no example available for %s',name)
            return ex_code,ex_idx
        else:
            if (n >= length(idx)):
                warning('example: only %d examples available for %s',length(idx) - 1,name)
                return ex_code,ex_idx
    
    if (nargout > 0):
        if (n > 0):
            if (n <= length(idx)):
                ex_code=code[idx[n]:idx[n + 1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/example.m:70
                ex_idx=matlabarray(cat(1,length(ex_code) + 1))
# /home/lei/octave-4.0.2/scripts/testfun/example.m:71
            else:
                ex_code=''
# /home/lei/octave-4.0.2/scripts/testfun/example.m:73
                ex_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/example.m:74
        else:
            ex_code=copy(code)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:77
            ex_idx=copy(idx)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:78
    else:
        if (n > 0):
            doidx=copy(n)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:82
        else:
            doidx=arange(1,length(idx) - 1)
# /home/lei/octave-4.0.2/scripts/testfun/example.m:84
        for i in arange(1,length(doidx)).reshape(-1):
            block=code[idx[doidx[i]]:idx[doidx[i] + 1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/example.m:88
            printf('%s example %d:%s\n\n',name,doidx[i],block)
    
    return ex_code,ex_idx
    
if __name__ == '__main__':
    pass
    
    ## WARNING: don't modify the demos without modifying the tests!
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} demo @var{name}
## @deftypefnx {Command} {} demo @var{name} @var{n}
## @deftypefnx {Function File} {} demo ("@var{name}")
## @deftypefnx {Function File} {} demo ("@var{name}", @var{n})
##
## Run example code block @var{n} associated with the function @var{name}.
##
## If @var{n} is not specified, all examples are run.
##
## The preferred location for example code blocks is embedded within the script
## m-file immediately following the code that it exercises.  Alternatively,
## the examples may be stored in a file with the same name but no extension
## located on Octave's load path.  To separate examples from regular script
## code all lines are prefixed by @code{#!}.  Each example must also be
## introduced by the keyword @qcode{"demo"} flush left to the prefix with no
## intervening spaces.  The remainder of the example can contain arbitrary
## Octave code.  For example:
##
## @example
## @group
## #!demo
## #! t = 0:0.01:2*pi;
## #! x = sin (t);
## #! plot (t, x);
## #! title ("one cycle of a sine wave");
## #! #-------------------------------------------------
## #! # the figure window shows one cycle of a sine wave
## @end group
## @end example
##
## Note that the code is displayed before it is executed so that a simple
## comment at the end suffices for labeling what is being shown.  For plots,
## labeling can also be done with @code{title} or @code{text}.  It is generally
## @strong{not} necessary to use @code{disp} or @code{printf} within the demo.
##
## Demos are run in a stand-alone function environment with no access to
## external variables.  This means that every demo must have separate
## initialization code.  Alternatively, all demos can be combined into a single
## large demo with the code
##
## @example
## #! input ("Press <enter> to continue: ", "s");
## @end example
##
## @noindent
## between the sections, but this usage is discouraged.  Other techniques to
## avoid multiple initialization blocks include using multiple plots with a new
## @code{figure} command between each plot, or using @code{subplot} to put
## multiple plots in the same window.
##
## Finally, because @code{demo} evaluates within a function context it is not
## possible to define new functions within the code.  Anonymous functions make
## a good substitute in most instances.  If function blocks @strong{must} be
## used then the code @code{eval (example ("function", n))} will allow Octave
## to see them.  This has its own problems, however, as @code{eval} only
## evaluates one line or statement at a time.  In this case the function
## declaration must be wrapped with @qcode{"if 1 <demo stuff> endif"} where
## @qcode{"if"} is on the same line as @qcode{"demo"}.  For example:
##
## @example
## @group
## #!demo if 1
## #!  function y = f(x)
## #!    y = x;
## #!  endfunction
## #!  f(3)
## #! endif
## @end group
## @end example
##
## @seealso{rundemos, example, test}
## @end deftypefn
    
    ## FIXME: modify subplot so that gnuplot_has_multiplot == 0 causes it to
## use the current figure window but pause if not plotting in the
## first subplot.
    
    
@function
def demo(name=None,n=0,*args,**kwargs):
    varargin = demo.varargin
    nargin = demo.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (ischar(n)):
        n=str2double(n)
# /home/lei/octave-4.0.2/scripts/testfun/demo.m:104
    
    if (logical_not((isreal(n) and isscalar(n) and n == fix(n)))):
        error('demo: N must be a scalar integer')
    
    code,idx=test(name,'grabdemo',nargout=2)
# /home/lei/octave-4.0.2/scripts/testfun/demo.m:111
    if (idx == - 1):
        warning('demo: no function %s found',name)
        return
    else:
        if (isempty(idx)):
            warning('demo: no demo available for %s',name)
            return
        else:
            if (n >= length(idx)):
                warning('demo: only %d demos available for %s',length(idx) - 1,name)
                return
    
    if (n > 0):
        doidx=copy(n)
# /home/lei/octave-4.0.2/scripts/testfun/demo.m:125
    else:
        doidx=arange(1,(length(idx) - 1))
# /home/lei/octave-4.0.2/scripts/testfun/demo.m:127
    
    for i in arange(1,length(doidx)).reshape(-1):
        ## Pause between demos
        if (i > 1):
            input_('Press <enter> to continue: ','s')
        ## Process each demo without failing
        try:
            block=code[idx[doidx[i]]:idx[doidx[i] + 1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/demo.m:137
            eval(cat('function __demo__ ()\n',block,'\nendfunction'))
            printf('%s example %d:%s\n\n',name,doidx[i],block)
            __demo__
        finally:
            pass
        clear('__demo__')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __prog_output_assert__ (@var{str})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __prog_output_assert__(str=None,*args,**kwargs):
    varargin = __prog_output_assert__.varargin
    nargin = __prog_output_assert__.nargin

    global _assert_printf
    if (isempty(_assert_printf)):
        ret=isempty(str)
# /home/lei/octave-4.0.2/scripts/testfun/__prog_output_assert__.m:27
    else:
        if (_assert_printf[end()] == '\n'):
            ret=strcmp(_assert_printf[1:(end() - 1)],str)
# /home/lei/octave-4.0.2/scripts/testfun/__prog_output_assert__.m:29
        else:
            ret=strcmp(_assert_printf,str)
# /home/lei/octave-4.0.2/scripts/testfun/__prog_output_assert__.m:31
    
    _assert_printf=''
# /home/lei/octave-4.0.2/scripts/testfun/__prog_output_assert__.m:33
    return ret
    
if __name__ == '__main__':
    pass
    
    ## No test coverage for internal function.  It is tested through calling fcn.
    
    ## Copyright (C) 2005-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __printf_assert__ (@dots{})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __printf_assert__(varargin=None,*args,**kwargs):
    varargin = __printf_assert__.varargin
    nargin = __printf_assert__.nargin

    global _assert_printf
    _assert_printf=cat(2,_assert_printf,sprintf(varargin[:]))
# /home/lei/octave-4.0.2/scripts/testfun/__printf_assert__.m:26
    return
    
if __name__ == '__main__':
    pass
    
    ## No test coverage for internal function.  It is tested through calling fcn.
    
    ## Copyright (C) 2010-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} runtests ()
## @deftypefnx {Function File} {} runtests (@var{directory})
## Execute built-in tests for all m-files in the specified @var{directory}.
##
## Test blocks in any C++ source files (@file{*.cc}) will also be executed
## for use with dynamically linked oct-file functions.
##
## If no directory is specified, operate on all directories in Octave's search
## path for functions.
## @seealso{rundemos, test, path}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def runtests(directory=None,*args,**kwargs):
    varargin = runtests.varargin
    nargin = runtests.nargin

    if (nargin == 0):
        dirs=ostrsplit(path(),pathsep())
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:37
        do_class_dirs=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:38
    else:
        if (nargin == 1):
            dirs=cellarray([canonicalize_file_name(directory)])
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:40
            if (isempty(dirs[1])):
                ## Search for directory name in path
                if (directory[end()] == '/' or directory[end()] == '\\'):
                    directory[end()]=[]
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:44
                fullname=dir_in_loadpath(directory)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:46
                if (isempty(fullname)):
                    error('runtests: DIRECTORY argument must be a valid pathname')
                dirs=cellarray([fullname])
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:50
            do_class_dirs=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:52
        else:
            print_usage()
    
    for i in arange(1,numel(dirs)).reshape(-1):
        d=dirs[i]
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:58
        run_all_tests(d,do_class_dirs)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def run_all_tests(directory=None,do_class_dirs=None,*args,**kwargs):
    varargin = run_all_tests.varargin
    nargin = run_all_tests.nargin

    flist=readdir(directory)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:65
    dirs=cellarray([])
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:66
    no_tests=cellarray([])
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:67
    printf('Processing files in %s:\n\n',directory)
    fflush(stdout)
    for i in arange(1,numel(flist)).reshape(-1):
        f=flist[i]
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:71
        if ((length(f) > 2 and strcmpi(f[(end() - 1):end()],'.m')) or (length(f) > 3 and strcmpi(f[(end() - 2):end()],'.cc'))):
            ff=fullfile(directory,f)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:74
            if (has_tests(ff)):
                print_test_file_name(f)
                p,n,xf,sk=test(ff,'quiet',nargout=4)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:77
                print_pass_fail(n,p)
                fflush(stdout)
            else:
                if (has_functions(ff)):
                    no_tests[end() + 1]=f
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:81
        else:
            if (f[1] == '@'):
                f=fullfile(directory,f)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:84
                if (isdir(f)):
                    dirs[end() + 1]=f
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:86
    
    if (logical_not(isempty(no_tests))):
        printf('\nThe following files in %s have no tests:\n\n',directory)
        printf('%s',list_in_columns(no_tests))
    
    ## Recurse into class directories since they are implied in the path
    if (do_class_dirs):
        for i in arange(1,numel(dirs)).reshape(-1):
            d=dirs[i]
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:98
            run_all_tests(d,false)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def has_functions(f=None,*args,**kwargs):
    varargin = has_functions.varargin
    nargin = has_functions.nargin

    n=length(f)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:105
    if (n > 3 and strcmpi(f[(end() - 2):end()],'.cc')):
        fid=fopen(f)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:107
        if (fid >= 0):
            str=fread(fid,'*char').T
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:109
            fclose(fid)
            retval=logical_not(isempty(regexp(str,'^(?:DEFUN|DEFUN_DLD|DEFUNX)\\>','lineanchors','once')))
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:111
        else:
            error('fopen failed: %s',f)
    else:
        if (n > 2 and strcmpi(f[(end() - 1):end()],'.m')):
            retval=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:117
        else:
            retval=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:119
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def has_tests(f=None,*args,**kwargs):
    varargin = has_tests.varargin
    nargin = has_tests.nargin

    fid=fopen(f)
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:124
    if (fid >= 0):
        str=fread(fid,'*char').T
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:126
        fclose(fid)
        retval=logical_not(isempty(regexp(str,'^%!(?:test|xtest|assert|error|warning)','lineanchors','once')))
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:128
    else:
        error('runtests: fopen failed: %s',f)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def print_pass_fail(n=None,p=None,*args,**kwargs):
    varargin = print_pass_fail.varargin
    nargin = print_pass_fail.nargin

    if (n > 0):
        printf(' PASS %4d/%-4d',p,n)
        nfail=n - p
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:138
        if (nfail > 0):
            printf(' FAIL %d',nfail)
    
    puts('\n')
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def print_test_file_name(nm=None,*args,**kwargs):
    varargin = print_test_file_name.varargin
    nargin = print_test_file_name.nargin

    filler=repmat('.',1,55 - length(nm))
# /home/lei/octave-4.0.2/scripts/testfun/runtests.m:147
    printf('  %s %s',nm,filler)
    return
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} speed (@var{f}, @var{init}, @var{max_n}, @var{f2}, @var{tol})
## @deftypefnx {Function File} {[@var{order}, @var{n}, @var{T_f}, @var{T_f2}] =} speed (@dots{})
##
## Determine the execution time of an expression (@var{f}) for various input
## values (@var{n}).
##
## The @var{n} are log-spaced from 1 to @var{max_n}.  For each @var{n}, an
## initialization expression (@var{init}) is computed to create any data needed
## for the test.  If a second expression (@var{f2}) is given then the
## execution times of the two expressions are compared.  When called without
## output arguments the results are printed to stdout and displayed
## graphically.
##
## @table @code
## @item @var{f}
## The code expression to evaluate.
##
## @item @var{max_n}
## The maximum test length to run.  The default value is 100.  Alternatively,
## use @code{[min_n, max_n]} or specify the @var{n} exactly with
## @code{[n1, n2, @dots{}, nk]}.
##
## @item @var{init}
## Initialization expression for function argument values.  Use @var{k} for
## the test number and @var{n} for the size of the test.  This should compute
## values for all variables used by @var{f}.  Note that @var{init} will be
## evaluated first for @math{k = 0}, so things which are constant throughout
## the test series can be computed once.  The default value is
## @code{@var{x} = randn (@var{n}, 1)}.
##
## @item @var{f2}
## An alternative expression to evaluate, so that the speed of two
## expressions can be directly compared.  The default is @code{[]}.
##
## @item @var{tol}
## Tolerance used to compare the results of expression @var{f} and expression
## @var{f2}.  If @var{tol} is positive, the tolerance is an absolute one.
## If @var{tol} is negative, the tolerance is a relative one.  The default is
## @code{eps}.  If @var{tol} is @code{Inf}, then no comparison will be made.
##
## @item @var{order}
## The time complexity of the expression @math{O(a*n^p)}.  This is a
## structure with fields @code{a} and @code{p}.
##
## @item @var{n}
## The values @var{n} for which the expression was calculated @strong{AND}
## the execution time was greater than zero.
##
## @item @var{T_f}
## The nonzero execution times recorded for the expression @var{f} in seconds.
##
## @item @var{T_f2}
## The nonzero execution times recorded for the expression @var{f2} in seconds.
## If required, the mean time ratio is simply @code{mean (T_f ./ T_f2)}.
##
## @end table
##
## The slope of the execution time graph shows the approximate power of the
## asymptotic running time @math{O(n^p)}.  This power is plotted for the
## region over which it is approximated (the latter half of the graph).  The
## estimated power is not very accurate, but should be sufficient to
## determine the general order of an algorithm.  It should indicate if, for
## example, the implementation is unexpectedly @math{O(n^2)} rather than
## @math{O(n)} because it extends a vector each time through the loop rather
## than pre-allocating storage.  In the current version of Octave, the
## following is not the expected @math{O(n)}.
##
## @example
## speed ("for i = 1:n, y@{i@} = x(i); endfor", "", [1000, 10000])
## @end example
##
## @noindent
## But it is if you preallocate the cell array @code{y}:
##
## @example
## @group
## speed ("for i = 1:n, y@{i@} = x(i); endfor", ...
##        "x = rand (n, 1); y = cell (size (x));", [1000, 10000])
## @end group
## @end example
##
## An attempt is made to approximate the cost of individual operations, but
## it is wildly inaccurate.  You can improve the stability somewhat by doing
## more work for each @code{n}.  For example:
##
## @example
## speed ("airy(x)", "x = rand (n, 10)", [10000, 100000])
## @end example
##
## When comparing two different expressions (@var{f}, @var{f2}), the slope of
## the line on the speedup ratio graph should be larger than 1 if the new
## expression is faster.  Better algorithms have a shallow slope.  Generally,
## vectorizing an algorithm will not change the slope of the execution time
## graph, but will shift it relative to the original.  For example:
##
## @example
## @group
## speed ("sum (x)", "", [10000, 100000], ...
##        "v = 0; for i = 1:length (x), v += x(i); endfor")
## @end group
## @end example
##
## The following is a more complex example.  If there was an original version
## of @code{xcorr} using for loops and a second version using an FFT, then
## one could compare the run speed for various lags as follows, or for a fixed
## lag with varying vector lengths as follows:
##
## @example
## @group
## speed ("xcorr (x, n)", "x = rand (128, 1);", 100,
##        "xcorr_orig (x, n)", -100*eps)
## speed ("xcorr (x, 15)", "x = rand (20+n, 1);", 100,
##        "xcorr_orig (x, n)", -100*eps)
## @end group
## @end example
##
## Assuming one of the two versions is in xcorr_orig, this would compare their
## speed and their output values.  Note that the FFT version is not exact, so
## one must specify an acceptable tolerance on the comparison @code{100*eps}.
## In this case, the comparison should be computed relatively, as
## @code{abs ((@var{x} - @var{y}) ./ @var{y})} rather than absolutely as
## @code{abs (@var{x} - @var{y})}.
##
## Type @kbd{example ("speed")} to see some real examples or
## @kbd{demo ("speed")} to run them.
## @end deftypefn
    
    ## FIXME: consider two dimensional speedup surfaces for functions like kron.
    
@function
def speed(__f1=None,__init=None,__max_n=100,__f2='',__tol=eps,*args,**kwargs):
    varargin = speed.varargin
    nargin = speed.nargin

    if (nargin < 1 or nargin > 6):
        print_usage()
    
    if (nargin < 2 or isempty(__init)):
        __init='x = randn (n, 1)'
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:155
    
    if (isempty(__max_n)):
        __max_n=100
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:159
    
    __numtests=15
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:162
    
    if (isscalar(__max_n)):
        __min_n=1
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:166
        assert_(__max_n > __min_n)
        __test_n=logspace(0,log10(__max_n),__numtests)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:168
    else:
        if (length(__max_n) == 2):
            __min_n,__max_n=deal(__max_n[1],__max_n[2],nargout=2)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:170
            assert_(__min_n >= 1)
            assert_(__max_n > __min_n)
            __test_n=logspace(log10(__min_n),log10(__max_n),__numtests)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:173
        else:
            assert_(all(__max_n > 0))
            __test_n=copy(__max_n)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:176
    
    ## Force n to be an integer.
    __test_n=unique(round(__test_n))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:179
    assert_(__test_n >= 1)
    __torig=__tnew=zeros(size(__test_n))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:182
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:182
    
    do_display=(nargout == 0)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:185
    if (do_display):
        disp(cat('testing ',__f1,'\ninit: ',__init))
    
    ## Add semicolon closure to all code fragments in case user has not done so.
    __init[end() + 1]=';'
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:192
    __f1[end() + 1]=';'
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:193
    if (logical_not(isempty(__f2))):
        __f2[end() + 1]=';'
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:195
    
    ## Make sure the functions are freshly loaded by evaluating them at
  ## test_n(1); first have to initialize the args though.
    n=1
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:200
    k=0
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:201
    eval(__init)
    eval(__f1)
    if (logical_not(isempty(__f2))):
        eval(__f2)
    
    ## Run the tests.
    for k in arange(1,length(__test_n)).reshape(-1):
        n=__test_n[k]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:210
        eval(__init)
        if (do_display):
            printf('n%i = %i  ',k,n)
            fflush(stdout)
        eval(cat('__t = time();',__f1,'__v1=ans; __t = time()-__t;'))
        if (__t < 0.25):
            eval(cat('__t2 = time();',__f1,'__t2 = time()-__t2;'))
            eval(cat('__t3 = time();',__f1,'__t3 = time()-__t3;'))
            __t=min(cat(__t,__t2,__t3))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:222
        __tnew[k]=__t
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:224
        if (logical_not(isempty(__f2))):
            eval(cat('__t = time();',__f2,'__v2=ans; __t = time()-__t;'))
            if (__t < 0.25):
                eval(cat('__t2 = time();',__f2,'__t2 = time()-__t2;'))
                eval(cat('__t3 = time();',__f2,'__t3 = time()-__t3;'))
                __t=min(cat(__t,__t2,__t3))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:231
            __torig[k]=__t
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:233
            if (logical_not(isinf(__tol))):
                assert_(__v1,__v2,__tol)
    
    ## Drop times of zero.
    if (isempty(__f2)):
        zidx=(__tnew < dot(100,eps))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:243
        __test_n[zidx]=[]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:244
        __tnew[zidx]=[]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:245
    else:
        zidx=(__tnew < logical_or(dot(100,eps),__torig) < dot(100,eps))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:247
        __test_n[zidx]=[]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:248
        __tnew[zidx]=[]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:249
        __torig[zidx]=[]
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:250
    
    if (isempty(__test_n)):
        error(cat('speed: All running times were zero.\n','error: speed: Choose larger MAX_N or do more work per function evaluation'))
    
    ## Approximate time complexity and return it if requested.
    tailidx=arange(ceil(length(__test_n) / 2),length(__test_n))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:259
    p=polyfit(log(__test_n[tailidx]),log(__tnew[tailidx]),1)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:260
    if (nargout > 0):
        __order.p = copy(p[1])
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:262
        __order.a = copy(exp(p[2]))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:263
    
    if (do_display):
        figure
        __init[end()]=''
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:269
        __f1[end()]=''
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:270
        if (logical_not(isempty(__f2))):
            __f2[end()]=''
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:272
    
    if (do_display and isempty(__f2)):
        loglog(__test_n,dot(__tnew,1000),'*-g;execution time;')
        xlabel('test length')
        ylabel('best execution time (ms)')
        title(cellarray([__f1,cat('init: ',__init)]))
    else:
        if (do_display):
            subplot(1,2,1)
            semilogx(__test_n,__torig / __tnew,cat('-*r;',strrep(__f1,';','.'),' / ',strrep(__f2,';','.'),';'),__test_n,__tnew / __torig,cat('-*g;',strrep(__f2,';','.'),' / ',strrep(__f1,';','.'),';'))
            title('Speedup Ratio')
            xlabel('test length')
            ylabel('speedup ratio')
            subplot(1,2,2)
            loglog(__test_n,dot(__tnew,1000),cat('*-g;',strrep(__f1,';','.'),';'),__test_n,dot(__torig,1000),cat('*-r;',strrep(__f2,';','.'),';'))
            title(cellarray(['Execution Times',cat('init: ',__init)]))
            xlabel('test length')
            ylabel('best execution time (ms)')
            ratio=mean(__torig / __tnew)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:303
            printf('\n\nMean runtime ratio = %.3g for \'%s\' vs \'%s\'\n',ratio,__f2,__f1)
    
    if (do_display):
        ## Plot time complexity approximation (using milliseconds).
        figure
        order=round(dot(10,p[1])) / 10
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:314
        if (order >= 0.1):
            order=sprintf('O(n^%g)',order)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:316
        else:
            order='O(1)'
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:318
        v=polyval(p,log(__test_n[tailidx]))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:320
        loglog(__test_n[tailidx],dot(exp(v),1000),sprintf('b;%s;',order))
        title(cellarray(['Time Complexity',__f1]))
        xlabel('test length')
        dt=exp(p[2])
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:327
        dt=dot(floor(dt / 10 ** floor(log10(dt))),10 ** floor(log10(dt)))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:328
        if (log10(dt) >= - 0.5):
            time=sprintf('%g s',dt)
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:330
        else:
            if (log10(dt) >= - 3.5):
                time=sprintf('%g ms',dot(dt,1000.0))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:332
            else:
                if (log10(dt) >= - 6.5):
                    time=sprintf('%g us',dot(dt,1000000.0))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:334
                else:
                    time=sprintf('%g ns',dot(dt,1000000000.0))
# /home/lei/octave-4.0.2/scripts/testfun/speed.m:336
        ## Display nicely formatted complexity.
        printf('\nFor %s:\n',__f1)
        printf('  asymptotic power: %s\n',order)
        printf('  approximate time per operation: %s\n',time)
    
    return __order,__test_n,__tnew,__torig
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Demos with declared functions do not work.  See bug #31815.
##        A workaround has been hacked by not declaring the functions
##        but using eval to create them in the proper context.
##        Unfortunately, we can't remove them from the user's workspace
##        because of another bug (#34497).
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: Tests are known to fail on operating systems with low resolution
##        timers such as MinGW.  Therefore, tests are made xtests so that false
##        failures are not reported.  However, it might be better to either
##        force the tests to do more work, or use #!testif to check the OS.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rundemos ()
## @deftypefnx {Function File} {} rundemos (@var{directory})
## Execute built-in demos for all m-files in the specified @var{directory}.
##
## Demo blocks in any C++ source files (@file{*.cc}) will also be executed
## for use with dynamically linked oct-file functions.
##
## If no directory is specified, operate on all directories in Octave's search
## path for functions.
## @seealso{demo, runtests, path}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def rundemos(directory=None,*args,**kwargs):
    varargin = rundemos.varargin
    nargin = rundemos.nargin

    if (nargin == 0):
        dirs=ostrsplit(path(),pathsep())
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:37
        do_class_dirs=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:38
    else:
        if (nargin == 1):
            dirs=cellarray([canonicalize_file_name(directory)])
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:40
            if (isempty(dirs[1])):
                ## Search for directory name in path
                if (directory[end()] == '/' or directory[end()] == '\\'):
                    directory[end()]=[]
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:44
                fullname=dir_in_loadpath(directory)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:46
                if (isempty(fullname)):
                    error('rundemos: DIRECTORY argument must be a valid pathname')
                dirs=cellarray([fullname])
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:50
            do_class_dirs=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:52
        else:
            print_usage()
    
    for i in arange(1,numel(dirs)).reshape(-1):
        d=dirs[i]
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:58
        run_all_demos(d,do_class_dirs)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def run_all_demos(directory=None,do_class_dirs=None,*args,**kwargs):
    varargin = run_all_demos.varargin
    nargin = run_all_demos.nargin

    flist=readdir(directory)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:65
    dirs=cellarray([])
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:66
    for i in arange(1,numel(flist)).reshape(-1):
        f=flist[i]
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:68
        if ((length(f) > 2 and strcmpi(f[(end() - 1):end()],'.m')) or (length(f) > 3 and strcmpi(f[(end() - 2):end()],'.cc'))):
            f=fullfile(directory,f)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:71
            if (has_demos(f)):
                try:
                    demo(f)
                finally:
                    pass
                if (i != numel(flist)):
                    input_('Press <enter> to continue: ','s')
        else:
            if (f[1] == '@'):
                f=fullfile(directory,f)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:83
                if (isdir(f)):
                    dirs[end() + 1]=f
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:85
    
    ## Recurse into class directories since they are implied in the path
    if (do_class_dirs):
        for i in arange(1,numel(dirs)).reshape(-1):
            d=dirs[i]
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:93
            run_all_demos(d,false)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def has_demos(f=None,*args,**kwargs):
    varargin = has_demos.varargin
    nargin = has_demos.nargin

    fid=fopen(f)
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:100
    if (f < 0):
        error('rundemos: fopen failed: %s',f)
    else:
        str=fread(fid,'*char').T
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:104
        fclose(fid)
        retval=logical_not(isempty(regexp(str,'^%!demo','lineanchors','once')))
# /home/lei/octave-4.0.2/scripts/testfun/rundemos.m:106
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2013-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __have_feature__ (feature)
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __have_feature__(feature=None,*args,**kwargs):
    varargin = __have_feature__.varargin
    nargin = __have_feature__.nargin

    features=octave_config_info('features')
# /home/lei/octave-4.0.2/scripts/testfun/__have_feature__.m:25
    if (iscellstr(feature)):
        retval=(all(isfield(features,feature)) and cellfun(lambda x=None: getattr(features,(x)),feature))
# /home/lei/octave-4.0.2/scripts/testfun/__have_feature__.m:27
    else:
        if (ischar(feature)):
            retval=isfield(features,feature) and getattr(features,(feature))
# /home/lei/octave-4.0.2/scripts/testfun/__have_feature__.m:30
        else:
            retval=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/__have_feature__.m:32
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## No test coverage for internal function.  It is tested through calling fcn.
    
    ## Copyright (C) 2005-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fail (@var{code})
## @deftypefnx {Function File} {} fail (@var{code}, @var{pattern})
## @deftypefnx {Function File} {} fail (@var{code}, "warning")
## @deftypefnx {Function File} {} fail (@var{code}, "warning", @var{pattern})
##
## Return true if @var{code} fails with an error message matching
## @var{pattern}, otherwise produce an error.
##
## @var{code} must be in the form of a string that is passed to the Octave
## interpreter via the @code{evalin} function, i.e., a (quoted) string constant
## or a string variable.
##
## Note that if @var{code} runs successfully, rather than failing, the error
## printed is:
##
## @example
##           expected error <.> but got none
## @end example
##
## If called with two arguments, the return value will be true only if
## @var{code} fails with an error message containing @var{pattern}
## (case sensitive).  If the code fails with a different error than the one
## specified in @var{pattern} then the message produced is:
##
## @example
## @group
##           expected <@var{pattern}>
##           but got <text of actual error>
## @end group
## @end example
##
## The angle brackets are not part of the output.
##
## When called with the @qcode{"warning"} option @code{fail} will produce an
## error if executing the code produces no warning.
## @seealso{assert, error}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
    
    
@function
def fail(code=None,pattern=None,warning_pattern=None,*args,**kwargs):
    varargin = fail.varargin
    nargin = fail.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    ## Parse input arguments
    test_warning=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:70
    if (nargin == 1):
        pattern=''
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:72
    else:
        if (nargin == 2 and logical_not(strcmp(pattern,'warning'))):
            ## Normal error test
            pass
        else:
            if (nargin >= 2 and strcmp(pattern,'warning')):
                test_warning=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:76
                if (nargin == 2):
                    pattern=''
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:78
                else:
                    pattern=copy(warning_pattern)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:80
            else:
                print_usage()
    
    ## Match any nonempty message
    if (isempty(pattern)):
        pattern='.'
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:88
    
    ## Allow assert (fail ())
    if (nargout):
        retval=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:93
    
    if (test_warning):
        ## Perform the warning test.
    ## Clear old warnings.
        lastwarn('')
        wstate=warning('query','quiet')
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:101
        warning('on','quiet')
        try:
            evalin('caller',cat(code,';'))
            warn=lastwarn()
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:106
            warning(wstate.state,'quiet')
            if (isempty(warn)):
                msg=sprintf('expected warning <%s> but got none',pattern)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:109
            else:
                if (logical_not(isempty(regexp(warn,pattern,'once')))):
                    return retval
                msg=sprintf('expected warning <%s>\nbut got <%s>',pattern,warn)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:114
        finally:
            pass
    else:
        ## Perform the error test.
        try:
            evalin('caller',cat(code,';'))
            msg=sprintf('expected error <%s> but got none',pattern)
# /home/lei/octave-4.0.2/scripts/testfun/fail.m:126
        finally:
            pass
    
    ## If we get here, then code didn't fail or error didn't match.
    error(msg)
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ##!fail ("warning ('next test')",'warning','next test');  # only allowed one warning test?!?
    
    ## Test that fail() itself will generate an error
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} test @var{name}
## @deftypefnx {Command} {} test @var{name} quiet|normal|verbose
## @deftypefnx {Function File} {} test ("@var{name}", "quiet|normal|verbose", @var{fid})
## @deftypefnx {Function File} {} test ("@var{name}", "quiet|normal|verbose", @var{fname})
## @deftypefnx {Function File} {@var{success} =} test (@dots{})
## @deftypefnx {Function File} {[@var{n}, @var{nmax}, @var{nxfail}, @var{nskip}] =} test (@dots{})
## @deftypefnx {Function File} {[@var{code}, @var{idx}] =} test ("@var{name}", "grabdemo")
## @deftypefnx {Function File} {} test ([], "explain", @var{fid})
## @deftypefnx {Function File} {} test ([], "explain", @var{fname})
##
## Perform built-in self-tests from the first file in the loadpath matching
## @var{name}.
##
## @code{test} can be called in either command or functional form.  The exact
## operation of test is determined by a combination of mode (interactive or
## batch), reporting level (@qcode{"quiet"}, @qcode{"normal"},
## @qcode{"verbose"}), and whether a logfile or summary output variable is
## used.
##
## The default mode when @code{test} is called from the command line is
## interactive.  In this mode, tests will be run until the first error is
## encountered, or all tests complete successfully.  In batch mode, all tests
## are run regardless of any failures, and the results are collected for
## reporting.  Tests which require user interaction, i.e., demo blocks,
## are never run in batch mode.
##
## Batch mode is enabled by either 1) specifying a logfile using the third
## argument @var{fname} or @var{fid}, or 2) requesting an output argument
## such as @var{success}, @var{n}, etc.
##
## The optional second argument determines the amount of output to generate and
## which types of tests to run.  The default value is @qcode{"normal"}.
## Requesting an output argument will suppress printing the final summary
## message and any intermediate warnings, unless verbose reporting is
## enabled.
##
## @table @asis
## @item @qcode{"quiet"}
## Print a summary message when all tests pass, or print an error with the
## results of the first bad test when a failure occurs.  Don't run tests which
## require user interaction.
##
## @item @qcode{"normal"}
## Display warning messages about skipped tests or failing xtests during test
## execution.
## Print a summary message when all tests pass, or print an error with the
## results of the first bad test when a failure occurs.  Don't run tests which
## require user interaction.
##
## @item @qcode{"verbose"}
## Display tests before execution.  Print all warning messages.  In interactive
## mode, run all tests including those which require user interaction.
## @end table
##
## The optional third input argument specifies a logfile where results of the
## tests should be written.  The logfile may be a character string
## (@var{fname}) or an open file descriptor ID (@var{fid}).  To enable batch
## processing, but still print the results to the screen, use @code{stdout} for
## @var{fid}.
##
## When called with just a single output argument @var{success}, @code{test}
## returns true if all of the tests were successful.  If called with more
## than one output argument then the number of successful tests (@var{n}),
## the total number of tests in the file (@var{nmax}), the number of xtest
## failures (@var{nxfail}), and the number of skipped tests (@var{nskip} are
## returned.
##
## Example
##
## @example
## @group
## test sind
## @result{}
## PASSES 5 out of 5 tests
##
## [n, nmax] = test ("sind")
## @result{}
## n =  5
## nmax =  5
## @end group
## @end example
##
## Additional Calling Syntaxes
##
## If the second argument is the string @qcode{"grabdemo"}, the contents of
## any built-in demo blocks are extracted but not executed.  The text for all
## code blocks is concatenated and returned as @var{code} with @var{idx} being
## a vector of positions of the ends of each demo block.  For an easier way to
## extract demo blocks from files, @xref{XREFexample,,example}.
##
## If the second argument is @qcode{"explain"} then @var{name} is ignored and
## an explanation of the line markers used in @code{test} output reports is
## written to the file specified by @var{fname} or @var{fid}.
##
## @seealso{assert, fail, demo, example, error}
## @end deftypefn
    
    ## Programming Note: All variables for test() must use the internal prefix "__".
## Shared variables are eval'ed into the current workspace and therefore might
## collide with the names used in the test.m function itself.
    
    
@function
def test(__name=None,__flag='normal',__fid=[],*args,**kwargs):
    varargin = test.varargin
    nargin = test.nargin

    ## Output from test is prefixed by a "key" to quickly understand the issue.
    
    
    
    
    
    if (nargin < 1 or nargin > 3):
        print_usage()
    else:
        if (logical_not(isempty(__name)) and logical_not(ischar(__name))):
            error('test: NAME must be a string')
        else:
            if (logical_not(ischar(__flag))):
                error('test: second argument must be a string')
            else:
                if (isempty(__name) and (nargin != 3 or logical_not(strcmp(__flag,'explain')))):
                    print_usage()
    
    ## Decide if error messages should be collected.
    __logfile=logical_not(isempty(__fid))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:141
    __batch=__logfile or nargout > 0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:142
    __close_fid=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:143
    if (__logfile):
        if (ischar(__fid)):
            __fname=copy(__fid)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:146
            __fid=fopen(__fname,'wt')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:147
            if (__fid < 0):
                error('test: could not open log file %s',__fname)
            __close_fid=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:151
        if (logical_not(strcmp(__flag,'explain'))):
            fprintf(__fid,'%sprocessing %s\n',__signal_file,__name)
            fflush(__fid)
    else:
        __fid=copy(stdout)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:158
    
    if (strcmp(__flag,'normal')):
        __grabdemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:162
        __rundemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:163
        if (__logfile):
            __verbose=1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:165
        else:
            if (__batch):
                __verbose=- 1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:167
            else:
                __verbose=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:169
    else:
        if (strcmp(__flag,'quiet')):
            __grabdemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:172
            __rundemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:173
            __verbose=- 1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:174
        else:
            if (strcmp(__flag,'verbose')):
                __grabdemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:176
                __rundemo=logical_not(__batch)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:177
                __verbose=1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:178
            else:
                if (strcmp(__flag,'grabdemo')):
                    __grabdemo=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:180
                    __rundemo=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:181
                    __verbose=- 1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:182
                    __demo_code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:183
                    __demo_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:184
                else:
                    if (strcmp(__flag,'explain')):
                        fprintf(__fid,'# %s new test file\n',__signal_file)
                        fprintf(__fid,'# %s no tests in file\n',__signal_empty)
                        fprintf(__fid,'# %s test had an unexpected result\n',__signal_fail)
                        fprintf(__fid,'# %s test was skipped\n',__signal_skip)
                        fprintf(__fid,'# %s code for the test\n\n',__signal_block)
                        fprintf(__fid,'# Search for the unexpected results in the file\n')
                        fprintf(__fid,'# then page back to find the file name which caused it.\n')
                        fprintf(__fid,'# The result may be an unexpected failure (in which\n')
                        fprintf(__fid,'# case an error will be reported) or an unexpected\n')
                        fprintf(__fid,'# success (in which case no error will be reported).\n')
                        fflush(__fid)
                        if (__close_fid):
                            fclose(__fid)
                        return __n,__nmax,__nxfail,__nskip
                    else:
                        error('test: unknown flag \'%s\'',__flag)
    
    ## Locate the file to test.
    __file=file_in_loadpath(__name,'all')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:206
    if (isempty(__file)):
        __file=file_in_loadpath(cat(__name,'.m'),'all')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:208
    
    if (isempty(__file)):
        __file=file_in_loadpath(cat(__name,'.cc'),'all')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:211
    
    if (iscell(__file)):
        if (isempty(__file)):
            __file=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:215
        else:
            __file=__file[1]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:217
    
    if (isempty(__file)):
        if (__grabdemo):
            __n=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:222
            __nmax=- 1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:223
        else:
            ftype=exist(__name)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:225
            if (ftype == 3):
                fprintf(__fid,'%s%s source code with tests for dynamically linked function not found\n',__signal_empty,__name)
            else:
                if (ftype == 5):
                    fprintf(__fid,'%s%s is a built-in function\n',__signal_empty,__name)
                else:
                    if (any(strcmp(__operators__(),__name))):
                        fprintf(__fid,'%s%s is an operator\n',__signal_empty,__name)
                    else:
                        if (any(strcmp(__keywords__(),__name))):
                            fprintf(__fid,'%s%s is a keyword\n',__signal_empty,__name)
                        else:
                            fprintf(__fid,'%s%s does not exist in path\n',__signal_empty,__name)
            fflush(__fid)
            if (nargout > 0):
                if (nargout == 1):
                    __n=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:240
                else:
                    __n=__nmax=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:242
# /home/lei/octave-4.0.2/scripts/testfun/test.m:242
        if (__close_fid):
            fclose(__fid)
        return __n,__nmax,__nxfail,__nskip
    
    ## Grab the test code from the file.
    __body=__extract_test_code(__file)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:253
    if (isempty(__body)):
        if (__grabdemo):
            __n=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:257
            __nmax=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:258
        else:
            fprintf(__fid,'%s%s has no tests available\n',__signal_empty,__file)
            fflush(__fid)
            if (nargout > 0):
                if (nargout == 1):
                    __n=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:264
                else:
                    __n=__nmax=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:266
# /home/lei/octave-4.0.2/scripts/testfun/test.m:266
        if (__close_fid):
            fclose(__fid)
        return __n,__nmax,__nxfail,__nskip
    else:
        ## Add a dummy comment block to the end for ease of indexing.
        if (__body[end()] == '\n'):
            __body=matlabarray(cat('\n',__body,'#'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:277
        else:
            __body=matlabarray(cat('\n',__body,'\n#'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:279
    
    ## Chop it up into blocks for evaluation.
    __lineidx=find(__body == '\n')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:284
    __blockidx=__lineidx[find(logical_not(isspace(__body[__lineidx + 1])))] + 1
# /home/lei/octave-4.0.2/scripts/testfun/test.m:285
    
    ## If in batch mode, with a logfile, report what is happening.
    if (__verbose > 0):
        disp(cat(__signal_file,__file))
    
    ## Assume all tests will pass.
    __all_success=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:294
    
    __tests=__successes=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:297
# /home/lei/octave-4.0.2/scripts/testfun/test.m:297
    __xfail=__xskip=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:298
# /home/lei/octave-4.0.2/scripts/testfun/test.m:298
    __shared=' '
# /home/lei/octave-4.0.2/scripts/testfun/test.m:299
    __shared_r=' '
# /home/lei/octave-4.0.2/scripts/testfun/test.m:300
    __clearfcn=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:301
    for __i in arange(1,numel(__blockidx) - 1).reshape(-1):
        ## FIXME: Should other global settings be similarly saved and restored?
        orig_wstate=warning()
# /home/lei/octave-4.0.2/scripts/testfun/test.m:305
        try:
            ## Extract the block.
            __block=__body[__blockidx[__i]:__blockidx[__i + 1] - 2]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:309
            if (__verbose > 0):
                fprintf(__fid,'%s%s\n',__signal_block,__block)
                fflush(__fid)
            ## Split __block into __type and __code.
            __idx=find(logical_not(isletter(__block)))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:318
            if (isempty(__idx)):
                __type=copy(__block)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:320
                __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:321
            else:
                __type=__block[1:__idx[1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:323
                __code=__block[__idx[1]:length(__block)]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:324
            ## Assume the block will succeed.
            __success=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:328
            __msg=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:329
            __isxtest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:330
            ### DEMO
            ## If in __grabdemo mode, then don't process any other block type.
      ## So that the other block types don't have to worry about
      ## this __grabdemo mode, the demo block processor grabs all block
      ## types and skips those which aren't demo blocks.
            __isdemo=strcmp(__type,'demo')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:339
            if (__grabdemo or __isdemo):
                __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:341
                if (__grabdemo and __isdemo):
                    if (isempty(__demo_code)):
                        __demo_code=copy(__code)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:345
                        __demo_idx=matlabarray(cat(1,length(__demo_code) + 1))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:346
                    else:
                        __demo_code=matlabarray(cat(__demo_code,__code))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:348
                        __demo_idx=matlabarray(cat(__demo_idx,length(__demo_code) + 1))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:349
                else:
                    if (__rundemo and __isdemo):
                        try:
                            ## process the code in an environment without variables
                            eval(sprintf('function __test__ ()\n%s\nendfunction',__code))
                            __test__
                            input_('Press <enter> to continue: ','s')
                        finally:
                            pass
                        clear('__test__')
                ## Code already processed.
                __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:366
                ### SHARED
            else:
                if (strcmp(__type,'shared')):
                    __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:371
                    __idx=find(__code == '\n')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:374
                    if (isempty(__idx)):
                        __vars=copy(__code)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:376
                        __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:377
                    else:
                        __vars=__code[1:__idx[1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:379
                        __code=__code[__idx[1]:length(__code)]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:380
                    ## Strip comments off the variables.
                    __idx=find(__vars == logical_or('%',__vars) == '#')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:384
                    if (logical_not(isempty(__idx))):
                        __vars=__vars[1:__idx[1] - 1]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:386
                    ## Assign default values to variables.
                    try:
                        __vars=deblank(__vars)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:391
                        if (logical_not(isempty(__vars))):
                            eval(cat(strrep(__vars,',','=[];'),'=[];'))
                            __shared=copy(__vars)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:394
                            __shared_r=matlabarray(cat('[ ',__vars,'] = '))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:395
                        else:
                            __shared=' '
# /home/lei/octave-4.0.2/scripts/testfun/test.m:397
                            __shared_r=' '
# /home/lei/octave-4.0.2/scripts/testfun/test.m:398
                    finally:
                        pass
                    ## Initialization code will be evaluated below.
                    ### FUNCTION
                else:
                    if (strcmp(__type,'function')):
                        __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:412
                        __name_position=function_name(__block)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:414
                        if (isempty(__name_position)):
                            __success=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:416
                            __msg=matlabarray(cat(__signal_fail,'test failed: missing function name\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:417
                        else:
                            __name=__block[__name_position[1]:__name_position[2]]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:419
                            __code=copy(__block)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:420
                            try:
                                eval(__code)
                                __clearfcn=sprintf('%sclear %s;\n',__clearfcn,__name)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:423
                            finally:
                                pass
                        __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:429
                        ### ENDFUNCTION
                    else:
                        if (strcmp(__type,'endfunction')):
                            ## endfunction simply declares the end of a previous function block.
        ## There is no processing to be done here, just skip to next block.
                            __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:436
                            __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:437
                            ### ASSERT/FAIL
                        else:
                            if (strcmp(__type,'assert') or strcmp(__type,'fail')):
                                __istest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:442
                                __code=copy(__block)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:444
                                ### ERROR/WARNING
                            else:
                                if (strcmp(__type,'error') or strcmp(__type,'warning')):
                                    __istest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:450
                                    __iswarning=strcmp(__type,'warning')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:451
                                    __pattern,__id,__code=getpattern(__code,nargout=3)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:452
                                    if (__id):
                                        __patstr=matlabarray(cat('id=',__id))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:454
                                    else:
                                        if (logical_not(strcmp(__pattern,'.'))):
                                            __patstr=matlabarray(cat('<',__pattern,'>'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:457
                                        else:
                                            __patstr=ifelse(__iswarning,'a warning','an error')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:459
                                    try:
                                        eval(sprintf('function __test__(%s)\n%s\nendfunction',__shared,__code))
                                    finally:
                                        pass
                                    if (__success):
                                        __success=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:471
                                        __warnstate=warning('query','quiet')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:472
                                        warning('on','quiet')
                                        lasterr('')
                                        lastwarn('')
                                        try:
                                            eval(sprintf('__test__(%s);',__shared))
                                            if (logical_not(__iswarning)):
                                                __msg=matlabarray(cat(__signal_fail,'error failed.\n','Expected ',__patstr,', but got no error\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:480
                                            else:
                                                if (logical_not(isempty(__id))):
                                                    __,__err=lastwarn(nargout=2)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:484
                                                    __mismatch=logical_not(strcmp(__err,__id))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:485
                                                else:
                                                    __err=trimerr(lastwarn(),'warning')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:487
                                                    __mismatch=isempty(regexp(__err,__pattern,'once'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:488
                                                warning(__warnstate.state,'quiet')
                                                if (isempty(__err)):
                                                    __msg=matlabarray(cat(__signal_fail,'warning failed.\n','Expected ',__patstr,', but got no warning\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:492
                                                else:
                                                    if (__mismatch):
                                                        __msg=matlabarray(cat(__signal_fail,'warning failed.\n','Expected ',__patstr,', but got <',__err,'>\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:495
                                                    else:
                                                        __success=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:498
                                        finally:
                                            pass
                                        clear('__test__')
                                    ## Code already processed.
                                    __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:525
                                    ### TESTIF
                                else:
                                    if (strcmp(__type,'testif')):
                                        __e=regexp(__code,'.$','lineanchors','once')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:530
                                        __feat_line=strtok(__code[1:__e],'#%')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:532
                                        __feat=regexp(__feat_line,'\\w+','match')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:533
                                        __feat=strrep(__feat,'HAVE_','')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:534
                                        __have_feat=__have_feature__(__feat)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:535
                                        if (__have_feat):
                                            __istest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:537
                                            __code=__code[__e + 1:end()]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:538
                                        else:
                                            __xskip
                                            __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:541
                                            __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:542
                                            __msg=matlabarray(cat(__signal_skip,'skipped test\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:543
                                        ### TEST
                                    else:
                                        if (strcmp(__type,'test')):
                                            __istest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:549
                                            ### XTEST
                                        else:
                                            if (strcmp(__type,'xtest')):
                                                __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:555
                                                __isxtest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:556
                                                ### Comment block.
                                            else:
                                                if (strcmp(__block[1:1],'#')):
                                                    __istest=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:562
                                                    __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:563
                                                    ### Unknown block.
                                                else:
                                                    __istest=copy(true)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:568
                                                    __success=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:569
                                                    __msg=matlabarray(cat(__signal_fail,'unknown test type!\n'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:570
                                                    __code=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:571
            ## evaluate code for test, shared, and assert.
            if (logical_not(isempty(__code))):
                try:
                    ## FIXME: Must check for embedded test functions, which cause
          ## segfaults, until issues with subfunctions in functions are fixed.
                    embed_func=regexp(__code,'^\\s*function ','once','lineanchors')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:579
                    if (isempty(embed_func)):
                        eval(sprintf('function %s__test__(%s)\n%s\nendfunction',__shared_r,__shared,__code))
                        eval(sprintf('%s__test__(%s);',__shared_r,__shared))
                    else:
                        error(cat('Functions embedded in %!test blocks are not allowed.\n','Use the %!function/%!endfunction syntax instead to define shared functions for testing.\n'))
                finally:
                    pass
                clear('__test__')
            ## All done.  Remember if we were successful and print any messages.
            if (logical_not(isempty(__msg)) and (__verbose >= 0 or __logfile)):
                ## Make sure the user knows what caused the error.
                if (__verbose < 1):
                    fprintf(__fid,'%s%s\n',__signal_block,__block)
                    fflush(__fid)
                fprintf(__fid,'%s\n',__msg)
                fflush(__fid)
                if (logical_not(strcmp(__type,'error')) and logical_not(strcmp(__type,'testif')) and logical_not(all(__shared == ' '))):
                    fputs(__fid,'shared variables ')
                    eval(sprintf('fdisp(__fid,var2struct(%s));',__shared))
                    fflush(__fid)
            if (logical_not(__success) and logical_not(__isxtest)):
                __all_success=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:622
                if (logical_not(__batch) or nargout == 1):
                    if (nargout > 0):
                        if (nargout == 1):
                            __n=copy(false)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:627
                        else:
                            __n=__nmax=0
# /home/lei/octave-4.0.2/scripts/testfun/test.m:629
# /home/lei/octave-4.0.2/scripts/testfun/test.m:629
                    if (__close_fid):
                        fclose(__fid)
                    return __n,__nmax,__nxfail,__nskip
            __tests += (__istest or __isxtest)
            __successes += __success and (__istest or __isxtest)
        finally:
            warning('off','all')
            warning(orig_wstate)
    
    ## Clear any functions created during test run
    eval(__clearfcn,'')
    if (nargout == 0):
        if (__tests or __xfail or __xskip):
            if (__xfail):
                printf('PASSES %d out of %d test%s (%d expected failure%s)\n',__successes,__tests,ifelse(__tests > 1,'s',''),__xfail,ifelse(__xfail > 1,'s',''))
            else:
                printf('PASSES %d out of %d test%s\n',__successes,__tests,ifelse(__tests > 1,'s',''))
            if (__xskip):
                printf('Skipped %d test%s due to missing features\n',__xskip,ifelse(__xskip > 1,'s',''))
        else:
            printf('%s%s has no tests available\n',__signal_empty,__file)
    else:
        if (__grabdemo):
            __n=copy(__demo_code)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:668
            __nmax=copy(__demo_idx)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:669
        else:
            if (nargout == 1):
                __n=copy(__all_success)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:671
            else:
                __n=copy(__successes)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:673
                __nmax=copy(__tests)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:674
                __nxfail=copy(__xfail)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:675
                __nskip=copy(__xskip)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:676
    
    return __n,__nmax,__nxfail,__nskip
    
if __name__ == '__main__':
    pass
    
    ## Create structure with fieldnames the name of the input variables.
    
@function
def var2struct(varargin=None,*args,**kwargs):
    varargin = var2struct.varargin
    nargin = var2struct.nargin

    for i in arange(1,nargin).reshape(-1):
        setattr(s,deblank(argn(i,arange())),varargin[i])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:685
    
    return s
    
if __name__ == '__main__':
    pass
    
    ## Find [start,end] of fn in 'function [a,b] = fn'.
    
@function
def function_name(def_=None,*args,**kwargs):
    varargin = function_name.varargin
    nargin = function_name.nargin

    pos=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:691
    
    right=find(def_ == '(',1)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:694
    if (isempty(right)):
        return pos
    
    right=find(def_[1:right - 1] != ' ',1,'last')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:698
    
    left=max(cat(find(def_[1:right] == ' ',1,'last'),find(def_[1:right] == '=',1,'last')))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:701
    if (isempty(left)):
        return pos
    
    left
    
    pos=matlabarray(cat(left,right))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:709
    return pos
    
if __name__ == '__main__':
    pass
    
    ## Strip <pattern> from '<pattern> code'.
## Also handles 'id=ID code'
    
@function
def getpattern(str=None,*args,**kwargs):
    varargin = getpattern.varargin
    nargin = getpattern.nargin

    pattern='.'
# /home/lei/octave-4.0.2/scripts/testfun/test.m:715
    id=matlabarray([])
# /home/lei/octave-4.0.2/scripts/testfun/test.m:716
    rest=copy(str)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:717
    str=trimleft(str)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:718
    if (logical_not(isempty(str)) and str[1] == '<'):
        close_=index(str,'>')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:720
        if (close_):
            pattern=str[2:close_ - 1]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:722
            rest=str[close_ + 1:end()]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:723
    else:
        if (strncmp(str,'id=',3)):
            id,rest=strtok(str[4:end()],nargout=2)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:726
    
    return pattern,id,rest
    
if __name__ == '__main__':
    pass
    
    ## Strip '.*prefix:' from '.*prefix: msg\n' and strip trailing blanks.
    
@function
def trimerr(msg=None,prefix=None,*args,**kwargs):
    varargin = trimerr.varargin
    nargin = trimerr.nargin

    idx=index(msg,cat(prefix,':'))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:732
    if (idx > 0):
        msg[1:idx + length(prefix)]=[]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:734
    
    msg=strtrim(msg)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:736
    return msg
    
if __name__ == '__main__':
    pass
    
    ## Strip leading blanks from string.
    
@function
def trimleft(str=None,*args,**kwargs):
    varargin = trimleft.varargin
    nargin = trimleft.nargin

    idx=find(logical_not(isspace(str)),1)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:741
    str=str[idx:end()]
# /home/lei/octave-4.0.2/scripts/testfun/test.m:742
    return str
    
if __name__ == '__main__':
    pass
    
    
@function
def __extract_test_code(nm=None,*args,**kwargs):
    varargin = __extract_test_code.varargin
    nargin = __extract_test_code.nargin

    fid=fopen(nm,'rt')
# /home/lei/octave-4.0.2/scripts/testfun/test.m:746
    body=''
# /home/lei/octave-4.0.2/scripts/testfun/test.m:747
    if (fid >= 0):
        while (ischar(ln=fgets(fid)
# /home/lei/octave-4.0.2/scripts/testfun/test.m:749)):

            if (strncmp(ln,'%!',2)):
                body=matlabarray(cat(body,ln[3:end()]))
# /home/lei/octave-4.0.2/scripts/testfun/test.m:751

        fclose(fid)
    
    return body
    
if __name__ == '__main__':
    pass
    
    ## example from toeplitz
    
    
    
    
    
    
    
    
    
    
    
    ## example from kron
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Now verify test() itself
    
    ## Test 'fail' keyword
    
    
    
    
    ## Test 'error' keyword
    
    ## Test 'warning' keyword
    
    ## Test 'shared' keyword
    
    
    
    
    
    
    
    ## Test 'function' keyword
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test 'assert' keyword
    
    
    ## Test 'demo' keyword
    
    
    
    
    
    
    
    
    
    ## Test 'testif' keyword
    
    ## Test 'xtest' keyword
    
    
    
    
    ## Test comment block. it can contain anything.
    
    
    
    
    ## Test test() input validation
    
    ## All of the following tests should fail.  These tests should
## be disabled unless you are developing test() since users don't
## like to be presented with expected failures.  I use '# !' to disable.
# !test   error("---------Failure tests.  Use test('test','verbose',1)");
# !test   assert([a,b,c],[1,3,6]);   # variables have wrong values
# !bogus                     # unknown block type
# !error  toeplitz([1,2,3]); # correct usage
# !test   syntax errors)     # syntax errors fail properly
# !shared garbage in         # variables must be comma separated
# !error  syntax++error      # error test fails on syntax errors
# !error  "succeeds.";       # error test fails if code succeeds
# !error <wrong pattern> error("message")  # error pattern must match
# !demo   with syntax error  # syntax errors in demo fail properly
# !shared a,b,c
# !demo                      # shared variables not available in demo
# ! assert (exist ("a", "var"))
# !error
# ! test ('/etc/passwd');
# ! test ("nonexistent file");
# ! ## These don't signal an error, so the test for an error fails. Note
# ! ## that the call doesn't reference the current fid (it is unavailable),
# ! ## so of course the informational message is not printed in the log.
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} csvread (@var{filename})
## @deftypefnx {Function File} {@var{x} =} csvread (@var{filename}, @var{dlm_opts})
## Read the comma-separated-value file @var{filename} into the matrix @var{x}.
##
## This function is equivalent to
##
## @example
## @var{x} = dlmread (@var{filename}, "," , @dots{})
## @end example
##
## @seealso{csvwrite, dlmread, dlmwrite}
## @end deftypefn
    
    
@function
def csvread(filename=None,varargin=None,*args,**kwargs):
    varargin = csvread.varargin
    nargin = csvread.nargin

    x=dlmread(filename,',',varargin[:])
# /home/lei/octave-4.0.2/scripts/io/csvread.m:34
    return x
    
if __name__ == '__main__':
    pass
    
    ## Tests for csvread() are in csvwrite()
## Mark file as being tested
    
    ## Copyright (C) 2010-2015 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{str} =} fileread (@var{filename})
## Read the contents of @var{filename} and return it as a string.
## @seealso{fread, textread, sscanf}
## @end deftypefn
    
    
@function
def fileread(filename=None,*args,**kwargs):
    varargin = fileread.varargin
    nargin = fileread.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(ischar(filename))):
        error('fileread: FILENAME argument must be a string')
    
    fid=fopen(filename,'r')
# /home/lei/octave-4.0.2/scripts/io/fileread.m:35
    if (fid < 0):
        error('fileread: cannot open file')
    
    try:
        str=(fread(fid,'*char')).T
# /home/lei/octave-4.0.2/scripts/io/fileread.m:41
    finally:
        fclose(fid)
    
    return str
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2002-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dlmwrite (@var{file}, @var{M})
## @deftypefnx {Function File} {} dlmwrite (@var{file}, @var{M}, @var{delim}, @var{r}, @var{c})
## @deftypefnx {Function File} {} dlmwrite (@var{file}, @var{M}, @var{key}, @var{val} @dots{})
## @deftypefnx {Function File} {} dlmwrite (@var{file}, @var{M}, "-append", @dots{})
## @deftypefnx {Function File} {} dlmwrite (@var{fid}, @dots{})
## Write the matrix @var{M} to the named file using delimiters.
##
## @var{file} should be a file name or writable file ID given by @code{fopen}.
##
## The parameter @var{delim} specifies the delimiter to use to separate values
## on a row.
##
## The value of @var{r} specifies the number of delimiter-only lines to add to
## the start of the file.
##
## The value of @var{c} specifies the number of delimiters to prepend to each
## line of data.
##
## If the argument @qcode{"-append"} is given, append to the end of @var{file}.
##
## In addition, the following keyword value pairs may appear at the end of
## the argument list:
##
## @table @asis
## @item @qcode{"append"}
## Either @qcode{"on"} or @qcode{"off"}.  See @qcode{"-append"} above.
##
## @item @qcode{"delimiter"}
## See @var{delim} above.
##
## @item @qcode{"newline"}
## The character(s) to use to separate each row.  Three special cases exist
## for this option.  @qcode{"unix"} is changed into
## @qcode{"@xbackslashchar{}n"}, @qcode{"pc"} is changed into
## @qcode{"@xbackslashchar{}r@xbackslashchar{}n"}, and @qcode{"mac"} is
## changed into @qcode{"@xbackslashchar{}r"}.  Any other value is used
## directly as the newline separator.
##
## @item @qcode{"roffset"}
## See @var{r} above.
##
## @item @qcode{"coffset"}
## See @var{c} above.
##
## @item @qcode{"precision"}
## The precision to use when writing the file.  It can either be a format
## string (as used by fprintf) or a number of significant digits.
## @end table
##
## @example
## dlmwrite ("file.csv", reshape (1:16, 4, 4));
## @end example
##
## @example
## dlmwrite ("file.tex", a, "delimiter", "&", "newline", "\n")
## @end example
##
## @seealso{dlmread, csvread, csvwrite}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
##
## This program was originally granted to the public domain
##
## 2002-03-08 Paul Kienzle <pkienzle@users.sf.net>
## * Initial revision
## 2005-11-27 Bill Denney <bill@givebillmoney.com>
## * Significant modifications of the input arguments for additional
## functionality.
    
    
@function
def dlmwrite(file=None,M=None,varargin=None,*args,**kwargs):
    varargin = dlmwrite.varargin
    nargin = dlmwrite.nargin

    if (nargin < 2):
        print_usage()
    
    ## set defaults
    delim=','
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:97
    r=c=0
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:98
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:98
    newline='\n'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:99
    if (ischar(M)):
        precision='%c'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:101
    else:
        precision='%.16g'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:103
    
    opentype='wt'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:105
    
    i=0
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:108
    while (i < length(varargin)):

        i
        if (strcmpi(varargin[i],'delimiter')):
            delim=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:112
        else:
            if (strcmpi(varargin[i],'newline')):
                newline=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:114
                if (strcmpi(newline,'unix')):
                    newline='\n'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:116
                else:
                    if (strcmpi(newline,'pc')):
                        newline='\r\n'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:118
                    else:
                        if (strcmpi(newline,'mac')):
                            newline='\r'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:120
            else:
                if (strcmpi(varargin[i],'roffset')):
                    r=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:123
                else:
                    if (strcmpi(varargin[i],'coffset')):
                        c=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:125
                    else:
                        if (strcmpi(varargin[i],'precision')):
                            precision=varargin[++ i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:127
                            if (logical_not(strcmpi(class_(precision),'char'))):
                                precision=sprintf('%%.%gg',precision)
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:129
                        else:
                            if (strcmpi(varargin[i],'-append')):
                                opentype='at'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:132
                            else:
                                if (strcmpi(varargin[i],'append')):
                                    i
                                    if (strcmpi(varargin[i],'on')):
                                        opentype='at'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:136
                                    else:
                                        if (strcmpi(varargin[i],'off')):
                                            opentype='wt'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:138
                                        else:
                                            error('dlmwrite: append must be "on" or "off"')
                                else:
                                    if (i == 1):
                                        delim=varargin[i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:144
                                    else:
                                        if (i == 2):
                                            r=varargin[i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:146
                                        else:
                                            if (i == 3):
                                                c=varargin[i]
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:148
                                            else:
                                                print_usage()

    
    ## Expand '\t' to TAB for Matlab compatibility
    if (strcmp(delim,'\\t')):
        delim='\t'
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:157
    
    if (ischar(file)):
        fid,msg=fopen(file,opentype,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:161
    else:
        if (isscalar(file) and isnumeric(file)):
            fid,msg=deal(file,'invalid file number',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:163
        else:
            error('dlmwrite: FILE must be a filename string or numeric FID')
    
    if (fid < 0):
        error(cat('dlmwrite: ',msg))
    else:
        if (r > 0):
            fprintf(fid,'%s',repmat(cat(repmat(delim,1,c + columns(M) - 1),newline),1,r))
        if (iscomplex(M)):
            cprecision=regexprep(precision,'^%([-\\d.])','%+$1')
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:176
            template=matlabarray(cat(precision,cprecision,'i',repmat(cat(delim,precision,cprecision,'i'),1,columns(M) - 1),newline))
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:177
        else:
            template=matlabarray(cat(precision,repmat(cat(delim,precision),1,columns(M) - 1),newline))
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:181
        if (c > 0):
            template=matlabarray(cat(repmat(delim,1,c),template))
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:185
        if (iscomplex(M)):
            M=M.T
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:188
            b=zeros(dot(2,rows(M)),columns(M))
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:189
            b[1:2:end(),:]=real(M)
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:190
            b[2:2:end(),:]=imag(M)
# /home/lei/octave-4.0.2/scripts/io/dlmwrite.m:191
            fprintf(fid,template,b)
        else:
            fprintf(fid,template,M.T)
        if (logical_not(isscalar(file))):
            fclose(fid)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2003-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} beep ()
## Produce a beep from the speaker (or visual bell).
##
## This function sends the alarm character @qcode{"@xbackslashchar{}a"} to
## the terminal. Depending on the user's configuration this may produce an
## audible beep, a visual bell, or nothing at all.
## @seealso{puts, fputs, printf, fprintf}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def beep(*args,**kwargs):
    varargin = beep.varargin
    nargin = beep.nargin

    if (nargin != 0):
        print_usage()
    
    puts('\x07')
    return
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2010-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} is_valid_file_id (@var{fid})
## Return true if @var{fid} refers to an open file.
## @seealso{freport, fopen}
## @end deftypefn
    
    
@function
def is_valid_file_id(fid=None,*args,**kwargs):
    varargin = is_valid_file_id.varargin
    nargin = is_valid_file_id.nargin

    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/io/is_valid_file_id.m:27
    if (nargin == 1):
        try:
            if (isscalar(fid)):
                file,mode,arch=fopen(fid,nargout=3)
# /home/lei/octave-4.0.2/scripts/io/is_valid_file_id.m:32
                retval=logical_not(isempty(file))
# /home/lei/octave-4.0.2/scripts/io/is_valid_file_id.m:33
        finally:
            pass
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Erik Kjellson
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{A} =} importdata (@var{fname})
## @deftypefnx {Function File} {@var{A} =} importdata (@var{fname}, @var{delimiter})
## @deftypefnx {Function File} {@var{A} =} importdata (@var{fname}, @var{delimiter}, @var{header_rows})
## @deftypefnx {Function File} {[@var{A}, @var{delimiter}] =} importdata (@dots{})
## @deftypefnx {Function File} {[@var{A}, @var{delimiter}, @var{header_rows}] =} importdata (@dots{})
## Import data from the file @var{fname}.
##
## Input parameters:
##
## @itemize
## @item @var{fname}
## The name of the file containing data.
##
## @item @var{delimiter}
## The character separating columns of data.  Use @code{\t} for tab.
## (Only valid for ASCII files)
##
## @item @var{header_rows}
## The number of header rows before the data begins.  (Only valid for ASCII
## files)
## @end itemize
##
## Different file types are supported:
##
## @itemize
## @item ASCII table
##
## Import ASCII table using the specified number of header rows and the
## specified delimiter.
##
## @item Image file
##
## @item @sc{matlab} file
##
## @item Spreadsheet files (depending on external software)
##
## @item WAV file
##
## @end itemize
##
## @seealso{textscan, dlmread, csvread, load}
## @end deftypefn
    
    ## Author: Erik Kjellson <erikiiofph7@users.sourceforge.net>
    
    
@function
def importdata(fname=None,delimiter='',header_rows=- 1,*args,**kwargs):
    varargin = importdata.varargin
    nargin = importdata.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(fname))):
        error('importdata: FNAME must be a string')
    else:
        if (strcmpi(fname,'-pastespecial')):
            error('importdata: option -pastespecial not implemented')
    
    if (nargin > 1):
        if (logical_not(ischar(delimiter)) or (length(delimiter) > 1 and logical_not(strcmp(delimiter,'\\t')))):
            error('importdata: DELIMITER must be a single character')
        if (strcmp(delimiter,'\\t')):
            delimiter='\t'
# /home/lei/octave-4.0.2/scripts/io/importdata.m:83
    
    if (nargin > 2):
        if (logical_not(isnumeric(header_rows)) or header_rows < 0 or header_rows != fix(header_rows)):
            error('importdata: HEADER_ROWS must be an integer >= 0')
    
    ## Check file format
  ## Get the extension from the file name.
    __,__,ext,__=fileparts(fname,nargout=4)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:96
    ext=lower(ext)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:97
    if cellarray(['.au','.snd','.flac','.ogg']) == (ext):
        error('importdata: not implemented for file format %s',ext)
    else:
        if cellarray(['.avi','.mj2','.mpg','.asf','.asx','.wmv','.mp4','.m4v','.mov']) == (ext):
            error('importdata: not implemented for file format %s',ext)
        else:
            if cellarray(['.bmp','.cur','.gif','.hdf','.ico','.jpe','.jpeg','.jpg','.jp2','.jpf','.jpx','.j2c','.j2k','.pbm','.pcx','.pgm','.png','.pnm','.ppm','.ras','.tif','.tiff','.xwd']) == (ext):
                delimiter=copy(NaN)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:108
                header_rows=0
# /home/lei/octave-4.0.2/scripts/io/importdata.m:109
                output.cdata,output.colormap,output.alpha=imread(fname,nargout=3)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:110
            else:
                if '.mat' == (ext):
                    delimiter=copy(NaN)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:112
                    header_rows=0
# /home/lei/octave-4.0.2/scripts/io/importdata.m:113
                    output=load(fname)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:114
                else:
                    if cellarray(['.xls','.xlsx','.wk1','.dbf','.pxl']) == (ext):
                        ## If there's no Excel file support simply fall back to unimplemented.m
                        output=xlsread(fname)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:117
                    else:
                        if cellarray(['.ods','.sxc','.fods','.uos','.xml']) == (ext):
                            ## unimplemented.m only knows ML functions; odsread isn't one but is in OF
                            try:
                                output=odsread(fname)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:121
                            finally:
                                pass
                        else:
                            if cellarray(['.wav','.wave']) == (ext):
                                delimiter=copy(NaN)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:127
                                header_rows=0
# /home/lei/octave-4.0.2/scripts/io/importdata.m:128
                                output.data,output.fs=wavread(fname,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:129
                            else:
                                ## Assume the file is in ASCII format.
                                output,delimiter,header_rows=importdata_ascii(fname,delimiter,header_rows,nargout=3)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:132
    
    ## If there are any empty fields in the output structure, then remove them
    if (isstruct(output) and numel(output) == 1):
        fields=fieldnames(output)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:138
        for i in arange(1,length(fields)).reshape(-1):
            if (isempty(getattr(output,(fields[i])))):
                output=rmfield(output,fields[i])
# /home/lei/octave-4.0.2/scripts/io/importdata.m:141
        ## If only one field is left, replace the structure with the field,
    ## i.e., output = output.onlyFieldLeft
        ## Update the list of fields
        if (numfields(output) == 1):
            output=getattr(output,(fields[1]))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:150
    
    return output,delimiter,header_rows
    
if __name__ == '__main__':
    pass
    
    
@function
def importdata_ascii(fname=None,delimiter=None,num_header_rows=None,*args,**kwargs):
    varargin = importdata_ascii.varargin
    nargin = importdata_ascii.nargin

    ## Define fields in the output structure so that the order will be correct.
    output.data = copy([])
# /home/lei/octave-4.0.2/scripts/io/importdata.m:159
    output.textdata = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:160
    output.rowheaders = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:161
    output.colheaders = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:162
    fid,msg=fopen(fname,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:164
    if (fid == - 1):
        error(msg)
    
    header_rows=0
# /home/lei/octave-4.0.2/scripts/io/importdata.m:169
    header_cols=0
# /home/lei/octave-4.0.2/scripts/io/importdata.m:170
    
    while (ischar(row=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:173)):

        ## If no delimiter determined yet, make a guess.
        if (isempty(delimiter)):
            ## This pattern can be fooled, but mostly does the job just fine.
            delim=regexpi(row,'[-+\\d.e*ij ]+([^-+\\de.ij])[-+\\de*.ij ]','tokens','once')
# /home/lei/octave-4.0.2/scripts/io/importdata.m:178
            #                     'tokens', 'once');
            if (logical_not(isempty(delim))):
                delimiter=delim[1]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:183
        if (delimiter == ' '):
            row_entries=regexp(strtrim(row),' +','split')
# /home/lei/octave-4.0.2/scripts/io/importdata.m:188
        else:
            row_entries=ostrsplit(row,delimiter)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:190
        row_data=str2double(row_entries)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:192
        if (all(isnan(row_data)) or header_rows < num_header_rows):
            header_rows
            output.textdata[end() + 1,1]=row
# /home/lei/octave-4.0.2/scripts/io/importdata.m:195
        else:
            if (logical_not(isempty(output.textdata))):
                if (delimiter == ' '):
                    output.colheaders = copy(regexp(strtrim(output.textdata[end()]),' +','split'))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:199
                else:
                    output.colheaders = copy(ostrsplit(output.textdata[end()],delimiter))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:202
            header_cols=find(logical_not(isnan(row_data)),1) - 1
# /home/lei/octave-4.0.2/scripts/io/importdata.m:205
            break

    
    if (row == - 1):
        ## No numeric data found => return file as cellstr array
    ## 1. Read as char string
        fseek(fid,0,'bof')
        output=fread(fid,Inf,'*char').T
# /home/lei/octave-4.0.2/scripts/io/importdata.m:216
        fclose(fid)
        idx=find(output[1:min(4096,length(output))] == '\n',1) - 1
# /home/lei/octave-4.0.2/scripts/io/importdata.m:219
        if (isindex(idx) and output[idx] == '\r'):
            dlm='\r\n'
# /home/lei/octave-4.0.2/scripts/io/importdata.m:221
        else:
            dlm='\n'
# /home/lei/octave-4.0.2/scripts/io/importdata.m:223
        ## 3. Split each line into a cell (column vector)
        output=strsplit(output,dlm).T
# /home/lei/octave-4.0.2/scripts/io/importdata.m:226
        if (isempty(output[end()])):
            output[end()]=[]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:229
        ## 5. Return after setting some output data
        delimiter=''
# /home/lei/octave-4.0.2/scripts/io/importdata.m:232
        header_rows=numel(output)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:233
        return output,delimiter,header_rows
    else:
        fclose(fid)
    
    if (num_header_rows >= 0):
        header_rows=copy(num_header_rows)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:240
    
    ## Now, let the efficient built-in routine do the bulk of the work.
    if (delimiter == ' '):
        output.data = copy(dlmread(fname,'',header_rows,header_cols,'emptyvalue',NA))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:245
    else:
        output.data = copy(dlmread(fname,delimiter,header_rows,header_cols,'emptyvalue',NA))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:248
    
    ## Go back and correct any individual values that did not convert.
    na_idx=isna(output.data)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:253
    if (header_cols > 0):
        na_idx=matlabarray(cat((true(rows(na_idx),header_cols)),na_idx))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:255
    
    if (any(ravel(na_idx))):
        file_content=ostrsplit(fileread(fname),'\n')
# /home/lei/octave-4.0.2/scripts/io/importdata.m:259
        na_rows=find(any(na_idx,2))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:261
        for ridx in ravel(na_rows).T.reshape(-1):
            row=file_content[ridx + header_rows]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:263
            if (delimiter == ' '):
                fields=regexp(strtrim(row),' +','split')
# /home/lei/octave-4.0.2/scripts/io/importdata.m:265
            else:
                fields=ostrsplit(row,delimiter)
# /home/lei/octave-4.0.2/scripts/io/importdata.m:267
            text=fields[na_idx[ridx,:]]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:270
            text=text[logical_not(strcmpi(text,'NA'))]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:271
            if (logical_not(isempty(text))):
                output.textdata[end() + 1:end() + numel(text),1]=text
# /home/lei/octave-4.0.2/scripts/io/importdata.m:273
            if (header_cols):
                output.rowheaders[end() + 1,:]=fields[1:header_cols]
# /home/lei/octave-4.0.2/scripts/io/importdata.m:276
    
    ## Final cleanup to satisfy output configuration
    if (all(cellfun('isempty',output.textdata))):
        output=output.data
# /home/lei/octave-4.0.2/scripts/io/importdata.m:284
    else:
        if (logical_not(isempty(output.rowheaders)) and logical_not(isempty(output.colheaders))):
            output=struct('data',cellarray([output.data]),'textdata',cellarray([output.textdata]))
# /home/lei/octave-4.0.2/scripts/io/importdata.m:286
    
    return output,delimiter,header_rows
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Eric Chassande-Mottin, CNRS (France)
## Parts Copyright (C) 2012-2015 Philip Nienhuis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{a}, @dots{}] =} strread (@var{str})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} strread (@var{str}, @var{format})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} strread (@var{str}, @var{format}, @var{format_repeat})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} strread (@var{str}, @var{format}, @var{prop1}, @var{value1}, @dots{})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} strread (@var{str}, @var{format}, @var{format_repeat}, @var{prop1}, @var{value1}, @dots{})
## Read data from a string.
##
## The string @var{str} is split into words that are repeatedly matched to the
## specifiers in @var{format}.  The first word is matched to the first
## specifier, the second to the second specifier and so forth.  If there are
## more words than specifiers, the process is repeated until all words have
## been processed.
##
## The string @var{format} describes how the words in @var{str} should be
## parsed.  It may contain any combination of the following specifiers:
##
## @table @code
## @item #s
## The word is parsed as a string.
##
## @item  #f
## @itemx #n
## The word is parsed as a number and converted to double.
##
## @item  #d
## @itemx #u
## The word is parsed as a number and converted to int32.
##
## @item #*', '#*f', '#*s
## The word is skipped.
##
## For #s and #d, #f, #n, #u and the associated #*s @dots{} specifiers an
## optional width can be specified as #Ns, etc. where N is an integer > 1.
## For #f, format specifiers like #N.Mf are allowed.
##
## @item literals
## In addition the format may contain literal character strings; these will be
## skipped during reading.
## @end table
##
## Parsed word corresponding to the first specifier are returned in the first
## output argument and likewise for the rest of the specifiers.
##
## By default, @var{format} is @t{"#f"}, meaning that numbers are read from
## @var{str}.  This will do if @var{str} contains only numeric fields.
##
## For example, the string
##
## @example
## @group
## @var{str} = "\
## Bunny Bugs   5.5\n\
## Duck Daffy  -7.5e-5\n\
## Penguin Tux   6"
## @end group
## @end example
##
## @noindent
## can be read using
##
## @example
## [@var{a}, @var{b}, @var{c}] = strread (@var{str}, "#s #s #f");
## @end example
##
## Optional numeric argument @var{format_repeat} can be used for limiting the
## number of items read:
##
## @table @asis
## @item -1
## (default) read all of the string until the end.
##
## @item N
## Read N times @var{nargout} items.  0 (zero) is an acceptable value for
## @var{format_repeat}.
## @end table
##
## The behavior of @code{strread} can be changed via property-value pairs.  The
## following properties are recognized:
##
## @table @asis
## @item @qcode{"commentstyle"}
## Parts of @var{str} are considered comments and will be skipped.
## @var{value} is the comment style and can be any of the following.
##
## @itemize
## @item @qcode{"shell"}
## Everything from @code{#} characters to the nearest end-of-line is skipped.
##
## @item @qcode{"c"}
## Everything between @code{/*} and @code{*/} is skipped.
##
## @item @qcode{"c++"}
## Everything from @code{//} characters to the nearest end-of-line is skipped.
##
## @item @qcode{"matlab"}
## Everything from @code{#} characters to the nearest end-of-line is skipped.
##
## @item user-supplied.  Two options:
## (1) One string, or 1x1 cell string: Skip everything to the right of it;
## (2) 2x1 cell string array: Everything between the left and right strings
## is skipped.
## @end itemize
##
## @item @qcode{"delimiter"}
## Any character in @var{value} will be used to split @var{str} into words
## (default value = any whitespace).  Note that whitespace is implicitly added
## to the set of delimiter characters unless a @qcode{"#s"} format conversion
## specifier is supplied; see @qcode{"whitespace"} parameter below.  The set
## of delimiter characters cannot be empty; if needed Octave substitutes a
## space as delimiter.
##
## @item @qcode{"emptyvalue"}
## Value to return for empty numeric values in non-whitespace delimited data.
## The default is NaN@.  When the data type does not support NaN (int32 for
## example), then default is zero.
##
## @item @qcode{"multipledelimsasone"}
## Treat a series of consecutive delimiters, without whitespace in between,
## as a single delimiter.  Consecutive delimiter series need not be vertically
## @qcode{"aligned"}.
##
## @item @qcode{"treatasempty"}
## Treat single occurrences (surrounded by delimiters or whitespace) of the
## string(s) in @var{value} as missing values.
##
## @item @qcode{"returnonerror"}
## If @var{value} true (1, default), ignore read errors and return normally.
## If false (0), return an error.
##
## @item @qcode{"whitespace"}
## Any character in @var{value} will be interpreted as whitespace and trimmed;
## the string defining whitespace must be enclosed in double quotes for proper
## processing of special characters like @qcode{"@xbackslashchar{}t"}.  In
## each data field, multiple consecutive whitespace characters are collapsed
## into one space and leading and trailing whitespace is removed.  The default
## value for whitespace is
## @c Note: the next line specifically has a newline which generates a space
## @c       in the output of qcode, but keeps the next line < 80 characters.
## @qcode{"
## @xbackslashchar{}b@xbackslashchar{}r@xbackslashchar{}n@xbackslashchar{}t"}
## (note the space).  Whitespace is always added to the set of delimiter
## characters unless at least one @qcode{"#s"} format conversion specifier is
## supplied; in that case only whitespace explicitly specified in
## @qcode{"delimiter"} is retained as delimiter and removed from the set of
## whitespace characters.  If whitespace characters are to be kept as-is (in
## e.g., strings), specify an empty value (i.e., @qcode{""}) for
## @qcode{"whitespace"}; obviously, whitespace cannot be a delimiter then.
##
## @end table
##
## When the number of words in @var{str} doesn't match an exact multiple of
## the number of format conversion specifiers, strread's behavior depends on
## the last character of @var{str}:
##
## @table @asis
## @item last character = @qcode{"@xbackslashchar{}n"}
## Data columns are padded with empty fields or Nan so that all columns have
## equal length
##
## @item last character is not @qcode{"@xbackslashchar{}n"}
## Data columns are not padded; strread returns columns of unequal length
##
## @end table
##
## @seealso{textscan, textread, load, dlmread, fscanf}
## @end deftypefn
    
    
@function
def strread(str=None,format='%f',varargin=None,*args,**kwargs):
    varargin = strread.varargin
    nargin = strread.nargin

    ## Check input
    if (nargin < 1):
        print_usage()
    
    if (isempty(str)):
        ## Return empty args (no match), rather than raising an error
        varargout=cell(1,nargout)
# /home/lei/octave-4.0.2/scripts/io/strread.m:197
        return varargout
    
    if (isempty(format)):
        format='%f'
# /home/lei/octave-4.0.2/scripts/io/strread.m:202
    
    if (logical_not(ischar(str)) or logical_not(ischar(format))):
        error('strread: STR and FORMAT arguments must be strings')
    
    if (strcmp(typeinfo(format),'sq_string')):
        format=do_string_escapes(format)
# /home/lei/octave-4.0.2/scripts/io/strread.m:210
    
    ## Parse format string to compare number of conversion fields and nargout
    nfields=numel(regexp(format,'(%(\\d*|\\d*\\.\\d*)?[nfduscq]|%\\[)','match'))
# /home/lei/octave-4.0.2/scripts/io/strread.m:214
    
    ## Otherwise:
    if (logical_not(nfields)):
        error('strread.m: no valid format conversion specifiers found\n')
    else:
        if ((max(nargout,1) != nfields) and logical_not(strcmp(format,'%f'))):
            error('strread: the number of output variables must match that specified by FORMAT')
    
    ## Check for format string repeat count
    format_repeat_count=- 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:224
    if (nargin > 2 and isnumeric(varargin[1])):
        if (varargin[1] >= 0):
            format_repeat_count=varargin[1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:227
        if (nargin > 3):
            varargin=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/io/strread.m:230
        else:
            varargin=cellarray([])
# /home/lei/octave-4.0.2/scripts/io/strread.m:232
    
    ## Parse options.  First initialize defaults
    comment_flag=copy(false)
# /home/lei/octave-4.0.2/scripts/io/strread.m:237
    delimiter_str=''
# /home/lei/octave-4.0.2/scripts/io/strread.m:238
    empty_str=''
# /home/lei/octave-4.0.2/scripts/io/strread.m:239
    eol_char=''
# /home/lei/octave-4.0.2/scripts/io/strread.m:240
    err_action=0
# /home/lei/octave-4.0.2/scripts/io/strread.m:241
    mult_dlms_s1=copy(false)
# /home/lei/octave-4.0.2/scripts/io/strread.m:242
    numeric_fill_value=copy(NaN)
# /home/lei/octave-4.0.2/scripts/io/strread.m:243
    white_spaces=' \x08\r\n\t'
# /home/lei/octave-4.0.2/scripts/io/strread.m:244
    for n in arange(1,length(varargin),2).reshape(-1):
        if 'bufsize' == (lower(varargin[n])):
            ## We could synthesize this, but that just seems weird...
            warning('strread: property \'bufsize\' is not implemented')
        else:
            if 'commentstyle' == (lower(varargin[n])):
                comment_flag=copy(true)
# /home/lei/octave-4.0.2/scripts/io/strread.m:251
                if 'c' == (lower(varargin[n + 1])):
                    comment_start,comment_end=deal('/*','*/',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:254
                else:
                    if 'c++' == (lower(varargin[n + 1])):
                        comment_start,comment_end=deal('//','eol_char',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:256
                    else:
                        if 'shell' == (lower(varargin[n + 1])):
                            comment_start,comment_end=deal('#','eol_char',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:258
                        else:
                            if 'matlab' == (lower(varargin[n + 1])):
                                comment_start,comment_end=deal('%','eol_char',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:260
                            else:
                                if (ischar(varargin[n + 1]) or (numel(varargin[n + 1]) == 1 and iscellstr(varargin[n + 1]))):
                                    comment_start,comment_end=deal(char(varargin[n + 1]),'eol_char',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:264
                                else:
                                    if (iscellstr(varargin[n + 1]) and numel(varargin[n + 1]) == 2):
                                        comment_start,comment_end=deal(varargin[n + 1][:],nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:266
                                    else:
                                        ## FIXME: A user may have numeric values specified: {'//', 7}
              ##        this will lead to an error in the warning message
                                        error('strread: unknown or unrecognized comment style \'%s\'',varargin[n + 1])
            else:
                if 'delimiter' == (lower(varargin[n])):
                    delimiter_str=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:275
                    if (strcmp(typeinfo(delimiter_str),'sq_string')):
                        delimiter_str=do_string_escapes(delimiter_str)
# /home/lei/octave-4.0.2/scripts/io/strread.m:277
                else:
                    if 'emptyvalue' == (lower(varargin[n])):
                        numeric_fill_value=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:280
                    else:
                        if 'expchars' == (lower(varargin[n])):
                            warning('strread: property \'expchars\' is not implemented')
                        else:
                            if 'whitespace' == (lower(varargin[n])):
                                white_spaces=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:284
                                if (strcmp(typeinfo(white_spaces),'sq_string')):
                                    white_spaces=do_string_escapes(white_spaces)
# /home/lei/octave-4.0.2/scripts/io/strread.m:286
                                ## The following parameters are specific to textscan and textread
                            else:
                                if 'endofline' == (lower(varargin[n])):
                                    eol_char=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:290
                                    if (strcmp(typeinfo(eol_char),'sq_string')):
                                        eol_char=do_string_escapes(eol_char)
# /home/lei/octave-4.0.2/scripts/io/strread.m:292
                                else:
                                    if 'returnonerror' == (lower(varargin[n])):
                                        err_action=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:295
                                    else:
                                        if 'multipledelimsasone' == (lower(varargin[n])):
                                            mult_dlms_s1=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:297
                                        else:
                                            if 'treatasempty' == (lower(varargin[n])):
                                                if (iscellstr(varargin[n + 1])):
                                                    empty_str=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:300
                                                else:
                                                    if (ischar(varargin[n + 1])):
                                                        empty_str=varargin[n + 1]
# /home/lei/octave-4.0.2/scripts/io/strread.m:302
                                                    else:
                                                        error('strread: \'treatasempty\' value must be string or cellstr')
                                            else:
                                                warning('strread: unknown property \'%s\'',varargin[n])
    
    ## First parse of FORMAT
    if (strcmpi(strtrim(format),'%f')):
        ## Default format specified.  Expand it (to desired nargout)
        fmt_words=cell(max(nargout,1),1)
# /home/lei/octave-4.0.2/scripts/io/strread.m:314
        fmt_words[1:max(nargout,1)]=format
# /home/lei/octave-4.0.2/scripts/io/strread.m:315
    else:
        ## Determine the number of words per line as a first guess.  Forms
    ## like #f<literal>) (w/o delimiter in between) are fixed further on
        format=strrep(format,'%',' %')
# /home/lei/octave-4.0.2/scripts/io/strread.m:319
        fmt_words=regexp(format,'[^ ]+','match')
# /home/lei/octave-4.0.2/scripts/io/strread.m:320
        fcs_ptrn='(%\\*?(\\d*|\\d*\\.\\d*)?[nfduscq]|%\\*?\\[)'
# /home/lei/octave-4.0.2/scripts/io/strread.m:323
        idy2=find(logical_not(cellfun('isempty',regexp(fmt_words,fcs_ptrn))))
# /home/lei/octave-4.0.2/scripts/io/strread.m:324
        errpat='(\\[.*\\]|[cq]|[nfdu]8|[nfdu]16|[nfdu]32|[nfdu]64)'
# /home/lei/octave-4.0.2/scripts/io/strread.m:327
        if (logical_not(all(cellfun('isempty',regexp(fmt_words[idy2],errpat))))):
            error('strread: %q, %c, %[] or bit width format specifiers are not supported yet.')
        ## Format conversion specifiers following literals w/o space/delim
    ## in between are separate now.  Separate those w trailing literals
        a=strfind(fmt_words[idy2],'%')
# /home/lei/octave-4.0.2/scripts/io/strread.m:334
        b=regexp(fmt_words[idy2],'[nfdus]','end')
# /home/lei/octave-4.0.2/scripts/io/strread.m:335
        for jj in arange(1,numel(a)).reshape(-1):
            ## From right to left to avoid losing track
            ii=numel(a) - jj + 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:338
            if (isempty(b[ii])):
                error('strread: unknown format specifier #%d (\'%s\')\n',ii,fmt_words[idy2[ii]])
            if (logical_not((length(fmt_words[idy2[ii]]) == b[ii](1)))):
                ## Split fmt_words(ii) into # conv specifier and trailing literal
                fmt_words[idy2[ii] + 1:end() + 1]=fmt_words[idy2[ii]:end()]
# /home/lei/octave-4.0.2/scripts/io/strread.m:346
                fmt_words[idy2[ii]]=fmt_words[idy2[ii]](arange(a[ii],b[ii](1)))
# /home/lei/octave-4.0.2/scripts/io/strread.m:347
                fmt_words[idy2[ii] + 1]=fmt_words[idy2[ii] + 1](arange(b[ii] + 1,end()))
# /home/lei/octave-4.0.2/scripts/io/strread.m:348
    
    num_words_per_line=numel(fmt_words)
# /home/lei/octave-4.0.2/scripts/io/strread.m:352
    
    if (logical_not(isempty(eol_char)) and strcmp(eol_char,'\r\n')):
        ## Strip CR from CRLF sequences
        str=strrep(str,'\r\n','\n')
# /home/lei/octave-4.0.2/scripts/io/strread.m:357
        eol_char='\n'
# /home/lei/octave-4.0.2/scripts/io/strread.m:359
    
    ## Remove comments in str
    if (comment_flag):
        ## Expand 'eol_char' here, after option processing which may have set value
        comment_end=regexprep(comment_end,'eol_char',eol_char)
# /home/lei/octave-4.0.2/scripts/io/strread.m:365
        cstart=strfind(str,comment_start)
# /home/lei/octave-4.0.2/scripts/io/strread.m:366
        cstop=strfind(str,comment_end)
# /home/lei/octave-4.0.2/scripts/io/strread.m:367
        if (isempty(cstop) or cstop[end()] != length(str)):
            cstop[end() + 1]=length(str)
# /home/lei/octave-4.0.2/scripts/io/strread.m:370
        if (logical_not(isempty(cstart))):
            ## Ignore nested openers.
            idx,cidx=unique(lookup(cstop,cstart),'first',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:374
            if (idx[end()] == length(cstop)):
                cidx[end()]=[]
# /home/lei/octave-4.0.2/scripts/io/strread.m:376
            cstart=cstart[cidx]
# /home/lei/octave-4.0.2/scripts/io/strread.m:378
        if (logical_not(isempty(cstop))):
            ## Ignore nested closers.
            idx,cidx=unique(lookup(cstart,cstop),'first',nargout=2)
# /home/lei/octave-4.0.2/scripts/io/strread.m:382
            if (idx[1] == 0):
                cidx[1]=[]
# /home/lei/octave-4.0.2/scripts/io/strread.m:384
            cstop=cstop[cidx]
# /home/lei/octave-4.0.2/scripts/io/strread.m:386
        len_=length(str)
# /home/lei/octave-4.0.2/scripts/io/strread.m:388
        c2len=length(comment_end)
# /home/lei/octave-4.0.2/scripts/io/strread.m:389
        if (cstop + c2len == len_):
            ## Ignore last char of to-the-end-of-line comments
            c2len
        str=cellslices(str,cat(1,cstop + c2len),cat(cstart - 1,len_))
# /home/lei/octave-4.0.2/scripts/io/strread.m:394
        str=matlabarray(cat(str[:]))
# /home/lei/octave-4.0.2/scripts/io/strread.m:395
    
    if (logical_not(isempty(white_spaces))):
        ## For numeric fields, whitespace is always a delimiter, but not for text
    ## fields
        if (isempty(regexp(format,'%\\*?\\d*s'))):
            ## Add whitespace to delimiter set
            delimiter_str=unique(cat(white_spaces,delimiter_str))
# /home/lei/octave-4.0.2/scripts/io/strread.m:403
        else:
            ## Remove any delimiter chars from white_spaces list
            white_spaces=setdiff(white_spaces,delimiter_str)
# /home/lei/octave-4.0.2/scripts/io/strread.m:406
    
    if (isempty(delimiter_str)):
        delimiter_str=' '
# /home/lei/octave-4.0.2/scripts/io/strread.m:410
    
    if (logical_not(isempty(eol_char))):
        ## Add eol_char to delimiter collection
        delimiter_str=unique(cat(delimiter_str,eol_char))
# /home/lei/octave-4.0.2/scripts/io/strread.m:414
        white_spaces=strrep(white_spaces,eol_char,'')
# /home/lei/octave-4.0.2/scripts/io/strread.m:416
    
    ii=numel(fmt_words)
# /home/lei/octave-4.0.2/scripts/io/strread.m:419
    while (ii > 0):

        if (ismember(fmt_words[ii],delimiter_str)(1)):
            fmt_words[ii]=[]
# /home/lei/octave-4.0.2/scripts/io/strread.m:422
            -- num_words_per_line
        -- ii

    
    pad_out=0
# /home/lei/octave-4.0.2/scripts/io/strread.m:428
    
    if (logical_not(isempty(white_spaces))):
        ## Check if trailing "\n" might signal padding output arrays to equal size
    ## before it is trimmed away below
        if (str[end()] == '\n' and nargout > 1):
            pad_out=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:434
        ## Condense all repeated whitespace into one single space
    ## FIXME: this will also fold repeated whitespace in a char field
        rxp_wsp=sprintf('[%s]+',white_spaces)
# /home/lei/octave-4.0.2/scripts/io/strread.m:438
        str=regexprep(str,rxp_wsp,' ')
# /home/lei/octave-4.0.2/scripts/io/strread.m:439
        if (str[1] == ' '):
            str=str[2:end()]
# /home/lei/octave-4.0.2/scripts/io/strread.m:442
        ## Check for single delimiter followed/preceded by whitespace
        if (logical_not(isempty(delimiter_str))):
            dlmstr=setdiff(delimiter_str,' ')
# /home/lei/octave-4.0.2/scripts/io/strread.m:446
            if (logical_not(isempty(dlmstr))):
                rxp_dlmwsp=sprintf('( [%s] | [%s]|[%s] )',dlmstr,dlmstr,dlmstr)
# /home/lei/octave-4.0.2/scripts/io/strread.m:448
                str=regexprep(str,rxp_dlmwsp,delimiter_str[1])
# /home/lei/octave-4.0.2/scripts/io/strread.m:449
        ## Wipe leading and trailing whitespace on each line (it may be
    ## delimiter too)
    ## FIXME: Double strrep on str is enormously expensive of CPU time.
    ## Can this be eliminated
        if (logical_not(isempty(eol_char))):
            str=strrep(str,cat(eol_char,' '),eol_char)
# /home/lei/octave-4.0.2/scripts/io/strread.m:457
            str=strrep(str,cat(' ',eol_char),eol_char)
# /home/lei/octave-4.0.2/scripts/io/strread.m:458
    
    ## Split 'str' into words
    words=split_by(str,delimiter_str,mult_dlms_s1,eol_char)
# /home/lei/octave-4.0.2/scripts/io/strread.m:463
    if (logical_not(isempty(white_spaces))):
        ## Trim leading and trailing 'white_spaces'. All whitespace has
    ## been converted to space above
        words=strtrim(words)
# /home/lei/octave-4.0.2/scripts/io/strread.m:467
    
    num_words=numel(words)
# /home/lei/octave-4.0.2/scripts/io/strread.m:469
    
    num_lines=ceil(num_words / num_words_per_line)
# /home/lei/octave-4.0.2/scripts/io/strread.m:471
    
    if (logical_not(isempty(empty_str))):
        for ii in arange(1,numel(empty_str)).reshape(-1):
            idz=strncmp(empty_str[ii],words,length(empty_str[ii]))
# /home/lei/octave-4.0.2/scripts/io/strread.m:476
            words[idz]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/io/strread.m:477
    
    ## fmt_words has been split properly now, but words{} has only been split on
  ## delimiter positions. As numeric fields can also be separated by
  ## whitespace, more splits may be needed.
  ## We also don't know the number of lines (as EndOfLine may have been set to
  ## "" (empty) by the caller).
  ##
  ## We also may have to cope with 3 cases as far as literals go:
  ## A: Trailing literals (#f<literal>) w/o delimiter in between.
  ## B: Leading literals (<literal>#f) w/o delimiter in between.
  ## C. Skipping leftover parts of specified skip fields (#*N )
  ## Some words columns may have to be split further to fix these.
  ## To find out, we'll match fmt_words to the words array to see what
  ## needs to be done. fwptr tracks which {fmt_words}# starts in what {words}#
    
    ## Find indices and pointers to possible literals in fmt_words
    idf=cellfun('isempty',strfind(fmt_words,'%'))
# /home/lei/octave-4.0.2/scripts/io/strread.m:496
    
    idg=logical_not(cellfun('isempty',regexp(fmt_words,'%\\*?\\d')))
# /home/lei/octave-4.0.2/scripts/io/strread.m:498
    idy=find(logical_or(idf,idg))
# /home/lei/octave-4.0.2/scripts/io/strread.m:499
    
    idn=logical_not(cellfun('isempty',regexp(fmt_words,'%[dnfu]')))
# /home/lei/octave-4.0.2/scripts/io/strread.m:501
    
    if (logical_not(isempty(idy))):
        ## Try-catch because complexity of strings to read can be infinite
        try:
            ## 1. Assess "period" in the split-up words array ( < num_words_per_line).
      ## Could be done using EndOfLine but that prohibits EndOfLine = "" option.
      ## Alternative below goes by simply parsing a first grab of words and
      ## matching fmt_words to words until the fmt_words array is exhausted.
      ## iwrd: ptr to current analyzed word.
      ## iwrdp: ptr to pos before analyzed char.
            iwrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:514
            iwrdp=0
# /home/lei/octave-4.0.2/scripts/io/strread.m:514
            iwrdl=length(words[1])
# /home/lei/octave-4.0.2/scripts/io/strread.m:514
            fwptr=zeros(1,numel(fmt_words))
# /home/lei/octave-4.0.2/scripts/io/strread.m:515
            ii=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:516
            while (ii <= numel(fmt_words)):

                nxt_wrd=0
# /home/lei/octave-4.0.2/scripts/io/strread.m:519
                fwptr[ii]=iwrd
# /home/lei/octave-4.0.2/scripts/io/strread.m:521
                if (idf[ii]):
                    ## Literal expected
                    if (isempty(strfind(fmt_words[ii],words[iwrd]))):
                        ## Not found in current word; supposed to be in next word
                        nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:527
                    else:
                        ## Found it in current word.  Subtract literal length
                        iwrdp += length(fmt_words[ii])
                        if (iwrdp > iwrdl):
                            ## Parse error.  Literal extends beyond delimiter (word boundary)
                            warning('strread: literal \'%s\' (fmt spec # %d) does not match data',fmt_words[ii],ii)
                            nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:536
                        else:
                            if (iwrdp == iwrdl):
                                ## Word completely "used up". Next word
                                nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:539
                else:
                    if (idg[ii]):
                        ## Fixed width specifier (#N or #*N): read just a part of word
                        sw=regexp(fmt_words[ii],'\\d','once')
# /home/lei/octave-4.0.2/scripts/io/strread.m:545
                        ew=regexp(fmt_words[ii],'[nfuds]') - 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:546
                        iwrdp += floor(str2double(fmt_words[ii](arange(sw,ew))))
                        if (iwrdp > iwrdl):
                            ## Match error. Field extends beyond word boundary.
                            warning('strread: field width \'%s\' (fmt spec # %d) extends beyond actual word limit',fmt_words[ii],ii)
                            nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:554
                        else:
                            if (iwrdp == iwrdl):
                                ## Word completely "used up".  Next word
                                nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:557
                    else:
                        ## A simple format conv. specifier. Either (1) uses rest of word, or
          ## (2) is squeezed between current iwrdp and next literal, or (3) uses
          ## next word. (3) is already taken care of.  So just check (1) & (2)
                        if (ii < numel(fmt_words) and idf[ii + 1]):
                            ## Next fmt_word is a literal...
                            if (logical_not(index(words[iwrd](arange(iwrdp + 1,end())),fmt_words[ii + 1]))):
                                ## ...but not found in current word => field uses rest of word
                                nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:568
                            else:
                                ## ..or it IS found.  Add inferred width of current conversion field
                                iwrdp += index(words[iwrd](arange(iwrdp + 1,end())),fmt_words[ii + 1]) - 1
                        else:
                            if (iwrdp <= iwrdl):
                                ## No bordering literal to the right => field occupies (rest of) word
                                nxt_wrd=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:575
                if (nxt_wrd):
                    ++ iwrd
                    iwrdp=0
# /home/lei/octave-4.0.2/scripts/io/strread.m:581
                    if (iwrd > numel(words)):
                        ## Apparently EOF; assume incomplete row already at L.1 of data
                        ii=numel(fmt_words)
# /home/lei/octave-4.0.2/scripts/io/strread.m:584
                    else:
                        if (ii < numel(fmt_words) and iwrd <= numel(words)):
                            iwrdl=length(words[iwrd])
# /home/lei/octave-4.0.2/scripts/io/strread.m:586
                ++ ii

            ## Done
            words_period=max(iwrd - 1,1)
# /home/lei/octave-4.0.2/scripts/io/strread.m:594
            num_lines=ceil(num_words / words_period)
# /home/lei/octave-4.0.2/scripts/io/strread.m:595
            num_words_padded=dot(num_lines,words_period) - num_words
# /home/lei/octave-4.0.2/scripts/io/strread.m:598
            if (num_words_padded):
                words=matlabarray(cat([words.T],[cell(num_words_padded,1)]))
# /home/lei/octave-4.0.2/scripts/io/strread.m:600
            words=reshape(words,words_period,num_lines)
# /home/lei/octave-4.0.2/scripts/io/strread.m:602
            icol=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:605
            ii=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:605
            while (ii <= num_words_per_line):

                ## Check if fmt_words(ii) contains a literal or fixed-width
                if ((idf[ii] or idg[ii]) and (rows(words) < num_words_per_line)):
                    if (idf[ii]):
                        s=strfind(words[icol,1],fmt_words[ii])
# /home/lei/octave-4.0.2/scripts/io/strread.m:611
                        if (isempty(s[:])):
                            error('strread: Literal \'%s\' not found in column %d',fmt_words[ii],icol)
                        s=s[:](1)
# /home/lei/octave-4.0.2/scripts/io/strread.m:615
                        e=s[1] + length(fmt_words[ii]) - 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:616
                    if (logical_not(strcmp(fmt_words[ii],words[icol,1]))):
                        ## Column doesn't exactly match literal => split needed.
            ## Insert a column
                        words[icol + 1:end() + 1,:]=words[icol:end(),:]
# /home/lei/octave-4.0.2/scripts/io/strread.m:621
                        jptr=find(logical_not(cellfun('isempty',words[icol,:])))
# /home/lei/octave-4.0.2/scripts/io/strread.m:623
                        if (logical_not(idg[ii]) and logical_not(isempty(s)) and s[1] == 1):
                            ## Leading literal.
              ## Assign literal to icol, paste rest in icol + 1
              ## Apply only to those cells that do have something beyond literal
                            jptr=find(cellfun('length',words[icol + 1,jptr],'UniformOutput',false) > e[1])
# /home/lei/octave-4.0.2/scripts/io/strread.m:630
                            words[icol + 1,:]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/io/strread.m:632
                            words[icol + 1,jptr]=cellfun(lambda x=None: substr(x,e[1] + 1,length(x) - e[1]),words[icol,jptr],'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/io/strread.m:633
                            words[icol,jptr]=fmt_words[ii]
# /home/lei/octave-4.0.2/scripts/io/strread.m:636
                            fwptr=matlabarray(cat(fwptr[1:ii],(++ fwptr(arange(ii + 1,end())))))
# /home/lei/octave-4.0.2/scripts/io/strread.m:637
                        else:
                            if (logical_not(idg[ii]) and logical_not(isempty(strfind(fmt_words[ii - 1],'%s')))):
                                ## Trailing literal.
                ## If preceding format == '#s' this is an error.
                                warning('strread: ambiguous \'%s\' specifier next to literal in column %d',icol)
                            else:
                                if (idg[ii]):
                                    ## Current field = fixed width. Strip into icol, rest in icol+1
                                    sw=regexp(fmt_words[ii],'\\d','once')
# /home/lei/octave-4.0.2/scripts/io/strread.m:646
                                    ew=regexp(fmt_words[ii],'[nfuds]') - 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:647
                                    wdth=floor(str2double(fmt_words[ii](arange(sw,ew))))
# /home/lei/octave-4.0.2/scripts/io/strread.m:648
                                    words[icol + 1,jptr]=cellfun(lambda x=None: x[wdth + 1:end()],words[icol,jptr],'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/io/strread.m:649
                                    if (isempty(cat(words[icol + 1,:][:]))):
                                        ## Apparently split wasn't needed as turns out to cover
                  ## entire column. So delete column again
                                        words[icol + 1,:]=[]
# /home/lei/octave-4.0.2/scripts/io/strread.m:654
                                    else:
                                        words[icol,jptr]=strtrunc(words[icol,jptr],wdth)
# /home/lei/octave-4.0.2/scripts/io/strread.m:656
                                        fwptr=matlabarray(cat(fwptr[1:ii],(++ fwptr(arange(ii + 1,end())))))
# /home/lei/octave-4.0.2/scripts/io/strread.m:657
                                else:
                                    ## FIXME: this assumes char(254)/char(255) won't occur in input!
                                    clear('wrds')
                                    wrds[1:2:dot(2,numel(words[icol,jptr]))]=strrep(words[icol,jptr],fmt_words[ii],cat(char(255),char(254)))
# /home/lei/octave-4.0.2/scripts/io/strread.m:662
                                    wrds[2:2:dot(2,numel(words[icol,jptr])) - 1]=char(255)
# /home/lei/octave-4.0.2/scripts/io/strread.m:665
                                    wrds=ostrsplit(cat(wrds[:]),char(255))
# /home/lei/octave-4.0.2/scripts/io/strread.m:666
                                    words[icol,jptr]=wrds[find(cellfun('isempty',strfind(wrds,char(254))))]
# /home/lei/octave-4.0.2/scripts/io/strread.m:667
                                    wrds[find(cellfun('isempty',strfind(wrds,char(254))))]=char(255)
# /home/lei/octave-4.0.2/scripts/io/strread.m:670
                                    words[icol + 1,jptr]=ostrsplit(strrep(cat(wrds[2:end()]),char(254),fmt_words[ii]),char(255))
# /home/lei/octave-4.0.2/scripts/io/strread.m:671
                                    -- ii
                                    fwptr=matlabarray(cat(fwptr[1:ii],(++ fwptr(arange(ii + 1,end())))))
# /home/lei/octave-4.0.2/scripts/io/strread.m:675
                else:
                    ## Conversion specifier.
          ## Peek if next fmt_word needs split from current column.
                    if (ii < num_words_per_line):
                        if (fwptr[ii] == fwptr[ii + 1]):
                            -- icol
                ## Next fmt_word, next column
                ++ ii
                ++ icol

            ## Done.
      ## Reshape words back into one long vector and strip padded empty words
            words=reshape(words,1,numel(words))(arange(1,end() - num_words_padded))
# /home/lei/octave-4.0.2/scripts/io/strread.m:695
        finally:
            pass
    
    ## For each specifier, process corresponding column
    k=1
# /home/lei/octave-4.0.2/scripts/io/strread.m:705
    for m in arange(1,num_words_per_line).reshape(-1):
        try:
            if (format_repeat_count < 0):
                data=words[m:num_words_per_line:end()]
# /home/lei/octave-4.0.2/scripts/io/strread.m:709
            else:
                if (format_repeat_count == 0):
                    data=cellarray([])
# /home/lei/octave-4.0.2/scripts/io/strread.m:711
                else:
                    lastline=min(dot(num_words_per_line,format_repeat_count) + m - 1,numel(words))
# /home/lei/octave-4.0.2/scripts/io/strread.m:713
                    data=words[m:num_words_per_line:lastline]
# /home/lei/octave-4.0.2/scripts/io/strread.m:715
                    if (num_lines > format_repeat_count):
                        num_lines=copy(format_repeat_count)
# /home/lei/octave-4.0.2/scripts/io/strread.m:717
            ## Map to format
      ## FIXME: Add support for formats like "<#s>", "#[a-zA-Z]"
      ##        Someone with regexp experience is needed.
            if '%s' == (fmt_words[m](arange(1,min(2,length(fmt_words[m]))))):
                if (pad_out):
                    data[end() + 1:num_lines]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/io/strread.m:727
                varargout[k]=data.T
# /home/lei/octave-4.0.2/scripts/io/strread.m:729
                k
            else:
                if cellarray(['%d','%u','%f','%n']) == (fmt_words[m](arange(1,min(2,length(fmt_words[m]))))):
                    n=cellfun('isempty',data)
# /home/lei/octave-4.0.2/scripts/io/strread.m:732
                    data=str2double(data)
# /home/lei/octave-4.0.2/scripts/io/strread.m:734
                    if (logical_not(isempty(regexp(fmt_words[m],'%[du]')))):
                        ## Cast to integer
            ## FIXME: NaNs will be transformed into zeros
                        data=int32(data)
# /home/lei/octave-4.0.2/scripts/io/strread.m:738
                    data[n]=numeric_fill_value
# /home/lei/octave-4.0.2/scripts/io/strread.m:740
                    if (pad_out):
                        data[end() + 1:num_lines]=numeric_fill_value
# /home/lei/octave-4.0.2/scripts/io/strread.m:742
                    varargout[k]=data.T
# /home/lei/octave-4.0.2/scripts/io/strread.m:744
                    k
                else:
                    if cellarray(['%0','%1','%2','%3','%4','%5','%6','%7','%8','%9']) == (fmt_words[m](arange(1,min(2,length(fmt_words[m]))))):
                        sw=regexp(fmt_words[m],'\\d','once')
# /home/lei/octave-4.0.2/scripts/io/strread.m:747
                        ew=regexp(fmt_words[m],'[nfudsq]') - 1
# /home/lei/octave-4.0.2/scripts/io/strread.m:748
                        nfmt=ostrsplit(fmt_words[m](arange(2,ew)),'.')
# /home/lei/octave-4.0.2/scripts/io/strread.m:749
                        swidth=str2double(nfmt[1])
# /home/lei/octave-4.0.2/scripts/io/strread.m:750
                        if cellarray(['d','u','f','n']) == (fmt_words[m](ew + 1)):
                            n=cellfun('isempty',data)
# /home/lei/octave-4.0.2/scripts/io/strread.m:753
                            ###        => ReturnOnError can't be implemented for numeric data
                            data=str2double(strtrunc(data,swidth))
# /home/lei/octave-4.0.2/scripts/io/strread.m:756
                            data[n]=numeric_fill_value
# /home/lei/octave-4.0.2/scripts/io/strread.m:757
                            if (pad_out):
                                data[end() + 1:num_lines]=numeric_fill_value
# /home/lei/octave-4.0.2/scripts/io/strread.m:759
                            if (numel(nfmt) > 1):
                                sprec=str2double(nfmt[2])
# /home/lei/octave-4.0.2/scripts/io/strread.m:762
                                data=dot(10 ** - sprec,round(dot(10 ** sprec,data)))
# /home/lei/octave-4.0.2/scripts/io/strread.m:763
                            else:
                                if (logical_not(isempty(regexp(fmt_words[m],'[du]')))):
                                    ## Cast to integer
                ## FIXME: NaNs will be transformed into zeros
                                    data=int32(data)
# /home/lei/octave-4.0.2/scripts/io/strread.m:767
                            varargout[k]=data.T
# /home/lei/octave-4.0.2/scripts/io/strread.m:769
                            k
                        else:
                            if 's' == (fmt_words[m](ew + 1)):
                                if (pad_out):
                                    data[end() + 1:num_lines]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/io/strread.m:773
                                varargout[k]=strtrunc(data,swidth).T
# /home/lei/octave-4.0.2/scripts/io/strread.m:775
                                k
                    else:
                        if cellarray(['%*','%*s']) == (fmt_words[m](arange(1,min(2,length(fmt_words[m]))))):
                            ## skip the word
                            pass
                        else:
                            ## Ensure descriptive content is consistent.
          ## Test made a bit lax to accomodate for incomplete last lines
                            n=find(logical_not(cellfun('isempty',data)))
# /home/lei/octave-4.0.2/scripts/io/strread.m:784
                            if (numel(unique(data[n])) > 1 or logical_not(strcmpi(unique(data),fmt_words[m]))):
                                error('strread: FORMAT does not match data')
        finally:
            pass
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def split_by(text=None,sep=None,mult_dlms_s1=None,eol_char=None,*args,**kwargs):
    varargin = split_by.varargin
    nargin = split_by.nargin

    ## Check & if needed, process MultipleDelimsAsOne parameter
    if (mult_dlms_s1):
        mult_dlms_s1=copy(true)
# /home/lei/octave-4.0.2/scripts/io/strread.m:808
        ## to avoid strrep on megabytes of data.
    ## If \n is in sep collection we need to enclose it in text
    ## to avoid it being included in consecutive delim series
        enchr=' '
# /home/lei/octave-4.0.2/scripts/io/strread.m:813
        if (index(sep,eol_char)):
            enchr=char(255)
# /home/lei/octave-4.0.2/scripts/io/strread.m:815
        text=strrep(text,eol_char,cat(enchr,eol_char,enchr))
# /home/lei/octave-4.0.2/scripts/io/strread.m:816
    else:
        mult_dlms_s1=copy(false)
# /home/lei/octave-4.0.2/scripts/io/strread.m:818
    
    ## Split text string along delimiters
    out=ostrsplit(text,sep,mult_dlms_s1)
# /home/lei/octave-4.0.2/scripts/io/strread.m:822
    if (index(sep,eol_char)):
        out=strrep(out,char(255),'')
# /home/lei/octave-4.0.2/scripts/io/strread.m:823
    
    ## In case of trailing delimiter, strip stray last empty word
    if (logical_not(isempty(out)) and any(sep == text[end()]) and logical_not(mult_dlms_s1)):
        out[end()]=[]
# /home/lei/octave-4.0.2/scripts/io/strread.m:826
    
    ## Empty cells converted to empty cellstrings.
    out[cellfun('isempty',out)]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/io/strread.m:830
    return out
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    #1 [a, b, c] = strread ("0.12 0.234 0.3567");
#1 assert (a, 0.12);
#1 assert (b, 0.234);
#1 assert (c, 0.3567);
    
    
    #1 assert (a, [0.41; 3.57]);
    
    
    
    
    
    
    
    
    
    
    
    ## MultipleDelimsAsOne
    
    
    
    
    
    
    ## Bug #44750
    
    
    ## delimiter as sq_string and dq_string
    
    
    ## whitespace as sq_string and dq_string
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test for no output arg (interactive use)
    
    ## Test #1 bug #42609
    
    
    
    
    ## Test #2 bug #42609
    
    
    
    
    ## Test #3 bug #42609
    
    
    
    
    ## Test #4 bug #42609
    
    
    
    
    ## Unsupported format specifiers
    
    ## Illegal format specifiers
    
    ## Test for false positives in check for non-supported format specifiers
    
    ## Test various forms of string format specifiers (bug #45712)
    
    
    
    ## Copyright (C) 2010-2014 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{C} =} textscan (@var{fid}, @var{format})
## @deftypefnx {Function File} {@var{C} =} textscan (@var{fid}, @var{format}, @var{n})
## @deftypefnx {Function File} {@var{C} =} textscan (@var{fid}, @var{format}, @var{param}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{C} =} textscan (@var{fid}, @var{format}, @var{n}, @var{param}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{C} =} textscan (@var{str}, @dots{})
## @deftypefnx {Function File} {[@var{C}, @var{position}] =} textscan (@var{fid}, @dots{})
## Read data from a text file or string.
##
## The string @var{str} or file associated with @var{fid} is read from and
## parsed according to @var{format}.  The function behaves like @code{strread}
## except it can also read from file instead of a string.  See the documentation
## of @code{strread} for details.
##
## In addition to the options supported by @code{strread}, this function
## supports a few more:
##
## @itemize
## @item @qcode{"collectoutput"}:
## A value of 1 or true instructs textscan to concatenate consecutive columns
## of the same class in the output cell array.  A value of 0 or false (default)
## leaves output in distinct columns.
##
## @item @qcode{"endofline"}:
## Specify @qcode{"@xbackslashchar{}r"}, @qcode{"@xbackslashchar{}n"} or
## @qcode{"@xbackslashchar{}r@xbackslashchar{}n"} (for CR, LF, or CRLF).  If no
## value is given, it will be inferred from the file.  If set to "" (empty
## string) EOLs are ignored as delimiters and added to whitespace.
##
## @item @qcode{"headerlines"}:
## The first @var{value} number of lines of @var{fid} are skipped.
##
## @item @qcode{"returnonerror"}:
## If set to numerical 1 or true (default), return normally when read errors
## have been encountered.  If set to 0 or false, return an error and no data.
## As the string or file is read by columns rather than by rows, and because
## textscan is fairly forgiving as regards read errors, setting this option
## may have little or no actual effect.
## @end itemize
##
## When reading from a character string, optional input argument @var{n}
## specifies the number of times @var{format} should be used (i.e., to limit
## the amount of data read).
## When reading from file, @var{n} specifies the number of data lines to read;
## in this sense it differs slightly from the format repeat count in strread.
##
## The output @var{C} is a cell array whose second dimension is determined
## by the number of format specifiers.
##
## The second output, @var{position}, provides the position, in characters,
## from the beginning of the file.
##
## If the format string is empty (not: omitted) and the file contains only
## numeric data (excluding headerlines), textscan will return data in a number
## of columns matching the number of numeric fields on the first data line of
## the file.
##
## @seealso{dlmread, fscanf, load, strread, textread}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
    
    
@function
def textscan(fid=None,format='%f',varargin=None,*args,**kwargs):
    varargin = textscan.varargin
    nargin = textscan.nargin

    BUFLENGTH=4096
# /home/lei/octave-4.0.2/scripts/io/textscan.m:83
    
    emptfmt=0
# /home/lei/octave-4.0.2/scripts/io/textscan.m:84
    
    ## Check input
    if (nargin < 1):
        print_usage()
    
    if (isempty(format)):
        emptfmt=1
# /home/lei/octave-4.0.2/scripts/io/textscan.m:92
        format='%f'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:93
    
    if (logical_not(ischar(format))):
        error('textscan: FORMAT must be a string')
    
    ## Determine the number of data fields & initialize output array
    num_fields=numel(regexp(format,'(%(\\d*|\\d*\\.\\d*)?[nfduscq]|%\\[)','match'))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:101
    if (logical_not(num_fields)):
        error('textscan.m: no valid format conversion specifiers found\n')
    
    C=cell(1,num_fields)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:105
    if (logical_not((isa(fid,'double') and fid > 0)) and logical_not(ischar(fid))):
        error('textscan: first argument must be a file id or character string')
    
    args=copy(varargin)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:111
    if (nargin > 2 and isnumeric(args[1])):
        nlines=args[1]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:113
    else:
        nlines=copy(Inf)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:115
    
    if (nlines < 1):
        printf('textscan: N = 0, no data read\n')
        return C,position
    
    if (logical_not(any(strcmpi(args,'emptyvalue')))):
        ## Matlab returns NaNs for missing values
        args[end() + 1:end() + 2]=cellarray(['emptyvalue',NaN])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:123
    
    ## Check default parameter values that differ for strread & textread
    
    ipos=find(strcmpi(args,'whitespace'))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:128
    if (isempty(ipos)):
        ## Matlab default whitespace = " \b\t"
        args[end() + 1:end() + 2]=cellarray(['whitespace',' \x08\t'])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:131
        whitespace=' \x08\t'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:132
    else:
        ## Check if there's at least one string format specifier
        has_str_fmt=regexp(format,'%[*]?\\d*s','once')
# /home/lei/octave-4.0.2/scripts/io/textscan.m:135
        ## don't add a space (char(32)) to whitespace
        if (logical_not((isempty(args[ipos + 1]) and has_str_fmt))):
            args[ipos + 1]=unique(cat(' ',args[ipos + 1]))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:139
        whitespace=args[ipos + 1]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:141
    
    if (logical_not(any(strcmpi(args,'delimiter')))):
        ## Matlab says default delimiter = whitespace.
    ## strread() will pick this up further
        args[end() + 1:end() + 2]=cellarray(['delimiter',''])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:147
        delimiter=''
# /home/lei/octave-4.0.2/scripts/io/textscan.m:148
    else:
        delimiter=args[find(strcmpi(args,'delimiter')) + 1]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:150
    
    collop=copy(false)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:153
    ipos=find(strcmpi(args,'collectoutput'))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:154
    if (logical_not(isempty(ipos))):
        ## Search & concatenate consecutive columns of same class requested
        if (isscalar(args[ipos + 1]) and (islogical(args[ipos + 1]) or isnumeric(args[ipos + 1]))):
            collop=args[ipos + 1]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:159
        else:
            warning('textscan: illegal value for CollectOutput parameter - ignored')
        ## Remove argument before call to strread() below
        args[ipos:ipos + 1]=[]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:164
    
    if (any(strcmpi(args,'returnonerror'))):
        ## Because of the way strread() reads data (columnwise) this parameter
    ## can't be neatly implemented.  strread() will pick it up anyway
        warning('textscan: ReturnOnError is not fully implemented')
    else:
        ## Set default value (=true)
        args[end() + 1:end() + 2]=cellarray(['returnonerror',1])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:173
    
    ## Check if a headerlines argument is specified
    headerlines=find(strcmpi(args,'headerlines'),1)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:177
    if (logical_not(isempty(headerlines))):
        ## Yep. But it is stray when reading from strings...
        if (ischar(fid)):
            warning('textscan: \'headerlines\' ignored when reading from strings')
    
    if (ischar(fid)):
        ## Read from a text string
        if (nargout == 2):
            error('textscan: cannot provide position information for character input')
        str=copy(fid)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:190
    else:
        st_pos=ftell(fid)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:192
        if (logical_not(isempty(headerlines))):
            ## Beware of missing or wrong headerline value
            if (headerlines == numel(args) or logical_not(isnumeric(args[headerlines + 1]))):
                error('Missing or illegal value for \'headerlines\'')
            ## Avoid conveying floats to fskipl
            args[headerlines + 1]=round(args[headerlines + 1])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:201
            if (args[headerlines + 1] > 0):
                ## Beware of zero valued headerline, fskipl would skip to EOF
                fskipl(fid,args[headerlines + 1])
                st_pos=ftell(fid)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:205
            else:
                if (args[headerlines + 1] < 0):
                    warning('textscan.m: negative headerline value ignored')
            args[headerlines:headerlines + 1]=[]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:209
        ## Read a first file chunk. Rest follows after endofline processing
        str,count=fscanf(fid,'%c',BUFLENGTH,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:212
    
    ## Check for empty result
    if (isempty(str)):
        warning('textscan: no data read')
        return C,position
    
    ## Check value of 'endofline'.  String or file doesn't seem to matter
    endofline=find(strcmpi(args,'endofline'),1)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:223
    if (logical_not(isempty(endofline))):
        if (ischar(args[endofline + 1])):
            eol_char=args[endofline + 1]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:226
            if (strcmp(typeinfo(eol_char),'sq_string')):
                eol_char=do_string_escapes(eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:228
            if (logical_not(any(strcmp(eol_char,cellarray(['','\n','\r','\r\n']))))):
                error('textscan: illegal EndOfLine character value specified')
        else:
            error('textscan: character value required for EndOfLine')
    else:
        if (logical_not(ischar(fid))):
            ## Determine EOL from file.
    ## Search for EOL candidates in the first BUFLENGTH chars
            eol_srch_len=min(length(str),BUFLENGTH)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:240
            if (logical_not(isempty(strfind(str[1:eol_srch_len],'\r\n')))):
                eol_char='\r\n'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:243
            else:
                if (logical_not(isempty(strfind(str[1:eol_srch_len],'\r')))):
                    eol_char='\r'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:246
                else:
                    eol_char='\n'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:249
        else:
            eol_char='\n'
# /home/lei/octave-4.0.2/scripts/io/textscan.m:252
        ## Set up the default endofline param value
        args[end() + 1:end() + 2]=cellarray(['endofline',eol_char])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:255
    
    if (logical_not(ischar(fid))):
        ## Now that we know what EOL looks like, we can process format_repeat_count.
    ## FIXME The below isn't ML-compatible: counts lines, not format string uses
        if (isfinite(nlines) and (nlines >= 0)):
            l_eol_char=length(eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:262
            eoi=findstr(str,eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:263
            n_eoi=length(eoi)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:264
            nblks=0
# /home/lei/octave-4.0.2/scripts/io/textscan.m:265
            while (n_eoi < nlines and count == BUFLENGTH):

                nstr,count=fscanf(fid,'%c',BUFLENGTH,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:268
                if (count > 0):
                    ## Watch out for multichar EOL being missed across buffer boundaries
                    if (l_eol_char > 1):
                        str=matlabarray(cat(str[end() - length(eol_char) + 2:end()],nstr))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:272
                    else:
                        str=copy(nstr)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:274
                    eoi=findstr(str,eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:276
                    n_eoi += numel(eoi)
                    ++ nblks

            ## Handle case of missing trailing EOL
            if (logical_not(strcmp(str[end() - length(eol_char) + 1:end()],eol_char))):
                eoi=matlabarray(cat(eoi[length(str)]))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:283
                ++ n_eoi
            ## OK, found EOL delimiting last requested line. Compute ptr (incl. EOL)
            if (isempty(eoi)):
                disp('textscan: format repeat count specified but no endofline found')
                data_size=dot(nblks,BUFLENGTH) + count
# /home/lei/octave-4.0.2/scripts/io/textscan.m:289
            else:
                ## Compute data size to read incl complete EOL
                data_size=(dot(nblks,BUFLENGTH)) + eoi[end() + min(nlines,n_eoi) - n_eoi] + l_eol_char - 1
# /home/lei/octave-4.0.2/scripts/io/textscan.m:292
            fseek(fid,st_pos,'bof')
            str=fscanf(fid,'%c',data_size)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:297
            args[1]=Inf
# /home/lei/octave-4.0.2/scripts/io/textscan.m:298
        else:
            fseek(fid,st_pos,'bof')
            str=fread(fid,'char=>char').T
# /home/lei/octave-4.0.2/scripts/io/textscan.m:301
    
    ## Strip trailing EOL to avoid returning stray missing values (f. strread).
  ## However, in case of CollectOutput request, presence of EOL is required;
  ## also in case of deliberately entered empty format string
    eol_at_end=strcmp(str[end() - length(eol_char) + 1:end()],eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:308
    if (collop or emptfmt):
        if (logical_not(eol_at_end)):
            str[end() + 1:end() + length(eol_char)]=eol_char
# /home/lei/octave-4.0.2/scripts/io/textscan.m:311
    else:
        if (eol_at_end):
            str[end() - length(eol_char) + 1:end()]=''
# /home/lei/octave-4.0.2/scripts/io/textscan.m:314
            if (isempty(str)):
                return C,position
    
    ## Call strread to make it do the real work
    C=cell(1,num_fields)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:320
    C[:]=strread(str,format,args[:])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:321
    
    if (emptfmt):
        ## Find end of first line
        eoi=index(str,eol_char)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:326
        if (eoi):
            ## str contains an EOL, proceed with assessing nr. of columns
            ncols=countcols(C,str[1:eoi - 1],delimiter,whitespace)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:329
            pad=mod(numel(C[1]),ncols)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:331
            if (pad):
                ## Pad output with emptyvalues (rest has been done by stread.m)
                emptv=find(strcmpi(args,'emptyvalue'))
# /home/lei/octave-4.0.2/scripts/io/textscan.m:334
                if (isempty(emptv)):
                    ## By default textscan returns NaNs for empty fields
                    C[1]=cat([C[1]],[NaN(ncols - pad,1)])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:337
                else:
                    ## Otherwise return supplied emptyvalue. Pick last occurrence
                    C[1]=cat([C[1]],[repmat(args[emptv[end()] + 1],ncols - pad,1)])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:340
            ## Compute nr. of rows
            nrows=floor(numel(C[1]) / ncols)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:344
            C[1]=reshape(C[1],ncols,numel(C[1]) / ncols).T
# /home/lei/octave-4.0.2/scripts/io/textscan.m:346
            for ii in arange(2,ncols).reshape(-1):
                C[ii]=C[1](arange(),ii)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:349
            C[1]=C[1](arange(),1)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:351
    
    ## If requested, collect output columns of same class
    if (collop):
        C=colloutp(C)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:357
    
    if (nargout == 2):
        ## Remember file position (persistent var)
        position=ftell(fid)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:362
    
    return C,position
    
if __name__ == '__main__':
    pass
    
    ## Assess nr of data fields on first line of data
    
@function
def countcols(C=None,str=None,dlm=None,wsp=None,*args,**kwargs):
    varargin = countcols.varargin
    nargin = countcols.nargin

    if (isempty(dlm)):
        ## Field separator = whitespace. Fold multiple whitespace into one
        str=regexprep(str,sprintf('[%s]',wsp),' ')
# /home/lei/octave-4.0.2/scripts/io/textscan.m:373
        str=strtrim(str)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:374
        ncols=numel(strfind(str,' ')) + 1
# /home/lei/octave-4.0.2/scripts/io/textscan.m:375
    else:
        ncols=numel(regexp(str,sprintf('[%s]',dlm))) + 1
# /home/lei/octave-4.0.2/scripts/io/textscan.m:377
    
    return ncols
    
if __name__ == '__main__':
    pass
    
    ## Collect consecutive columns of same class into one cell column
    
@function
def colloutp(C=None,*args,**kwargs):
    varargin = colloutp.varargin
    nargin = colloutp.nargin

    ## Start at rightmost column and work backwards to avoid ptr mixup
    ii=numel(C)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:387
    while (ii > 1):

        clss1=class_(C[ii])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:389
        jj=copy(ii)
# /home/lei/octave-4.0.2/scripts/io/textscan.m:390
        while (jj > 1 and strcmp(clss1,class_(C[jj - 1]))):

            ## Column to the left is still same class; check next column to the left
            -- jj

        if (jj < ii):
            ## Concatenate columns into current column
            C[jj]=cat(C[jj:ii])
# /home/lei/octave-4.0.2/scripts/io/textscan.m:397
            C[jj + 1:ii]=[]
# /home/lei/octave-4.0.2/scripts/io/textscan.m:399
            ii=jj - 1
# /home/lei/octave-4.0.2/scripts/io/textscan.m:400
        else:
            ## No similar class in column to the left, search from there
            -- ii

    
    return C
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test with default endofline parameter
    
    
    ## Test with endofline parameter set to "" (empty) - newline should be in word
    
    
    
    
    
    
    ## CollectOutput test
    
    
    
    
    
    
    
    ## CollectOutput test with uneven column length files
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    
    
    
    ## bug #37023 (actually a strread test)
    
    
    
    ## Whitespace test (bug #37333) using delimiter ";"
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Whitespace test (bug #37333), adding multipleDelimsAsOne true arg
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Whitespace test (bug #37333), adding multipleDelimsAsOne false arg
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Whitespace test (bug #37333) whitespace "" arg
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Whitespace test (bug #37333), whitespace " " arg
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test reading from a real file
    
    
    
    
    
    
    
    
    
    
    ## Tests reading with empty format, should return proper nr of columns
    
    
    
    
    
    
    
    
    
    
    
    ## Tests reading with empty format; empty fields & incomplete lower row
    
    
    
    
    
    
    
    
    ## Error message tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Bug #41824
    
    ## Bug #42343-1, just test supplied emptyvalue (actually done by strread.m)
    
    ## Bug #42343-2, test padding with supplied emptyvalue (done by textscan.m)
    
    
    ## Bug #42528
    
    
    ## Illegal format specifiers
    
    ## Properly process single-quoted EOL args (bug #46477)
    
    
    
    ## Copyright (C) 2009-2015 Eric Chassande-Mottin, CNRS (France)
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{a}, @dots{}] =} textread (@var{filename})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} textread (@var{filename}, @var{format})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} textread (@var{filename}, @var{format}, @var{n})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} textread (@var{filename}, @var{format}, @var{prop1}, @var{value1}, @dots{})
## @deftypefnx {Function File} {[@var{a}, @dots{}] =} textread (@var{filename}, @var{format}, @var{n}, @var{prop1}, @var{value1}, @dots{})
## Read data from a text file.
##
## The file @var{filename} is read and parsed according to @var{format}.  The
## function behaves like @code{strread} except it works by parsing a file
## instead of a string.  See the documentation of @code{strread} for details.
##
## In addition to the options supported by @code{strread}, this function
## supports two more:
##
## @itemize
## @item @qcode{"headerlines"}:
## The first @var{value} number of lines of @var{filename} are skipped.
##
## @item @qcode{"endofline"}:
## Specify a single character or
## @qcode{"@xbackslashchar{}r@xbackslashchar{}n"}.  If no value is given, it
## will be inferred from the file.  If set to @qcode{""} (empty string) EOLs
## are ignored as delimiters.
## @end itemize
##
## The optional input @var{n} (format repeat count) specifies the number of
## times the format string is to be used or the number of lines to be read,
## whichever happens first while reading.  The former is equivalent to
## requesting that the data output vectors should be of length @var{N}.
## Note that when reading files with format strings referring to multiple
## lines, @var{n} should rather be the number of lines to be read than the
## number of format string uses.
##
## If the format string is empty (not just omitted) and the file contains only
## numeric data (excluding headerlines), textread will return a rectangular
## matrix with the number of columns matching the number of numeric fields on
## the first data line of the file.  Empty fields are returned as zero values.
##
## Examples:
##
## @example
##   Assume a data file like:
##   1 a 2 b
##   3 c 4 d
##   5 e
## @end example
##
## @example
##   [a, b] = textread (f, "#f #s")
##   returns two columns of data, one with doubles, the other a
##   cellstr array:
##   a = [1; 2; 3; 4; 5]
##   b = @{"a"; "b"; "c"; "d"; "e"@}
## @end example
##
## @example
##   [a, b] = textread (f, "#f #s", 3)
##   (read data into two culumns, try to use the format string
##   three times)
##   returns
##   a = [1; 2; 3]
##   b = @{"a"; "b"; "c"@}
##
## @end example
##
## @example
##   With a data file like:
##   1
##   a
##   2
##   b
##
##   [a, b] = textread (f, "#f #s", 2)
##   returns a = 1 and b = @{"a"@}; i.e., the format string is used
##   only once because the format string refers to 2 lines of the
##   data file. To obtain 2x1 data output columns, specify N = 4
##   (number of data lines containing all requested data) rather
##   than 2.
## @end example
##
## @seealso{strread, load, dlmread, fscanf, textscan}
## @end deftypefn
    
    
@function
def textread(filename=None,format='%f',varargin=None,*args,**kwargs):
    varargin = textread.varargin
    nargin = textread.nargin

    BUFLENGTH=4096
# /home/lei/octave-4.0.2/scripts/io/textread.m:105
    
    ## Check input
    if (nargin < 1):
        print_usage()
    
    if (logical_not(ischar(filename)) or logical_not(ischar(format))):
        error('textread: FILENAME and FORMAT arguments must be strings')
    
    if (logical_not(isempty(varargin)) and isnumeric(varargin[1])):
        nlines=varargin[1]
# /home/lei/octave-4.0.2/scripts/io/textread.m:117
    else:
        nlines=copy(Inf)
# /home/lei/octave-4.0.2/scripts/io/textread.m:119
    
    if (nlines < 1):
        printf('textread: N = 0, no data read\n')
        varargout=cell(1,nargout)
# /home/lei/octave-4.0.2/scripts/io/textread.m:123
        return varargout
    
    ## Read file
    fid=fopen(filename,'r')
# /home/lei/octave-4.0.2/scripts/io/textread.m:128
    if (fid == - 1):
        error('textread: could not open \'%s\' for reading',filename)
    
    ## Skip header lines if requested
    headerlines=find(strcmpi(varargin,'headerlines'),1)
# /home/lei/octave-4.0.2/scripts/io/textread.m:134
    if (logical_not(isempty(headerlines))):
        ## Beware of missing or wrong headerline value
        if (headerlines == numel(varargin) or logical_not(isnumeric(varargin[headerlines + 1]))):
            error('missing or illegal value for \'headerlines\'')
        ## Avoid conveying floats to fskipl
        varargin[headerlines + 1]=round(varargin[headerlines + 1])
# /home/lei/octave-4.0.2/scripts/io/textread.m:142
        if (varargin[headerlines + 1] > 0):
            fskipl(fid,varargin[headerlines + 1])
        else:
            if (varargin[headerlines + 1] < 0):
                warning('textread: negative headerline value ignored')
        varargin[headerlines:headerlines + 1]=[]
# /home/lei/octave-4.0.2/scripts/io/textread.m:149
    
    st_pos=ftell(fid)
# /home/lei/octave-4.0.2/scripts/io/textread.m:151
    
    str,count=fscanf(fid,'%c',BUFLENGTH,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/textread.m:154
    if (isempty(str) or count < 1):
        warning('textread: empty file')
        varargout=cell(1,nargout)
# /home/lei/octave-4.0.2/scripts/io/textread.m:157
        return varargout
    
    endofline=find(strcmpi(varargin,'endofline'),1)
# /home/lei/octave-4.0.2/scripts/io/textread.m:161
    if (logical_not(isempty(endofline))):
        ## 'endofline' option set by user.
        if (ischar(varargin[endofline + 1])):
            eol_char=varargin[endofline + 1]
# /home/lei/octave-4.0.2/scripts/io/textread.m:165
            if (strcmp(typeinfo(eol_char),'sq_string')):
                eol_char=do_string_escapes(eol_char)
# /home/lei/octave-4.0.2/scripts/io/textread.m:167
            if (logical_not(any(strcmp(eol_char,cellarray(['','\n','\r','\r\n']))))):
                error('textscan: illegal EndOfLine character value specified')
        else:
            error('character value required for EndOfLine')
    else:
        ## Determine EOL from file.
    ## Search for EOL candidates in the first BUFLENGTH chars
    ## FIXME Ignore risk of 2-byte EOL (\r\n) being split at exactly BUFLENGTH
        eol_srch_len=min(length(str),BUFLENGTH)
# /home/lei/octave-4.0.2/scripts/io/textread.m:179
        if (logical_not(isempty(strfind(str[1:eol_srch_len],'\r\n')))):
            eol_char='\r\n'
# /home/lei/octave-4.0.2/scripts/io/textread.m:182
        else:
            if (logical_not(isempty(strfind(str[1:eol_srch_len],'\r')))):
                eol_char='\r'
# /home/lei/octave-4.0.2/scripts/io/textread.m:185
            else:
                eol_char='\n'
# /home/lei/octave-4.0.2/scripts/io/textread.m:188
        ## Set up default endofline param value
        varargin[end() + 1:end() + 2]=cellarray(['endofline',eol_char])
# /home/lei/octave-4.0.2/scripts/io/textread.m:191
    
    ## Now that we know what EOL looks like, we can process format_repeat_count.
  ## FIXME: The below isn't ML-compatible: counts lines, not format string uses
    if (isfinite(nlines) and (nlines > 0)):
        l_eol_char=length(eol_char)
# /home/lei/octave-4.0.2/scripts/io/textread.m:197
        eoi=findstr(str,eol_char)
# /home/lei/octave-4.0.2/scripts/io/textread.m:198
        n_eoi=length(eoi)
# /home/lei/octave-4.0.2/scripts/io/textread.m:199
        nblks=0
# /home/lei/octave-4.0.2/scripts/io/textread.m:200
        while (n_eoi < nlines and count == BUFLENGTH):

            nstr,count=fscanf(fid,'%c',BUFLENGTH,nargout=2)
# /home/lei/octave-4.0.2/scripts/io/textread.m:203
            if (count > 0):
                ## Watch out for multichar EOL being missed across buffer boundaries
                if (l_eol_char > 1):
                    str=matlabarray(cat(str[end() - length(eol_char) + 2:end()],nstr))
# /home/lei/octave-4.0.2/scripts/io/textread.m:207
                else:
                    str=copy(nstr)
# /home/lei/octave-4.0.2/scripts/io/textread.m:209
                eoi=findstr(str,eol_char)
# /home/lei/octave-4.0.2/scripts/io/textread.m:211
                n_eoi += numel(eoi)
                ++ nblks

        ## Handle case of missing or incomplete trailing EOL
        if (logical_not(strcmp(str[end() - length(eol_char) + 1:end()],eol_char))):
            eoi=matlabarray(cat(eoi[length(str)]))
# /home/lei/octave-4.0.2/scripts/io/textread.m:218
            ++ n_eoi
        ## Found EOL delimiting last requested line. Compute ptr (incl. EOL)
        if (isempty(eoi)):
            eoi_pos=dot(nblks,BUFLENGTH) + count
# /home/lei/octave-4.0.2/scripts/io/textread.m:223
        else:
            eoi_pos=(dot(nblks,BUFLENGTH)) + eoi[end() + min(nlines,n_eoi) - n_eoi]
# /home/lei/octave-4.0.2/scripts/io/textread.m:225
        fseek(fid,st_pos,'bof')
        str=fscanf(fid,'%c',eoi_pos)
# /home/lei/octave-4.0.2/scripts/io/textread.m:228
    else:
        fseek(fid,st_pos,'bof')
        str=fread(fid,'char=>char').T
# /home/lei/octave-4.0.2/scripts/io/textread.m:231
    
    fclose(fid)
    
    if (isempty(find(strcmpi('whitespace',varargin)))):
        varargin[end() + 1:end() + 2]=cellarray(['whitespace',' \x08\t'])
# /home/lei/octave-4.0.2/scripts/io/textread.m:237
    
    ## Call strread to make it do the real work
    varargout[1:max(nargout,1)]=strread(str,format,varargin[:])
# /home/lei/octave-4.0.2/scripts/io/textread.m:241
    
    ## In ML this only works in case of an empty format string
    if (isempty(format)):
        ## Get number of fields per line.
    ## 1. Get eol_char position
        iwhsp=find(strcmpi('whitespace',varargin))
# /home/lei/octave-4.0.2/scripts/io/textread.m:248
        whsp=varargin[iwhsp + 1]
# /home/lei/octave-4.0.2/scripts/io/textread.m:249
        idx=regexp(str,eol_char,'once')
# /home/lei/octave-4.0.2/scripts/io/textread.m:250
        if (logical_not(isempty(idx))):
            str=str[1:idx - 1]
# /home/lei/octave-4.0.2/scripts/io/textread.m:253
        idelimiter=find(strcmpi(varargin,'delimiter'),1)
# /home/lei/octave-4.0.2/scripts/io/textread.m:255
        if (isempty(idelimiter)):
            ## Assume delimiter = whitespace
      ## 3A. whitespace incl. consecutive whitespace => single space
            str=regexprep(str,sprintf('[%s]+',whsp),' ')
# /home/lei/octave-4.0.2/scripts/io/textread.m:259
            str=strtrim(str)
# /home/lei/octave-4.0.2/scripts/io/textread.m:261
            ncols=numel(strfind(str,' ')) + 1
# /home/lei/octave-4.0.2/scripts/io/textread.m:263
        else:
            ## 3B. Just count delimiters. FIXME: delimiters could occur in literals
            delimiter=varargin[idelimiter + 1]
# /home/lei/octave-4.0.2/scripts/io/textread.m:266
            ncols=numel(regexp(str,sprintf('[%s]',delimiter))) + 1
# /home/lei/octave-4.0.2/scripts/io/textread.m:267
        ## 6. Reshape; watch out, we need a transpose
        nrows=ceil(numel(varargout[1]) / ncols)
# /home/lei/octave-4.0.2/scripts/io/textread.m:270
        pad=mod(numel(varargout[1]),ncols)
# /home/lei/octave-4.0.2/scripts/io/textread.m:271
        if (pad > 0):
            pad=ncols - pad
# /home/lei/octave-4.0.2/scripts/io/textread.m:273
            varargout[1][end() + 1:end() + pad]=NaN
# /home/lei/octave-4.0.2/scripts/io/textread.m:274
        varargout[1]=reshape(varargout[1],ncols,nrows).T
# /home/lei/octave-4.0.2/scripts/io/textread.m:276
        varargout[1][find(isnan(varargout[1]))]=0
# /home/lei/octave-4.0.2/scripts/io/textread.m:278
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test reading 2D matrix with empty format
    
    
    
    
    
    
    ## Read multiple lines using empty format string
    
    
    
    
    
    
    
    
    
    ## Empty format, corner case = one line w/o EOL
    
    
    
    
    
    
    
    
    
    ## Tests with format repeat count #1
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests with format repeat count #2, missing last EOL
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests with format repeat count #3, incomplete last line
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests with format repeat count #4, incomplete last line but with trailing EOL
    
    
    
    
    
    
    
    
    ##! [a, b] = textread (f, "#d #s", 5);
##! assert (a, int32 ([10; 20; 30; 40]));
##! assert (b, {"a"; "b"; "c"; ""});
    
    ## Tests with format repeat count #5, nr of data lines = limiting factor
    
    
    
    
    
    
    
    
    ## Read multiple lines using empty format string, missing data (should be 0)
    
    
    
    
    
    
    
    
    
    ## Test with empty positions - ML returns 0 for empty fields
    
    
    
    
    
    
    
    
    
    ## Another test with empty format + positions, now with more incomplete lower
## row (must be appended with zeros to get rectangular matrix)
    
    
    
    
    
    
    
    
    
    ## Test endofline
    
    
    
    
    
    
    
    
    
    
    
    ## Properly process single-quoted EOL args (bug #46477)
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} csvwrite (@var{filename}, @var{x})
## @deftypefnx {Function File} {} csvwrite (@var{filename}, @var{x}, @var{dlm_opts})
## Write the matrix @var{x} to the file @var{filename} in
## @w{comma-separated-value} format.
##
## This function is equivalent to
##
## @example
## dlmwrite (@var{filename}, @var{x}, ",", @dots{})
## @end example
##
## @seealso{csvread, dlmwrite, dlmread}
## @end deftypefn
    
    
@function
def csvwrite(filename=None,x=None,varargin=None,*args,**kwargs):
    varargin = csvwrite.varargin
    nargin = csvwrite.nargin

    dlmwrite(filename,x,',',varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} blanks (@var{n})
## Return a string of @var{n} blanks.
##
## For example:
##
## @example
## @group
## blanks (10);
## whos ans
##      @result{}
##       Attr Name        Size                     Bytes  Class
##       ==== ====        ====                     =====  =====
##            ans         1x10                        10  char
## @end group
## @end example
## @seealso{repmat}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
    
    
@function
def blanks(n=None,*args,**kwargs):
    varargin = blanks.varargin
    nargin = blanks.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not((isscalar(n) and n == fix(n) and n >= 0))):
            error('blanks: N must be a non-negative integer')
    
    ## If 1:n is empty, the following expression will create an empty
  ## character string.  Otherwise, it will create a row vector.
    s[1:n]=' '
# /home/lei/octave-4.0.2/scripts/strings/blanks.m:51
    return s
    
if __name__ == '__main__':
    pass
    
    ## There really isn't that much to test here
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cstrcat (@var{s1}, @var{s2}, @dots{})
## Return a string containing all the arguments concatenated horizontally
## with trailing white space preserved.
##
## For example:
##
## @example
## @group
## cstrcat ("ab   ", "cd")
##       @result{} "ab   cd"
## @end group
## @end example
##
## @example
## @group
## s = [ "ab"; "cde" ];
## cstrcat (s, s, s)
##       @result{} "ab ab ab "
##          "cdecdecde"
## @end group
## @end example
## @seealso{strcat, char, strvcat}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def cstrcat(varargin=None,*args,**kwargs):
    varargin = cstrcat.varargin
    nargin = cstrcat.nargin

    if (nargin < 1):
        print_usage()
    else:
        if (logical_not(iscellstr(varargin))):
            error('cstrcat: expecting arguments to character strings')
    
    st=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/strings/cstrcat.m:54
    return st
    
if __name__ == '__main__':
    pass
    
    ## Test the dimensionality
## 1d
    
    ## 2d
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2002-2015 Rolf Fabian
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{s} =} mat2str (@var{x}, @var{n})
## @deftypefnx {Function File} {@var{s} =} mat2str (@var{x}, @var{n}, "class")
## Format real, complex, and logical matrices as strings.
##
## The returned string may be used to reconstruct the original matrix by using
## the @code{eval} function.
##
## The precision of the values is given by @var{n}.  If @var{n} is a scalar
## then both real and imaginary parts of the matrix are printed to the same
## precision.  Otherwise @code{@var{n}(1)} defines the precision of the real
## part and @code{@var{n}(2)} defines the precision of the imaginary part.
## The default for @var{n} is 15.
##
## If the argument @qcode{"class"} is given then the class of @var{x} is
## included in the string in such a way that @code{eval} will result in the
## construction of a matrix of the same class.
##
## @example
## @group
## mat2str ([ -1/3 + i/7; 1/3 - i/7 ], [4 2])
##      @result{} "[-0.3333+0.14i;0.3333-0.14i]"
##
## mat2str ([ -1/3 +i/7; 1/3 -i/7 ], [4 2])
##      @result{} "[-0.3333+0i 0+0.14i;0.3333+0i -0-0.14i]"
##
## mat2str (int16 ([1 -1]), "class")
##      @result{} "int16([1 -1])"
##
## mat2str (logical (eye (2)))
##      @result{} "[true false;false true]"
##
## isequal (x, eval (mat2str (x)))
##      @result{} 1
## @end group
## @end example
##
## @seealso{sprintf, num2str, int2str}
## @end deftypefn
    
    ## Author: Rolf Fabian <fabian@tu-cottbus.de>
    
    
@function
def mat2str(x=None,n=15,cls='',*args,**kwargs):
    varargin = mat2str.varargin
    nargin = mat2str.nargin

    if (nargin < 1 or nargin > 3 or logical_not((isnumeric(x) or islogical(x)))):
        print_usage()
    else:
        if (ndims(x) > 2):
            error('mat2str: X must be two dimensional')
    
    if (nargin == 2 and ischar(n)):
        cls=copy(n)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:70
        n=15
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:71
    else:
        if (isempty(n)):
            n=15
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:73
        else:
            if (numel(n) > 2):
                error('mat2str: N must have only 1 or 2 elements')
            else:
                n=fix(n)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:77
    
    x_islogical=islogical(x)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:80
    x_iscomplex=iscomplex(x)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:81
    if (x_iscomplex):
        if (isscalar(n)):
            n=matlabarray(cat(n,n))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:85
        fmt=sprintf('%%.%dg%%+.%dgi',n[1],n[2])
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:87
    else:
        if (x_islogical):
            v=cellarray(['false','true'])
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:89
            fmt='%s'
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:90
        else:
            fmt=sprintf('%%.%dg',n[1])
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:92
    
    nel=numel(x)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:95
    if (nel == 0):
        ## Empty, only print brackets
        s='[]'
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:99
    else:
        if (nel == 1):
            ## Scalar X, don't print brackets
            if (x_iscomplex):
                s=sprintf(fmt,real(x),imag(x))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:103
            else:
                if (x_islogical):
                    s=v[x + 1]
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:105
                else:
                    s=sprintf(fmt,x)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:107
        else:
            ## Non-scalar X, print brackets
            fmt=matlabarray(cat(fmt,' '))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:111
            if (x_iscomplex):
                t=x.T
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:113
                s=sprintf(fmt,cat([real(ravel(t)).T],[imag(ravel(t)).T]))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:114
            else:
                if (x_islogical):
                    t=v[x + 1]
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:116
                    s=cstrcat(sprintf(fmt,t[:]))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:117
                else:
                    s=sprintf(fmt,x.T)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:119
            s=matlabarray(cat('[',s))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:122
            s[end()]=']'
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:123
            idx=strfind(s,' ')
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:124
            nc=columns(x)
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:125
            s[idx[nc:nc:end()]]=';'
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:126
    
    if (strcmp('class',cls)):
        s=matlabarray(cat(class_(x),'(',s,')'))
# /home/lei/octave-4.0.2/scripts/strings/mat2str.m:130
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} regexptranslate (@var{op}, @var{s})
## Translate a string for use in a regular expression.
##
## This may include either wildcard replacement or special character escaping.
##
## The behavior is controlled by @var{op} which can take the following
## values
##
## @table @asis
## @item @qcode{"wildcard"}
## The wildcard characters @code{.}, @code{*}, and @code{?} are replaced with
## wildcards that are appropriate for a regular expression.  For example:
##
## @example
## @group
## regexptranslate ("wildcard", "*.m")
##      @result{} ".*\.m"
## @end group
## @end example
##
## @item @qcode{"escape"}
## The characters @code{$.?[]}, that have special meaning for regular
## expressions are escaped so that they are treated literally.  For example:
##
## @example
## @group
## regexptranslate ("escape", "12.5")
##      @result{} "12\.5"
## @end group
## @end example
##
## @end table
## @seealso{regexp, regexpi, regexprep}
## @end deftypefn
    
    
@function
def regexptranslate(op=None,s=None,*args,**kwargs):
    varargin = regexptranslate.varargin
    nargin = regexptranslate.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(ischar(op))):
        error('regexptranslate: operation OP must be a string')
    
    op=tolower(op)
# /home/lei/octave-4.0.2/scripts/strings/regexptranslate.m:65
    if (strcmp('wildcard',op)):
        y=strrep(strrep(strrep(s,'.','\\.'),'*','.*'),'?','.')
# /home/lei/octave-4.0.2/scripts/strings/regexptranslate.m:67
    else:
        if (strcmp('escape',op)):
            y=regexprep(s,'([][(){}.*+?^$|\\\\])','\\\\$1')
# /home/lei/octave-4.0.2/scripts/strings/regexptranslate.m:71
        else:
            error('regexptranslate: invalid operation OP')
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} substr (@var{s}, @var{offset})
## @deftypefnx {Function File} {} substr (@var{s}, @var{offset}, @var{len})
## Return the substring of @var{s} which starts at character number
## @var{offset} and is @var{len} characters long.
##
## Position numbering for offsets begins with 1.  If @var{offset} is negative,
## extraction starts that far from the end of the string.
##
## If @var{len} is omitted, the substring extends to the end of @var{s}.  A
## negative value for @var{len} extracts to within @var{len} characters of
## the end of the string
##
## Examples:
##
## @example
## @group
## substr ("This is a test string", 6, 9)
##      @result{} "is a test"
## substr ("This is a test string", -11)
##      @result{} "test string"
## substr ("This is a test string", -11, -7)
##      @result{} "test"
## @end group
## @end example
##
## This function is patterned after the equivalent function in Perl.
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
    
    
@function
def substr(s=None,offset=None,len_=None,*args,**kwargs):
    varargin = substr.varargin
    nargin = substr.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(s))):
        error('substr: S must be a string or string array')
    else:
        if (logical_not(isscalar(offset)) or (nargin == 3 and logical_not(isscalar(len_)))):
            error('substr: OFFSET and LEN must be scalar integers')
    
    offset=fix(offset)
# /home/lei/octave-4.0.2/scripts/strings/substr.m:63
    nc=columns(s)
# /home/lei/octave-4.0.2/scripts/strings/substr.m:64
    if (abs(offset) > nc or offset == 0):
        error('substr: OFFSET = %d out of range',offset)
    
    if (offset <= 0):
        offset += nc + 1
    
    if (nargin == 2):
        eos=copy(nc)
# /home/lei/octave-4.0.2/scripts/strings/substr.m:74
    else:
        len_=fix(len_)
# /home/lei/octave-4.0.2/scripts/strings/substr.m:76
        if (len_ < 0):
            eos=nc + len_
# /home/lei/octave-4.0.2/scripts/strings/substr.m:78
        else:
            eos=offset + len_ - 1
# /home/lei/octave-4.0.2/scripts/strings/substr.m:80
    
    if (eos > nc):
        error('substr: length LEN = %d out of range',len_)
    else:
        if (offset > eos and len_ != 0):
            error('substr: No overlap with chosen values of OFFSET and LEN')
    
    t=s[:,offset:eos]
# /home/lei/octave-4.0.2/scripts/strings/substr.m:90
    return t
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} strjust (@var{s})
## @deftypefnx {Function File} {} strjust (@var{s}, @var{pos})
## Return the text, @var{s}, justified according to @var{pos}, which may
## be @qcode{"left"}, @qcode{"center"}, or @qcode{"right"}.
##
## If @var{pos} is omitted it defaults to @qcode{"right"}.
##
## Null characters are replaced by spaces.  All other character data are
## treated as non-white space.
##
## Example:
##
## @example
## @group
## strjust (["a"; "ab"; "abc"; "abcd"])
##      @result{}
##         "   a"
##         "  ab"
##         " abc"
##         "abcd"
## @end group
## @end example
## @seealso{deblank, strrep, strtrim, untabify}
## @end deftypefn
    
    
@function
def strjust(s=None,pos='right',*args,**kwargs):
    varargin = strjust.varargin
    nargin = strjust.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not(ischar(s)) or ndims(s) > 2):
            error('strjust: S must be a string or 2-D character matrix')
    
    if (isempty(s)):
        y=copy(s)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:55
        return y
    
    ## Apparently, Matlab considers nulls to be blanks as well; however, does
  ## not preserve the nulls, but rather converts them to blanks.  That's a
  ## bit unexpected, but it allows simpler processing, because we can move
  ## just the nonblank characters. So we'll do the same here.
    
    nr,nc=size(s,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:64
    
    nonbl=s != logical_and(' ',s) != '\x00'
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:66
    idx,jdx=find(nonbl,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:67
    if (strcmpi(pos,'right')):
        ## We wish to find the maximum column index for each row. Because jdx is
    ## sorted, we can take advantage of the fact that assignment is processed
    ## sequentially and for duplicate indices the last value will remain.
        maxs=repmat(nc,cat(nr,1))
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:73
        maxs[idx]=jdx
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:74
        shift=nc - maxs
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:75
    else:
        if (strcmpi(pos,'left')):
            ## See above for explanation.
            mins=ones(nr,1)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:78
            mins[flipud(ravel(idx))]=flipud(ravel(jdx))
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:79
            shift=1 - mins
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:80
        else:
            ## Use both of the above to achieve centering.
            mins=ones(nr,1)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:83
            mins[flipud(ravel(idx))]=flipud(ravel(jdx))
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:84
            maxs=repmat(nc,cat(nr,1))
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:85
            maxs[idx]=jdx
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:86
            shift=floor((nc + 1 - maxs - mins) / 2)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:87
    
    ## Adjust the column indices.
    jdx += shift[idx]
    
    y=repmat(' ',nr,nc)
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:94
    y[sub2ind(cat(nr,nc),idx,jdx)]=s[nonbl]
# /home/lei/octave-4.0.2/scripts/strings/strjust.m:95
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} dec2bin (@var{d}, @var{len})
## Return a binary number corresponding to the non-negative integer @var{d},
## as a string of ones and zeros.
##
## For example:
##
## @example
## @group
## dec2bin (14)
##      @result{} "1110"
## @end group
## @end example
##
## If @var{d} is a matrix or cell array, return a string matrix with one row
## per element in @var{d}, padded with leading zeros to the width of the
## largest value.
##
## The optional second argument, @var{len}, specifies the minimum number of
## digits in the result.
## @seealso{bin2dec, dec2base, dec2hex}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def dec2bin(d=None,len_=None,*args,**kwargs):
    varargin = dec2bin.varargin
    nargin = dec2bin.nargin

    if (nargin == 1):
        b=dec2base(d,2)
# /home/lei/octave-4.0.2/scripts/strings/dec2bin.m:48
    else:
        if (nargin == 2):
            b=dec2base(d,2,len_)
# /home/lei/octave-4.0.2/scripts/strings/dec2bin.m:50
        else:
            print_usage()
    
    return b
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{validstr} =} validatestring (@var{str}, @var{strarray})
## @deftypefnx {Function File} {@var{validstr} =} validatestring (@var{str}, @var{strarray}, @var{funcname})
## @deftypefnx {Function File} {@var{validstr} =} validatestring (@var{str}, @var{strarray}, @var{funcname}, @var{varname})
## @deftypefnx {Function File} {@var{validstr} =} validatestring (@dots{}, @var{position})
## Verify that @var{str} is an element, or substring of an element, in
## @var{strarray}.
##
## When @var{str} is a character string to be tested, and @var{strarray} is a
## cellstr of valid values, then @var{validstr} will be the validated form
## of @var{str} where validation is defined as @var{str} being a member
## or substring of @var{validstr}.  This is useful for both verifying
## and expanding short options, such as @qcode{"r"}, to their longer forms,
## such as @qcode{"red"}.  If @var{str} is a substring of @var{validstr}, and
## there are multiple matches, the shortest match will be returned if all
## matches are substrings of each other.  Otherwise, an error will be raised
## because the expansion of @var{str} is ambiguous.  All comparisons are case
## insensitive.
##
## The additional inputs @var{funcname}, @var{varname}, and @var{position}
## are optional and will make any generated validation error message more
## specific.
##
## Examples:
## @c Set example in small font to prevent overfull line
##
## @smallexample
## @group
## validatestring ("r", @{"red", "green", "blue"@})
## @result{} "red"
##
## validatestring ("b", @{"red", "green", "blue", "black"@})
## @result{} error: validatestring: multiple unique matches were found for 'b':
##    blue, black
## @end group
## @end smallexample
##
## @seealso{strcmp, strcmpi, validateattributes, inputParser}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
    
    
@function
def validatestring(str=None,strarray=None,varargin=None,*args,**kwargs):
    varargin = validatestring.varargin
    nargin = validatestring.nargin

    if (nargin < 2 or nargin > 5):
        print_usage()
    
    position=0
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:67
    
    if (logical_not(isempty(varargin)) and isnumeric(varargin[end()])):
        position=fix(varargin[end()])
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:70
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:71
    
    funcname=varname=''
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:74
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:74
    char_idx=cellfun('isclass',varargin,'char')
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:75
    n_chararg=sum(char_idx)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:76
    if (n_chararg > 2):
        error('validatestring: invalid number of character inputs (3)')
    else:
        if (n_chararg == 2):
            funcname,varname=deal(varargin[char_idx],nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:80
        else:
            if (n_chararg == 1):
                funcname=varargin[char_idx]
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:82
    
    ## Check the inputs
    if (logical_not(ischar(str))):
        error('validatestring: STR must be a character string')
    else:
        if (logical_not(isrow(str))):
            error('validatestring: STR must be a single row vector')
        else:
            if (logical_not(iscellstr(strarray))):
                error('validatestring: STRARRAY must be a cellstr')
            else:
                if (logical_not(isempty(funcname)) and logical_not(isrow(funcname))):
                    error('validatestring: FUNCNAME must be a single row vector')
                else:
                    if (logical_not(isempty(varname)) and logical_not(isrow(varname))):
                        error('validatestring: VARNAME must be a single row vector')
                    else:
                        if (position < 0):
                            error('validatestring: POSITION must be >= 0')
    
    ## Make static part of error string that uses funcname, varname, and position
    errstr=''
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:101
    if (logical_not(isempty(funcname))):
        errstr=matlabarray(cat(funcname,': '))
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:103
    
    if (logical_not(isempty(varname))):
        errstr=matlabarray(cat(errstr,varname,' '))
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:106
    else:
        errstr=sprintf('%s\'%s\' ',errstr,str)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:108
    
    if (position > 0):
        errstr=sprintf('%s(argument #%i) ',errstr,position)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:111
    
    matches=strncmpi(str,ravel(strarray),length(str))
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:114
    nmatches=sum(matches)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:115
    if (nmatches == 0):
        error('%sdoes not match any of\n%s',errstr,sprintf('%s, ',strarray[:])(arange(1,end() - 2)))
    else:
        if (nmatches == 1):
            str=strarray[matches]
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:120
        else:
            ## Are the matches substrings of each other?
    ## If true, choose the shortest.  If not, raise an error.
            match_idx=find(matches)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:124
            match_len=cellfun('length',strarray[match_idx])
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:125
            min_len,min_idx=min(match_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:126
            short_str=strarray[match_idx[min_idx]]
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:127
            submatch=strncmpi(short_str,strarray[match_idx],min_len)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:128
            if (all(submatch)):
                str=copy(short_str)
# /home/lei/octave-4.0.2/scripts/strings/validatestring.m:130
            else:
                error('%sallows multiple unique matches:\n%s',errstr,sprintf('%s, ',strarray[match_idx])(arange(1,end() - 2)))
    
    return str
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} findstr (@var{s}, @var{t})
## @deftypefnx {Function File} {} findstr (@var{s}, @var{t}, @var{overlap})
## Return the vector of all positions in the longer of the two strings @var{s}
## and @var{t} where an occurrence of the shorter of the two starts.
##
## If the optional argument @var{overlap} is true (default), the returned
## vector can include overlapping positions.  For example:
##
## @example
## @group
## findstr ("ababab", "a")
##      @result{} [1, 3, 5];
## findstr ("abababa", "aba", 0)
##      @result{} [1, 5]
## @end group
## @end example
##
## @strong{Caution:} @code{findstr} is scheduled for deprecation.  Use
## @code{strfind} in all new code.
## @seealso{strfind, strmatch, strcmp, strncmp, strcmpi, strncmpi, find}
## @end deftypefn
    
    ## Note that this implementation swaps the strings if second one is longer
## than the first, so try to put the longer one first.
##
## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
    
    
@function
def findstr(s=None,t=None,overlap=true,*args,**kwargs):
    varargin = findstr.varargin
    nargin = findstr.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (all(size(s) > 1) or all(size(t) > 1)):
        error('findstr: arguments must have only one non-singleton dimension')
    
    ## Make S be the longer string.
    if (length(s) < length(t)):
        s,t=deal(t,s,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:60
    
    l_s=length(s)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:63
    l_t=length(t)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:64
    if (l_t == 0):
        ## zero length target: return empty set
        v=matlabarray([])
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:68
    else:
        if (l_t == 1):
            ## length one target: simple find
            v=find(s == t)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:72
        else:
            if (l_t == 2):
                ## length two target: find first at i and second at i+1
                v=find(s[1:l_s - 1] == logical_and(t[1],s[2:l_s]) == t[2])
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:76
            else:
                ## length three or more: match the first three by find then go through
    ## the much smaller list to determine which of them are real matches
                limit=l_s - l_t + 1
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:81
                v=find(s[1:limit] == logical_and(t[1],s[2:limit + 1]) == logical_and(t[2],s[3:limit + 2]) == t[3])
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:82
    
    ## Need to search the index vector if our find was too short
  ## (target length > 3), or if we don't allow overlaps.  Note though
  ## that there cannot be any overlaps if the first character in the
  ## target is different from the remaining characters in the target,
  ## so a single character, two different characters, or first character
  ## different from the second two don't need to be searched.
    if (l_t >= 3 or (logical_not(overlap) and l_t > 1 and any(t[1] == t[2:l_t]))):
        ## force strings to be both row vectors or both column vectors
        if (all(size(s) != size(t))):
            t=t.T
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:96
        ## determine which ones to keep
        keep=zeros(size(v))
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:100
        ind=arange(0,l_t - 1)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:101
        if (overlap):
            for idx in arange(1,length(v)).reshape(-1):
                keep[idx]=all(s[v[idx] + ind] == t)
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:104
        else:
            ## First possible position for next non-overlapping match.
            next=1
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:108
            for idx in arange(1,length(v)).reshape(-1):
                if (v[idx] >= next and s[v[idx] + ind] == t):
                    keep[idx]=1
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:111
                    next=v[idx] + l_t
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:113
                else:
                    keep[idx]=0
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:115
        if (logical_not(isempty(v))):
            v=v[find(keep)]
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:120
    
    if (isempty(v)):
        v=matlabarray([])
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:125
    
    ## Always return a row vector, because that's what the old one did.
    if (iscolumn(v)):
        v=v.T
# /home/lei/octave-4.0.2/scripts/strings/findstr.m:130
    
    return v
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} index (@var{s}, @var{t})
## @deftypefnx {Function File} {} index (@var{s}, @var{t}, @var{direction})
## Return the position of the first occurrence of the string @var{t} in the
## string @var{s}, or 0 if no occurrence is found.
##
## @var{s} may also be a string array or cell array of strings.
##
## For example:
##
## @example
## @group
## index ("Teststring", "t")
##     @result{} 4
## @end group
## @end example
##
## If @var{direction} is @qcode{"first"}, return the first element found.
## If @var{direction} is @qcode{"last"}, return the last element found.
##
## @seealso{find, rindex}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
## This is patterned after the AWK function of the same name.
    
    
@function
def index(s=None,t=None,direction='first',*args,**kwargs):
    varargin = index.varargin
    nargin = index.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (ischar(s)):
        if (logical_not(isrow(s))):
            s=cellstr(s)
# /home/lei/octave-4.0.2/scripts/strings/index.m:54
    else:
        if (logical_not(iscellstr(s))):
            error('index: S must be a string, string array, or cellstr')
    
    f=strfind(s,t)
# /home/lei/octave-4.0.2/scripts/strings/index.m:60
    if (isempty(f)):
        f=0
# /home/lei/octave-4.0.2/scripts/strings/index.m:62
    else:
        if (iscell(f)):
            f[cellfun('isempty',f)]=cellarray([0])
# /home/lei/octave-4.0.2/scripts/strings/index.m:64
    
    direction=tolower(direction)
# /home/lei/octave-4.0.2/scripts/strings/index.m:67
    if (strcmp(direction,'first')):
        if (iscell(f)):
            n=cellfun('min',f)
# /home/lei/octave-4.0.2/scripts/strings/index.m:71
        else:
            n=f[1]
# /home/lei/octave-4.0.2/scripts/strings/index.m:73
    else:
        if (strcmp(direction,'last')):
            if (iscell(f)):
                n=cellfun('max',f)
# /home/lei/octave-4.0.2/scripts/strings/index.m:77
            else:
                n=f[end()]
# /home/lei/octave-4.0.2/scripts/strings/index.m:79
        else:
            error('index: DIRECTION must be either "first" or "last"')
    
    return n
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## test everything out in reverse
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1998-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isletter (@var{s})
## Return a logical array which is true where the elements of @var{s}
## are letters and false where they are not.
##
## This is an alias for the @code{isalpha} function.
## @seealso{isalpha, isdigit, ispunct, isspace, iscntrl, isalnum}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def isletter(s=None,*args,**kwargs):
    varargin = isletter.varargin
    nargin = isletter.nargin

    if (nargin != 1):
        print_usage()
    
    retval=isalpha(s)
# /home/lei/octave-4.0.2/scripts/strings/isletter.m:36
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2008-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isstrprop (@var{str}, @var{prop})
## Test character string properties.
##
## For example:
##
## @example
## @group
## isstrprop ("abc123", "alpha")
## @result{} [1, 1, 1, 0, 0, 0]
## @end group
## @end example
##
## If @var{str} is a cell array, @code{isstrpop} is applied recursively to
## each element of the cell array.
##
## Numeric arrays are converted to character strings.
##
## The second argument @var{prop} must be one of
##
## @table @asis
## @item @qcode{"alpha"}
## True for characters that are alphabetic (letters).
##
## @item  @qcode{"alnum"}
## @itemx @qcode{"alphanum"}
## True for characters that are alphabetic or digits.
##
## @item @qcode{"lower"}
## True for lowercase letters.
##
## @item @qcode{"upper"}
## True for uppercase letters.
##
## @item @qcode{"digit"}
## True for decimal digits (0-9).
##
## @item @qcode{"xdigit"}
## True for hexadecimal digits (@nospell{a-fA-F0-9}).
##
## @item  @qcode{"space"}
## @itemx @qcode{"wspace"}
## True for whitespace characters (space, formfeed, newline, carriage return,
## tab, vertical tab).
##
## @item @qcode{"punct"}
## True for punctuation characters (printing characters except space or
## letter or digit).
##
## @item @qcode{"cntrl"}
## True for control characters.
##
## @item  @qcode{"graph"}
## @itemx @qcode{"graphic"}
## True for printing characters except space.
##
## @item @qcode{"print"}
## True for printing characters including space.
##
## @item @qcode{"ascii"}
## True for characters that are in the range of ASCII encoding.
##
## @end table
##
## @seealso{isalpha, isalnum, islower, isupper, isdigit, isxdigit,
## isspace, ispunct, iscntrl, isgraph, isprint, isascii}
## @end deftypefn
    
    
@function
def isstrprop(str=None,prop=None,*args,**kwargs):
    varargin = isstrprop.varargin
    nargin = isstrprop.nargin

    if (nargin != 2):
        print_usage()
    
    if 'alpha' == (prop):
        retval=isalpha(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:95
    else:
        if cellarray(['alnum','alphanum']) == (prop):
            retval=isalnum(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:97
        else:
            if 'ascii' == (prop):
                retval=isascii(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:99
            else:
                if 'cntrl' == (prop):
                    retval=iscntrl(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:101
                else:
                    if 'digit' == (prop):
                        retval=isdigit(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:103
                    else:
                        if cellarray(['graph','graphic']) == (prop):
                            retval=isgraph(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:105
                        else:
                            if 'lower' == (prop):
                                retval=islower(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:107
                            else:
                                if 'print' == (prop):
                                    retval=isprint(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:109
                                else:
                                    if 'punct' == (prop):
                                        retval=ispunct(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:111
                                    else:
                                        if cellarray(['space','wspace']) == (prop):
                                            retval=isspace(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:113
                                        else:
                                            if 'upper' == (prop):
                                                retval=isupper(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:115
                                            else:
                                                if 'xdigit' == (prop):
                                                    retval=isxdigit(str)
# /home/lei/octave-4.0.2/scripts/strings/isstrprop.m:117
                                                else:
                                                    error('isstrprop: invalid string property')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2006-2015 William Poetra Yoga Hadisoeseno
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} strtrunc (@var{s}, @var{n})
## Truncate the character string @var{s} to length @var{n}.
##
## If @var{s} is a character matrix, then the number of columns is adjusted.
##
## If @var{s} is a cell array of strings, then the operation is performed
## on each cell element and the new cell array is returned.
## @end deftypefn
    
    
@function
def strtrunc(s=None,n=None,*args,**kwargs):
    varargin = strtrunc.varargin
    nargin = strtrunc.nargin

    if (nargin != 2):
        print_usage()
    
    n=fix(n)
# /home/lei/octave-4.0.2/scripts/strings/strtrunc.m:35
    if (logical_not(isscalar(n)) or n < 0):
        error('strtrunc: length N must be a positive integer (N >= 0)')
    
    if (ischar(s)):
        if (n < columns(s)):
            s=s[:,1:n]
# /home/lei/octave-4.0.2/scripts/strings/strtrunc.m:42
    else:
        if (iscellstr(s)):
            ## Convoluted approach converts cellstr to char matrix, trims the character
    ## matrix using indexing, and then converts back to cellstr with mat2cell.
    ## This approach is 24X faster than using cellfun with call to strtrunc
            idx=cellfun('size',s,2) > n
# /home/lei/octave-4.0.2/scripts/strings/strtrunc.m:48
            rows=cellfun('size',s[idx],1)
# /home/lei/octave-4.0.2/scripts/strings/strtrunc.m:49
            if (logical_not(isempty(rows))):
                s[idx]=mat2cell(char(s[idx])(arange(),arange(1,n)),rows)
# /home/lei/octave-4.0.2/scripts/strings/strtrunc.m:51
        else:
            error('strtrunc: S must be a character string or a cell array of strings')
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} str2num (@var{s})
## @deftypefnx {Function File} {[@var{x}, @var{state}] =} str2num (@var{s})
## Convert the string (or character array) @var{s} to a number (or an array).
##
## Examples:
##
## @example
## @group
## str2num ("3.141596")
##       @result{} 3.141596
##
## str2num (["1, 2, 3"; "4, 5, 6"])
##       @result{} 1  2  3
##          4  5  6
## @end group
## @end example
##
## The optional second output, @var{state}, is logically true when the
## conversion is successful.  If the conversion fails the numeric output,
## @var{x}, is empty and @var{state} is false.
##
## @strong{Caution:} As @code{str2num} uses the @code{eval} function to do the
## conversion, @code{str2num} will execute any code contained in the string
## @var{s}.  Use @code{str2double} for a safer and faster conversion.
##
## For cell array of strings use @code{str2double}.
## @seealso{str2double, eval}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def str2num(s=None,*args,**kwargs):
    varargin = str2num.varargin
    nargin = str2num.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(ischar(s))):
            error('str2num: S must be a string or string array')
    
    s[:,end() + 1]=';'
# /home/lei/octave-4.0.2/scripts/strings/str2num.m:59
    s=sprintf('m = [%s];',reshape(s.T,1,numel(s)))
# /home/lei/octave-4.0.2/scripts/strings/str2num.m:60
    state=copy(true)
# /home/lei/octave-4.0.2/scripts/strings/str2num.m:61
    eval(s,'m = []; state = false;')
    if (ischar(m)):
        m=matlabarray([])
# /home/lei/octave-4.0.2/scripts/strings/str2num.m:64
        state=copy(false)
# /home/lei/octave-4.0.2/scripts/strings/str2num.m:65
    
    return m,state
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rindex (@var{s}, @var{t})
## Return the position of the last occurrence of the character string
## @var{t} in the character string @var{s}, or 0 if no occurrence is
## found.
##
## @var{s} may also be a string array or cell array of strings.
##
## For example:
##
## @example
## @group
## rindex ("Teststring", "t")
##      @result{} 6
## @end group
## @end example
##
## The @code{rindex} function is equivalent to @code{index} with
## @var{direction} set to @qcode{"last"}.
##
## @seealso{find, index}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
## This is patterned after the AWK function of the same name.
    
    
@function
def rindex(s=None,t=None,*args,**kwargs):
    varargin = rindex.varargin
    nargin = rindex.nargin

    if (nargin != 2):
        print_usage()
    
    n=index(s,t,'last')
# /home/lei/octave-4.0.2/scripts/strings/rindex.m:52
    return n
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2010-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} untabify (@var{t})
## @deftypefnx {Function File} {} untabify (@var{t}, @var{tw})
## @deftypefnx {Function File} {} untabify (@var{t}, @var{tw}, @var{deblank})
## Replace TAB characters in @var{t} with spaces.
##
## The input, @var{t}, may be either a 2-D character array, or a cell array of
## character strings.  The output is the same class as the input.
##
## The tab width is specified by @var{tw}, and defaults to eight.
##
## If the optional argument @var{deblank} is true, then the spaces will be
## removed from the end of the character data.
##
## The following example reads a file and writes an untabified version of the
## same file with trailing spaces stripped.
##
## @example
## @group
## fid = fopen ("tabbed_script.m");
## text = char (fread (fid, "uchar")');
## fclose (fid);
## fid = fopen ("untabified_script.m", "w");
## text = untabify (strsplit (text, "\n"), 8, true);
## fprintf (fid, "#s\n", text@{:@});
## fclose (fid);
## @end group
## @end example
##
## @seealso{strjust, strsplit, deblank}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: 2010-10-15
    
    
@function
def untabify(t=None,tw=8,dblank=false,*args,**kwargs):
    varargin = untabify.varargin
    nargin = untabify.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    else:
        if (logical_not((ischar(t) or iscellstr(t)))):
            error('untabify: T must be a string or cellstring')
    
    if (ischar(t)):
        s=replace_tabs(t,tw)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:63
    else:
        s=cellfun(replace_tabs,t,cellarray([tw]),'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:65
    
    if (dblank):
        s=deblank(s)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:69
    
    return s
    
if __name__ == '__main__':
    pass
    
    
@function
def replace_tabs(t=None,tw=None,*args,**kwargs):
    varargin = replace_tabs.varargin
    nargin = replace_tabs.nargin

    if (ndims(t) != 2):
        error('untabify: character strings to untabify must have 2 dimensions')
    
    if (isempty(t)):
        s=copy(t)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:81
    else:
        nr=rows(t)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:83
        sc=cell(nr,1)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:84
        for j in arange(1,nr).reshape(-1):
            n=arange(1,numel(t[j,:]))
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:86
            m=find(t[j,:] == '\t')
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:87
            t[j,m]=' '
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:88
            for i in arange(1,numel(m)).reshape(-1):
                k=dot(tw,ceil(n[m[i]] / tw))
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:90
                dn=k - n[m[i]]
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:91
                n[m[i]:end()] += dn
            sc[j]=blanks(n[end()])
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:94
            sc[j][n]=t[j,:]
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:95
        s=char(sc)
# /home/lei/octave-4.0.2/scripts/strings/untabify.m:97
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{idx} =} strchr (@var{str}, @var{chars})
## @deftypefnx {Function File} {@var{idx} =} strchr (@var{str}, @var{chars}, @var{n})
## @deftypefnx {Function File} {@var{idx} =} strchr (@var{str}, @var{chars}, @var{n}, @var{direction})
## @deftypefnx {Function File} {[@var{i}, @var{j}] =} strchr (@dots{})
## Search for the string @var{str} for occurrences of characters from
## the set @var{chars}.
##
## The return value(s), as well as the @var{n} and @var{direction} arguments
## behave identically as in @code{find}.
##
## This will be faster than using regexp in most cases.
##
## @seealso{find}
## @end deftypefn
    
    
@function
def strchr(str=None,chars=None,varargin=None,*args,**kwargs):
    varargin = strchr.varargin
    nargin = strchr.nargin

    if (nargin < 2):
        print_usage()
    else:
        if (logical_not(ischar(str))):
            error('strchr: STR argument must be a string or string array')
        else:
            if (logical_not(ischar(chars))):
                error('strchr: CHARS argument must be a string')
    
    if (isempty(chars)):
        mask=false(size(str))
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:46
    else:
        if (length(chars) <= 4):
            ## With a few characters, it pays off to build the mask incrementally.
    ## We do it via a for loop to save memory.
            mask=str == chars[1]
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:50
            for i in arange(2,length(chars)).reshape(-1):
                mask |= str == chars[i]
        else:
            ## Index the str into a mask of valid values.
    ## This is slower than it could be because of the +1 issue.
            f=false(256,1)
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:57
            f[uint8(chars) + 1]=true
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:58
            si=uint32(str)
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:60
            ++ si
            mask=reshape(f[si],size(str))
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:63
    
    varargout=cell(1,nargout)
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:66
    varargout[1]=[]
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:67
    varargout[:]=find(mask,varargin[:])
# /home/lei/octave-4.0.2/scripts/strings/strchr.m:68
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007 Muthiah Annamalai
## Copyright (C) 2013-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{str} =} strjoin (@var{cstr})
## @deftypefnx {Function File} {@var{str} =} strjoin (@var{cstr}, @var{delimiter})
## Join the elements of the cell string array, @var{cstr}, into a single
## string.
##
## If no @var{delimiter} is specified, the elements of @var{cstr} are
## separated by a space.
##
## If @var{delimiter} is specified as a string, the cell string array is
## joined using the string.  Escape sequences are supported.
##
## If @var{delimiter} is a cell string array whose length is one less than
## @var{cstr}, then the elements of @var{cstr} are joined by interleaving the
## cell string elements of @var{delimiter}.  Escape sequences are not
## supported.
##
## @example
## @group
## strjoin (@{'Octave','Scilab','Lush','Yorick'@}, '*')
##       @result{} 'Octave*Scilab*Lush*Yorick'
## @end group
## @end example
## @seealso{strsplit}
## @end deftypefn
    
    ## Author: Muthiah Annamalai <muthiah.annamalai@uta.edu>
## Author: Ben Abbott <bpabbott@mac.com>
    
    
@function
def strjoin(cstr=None,delimiter=None,*args,**kwargs):
    varargin = strjoin.varargin
    nargin = strjoin.nargin

    if (nargin == 1):
        delimiter=' '
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:52
    else:
        if (nargin < 1 or nargin > 2):
            print_usage()
        else:
            if (logical_not((iscellstr(cstr) and (ischar(delimiter) or iscellstr(delimiter))))):
                print_usage()
    
    if (numel(cstr) == 1):
        rval=cstr[1]
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:60
        return rval
    
    if (ischar(delimiter)):
        delimiter=do_string_escapes(delimiter)
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:65
        delimiter=cellarray([delimiter])
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:66
    
    num=numel(cstr)
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:69
    if (numel(delimiter) == 1 and num > 1):
        delimiter=repmat(delimiter,1,num)
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:71
        delimiter[end()]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:72
    else:
        if (num > 0 and numel(delimiter) != num - 1):
            error('strjoin:cellstring_delimiter_mismatch','strjoin: the number of delimiters does not match the number of strings')
        else:
            delimiter[end() + 1]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:77
    
    if (num == 0):
        rval=''
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:81
    else:
        rval=matlabarray(cat(cat([ravel(cstr).T],[ravel(delimiter).T])[:]))
# /home/lei/octave-4.0.2/scripts/strings/strjoin.m:83
    
    return rval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} base2dec (@var{s}, @var{base})
## Convert @var{s} from a string of digits in base @var{base} to a decimal
## integer (base 10).
##
## @example
## @group
## base2dec ("11120", 3)
##    @result{} 123
## @end group
## @end example
##
## If @var{s} is a string matrix, return a column vector with one value per
## row of @var{s}.  If a row contains invalid symbols then the corresponding
## value will be NaN@.
##
## If @var{s} is a cell array of strings, return a column vector with one
## value per cell element in @var{s}.
##
## If @var{base} is a string, the characters of @var{base} are used as the
## symbols for the digits of @var{s}.  Space (' ') may not be used as a symbol.
##
## @example
## @group
## base2dec ("yyyzx", "xyz")
##    @result{} 123
## @end group
## @end example
## @seealso{dec2base, bin2dec, hex2dec}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def base2dec(s=None,base=None,*args,**kwargs):
    varargin = base2dec.varargin
    nargin = base2dec.nargin

    if (nargin != 2):
        print_usage()
    
    if (iscellstr(s)):
        s=char(s)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:60
    else:
        if (logical_not(ischar(s))):
            error('base2dec: S must be a string or cellstring')
    
    symbols='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:65
    if (ischar(base)):
        symbols=copy(base)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:67
        base=length(symbols)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:68
        if (length(unique(symbols)) != base):
            error('base2dec: symbols representing digits must be unique')
        if (any(isspace(symbols))):
            error('base2dec: whitespace characters are not valid symbols')
    else:
        if (logical_not(isscalar(base))):
            error('base2dec: cannot convert from several bases at once')
        else:
            if (base < 2 or base > length(symbols)):
                error('base2dec: BASE must be between 2 and 36, or a string of symbols')
            else:
                s=toupper(s)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:80
    
    ## Right justify the values and squeeze out any spaces.
  ## This looks complicated, but indexing solution is very fast
  ## compared to alternatives which use cellstr or cellfun or looping.
    nr,nc=size(s,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:86
    if (nc > 1):
        s=s.T
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:88
        nonbl=s != ' '
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:89
        num_nonbl=sum(nonbl)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:90
        nc=max(num_nonbl)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:91
        num_blank=nc - num_nonbl
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:92
        R=repmat(cat([1,2],[0,0]),1,nr)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:93
        R[2,1:2:dot(2,nr)]=num_blank
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:94
        R[2,2:2:dot(2,nr)]=num_nonbl
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:95
        idx=repelems(cat(false,true),R)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:96
        idx=reshape(idx,nc,nr)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:97
        s2=repmat(' ',nc,nr)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:100
        s2[idx]=s[nonbl]
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:101
        s=s2.T
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:102
    
    ## Lookup value of symbols in symbol table, with invalid symbols
  ## evaluating to NaN and space evaluating to 0.
    table=NaN(1,256)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:107
    table[toascii(symbols[1:base])]=arange(0,base - 1)
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:108
    table[toascii(' ')]=0
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:109
    s=reshape(table[toascii(s)],size(s))
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:110
    
    ## and sum the rows.
    out=dot(s,(base ** (arange(columns(s) - 1,0,- 1)).T))
# /home/lei/octave-4.0.2/scripts/strings/base2dec.m:114
    return out
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Bug #35621
    
    ## Test input validation
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} strcat (@var{s1}, @var{s2}, @dots{})
## Return a string containing all the arguments concatenated
## horizontally.
##
## If the arguments are cell strings, @code{strcat} returns a cell string
## with the individual cells concatenated.  For numerical input, each element
## is converted to the corresponding ASCII character.  Trailing white space
## for any character string input is eliminated before the strings are
## concatenated.  Note that cell string values do @strong{not} have
## whitespace trimmed.
##
## For example:
##
## @example
## @group
## strcat ("|", " leading space is preserved", "|")
##     @result{} | leading space is preserved|
## @end group
## @end example
##
## @example
## @group
## strcat ("|", "trailing space is eliminated ", "|")
##     @result{} |trailing space is eliminated|
## @end group
## @end example
##
## @example
## @group
## strcat ("homogeneous space |", "  ", "| is also eliminated")
##     @result{} homogeneous space || is also eliminated
## @end group
## @end example
##
## @example
## @group
## s = [ "ab"; "cde" ];
## strcat (s, s, s)
##     @result{}
##         "ababab   "
##         "cdecdecde"
## @end group
## @end example
##
## @example
## @group
## s = @{ "ab"; "cd " @};
## strcat (s, s, s)
##     @result{}
##         @{
##           [1,1] = ababab
##           [2,1] = cd cd cd
##         @}
## @end group
## @end example
##
## @seealso{cstrcat, char, strvcat}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def strcat(varargin=None,*args,**kwargs):
    varargin = strcat.varargin
    nargin = strcat.nargin

    if (nargin == 0):
        print_usage()
    
    if (nargin == 1):
        st=varargin[1]
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:89
    else:
        ## Convert to cells of strings
        uo='uniformoutput'
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:92
        reals=cellfun('isreal',varargin)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:93
        if (any(reals)):
            varargin[reals]=cellfun('char',varargin[reals],uo,false)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:95
        chars=cellfun('isclass',varargin,'char')
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:97
        allchar=all(chars)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:98
        varargin[chars]=cellfun('cellstr',varargin[chars],uo,false)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:99
        if (logical_not(all(cellfun('isclass',varargin,'cell')))):
            error('strcat: inputs must be strings or cells of strings')
        ## We don't actually need to bring all cells to common size, because
    ## cellfun can now expand scalar cells.
        err=common_size(varargin[:])
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:106
        if (err):
            error('strcat: arguments must be the same size, or be scalars')
        ## Cellfun handles everything for us.
        st=cellfun('horzcat',varargin[:],uo,false)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:113
        if (allchar):
            ## If all inputs were strings, return strings.
            st=char(st)
# /home/lei/octave-4.0.2/scripts/strings/strcat.m:117
    
    return st
    
if __name__ == '__main__':
    pass
    
    ## test the dimensionality
## 1d
    
    
    
    
    
    
    ## 2d
    
    ## test for deblanking implied trailing spaces of character input
    
    
    ## test for mixing character and cell inputs
    
    ## test for scalar strings with vector strings
    
    ## test with cells with strings of differing lengths
    
    
    
    
    
    ## Copyright (C) 2009-2015 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{cstr}] =} strsplit (@var{str})
## @deftypefnx {Function File} {[@var{cstr}] =} strsplit (@var{str}, @var{del})
## @deftypefnx {Function File} {[@var{cstr}] =} strsplit (@dots{}, @var{name}, @var{value})
## @deftypefnx {Function File} {[@var{cstr}, @var{matches}] =} strsplit (@dots{})
## Split the string @var{str} using the delimiters specified by @var{del} and
## return a cell string array of substrings.
##
## If a delimiter is not specified the string is split at whitespace
## @code{@{" ", "\f", "\n", "\r", "\t", "\v"@}}.  Otherwise, the delimiter,
## @var{del} must be a string or cell array of strings.  By default,
## consecutive delimiters in the input string @var{s} are collapsed into one
## resulting in a single split.
##
## Supported @var{name}/@var{value} pair arguments are:
##
## @itemize
## @item @var{collapsedelimiters} which may take the value of @code{true}
## (default) or @code{false}.
##
## @item @var{delimitertype} which may take the value of @qcode{"simple"}
## (default) or @nospell{@qcode{"regularexpression"}}.  A simple delimiter
## matches the text exactly as written.  Otherwise, the syntax for regular
## expressions outlined in @code{regexp} is used.
## @end itemize
##
## The optional second output, @var{matches}, returns the delimiters which were
## matched in the original string.
##
## Examples with simple delimiters:
##
## @example
## strsplit ("a b c")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## strsplit ("a,b,c", ",")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## strsplit ("a foo b,bar c", @{" ", ",", "foo", "bar"@})
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## strsplit ("a,,b, c", @{",", " "@}, "collapsedelimiters", false)
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] =
##             [1,3] = b
##             [1,4] =
##             [1,5] = c
##           @}
##
## @end example
##
## Examples with @nospell{regularexpression} delimiters:
##
## @smallexample
## strsplit ("a foo b,bar c", ',|\s|foo|bar', "delimitertype", "regularexpression")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## strsplit ("a,,b, c", '[, ]', "collapsedelimiters", false, "delimitertype", "regularexpression")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] =
##             [1,3] = b
##             [1,4] =
##             [1,5] = c
##           @}
##
## strsplit ("a,\t,b, c", @{',', '\s'@}, "delimitertype", "regularexpression")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## strsplit ("a,\t,b, c", @{',', ' ', '\t'@}, "collapsedelimiters", false)
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] =
##             [1,3] =
##             [1,4] = b
##             [1,5] =
##             [1,6] = c
##           @}
## @end smallexample
##
## @seealso{ostrsplit, strjoin, strtok, regexp}
## @end deftypefn
    
    
@function
def strsplit(str=None,del_=None,varargin=None,*args,**kwargs):
    varargin = strsplit.varargin
    nargin = strsplit.nargin

    args.collapsedelimiters = copy(true)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:133
    args.delimitertype = copy('simple')
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:134
    reg,params=parseparams(varargin,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:136
    if (nargin < 1):
        print_usage()
    else:
        if (numel(reg) > 1):
            print_usage()
        else:
            if (numel(reg) == 1):
                ## This is undocumented behavior to accept a logical 3rd arg.
                if (islogical(reg[1])):
                    args.collapsedelimiters = copy(reg[1])
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:145
                else:
                    print_usage()
    
    fields=fieldnames(args)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:150
    for n in arange(1,numel(params),2).reshape(-1):
        if (any(strcmpi(params[n],fields))):
            setattr(args,tolower(params[n]),params[n + 1])
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:153
        else:
            if (ischar(varargin[n])):
                error('strsplit:invalid_parameter_name','strsplit: invalid parameter name, \'%s\'',varargin[n])
            else:
                print_usage()
    
    ## Save the length of the "delimitertype" parameter
    length_deltype=length(args.delimitertype)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:163
    if (nargin == 1 or (nargin > 1 and islogical(del_))):
        if (nargin > 1):
            ## Second input is the "collapsedelimiters" parameter
            args.collapsedelimiters = copy(del_)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:168
        ## Set proper default for the delimiter type
        if (strncmpi(args.delimitertype,'simple',length_deltype)):
            del_=cellarray([' ','\x0c','\n','\r','\t','\x0b'])
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:172
        else:
            del_='\\s'
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:174
    
    if (logical_not(ischar(str)) or (logical_not(ischar(del_)) and logical_not(iscellstr(del_)))):
        error('strsplit: S and DEL must be string values')
    else:
        if (logical_not(isscalar(args.collapsedelimiters))):
            error('strsplit: COLLAPSEDELIMITERS must be a scalar value')
    
    if (strncmpi(args.delimitertype,'simple',length_deltype)):
        is_simple=copy(true)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:185
    else:
        if (strncmpi(args.delimitertype,'regularexpression',length_deltype)):
            is_simple=copy(false)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:187
        else:
            error('strsplit:invalid_delimitertype','strsplit: Invalid DELIMITERTYPE')
    
    if (is_simple):
        if (iscellstr(del_)):
            del_=cellfun(do_string_escapes,del_,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:194
        else:
            del_=do_string_escapes(del_)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:196
        ## Escape characters which have a special meaning in regexp.
        del_=regexprep(del_,'([{}()[\\]^$.*?+|\\\\])','\\\\$1')
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:199
    
    if (isempty(str)):
        cstr=cellarray([str])
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:203
    else:
        if (iscellstr(del_)):
            del_=sprintf('%s|',del_[:])
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:206
            del_[end()]=[]
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:207
        if (args.collapsedelimiters):
            del_=matlabarray(cat('(',del_,')+'))
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:210
        cstr,matches=regexp(str,del_,'split','match',nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/strsplit.m:212
    
    return cstr,matches
    
if __name__ == '__main__':
    pass
    
    
    
    ## Split on all whitespace.
    
    
    ## Split on "ain".
    
    
    ## Split on " " and "ain" (treating multiple delimiters as one).
    
    
    
    
    
    
    
    
    
    
    ## Split on " " and "ain", and treat multiple delimiters separately.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test "match" for consecutive delmiters
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Compatibility
    
    
    
    
    ## Bug #44641
    
    
    ## Bug #47403
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} bin2dec (@var{s})
## Return the decimal number corresponding to the binary number represented
## by the string @var{s}.
##
## For example:
##
## @example
## @group
## bin2dec ("1110")
##      @result{} 14
## @end group
## @end example
##
## Spaces are ignored during conversion and may be used to make the binary
## number more readable.
##
## @example
## @group
## bin2dec ("1000 0001")
##      @result{} 129
## @end group
## @end example
##
## If @var{s} is a string matrix, return a column vector with one converted
## number per row of @var{s}; Invalid rows evaluate to NaN@.
##
## If @var{s} is a cell array of strings, return a column vector with one
## converted number per cell element in @var{s}.
## @seealso{dec2bin, base2dec, hex2dec}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def bin2dec(s=None,*args,**kwargs):
    varargin = bin2dec.varargin
    nargin = bin2dec.nargin

    if (nargin != 1):
        print_usage()
    
    d=base2dec(s,2)
# /home/lei/octave-4.0.2/scripts/strings/bin2dec.m:60
    return d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{cstr}] =} ostrsplit (@var{s}, @var{sep})
## @deftypefnx {Function File} {[@var{cstr}] =} ostrsplit (@var{s}, @var{sep}, @var{strip_empty})
## Split the string @var{s} using one or more separators @var{sep} and return
## a cell array of strings.
##
## Consecutive separators and separators at boundaries result in empty
## strings, unless @var{strip_empty} is true.  The default value of
## @var{strip_empty} is false.
##
## 2-D character arrays are split at separators and at the original column
## boundaries.
##
## Example:
##
## @example
## @group
## ostrsplit ("a,b,c", ",")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = c
##           @}
##
## ostrsplit (["a,b" ; "cde"], ",")
##       @result{}
##           @{
##             [1,1] = a
##             [1,2] = b
##             [1,3] = cde
##           @}
## @end group
## @end example
## @seealso{strsplit, strtok}
## @end deftypefn
    
    
@function
def ostrsplit(s=None,sep=None,strip_empty=false,*args,**kwargs):
    varargin = ostrsplit.varargin
    nargin = ostrsplit.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    else:
        if (logical_not(ischar(s)) or logical_not(ischar(sep))):
            error('ostrsplit: S and SEP must be string values')
        else:
            if (logical_not(isscalar(strip_empty))):
                error('ostrsplit: STRIP_EMPTY must be a scalar value')
    
    if (isempty(s)):
        cstr=cell(size(s))
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:67
    else:
        if (rows(s) > 1):
            ## For 2-D arrays, add separator character at line boundaries
      ## and transform to single string
            s[:,end() + 1]=sep[1]
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:72
            s=reshape(s.T,1,numel(s))
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:73
            s[end()]=[]
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:74
        ## Split s according to delimiter
        if (isscalar(sep)):
            ## Single separator
            idx=find(s == sep)
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:80
        else:
            ## Multiple separators
            idx=strchr(s,sep)
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:83
        ## Get substring lengths.
        if (isempty(idx)):
            strlens=length(s)
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:88
        else:
            strlens=matlabarray(cat(idx[1] - 1,diff(idx) - 1,numel(s) - idx[end()]))
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:90
        ## Remove separators.
        s[idx]=[]
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:93
        if (strip_empty):
            ## Omit zero lengths.
            strlens=strlens[strlens != 0]
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:96
        ## Convert!
        cstr=mat2cell(s,1,strlens)
# /home/lei/octave-4.0.2/scripts/strings/ostrsplit.m:100
    
    return cstr
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2013 Paul Kienzle
## Copyright (C) 2003 Alois Schloegl
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} strmatch (@var{s}, @var{A})
## @deftypefnx {Function File} {} strmatch (@var{s}, @var{A}, "exact")
## Return indices of entries of @var{A} which begin with the string @var{s}.
##
## The second argument @var{A} must be a string, character matrix, or a cell
## array of strings.
##
## If the third argument @qcode{"exact"} is not given, then @var{s} only
## needs to match @var{A} up to the length of @var{s}.  Trailing spaces and
## nulls in @var{s} and @var{A} are ignored when matching.
##
## For example:
##
## @example
## @group
## strmatch ("apple", "apple juice")
##      @result{} 1
##
## strmatch ("apple", ["apple  "; "apple juice"; "an apple"])
##      @result{} [1; 2]
##
## strmatch ("apple", ["apple  "; "apple juice"; "an apple"], "exact")
##      @result{} [1]
## @end group
## @end example
##
## @strong{Caution:} @code{strmatch} is scheduled for deprecation.  Use
## @code{strncmp} (normal case), or @code{strcmp} (@qcode{"exact"} case), or
## @code{regexp} in all new code.
## @seealso{strfind, findstr, strcmp, strncmp, strcmpi, strncmpi, find}
## @end deftypefn
    
    ## Author: Paul Kienzle, Alois Schloegl
## Adapted-by: jwe
    
    
@function
def strmatch(s=None,A=None,exact=None,*args,**kwargs):
    varargin = strmatch.varargin
    nargin = strmatch.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(s)) or (logical_not(isempty(s)) and logical_not(isvector(s)))):
        error('strmatch: S must be a string')
    else:
        if (logical_not((ischar(A) or iscellstr(A)))):
            error('strmatch: A must be a string or cell array of strings')
    
    ## Trim blanks and nulls from search string
    s=regexprep(s,'[ \\0]+$','')
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:70
    len_=length(s)
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:71
    exact=nargin == 3 and ischar(exact) and strcmp(exact,'exact')
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:73
    if (ischar(A)):
        nr,nc=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:76
        if (len_ > nc):
            idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:78
        else:
            match=all(bsxfun(eq,A[:,1:len_],s),2)
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:80
            if (exact):
                AA=A[:,len_ + 1:nc]
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:82
                match &= all(AA == logical_or(' ',AA) == '\x00',2)
            idx=find(match)
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:85
    else:
        if (len_ > 0):
            idx=find(strncmp(s,A,len_))
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:89
        else:
            idx=find(strcmp(s,A))
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:91
        if (exact):
            ## We can't just use strcmp, because we need to ignore spaces at end.
            B=regexprep(A[idx],'[ \\0]+$','')
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:95
            idx=idx[strcmp(s,B)]
# /home/lei/octave-4.0.2/scripts/strings/strmatch.m:96
    
    return idx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} strtrim (@var{s})
## Remove leading and trailing whitespace from @var{s}.
##
## If @var{s} is a matrix, @var{strtrim} trims each row to the length of
## longest string.  If @var{s} is a cell array of strings, operate recursively
## on each string element.
##
## For example:
##
## @example
## @group
## strtrim ("    abc  ")
##      @result{}  "abc"
##
## strtrim ([" abc   "; "   def   "])
##      @result{}  ["abc  "  ; "  def"]
## @end group
## @end example
## @seealso{deblank}
## @end deftypefn
    
    ## Author: John Swensen <jpswensen@jhu.edu>
    
    ## This function was derived from deblank.
    
    
@function
def strtrim(s=None,*args,**kwargs):
    varargin = strtrim.varargin
    nargin = strtrim.nargin

    if (nargin != 1):
        print_usage()
    
    if (ischar(s)):
        k=find(logical_not(isspace(s)))
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:53
        if (isempty(s) or isempty(k)):
            s=''
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:55
        else:
            s=s[:,ceil(min(k) / rows(s)):ceil(max(k) / rows(s))]
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:57
    else:
        if (iscell(s)):
            char_idx=cellfun('isclass',s,'char')
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:62
            cell_idx=cellfun('isclass',s,'cell')
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:63
            if (logical_not(all(logical_or(char_idx,cell_idx)))):
                error('strtrim: S argument must be a string or cellstring')
            ## Divide work load.  Recursive cellfun strtrim call is slow
    ## and avoided where possible.
            s[char_idx]=regexprep(s[char_idx],'^[\\s\x0b]+|[\\s\x0b]+$','')
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:70
            s[cell_idx]=cellfun('strtrim',s[cell_idx],'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/strings/strtrim.m:71
        else:
            error('strtrim: S argument must be a string or cellstring')
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} deblank (@var{s})
## Remove trailing whitespace and nulls from @var{s}.
##
## If @var{s} is a matrix, @var{deblank} trims each row to the length of
## longest string.  If @var{s} is a cell array of strings, operate
## recursively on each string element.
##
## Examples:
##
## @example
## @group
## deblank ("    abc  ")
##      @result{}  "    abc"
##
## deblank ([" abc   "; "   def   "])
##      @result{}  [" abc  " ; "   def"]
## @end group
## @end example
## @seealso{strtrim}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Adapted-By: jwe
    
    
@function
def deblank(s=None,*args,**kwargs):
    varargin = deblank.varargin
    nargin = deblank.nargin

    if (nargin != 1):
        print_usage()
    
    if (ischar(s)):
        k=find(logical_and(logical_not(isspace(s)),s) != '\x00')
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:52
        if (isempty(s) or isempty(k)):
            s=''
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:54
        else:
            s=s[:,1:ceil(max(k) / rows(s))]
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:56
    else:
        if (iscell(s)):
            char_idx=cellfun('isclass',s,'char')
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:61
            cell_idx=cellfun('isclass',s,'cell')
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:62
            if (logical_not(all(logical_or(char_idx,cell_idx)))):
                error('deblank: S argument must be a string or cellstring')
            ## Divide work load.  Recursive cellfun deblank call is slow
    ## and avoided where possible.
            s[char_idx]=regexprep(s[char_idx],'[\\s\x0b\\0]+$','')
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:69
            s[cell_idx]=cellfun('deblank',s[cell_idx],'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/strings/deblank.m:70
        else:
            error('deblank: S argument must be a string or cellstring')
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dec2base (@var{d}, @var{base})
## @deftypefnx {Function File} {} dec2base (@var{d}, @var{base}, @var{len})
## Return a string of symbols in base @var{base} corresponding to the
## non-negative integer @var{d}.
##
## @example
## @group
## dec2base (123, 3)
##    @result{} "11120"
## @end group
## @end example
##
## If @var{d} is a matrix or cell array, return a string matrix with one row
## per element in @var{d}, padded with leading zeros to the width of the
## largest value.
##
## If @var{base} is a string then the characters of @var{base} are used as
## the symbols for the digits of @var{d}.  Space (' ') may not be used as a
## symbol.
##
## @example
## @group
## dec2base (123, "aei")
##    @result{} "eeeia"
## @end group
## @end example
##
## The optional third argument, @var{len}, specifies the minimum number of
## digits in the result.
## @seealso{base2dec, dec2bin, dec2hex}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def dec2base(d=None,base=None,len_=None,*args,**kwargs):
    varargin = dec2base.varargin
    nargin = dec2base.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (iscell(d)):
        d=cell2mat(d)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:62
    
    ## Create column vector for algorithm
    if (logical_not(iscolumn(d))):
        d=ravel(d)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:67
    
    ## Treat logical as numeric for compatibility with ML
    if (islogical(d)):
        d=double(d)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:72
    else:
        if (logical_not(isnumeric(d)) or iscomplex(d) or any(d < logical_or(0,d) != fix(d))):
            error('dec2base: input must be real non-negative integers')
    
    symbols='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:77
    if (ischar(base)):
        symbols=copy(base)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:79
        base=length(symbols)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:80
        if (length(unique(symbols)) != base):
            error('dec2base: symbols representing digits must be unique')
        if (any(isspace(symbols))):
            error('dec2base: whitespace characters are not valid symbols')
    else:
        if (logical_not(isscalar(base))):
            error('dec2base: cannot convert from several bases at once')
        else:
            if (base < 2 or base > length(symbols)):
                error('dec2base: BASE must be between 2 and 36, or a string of symbols')
    
    ## determine number of digits required to handle all numbers, can overflow
  ## by 1 digit
    max_len=round(log(max(max(ravel(d)),1)) / log(base)) + 1
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:95
    if (nargin == 3):
        max_len=max(max_len,len_)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:98
    
    ## determine digits for each number
    digits=zeros(length(d),max_len)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:102
    for k in arange(max_len,1,- 1).reshape(-1):
        digits[:,k]=mod(d,base)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:104
        d=round((d - digits[:,k]) / base)
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:105
    
    ## convert digits to symbols
    retval=reshape(symbols[digits + 1],size(digits))
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:109
    
    ## that LEN is provided, and is less than the computed MAX_LEN and
  ## MAX_LEN is computed to be one larger than necessary, so we would
  ## have a leading zero to remove.  But if LEN >= MAX_LEN, we should
  ## not remove any leading zeros.
    if ((nargin == 2 or (nargin == 3 and max_len > len_)) and length(retval) != 1 and logical_not(any(retval[:,1] != symbols[1]))):
        retval=retval[:,2:end()]
# /home/lei/octave-4.0.2/scripts/strings/dec2base.m:118
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hex2dec (@var{s})
## Return the integer corresponding to the hexadecimal number represented by
## the string @var{s}.
##
## For example:
##
## @example
## @group
## hex2dec ("12B")
##       @result{} 299
## hex2dec ("12b")
##       @result{} 299
## @end group
## @end example
##
## If @var{s} is a string matrix, return a column vector with one converted
## number per row of @var{s}; Invalid rows evaluate to NaN@.
##
## If @var{s} is a cell array of strings, return a column vector with one
## converted number per cell element in @var{s}.
##
## @seealso{dec2hex, base2dec, bin2dec}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def hex2dec(s=None,*args,**kwargs):
    varargin = hex2dec.varargin
    nargin = hex2dec.nargin

    if (nargin != 1):
        print_usage()
    
    d=base2dec(s,16)
# /home/lei/octave-4.0.2/scripts/strings/hex2dec.m:53
    return d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{tok}, @var{rem}] =} strtok (@var{str})
## @deftypefnx {Function File} {[@var{tok}, @var{rem}] =} strtok (@var{str}, @var{delim})
##
## Find all characters in the string @var{str} up to, but not including, the
## first character which is in the string @var{delim}.
##
## @var{str} may also be a cell array of strings in which case the function
## executes on every individual string and returns a cell array of tokens and
## remainders.
##
## Leading delimiters are ignored.  If @var{delim} is not specified,
## whitespace is assumed.
##
## If @var{rem} is requested, it contains the remainder of the string, starting
## at the first delimiter.
##
## Examples:
##
## @example
## @group
## strtok ("this is the life")
##      @result{} "this"
##
## [tok, rem] = strtok ("14*27+31", "+-*/")
##      @result{}
##         tok = 14
##         rem = *27+31
## @end group
## @end example
## @seealso{index, strsplit, strchr, isspace}
## @end deftypefn
    
    
@function
def strtok(str=None,delim=None,*args,**kwargs):
    varargin = strtok.varargin
    nargin = strtok.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not((ischar(str) or iscellstr(str)))):
            error('strtok: STR must be a string or cell array of strings.')
        else:
            if (ischar(str) and logical_not(isvector(str)) and logical_not(isempty(str))):
                error('strtok: STR cannot be a 2-D character array.')
    
    if (nargin < 2 or isempty(delim)):
        ws_delim=copy(true)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:63
    else:
        ws_delim=copy(false)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:65
    
    if (isempty(str)):
        tok=rem=''
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:69
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:69
    else:
        if (ischar(str)):
            if (ws_delim):
                idx=isspace(str)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:72
            else:
                if (length(delim) <= 7):
                    ## Build index of delimiters incrementally for low N.
                    idx=str == delim[1]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:75
                    for i in arange(2,length(delim)).reshape(-1):
                        idx |= str == delim[i]
                else:
                    ## Index the str into a mask of valid values.  Faster for large N.
                    f=false(256,1)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:81
                    f[uint8(delim) + 1]=true
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:83
                    si=uint32(str)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:85
                    ++ si
                    idx=f[si]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:88
            idx_dlim=find(idx,1)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:91
            idx_nodlim=find(logical_not(idx),1)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:92
            if (isempty(idx_dlim)):
                ## No delimiter.  Return whole string.
                tok=copy(str)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:95
                rem=''
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:96
            else:
                if (idx_dlim > idx_nodlim):
                    ## Normal case.  No leading delimiters and at least 1 delimiter in STR.
                    tok=str[1:idx_dlim - 1]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:99
                    rem=str[idx_dlim:end()]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:100
                else:
                    ## Leading delimiter found.
                    idx_dlim=find(idx[idx_nodlim + 1:end()],1)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:103
                    if (isempty(idx_dlim)):
                        ## No further delimiters.  Return STR stripped of delimiter prefix.
                        tok=str[idx_nodlim:end()]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:106
                        rem=''
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:107
                    else:
                        ## Strip delimiter prefix.  Return STR up to 1st delimiter
                        tok=str[idx_nodlim:(idx_dlim + idx_nodlim - 1)]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:110
                        rem=str[(idx_dlim + idx_nodlim):end()]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:111
        else:
            if (ws_delim):
                delim='\\s'
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:116
            ptn=matlabarray(cat('^[',delim,']*','([^',delim,']+)','([',delim,'].*)$'))
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:118
            matches=regexp(str,ptn,'tokens')
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:119
            eidx=cellfun('isempty',matches)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:120
            midx=logical_not(eidx)
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:121
            tok=cell(size(str))
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:122
            tok[eidx]=regexprep(str[eidx],cat('^[',delim,']+'),'')
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:123
            tmp=matlabarray(cat(matches[midx]))
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:125
            if (logical_not(isempty(tmp))):
                tmp=matlabarray(cat(tmp[:]))
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:127
            tok[midx]=tmp[1:2:end()]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:129
            if (isargout(2)):
                rem=cell(size(str))
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:131
                rem[eidx]=cellarray([''])
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:132
                rem[midx]=tmp[2:2:end()]
# /home/lei/octave-4.0.2/scripts/strings/strtok.m:133
    
    return tok,rem
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test the tokens for all cases
    
    
    
    
    
    
    
    ## Test the remainder for all cases
    
    ## Test all tokens and remainders with cell array input
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Simple check for 2, 3, and 4 delimeters
    
    
    
    ## Test all cases for 8 delimiters since a different
    
    
    
    
    
    
    
    
    ## Test 'bad' string orientations
    
    
    ## Test with TAB, LF, VT, FF, and CR
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} dec2hex (@var{d}, @var{len})
## Return the hexadecimal string corresponding to the non-negative integer
## @var{d}.
##
## For example:
##
## @example
## @group
## dec2hex (2748)
##      @result{} "ABC"
## @end group
## @end example
##
## If @var{d} is a matrix or cell array, return a string matrix with one row
## per element in @var{d}, padded with leading zeros to the width of the
## largest value.
##
## The optional second argument, @var{len}, specifies the minimum number of
## digits in the result.
## @seealso{hex2dec, dec2base, dec2bin}
## @end deftypefn
    
    ## Author: Daniel Calvelo <dcalvelo@yahoo.com>
## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
    
    
@function
def dec2hex(d=None,len_=None,*args,**kwargs):
    varargin = dec2hex.varargin
    nargin = dec2hex.nargin

    if (nargin == 1):
        h=dec2base(d,16)
# /home/lei/octave-4.0.2/scripts/strings/dec2hex.m:48
    else:
        if (nargin == 2):
            h=dec2base(d,16,len_)
# /home/lei/octave-4.0.2/scripts/strings/dec2hex.m:50
        else:
            print_usage()
    
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} setpref (@var{group}, @var{pref}, @var{val})
## Set a preference @var{pref} to the given @var{val} in the named preference
## group @var{group}.
##
## The named preference group must be a character string.
##
## The preference @var{pref} may be a character string or a cell array of
## character strings.
##
## The corresponding value @var{val} may be any value, or, if @var{pref} is a
## cell array of strings, @var{val} must be a cell array of values with the
## same size as @var{pref}.
##
## If the named preference or group does not exist, it is added.
## @seealso{addpref, getpref, ispref, rmpref}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def setpref(group=None,pref=None,val=None,*args,**kwargs):
    varargin = setpref.varargin
    nargin = setpref.nargin

    if (nargin == 3):
        if (ischar(group)):
            prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/setpref.m:43
            if (ischar(pref)):
                setattr(getattr(prefs,(group)),pref,val)
# /home/lei/octave-4.0.2/scripts/prefs/setpref.m:45
            else:
                if (iscellstr(pref)):
                    if (size_equal(pref,val)):
                        for i in arange(1,numel(pref)).reshape(-1):
                            setattr(getattr(prefs,(group)),pref[i],val)
# /home/lei/octave-4.0.2/scripts/prefs/setpref.m:49
                    else:
                        error('size mismatch for pref and val')
                else:
                    error('expecting pref to be a character string or cellstr')
            saveprefs(prefs)
        else:
            error('expecting group to be a character string')
    else:
        print_usage()
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ispref (@var{group}, @var{pref})
## @deftypefnx {Function File} {} ispref (@var{group})
## Return true if the named preference @var{pref} exists in the preference
## group @var{group}.
##
## The named preference group must be a character string.
##
## The preference @var{pref} may be a character string or a cell array of
## character strings.
##
## If @var{pref} is not specified, return true if the preference group
## @var{group} exists.
## @seealso{getpref, addpref, setpref, rmpref}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def ispref(group=None,pref=None,*args,**kwargs):
    varargin = ispref.varargin
    nargin = ispref.nargin

    if (nargin == 1):
        retval=isfield(loadprefs(),group)
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:40
    else:
        if (nargin == 2):
            prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:42
            if (isfield(prefs,group)):
                grp=getattr(prefs,(group))
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:44
                if (ischar(pref) or iscellstr(pref)):
                    retval=isfield(grp,pref)
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:46
                else:
                    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:48
            else:
                retval=copy(false)
# /home/lei/octave-4.0.2/scripts/prefs/ispref.m:51
        else:
            print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rmpref (@var{group}, @var{pref})
## @deftypefnx {Function File} {} rmpref (@var{group})
## Remove the named preference @var{pref} from the preference group @var{group}.
##
## The named preference group must be a character string.
##
## The preference @var{pref} may be a character string or cell array of strings.
##
## If @var{pref} is not specified, remove the preference group @var{group}.
##
## It is an error to remove a nonexistent preference or group.
## @seealso{addpref, ispref, setpref, getpref}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def rmpref(group=None,pref=None,*args,**kwargs):
    varargin = rmpref.varargin
    nargin = rmpref.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not(ischar(group))):
            error('rmpref: GROUP must be a string')
        else:
            if (nargin == 2 and logical_not((ischar(pref) or iscellstr(pref)))):
                error('rmpref: PREF must be a string or cell array of strings')
    
    if (nargin == 1):
        if (ispref(group)):
            prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:48
            prefs=rmfield(prefs,group)
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:49
            saveprefs(prefs)
        else:
            error('rmpref: group <%s> does not exist',group)
    else:
        valid=ispref(group,pref)
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:55
        if (all(valid)):
            prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:57
            setattr(prefs,group,rmfield(getattr(prefs,(group)),pref))
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:58
            saveprefs(prefs)
        else:
            if (logical_not(ispref(group))):
                error('rmpref: group <%s> does not exist',group)
            else:
                idx=find(logical_not(valid),1)
# /home/lei/octave-4.0.2/scripts/prefs/rmpref.m:64
                error('rmpref: pref <%s> does not exist',(cellstr(pref))[idx])
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} addpref (@var{group}, @var{pref}, @var{val})
## Add a preference @var{pref} and associated value @var{val} to the named
## preference group @var{group}.
##
## The named preference group must be a character string.
##
## The preference @var{pref} may be a character string or a cell array of
## character strings.
##
## The corresponding value @var{val} may be any value, or, if @var{pref} is a
## cell array of strings, @var{val} must be a cell array of values with the
## same size as @var{pref}.
## @seealso{setpref, getpref, ispref, rmpref}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def addpref(group=None,pref=None,val=None,*args,**kwargs):
    varargin = addpref.varargin
    nargin = addpref.nargin

    if (nargin == 3):
        if (ischar(group)):
            prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/addpref.m:41
            if (ischar(pref)):
                if (isfield(group,pref)):
                    error('preference %s already exists in group %s',pref,group)
                else:
                    setattr(getattr(prefs,(group)),pref,val)
# /home/lei/octave-4.0.2/scripts/prefs/addpref.m:46
            else:
                if (iscellstr(pref)):
                    if (size_equal(pref,val)):
                        for i in arange(1,numel(pref)).reshape(-1):
                            if (isfield(group,pref[i])):
                                error('preference %s already exists in group %s',pref[i],group)
                            else:
                                setattr(getattr(prefs,(group)),pref[i],val)
# /home/lei/octave-4.0.2/scripts/prefs/addpref.m:55
                    else:
                        error('size mismatch for pref and val')
                else:
                    error('expecting pref to be a character string or cellstr')
            saveprefs(prefs)
        else:
            error('expecting group to be a character string')
    else:
        print_usage()
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2013-2015 John Donoghue
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} prefdir
## @deftypefnx {Command} {@var{dir} =} prefdir
## Return the directory that contains the preferences for Octave.
##
## Examples:
##
## Display the preferences directory
##
## @example
## prefdir
## @end example
##
## Change to the preferences folder
##
## @example
## cd (prefdir)
## @end example
## @seealso{getpref, setpref, addpref, rmpref, ispref}
## @end deftypefn
    
    ## Author: John Donoghue
## Version: 0.01
    
    
@function
def prefdir(*args,**kwargs):
    varargin = prefdir.varargin
    nargin = prefdir.nargin

    folder=get_home_directory()
# /home/lei/octave-4.0.2/scripts/prefs/prefdir.m:45
    return folder
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} loadprefs ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def loadprefs(*args,**kwargs):
    varargin = loadprefs.varargin
    nargin = loadprefs.nargin

    file=prefsfile()
# /home/lei/octave-4.0.2/scripts/prefs/private/loadprefs.m:28
    s=stat(file)
# /home/lei/octave-4.0.2/scripts/prefs/private/loadprefs.m:30
    if (isstruct(s) and S_ISREG(s.mode)):
        tmp=load(file)
# /home/lei/octave-4.0.2/scripts/prefs/private/loadprefs.m:33
        retval=tmp.prefs
# /home/lei/octave-4.0.2/scripts/prefs/private/loadprefs.m:34
    else:
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/prefs/private/loadprefs.m:36
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} prefsfile ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def prefsfile(*args,**kwargs):
    varargin = prefsfile.varargin
    nargin = prefsfile.nargin

    retval=matlabarray(cat(prefdir(),filesep(),'.octave_prefs'))
# /home/lei/octave-4.0.2/scripts/prefs/private/prefsfile.m:28
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} saveprefs ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def saveprefs(s=None,*args,**kwargs):
    varargin = saveprefs.varargin
    nargin = saveprefs.nargin

    prefs=copy(s)
# /home/lei/octave-4.0.2/scripts/prefs/private/saveprefs.m:28
    save(prefsfile(),'prefs')
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2013-2015 John Donoghue
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Command} {} preferences
## Display the GUI preferences dialog window for Octave.
## @end deftypefn
    
    ## Author: John Donoghue
## Version: 0.01
    
    
@function
def preferences(*args,**kwargs):
    varargin = preferences.varargin
    nargin = preferences.nargin

    if (isguirunning()):
        __octave_link_show_preferences__()
    else:
        warning('preferences: GUI must be running to use preferences dialog')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} getpref (@var{group}, @var{pref})
## @deftypefnx {Function File} {} getpref (@var{group}, @var{pref}, @var{default})
## @deftypefnx {Function File} {} getpref (@var{group})
## Return the preference value corresponding to the named preference @var{pref}
## in the preference group @var{group}.
##
## The named preference group must be a character string.
##
## If @var{pref} does not exist in @var{group} and @var{default} is
## specified, return @var{default}.
##
## The preference @var{pref} may be a character string or a cell array of
## character strings.
##
## The corresponding default value @var{default} may be any value, or, if
## @var{pref} is a cell array of strings, @var{default} must be a cell array
## of values with the same size as @var{pref}.
##
## If neither @var{pref} nor @var{default} are specified, return a structure
## of preferences for the preference group @var{group}.
##
## If no arguments are specified, return a structure containing all groups of
## preferences and their values.
## @seealso{addpref, setpref, ispref, rmpref}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def getpref(group=None,pref=None,default=None,*args,**kwargs):
    varargin = getpref.varargin
    nargin = getpref.nargin

    if (nargin == 0):
        retval=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:51
    else:
        if (nargin == 1):
            if (ischar(group)):
                prefs=loadprefs()
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:54
                if (isfield(prefs,group)):
                    retval=getattr(prefs,(group))
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:56
                else:
                    retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:58
            else:
                error('expecting group to be a character string')
        else:
            if (nargin == 2 or nargin == 3):
                grp=getpref(group)
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:64
                if (ischar(pref)):
                    if (isfield(grp,pref)):
                        retval=getattr(grp,(pref))
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:67
                    else:
                        if (nargin == 3):
                            retval=copy(default)
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:69
                        else:
                            error('preference %s does not exist in group %s',pref,group)
                else:
                    if (iscellstr(pref)):
                        if (nargin == 2 or size_equal(pref,default)):
                            for i in arange(1,numel(pref)).reshape(-1):
                                if (isfield(grp,pref[i])):
                                    setattr(retval,pref,getattr(grp,(pref[i])))
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:77
                                else:
                                    if (nargin == 3):
                                        setattr(retval,pref,default[i])
# /home/lei/octave-4.0.2/scripts/prefs/getpref.m:79
                                    else:
                                        error('preference %s does not exist in group %s',pref[i],group)
                        else:
                            error('size mismatch for pref and default')
                    else:
                        error('expecting pref to be a character string or cellstr')
            else:
                print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Testing these functions will require some care to avoid wiping out
## existing (or creating unwanted) preferences for the user running the
## tests.
    
    ## Copyright (C) 2014-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nfields (@var{s})
## Return the number of fields of the structure @var{s}.
##
## @strong{Warning:} @code{nfields} is scheduled for removal in version 4.4.
## Use @code{numfields} instead.
## @seealso{numfields, fieldnames}
## @end deftypefn
    
    ## Deprecated in 4.0
    
    
@function
def nfields(varargin=None,*args,**kwargs):
    varargin = nfields.varargin
    nargin = nfields.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/nfields.m:34
        warning('Octave:deprecated-function','nfields is obsolete and will be removed from a future version of Octave; please use numfields instead')
    
    if (nargin < 1):
        print_usage()
    
    retval=numfields(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/nfields.m:43
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} setaudio ()
## @deftypefnx {Function File} {} setaudio (@var{w_type})
## @deftypefnx {Function File} {} setaudio (@var{w_type}, @var{value})
##
## @code{setaudio} is deprecated and will be removed in Octave version 4.4.
## Please scale the audio signal in all new code or use the operating system's
## native tools to adjust audio input and output levels.
##
## Execute the shell command @samp{mixer}, possibly with optional
## arguments @var{w_type} and @var{value}.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 5 October 1994
## Adapted-By: jwe
    
    
@function
def setaudio(w_type=None,value=None,*args,**kwargs):
    varargin = setaudio.varargin
    nargin = setaudio.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/setaudio.m:40
        warning('Octave:deprecated-function','setaudio is obsolete and will be removed from a future version of Octave, please scale the audio signal instead')
    
    if (nargin == 0):
        system('mixer')
    else:
        if (nargin == 1):
            system(sprintf('mixer %s',w_type))
        else:
            if (nargin == 2):
                system(sprintf('mixer %s %d',w_type,value))
            else:
                print_usage()
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{tetr} =} delaunay3 (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {@var{tetr} =} delaunay3 (@var{x}, @var{y}, @var{z}, @var{options})
##
## @code{delaunay3} is deprecated and will be removed in Octave version 4.4.
## Please use @code{delaunay} in all new code.
##
## Compute the Delaunay triangulation for a 3-D set of points.
## The return value @var{tetr} is a set of tetrahedrons which satisfies the
## Delaunay circum-circle criterion, i.e., only a single data point from
## [@var{x}, @var{y}, @var{z}] is within the circum-circle of the defining
## tetrahedron.
##
## The set of tetrahedrons @var{tetr} is a matrix of size [n, 4].  Each
## row defines a tetrahedron and the four columns are the four vertices
## of the tetrahedron.  The value of @code{@var{tetr}(i,j)} is an index into
## @var{x}, @var{y}, @var{z} for the location of the j-th vertex of the i-th
## tetrahedron.
##
## An optional fourth argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
## The default options are @code{@{"Qt", "Qbb", "Qc", "Qz"@}}.
##
## If @var{options} is not present or @code{[]} then the default arguments are
## used.  Otherwise, @var{options} replaces the default argument list.
## To append user options to the defaults it is necessary to repeat the
## default arguments in @var{options}.  Use a null string to pass no arguments.
##
## @seealso{delaunay, delaunayn, convhull, voronoi, tetramesh}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    ## Deprecated in 4.0
    
    
@function
def delaunay3(x=None,y=None,z=None,options=None,*args,**kwargs):
    varargin = delaunay3.varargin
    nargin = delaunay3.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/delaunay3.m:60
        warning('Octave:deprecated-function','delaunay3 is obsolete and will be removed from a future version of Octave, please use delaunay instead')
    
    if (nargin < 3 or nargin > 4):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y) and isvector(z) and length(x) == length(y) and length(x) == length(z)))):
        error('delaunay: X, Y, and Z must be the same size')
    else:
        if (nargin == 4 and logical_not((ischar(options) or iscellstr(options)))):
            error('delaunay3: OPTIONS must be a string or cell array of strings')
    
    if (nargin == 3):
        tetr=delaunayn(cat(ravel(x),ravel(y),ravel(z)))
# /home/lei/octave-4.0.2/scripts/deprecated/delaunay3.m:77
    else:
        tetr=delaunayn(cat(ravel(x),ravel(y),ravel(z)),options)
# /home/lei/octave-4.0.2/scripts/deprecated/delaunay3.m:79
    
    return tetr
    
if __name__ == '__main__':
    pass
    
    
    
    ## FIXME: Need input validation tests
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} gmap40 ()
## @deftypefnx {Function File} {@var{map} =} gmap40 (@var{n})
##
## @code{gmap40} is deprecated and will be removed in Octave version 4.4.
##
## Create color colormap.  The colormap consists of red, green, blue, yellow,
## magenta and cyan.
##
## This colormap is specifically designed for users of gnuplot 4.0 where these
## 6 colors are the allowable ones for patch objects.
##
## The argument @var{n} must be a scalar.
## If unspecified, a length of 6 is assumed.  Larger values of @var{n} result
## in a repetition of the above colors.
## @seealso{colormap}
## @end deftypefn
    
    ## PKG_ADD: colormap ("register", "gmap40");
## PKG_DEL: colormap ("unregister", "gmap40");
    
    ## Deprecated in 4.0
    
    
@function
def gmap40(n=rows(colormap()),*args,**kwargs):
    varargin = gmap40.varargin
    nargin = gmap40.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/gmap40.m:46
        warning('Octave:deprecated-function','gmap40 is obsolete and will be removed from a future version of Octave')
    
    if (nargin > 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('gmap40: N must be a scalar')
    
    if (n > 0):
        C=matlabarray(cat([1,0,0],[0,1,0],[0,0,1],[1,1,0],[1,0,1],[0,1,1]))
# /home/lei/octave-4.0.2/scripts/deprecated/gmap40.m:58
        map=C[rem(arange(0,(n - 1)),6) + 1,:]
# /home/lei/octave-4.0.2/scripts/deprecated/gmap40.m:59
    else:
        map=zeros(0,3)
# /home/lei/octave-4.0.2/scripts/deprecated/gmap40.m:61
    
    return map
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} fmod (@var{x}, @var{y})
##
## @code{fmod} is deprecated and will be removed in Octave version 4.4.
## Please use @code{rem} in all new code.
##
## Return the remainder of the division @code{@var{x} / @var{y}}, computed
## using the expression
##
## @example
## x - y .* fix (x ./ y)
## @end example
##
## An error message is printed if the dimensions of the arguments do not
## agree, or if either of the arguments is complex.
## @seealso{rem, mod}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def fmod(varargin=None,*args,**kwargs):
    varargin = fmod.varargin
    nargin = fmod.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/fmod.m:43
        warning('Octave:deprecated-function','fmod is obsolete and will be removed from a future version of Octave, please use rem instead')
    
    retval=rem(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/fmod.m:48
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Loadable Function} {@var{obj} =} java_new (@var{name})
## @deftypefnx {Loadable Function} {@var{obj} =} java_new (@var{name}, @var{arg1}, @dots{})
## Create a Java object of class @var{name}, by calling the class constructor
## with the arguments @var{arg1}, @dots{}
##
## @example
## @group
##   x = java_new ("java.lang.StringBuffer")
##   x = java_new ("java.lang.StringBuffer", "Initial string")
## @end group
## @end example
##
## @seealso{javaObject, javaMethod}
## @end deftypefn
    
    
@function
def java_new(varargin=None,*args,**kwargs):
    varargin = java_new.varargin
    nargin = java_new.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/java_new.m:39
        warning('Octave:deprecated-function','java_new is obsolete and will be removed from a future version of Octave; please use javaObject instead')
    
    if (nargin < 1):
        print_usage()
    
    retval=javaObject(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/java_new.m:48
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{val} =} java_debug ()
## @deftypefnx {Built-in Function} {@var{old_val} =} java_debug (@var{new_val})
## @deftypefnx {Built-in Function} {} java_debug (@var{new_val}, "local")
## Query or set the internal variable that determines whether extra debugging
## information regarding the initialization of the JVM and any Java exceptions
## is printed.
##
## When called from inside a function with the @qcode{"local"} option, the
## variable is changed locally for the function and any subroutines it calls.
##  The original variable value is restored when exiting the function.
## @seealso{debug_java, java_convert_matrix, java_unsigned_conversion}
## @end deftypefn
    
    
@function
def java_debug(varargin=None,*args,**kwargs):
    varargin = java_debug.varargin
    nargin = java_debug.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/java_debug.m:37
        warning('Octave:deprecated-function','java_debug is obsolete and will be removed from a future version of Octave; use debug_java instead')
    
    if (nargin > 2):
        print_usage()
    
    old_val=debug_java(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/java_debug.m:46
    return old_val
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} playaudio (@var{name}, @var{ext})
## @deftypefnx {Function File} {} playaudio (@var{x})
##
## @code{playaudio} is deprecated and will be removed in Octave version 4.4.
## Please use @code{audioplayer} in all new code.
##
## Play the audio file @file{@var{name}.@var{ext}} or the audio data
## stored in the vector @var{x}.
## @seealso{lin2mu, mu2lin, loadaudio, saveaudio, setaudio, record}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 11 April 1994
## Adapted-By: jwe
    
    
@function
def playaudio(name=None,ext=None,*args,**kwargs):
    varargin = playaudio.varargin
    nargin = playaudio.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:39
        warning('Octave:deprecated-function','playaudio is obsolete and will be removed from a future version of Octave, please use audioplayer instead')
    
    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1 and isnumeric(name)):
        ## play a vector
        if (logical_not(isvector(name))):
            error('playaudio: X must be a vector')
        X=ravel(name) + 127
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:53
        try:
            file=tempname()
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:55
            fid=fopen(file,'wb')
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:56
            fwrite(fid,X,'uchar')
            fclose(fid)
            status,out=system(sprintf('cat "%s" > /dev/dsp',file),nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:59
            if (status != 0):
                system(sprintf('paplay --raw "%s"',file))
        finally:
            unlink(file)
    else:
        if (nargin >= 1 and ischar(name)):
            ## play a file
            if (nargin == 1):
                name=matlabarray(cat(name,'.lin'))
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:69
            else:
                if (nargin == 2):
                    name=matlabarray(cat(name,'.',ext))
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:71
            if (any(strcmp(ext,cellarray(['lin','raw'])))):
                status,out=system(sprintf('cat "%s" > /dev/dsp',name),nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:74
                if (status != 0):
                    system(sprintf('paplay --raw "%s"',name))
            else:
                if (any(strcmp(ext,cellarray(['mu','au','snd','ul'])))):
                    status,out=system(sprintf('cat "%s" > /dev/audio',name),nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/playaudio.m:79
                    if (status != 0):
                        system(sprintf('paplay "%s"',name))
                else:
                    error('playaudio: unsupported extension \'%s\'',ext)
        else:
            print_usage()
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} finite (@var{x})
##
## @code{finite} is deprecated and will be removed in Octave version 4.4.
## Please use @code{isfinite} in all new code.
##
## Return a logical array which is true where the elements of @var{x} are
## finite values and false where they are not.
## For example:
##
## @example
## @group
## finite ([13, Inf, NA, NaN])
##      @result{} [ 1, 0, 0, 0 ]
## @end group
## @end example
## @seealso{isfinite, isinf, isnan, isna}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def finite(varargin=None,*args,**kwargs):
    varargin = finite.varargin
    nargin = finite.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/finite.m:44
        warning('Octave:deprecated-function','finite is obsolete and will be removed from a future version of Octave, please use isfinite instead')
    
    retval=isfinite(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/finite.m:49
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## @deftypefn  {Built-in Function} {[@var{L}, @var{U}, @var{P}, @var{Q}] =} luinc (@var{A}, '0')
## @deftypefnx {Built-in Function} {[@var{L}, @var{U}, @var{P}, @var{Q}] =} luinc (@var{A}, @var{droptol})
## @deftypefnx {Built-in Function} {[@var{L}, @var{U}, @var{P}, @var{Q}] =} luinc (@var{A}, @var{opts})
##
## @code{luinc} is deprecated and will be removed in Octave version 4.4.
## Please use @code{ilu} or @code{ichol} in all new code.
##
## Produce the incomplete LU@tie{}factorization of the sparse matrix @var{A}.
## Two types of incomplete factorization are possible, and the type
## is determined by the second argument to @code{luinc}.
##
## Called with a second argument of @qcode{'0'}, the zero-level incomplete
## LU@tie{}factorization is produced.  This creates a factorization of @var{A}
## where the position of the nonzero arguments correspond to the same
## positions as in the matrix @var{A}.
##
## Alternatively, the fill-in of the incomplete LU@tie{}factorization can
## be controlled through the variable @var{droptol} or the structure
## @var{opts}.  The @sc{umfpack} multifrontal factorization code by Tim A.
## Davis is used for the incomplete LU@tie{}factorization, (availability
## @url{http://www.cise.ufl.edu/research/sparse/umfpack/})
##
## @var{droptol} determines the values below which the values in the
## LU@tie{} factorization are dropped and replaced by zero.  It must be a
## positive scalar, and any values in the factorization whose absolute value
## are less than this value are dropped, expect if leaving them increase the
## sparsity of the matrix.  Setting @var{droptol} to zero results in a complete
## LU@tie{}factorization which is the default.
##
## @var{opts} is a structure containing one or more of the fields
##
## @table @code
## @item droptol
## The drop tolerance as above.  If @var{opts} only contains @code{droptol}
## then this is equivalent to using the variable @var{droptol}.
##
## @item milu
## A logical variable flagging whether to use the modified incomplete
## LU@tie{} factorization.  In the case that @code{milu} is true, the dropped
## values are subtracted from the diagonal of the matrix @var{U} of the
## factorization.  The default is @code{false}.
##
## @item udiag
## A logical variable that flags whether zero elements on the diagonal of
## @var{U} should be replaced with @var{droptol} to attempt to avoid singular
## factors.  The default is @code{false}.
##
## @item thresh
## Defines the pivot threshold in the interval [0,1].  Values outside that
## range are ignored.
## @end table
##
## All other fields in @var{opts} are ignored.  The outputs from @code{luinc}
## are the same as for @code{lu}.
##
## Given the string argument @qcode{\"vector\"}, @code{luinc} returns the
## values of @var{p} @var{q} as vector values.
## @seealso{ilu, ichol, lu, sparse}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def luinc(varargin=None,*args,**kwargs):
    varargin = luinc.varargin
    nargin = luinc.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/luinc.m:85
        warning('Octave:deprecated-function','luinc is obsolete and will be removed from a future version of Octave, please use ilu or ichol instead')
    
    L,U,P,Q=__luinc__(varargin[:],nargout=4)
# /home/lei/octave-4.0.2/scripts/deprecated/luinc.m:90
    return L,U,P,Q
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Built-in Function} {} usage (@var{msg})
##
## @code{usage} is deprecated and will be removed in Octave version 4.4.
## Please use @code{print_usage} in all new code.
##
## Print the message @var{msg}, prefixed by the string @samp{usage: }, and
## set Octave's internal error state such that control will return to the
## top level without evaluating any more commands.  This is useful for
## aborting from functions.
##
## After @code{usage} is evaluated, Octave will print a traceback of all
## the function calls leading to the usage message.
##
## You should use this function for reporting problems errors that result
## from an improper call to a function, such as calling a function with an
## incorrect number of arguments, or with arguments of the wrong type.  For
## example, most functions distributed with Octave begin with code like
## this
##
## @example
## @group
## if (nargin != 2)
##   usage (\"foo (a, b)\");
## endif
## @end group
## @end example
##
## @noindent
## to check for the proper number of arguments.
## @seealso{print_usage}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def usage(varargin=None,*args,**kwargs):
    varargin = usage.varargin
    nargin = usage.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/usage.m:58
        warning('Octave:deprecated-function','usage is obsolete and will be removed from a future version of Octave, please use print_usage instead')
    
    retval=__usage__(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/usage.m:63
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Built-in Function} {} fnmatch (@var{pattern}, @var{string})
##
## @code{fnmatch} is deprecated and will be removed in Octave version 4.4.
## Please use @code{glob} or @code{regexp} in all new code.
##
## Return true or false for each element of @var{string} that matches any of
## the elements of the string array @var{pattern}, using the rules of
## filename pattern matching.  For example:
##
## @example
## @group
## fnmatch (\"a*b\", @{\"ab\"; \"axyzb\"; \"xyzab\"@})
##      @result{} [ 1; 1; 0 ]
## @end group
## @end example
## @seealso{glob, regexp}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def fnmatch(varargin=None,*args,**kwargs):
    varargin = fnmatch.varargin
    nargin = fnmatch.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/fnmatch.m:44
        warning('Octave:deprecated-function','fnmatch is obsolete and will be removed from a future version of Octave, please use glob or regexp instead')
    
    retval=__fnmatch__(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/fnmatch.m:49
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javafields (@var{javaobj})
## @deftypefnx {Function File} {} javafields ("@var{classname}")
## @deftypefnx {Function File} {@var{fld_names} =} javafields (@dots{})
## Return the fields of a Java object or Java class in the form of a cell
## array of strings.  If no output is requested, print the result
## to the standard output.
## @seealso{fieldnames, methods, javaObject}
## @end deftypefn
    
    
@function
def javafields(javaobj=None,*args,**kwargs):
    varargin = javafields.varargin
    nargin = javafields.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/javafields.m:33
        warning('Octave:deprecated-function','javafields is obsolete and will be removed from a future version of Octave, please use fieldnames instead')
    
    if (nargin != 1):
        print_usage()
    
    c_methods=javaMethod('getFields','org.octave.ClassHelper',javaobj)
# /home/lei/octave-4.0.2/scripts/deprecated/javafields.m:42
    method_list=ostrsplit(c_methods,';')
# /home/lei/octave-4.0.2/scripts/deprecated/javafields.m:43
    if (nargout == 0):
        if (logical_not(isempty(method_list))):
            disp(method_list)
    else:
        fld_names=cellstr(method_list)
# /home/lei/octave-4.0.2/scripts/deprecated/javafields.m:50
    
    return fld_names
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javamethods (@var{javaobj})
## @deftypefnx {Function File} {} javamethods ("@var{classname}")
## @deftypefnx {Function File} {@var{mtd_names} =} javamethods (@dots{})
## Return the methods of a Java object or Java class in the form of a cell
## array of strings.  If no output is requested, print the result to the
## standard output.
## @seealso{methods, fieldnames, javaMethod, javaObject}
## @end deftypefn
    
    
@function
def javamethods(classname=None,*args,**kwargs):
    varargin = javamethods.varargin
    nargin = javamethods.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/javamethods.m:33
        warning('Octave:deprecated-function','javamethods is obsolete and will be removed from a future version of Octave, please use methods instead')
    
    if (nargin != 1):
        print_usage()
    
    cls_methods=javaMethod('getMethods','org.octave.ClassHelper',classname)
# /home/lei/octave-4.0.2/scripts/deprecated/javamethods.m:42
    method_list=ostrsplit(cls_methods,';')
# /home/lei/octave-4.0.2/scripts/deprecated/javamethods.m:43
    if (nargout == 0):
        if (logical_not(isempty(method_list))):
            disp(method_list)
    else:
        mtd_names=cellstr(method_list)
# /home/lei/octave-4.0.2/scripts/deprecated/javamethods.m:50
    
    return mtd_names
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{val} =} default_save_options ()
## @deftypefnx {Built-in Function} {@var{old_val} =} default_save_options (@var{new_val})
## @deftypefnx {Built-in Function} {} default_save_options (@var{new_val}, "local")
## This function has been deprecated.  Use @code{@file{save_default_options}}
## instead.
## @seealso{save_default_options}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def default_save_options(varargin=None,*args,**kwargs):
    varargin = default_save_options.varargin
    nargin = default_save_options.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/default_save_options.m:34
        warning('Octave:deprecated-function','default_save_options is obsolete and will be removed from a future version of Octave, please use save_default_options instead')
    
    retval=save_default_options(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/default_save_options.m:39
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2003-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isstr (@var{a})
## This function has been deprecated.  Use ischar instead.
## @end deftypefn
    
    ## Author: jwe
    
    ## Deprecated in version 3.0
## Matlab still has this function, so don't remove just yet.
    
    
@function
def isstr(varargin=None,*args,**kwargs):
    varargin = isstr.varargin
    nargin = isstr.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/isstr.m:33
        warning('Octave:deprecated-function','isstr is obsolete and will be removed from a future version of Octave, please use ischar instead')
    
    retval=ischar(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/isstr.m:38
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007-2013 Shai Ayal
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Loadable Function} {@var{old_val} =} mouse_wheel_zoom (@var{new_val})
## Query or set the mouse wheel zoom factor.
##
## The zoom factor is a number in the range (0,1) which is the
## percentage of the current axis limits that will be used when zooming.
## For example, if the current x-axis limits are [0, 50] and
## @code{mouse_wheel_zoom} is 0.4 (40#), then a zoom operation will
## change the limits by 20.
#### @end deftypefn
    
    ## Deprecated in 4.0
    
    
@function
def mouse_wheel_zoom(val=None,*args,**kwargs):
    varargin = mouse_wheel_zoom.varargin
    nargin = mouse_wheel_zoom.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/mouse_wheel_zoom.m:36
        warning('Octave:deprecated-function','mouse_wheel_zoom is obsolete and will be removed from a future version of Octave, please use the mousehweelzoom axes property instead')
    
    if (nargin != 1):
        print_usage()
    
    fig=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/deprecated/mouse_wheel_zoom.m:45
    if (isempty(fig)):
        retval=get(0,'defaultaxesmousewheelzoom')
# /home/lei/octave-4.0.2/scripts/deprecated/mouse_wheel_zoom.m:47
        set(0,'defaultaxesmousewheelzoom',val)
    else:
        retval=get(gca,'mousewheelzoom')
# /home/lei/octave-4.0.2/scripts/deprecated/mouse_wheel_zoom.m:50
        set(gca,'mousewheelzoom',val)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} saveaudio (@var{name}, @var{x}, @var{ext}, @var{bps})
##
## @code{saveaudio} is deprecated and will be removed in Octave version 4.4.
## Please use @code{audiowrite} in all new code.
##
## Save a vector @var{x} of audio data to the file
## @file{@var{name}.@var{ext}}.  The optional parameters @var{ext} and
## @var{bps} determine the encoding and the number of bits per sample used
## in the audio file (see @code{loadaudio}); defaults are @file{lin} and
## 8, respectively.
## @seealso{lin2mu, mu2lin, loadaudio, playaudio, setaudio, record}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 5 September 1994
## Adapted-By: jwe
    
    
@function
def saveaudio(name=None,x=None,ext=None,bps=None,*args,**kwargs):
    varargin = saveaudio.varargin
    nargin = saveaudio.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:41
        warning('Octave:deprecated-function','saveaudio is obsolete and will be removed from a future version of Octave, please use audiowrite instead')
    
    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (nargin == 2):
        ext='lin'
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:51
    
    if (nargin < 4):
        bps=8
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:55
    else:
        if (bps != 8 and bps != 16):
            error('saveaudio: BPS must be either 8 or 16')
    
    nr,nc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:60
    if (nc != 1):
        if (nr == 1):
            x=x.T
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:63
            nr=copy(nc)
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:64
        else:
            error('saveaudio: X must be a vector')
    
    num=fopen(cat(name,'.',ext),'wb')
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:70
    if (strcmp(ext,'lin') or strcmp(ext,'raw')):
        if (bps == 8):
            ld=max(abs(x))
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:74
            if (ld > 127):
                if (ld < 16384):
                    sc=64 / ld
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:77
                else:
                    sc=1 / 256
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:79
                x=fix(dot(x,sc))
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:81
            x=x + 127
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:83
            c=fwrite(num,x,'uchar')
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:84
        else:
            c=fwrite(num,x,'short')
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:86
    else:
        if (strcmp(ext,'mu') or strcmp(ext,'au') or strcmp(ext,'snd') or strcmp(ext,'ul')):
            y=lin2mu(x)
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:90
            c=fwrite(num,y,'uchar')
# /home/lei/octave-4.0.2/scripts/deprecated/saveaudio.m:91
        else:
            fclose(num)
            error('saveaudio: unsupported extension')
    
    fclose(num)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {} find_dir_in_path (@var{dir})
## @deftypefnx {Built-in Function} {} find_dir_in_path (@var{dir}, "all")
## This function has been deprecated.  Use @code{dir_in_loadpath} instead.
## @seealso{dir_in_loadpath}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def find_dir_in_path(varargin=None,*args,**kwargs):
    varargin = find_dir_in_path.varargin
    nargin = find_dir_in_path.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/find_dir_in_path.m:32
        warning('Octave:deprecated-function','find_dir_in_path is obsolete and will be removed from a future version of Octave, please use dir_in_loadpath instead')
    
    retval=dir_in_loadpath(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/find_dir_in_path.m:37
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Built-in Function} {} read_readline_init_file (@var{file})
## This function has been deprecated.  Use
## @code{@file{readline_read_init_file}} instead.
## @seealso{readline_read_init_file}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def read_readline_init_file(varargin=None,*args,**kwargs):
    varargin = read_readline_init_file.varargin
    nargin = read_readline_init_file.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/read_readline_init_file.m:32
        warning('Octave:deprecated-function','read_readline_init_file is obsolete and will be removed from a future version of Octave, please use readline_read_init_file instead')
    
    readline_read_init_file(varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} loadaudio (@var{name}, @var{ext}, @var{bps})
##
## @code{loadaudio} is deprecated and will be removed in Octave version 4.4.
## Please use @code{audioread} in all new code.
##
## Load audio data from the file @file{@var{name}.@var{ext}} into the
## vector @var{x}.
##
## The extension @var{ext} determines how the data in the audio file is
## interpreted; the extensions @file{lin} (default) and @file{raw}
## correspond to linear, the extensions @file{au}, @file{mu}, or @file{snd}
## to mu-law encoding.
##
## The argument @var{bps} can be either 8 (default) or 16, and specifies
## the number of bits per sample used in the audio file.
## @seealso{lin2mu, mu2lin, saveaudio, playaudio, setaudio, record}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 10 April 1994
## Adapted-By: jwe
    
    
@function
def loadaudio(name=None,ext=None,bps=None,*args,**kwargs):
    varargin = loadaudio.varargin
    nargin = loadaudio.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:47
        warning('Octave:deprecated-function','loadaudio is obsolete and will be removed from a future version of Octave, please use audioread instead')
    
    if (nargin == 0 or nargin > 3):
        print_usage()
    
    if (nargin == 1):
        ext='lin'
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:57
    
    if (nargin < 3):
        bps=8
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:61
    else:
        if (bps != 8 and bps != 16):
            error('loadaudio: BPS must be either 8 or 16')
    
    name=matlabarray(cat(name,'.',ext))
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:66
    num=fopen(name,'rb')
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:67
    if (strcmp(ext,'lin') or strcmp(ext,'raw') or strcmp(ext,'pcm')):
        if (bps == 8):
            Y,c=fread(num,inf,'uchar',nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:71
            X=Y - 127
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:72
        else:
            X,c=fread(num,inf,'short',nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:74
    else:
        if (strcmp(ext,'mu') or strcmp(ext,'au') or strcmp(ext,'snd') or strcmp(ext,'ul')):
            Y,c=fread(num,inf,'uchar',nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:78
            m=find(Y[1:64] == 0,1,'last')
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:80
            if (logical_not(isempty(m))):
                Y[1:m]=[]
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:82
            X=mu2lin(Y,bps)
# /home/lei/octave-4.0.2/scripts/deprecated/loadaudio.m:84
        else:
            fclose(num)
            error('loadaudio: unsupported extension')
    
    fclose(num)
    return X
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Hoxide Ma
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{zi} =} bicubic (@var{x}, @var{y}, @var{z}, @var{xi}, @var{yi}, @var{extrapval})
##
## @code{bicubic} is deprecated and will be removed in Octave version 4.4.
## Use @code{interp2 (@dots{}, "spline")} for the equivalent functionality.
##
## Return a matrix @var{zi} corresponding to the bicubic
## interpolations at @var{xi} and @var{yi} of the data supplied
## as @var{x}, @var{y} and @var{z}.  Points outside the grid are set
## to @var{extrapval}.
##
## See @url{http://wiki.woodpecker.org.cn/moin/Octave/Bicubic}
## for further information.
## @seealso{interp2}
## @end deftypefn
    
    ## Bicubic interpolation method.
## Author: Hoxide Ma <hoxide_dirac@yahoo.com.cn>
    
    ## Deprecated in version 4.0
    
    
@function
def bicubic(x=None,y=None,z=None,xi=None,yi=None,extrapval=None,spline_alpha=None,*args,**kwargs):
    varargin = bicubic.varargin
    nargin = bicubic.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:44
        warning('Octave:deprecated-function','bicubic is obsolete and will be removed from a future version of Octave, please use interp2 instead')
    
    if (nargin < 1 or nargin > 7):
        print_usage()
    
    if (nargin == 7 and isscalar(spline_alpha)):
        a=copy(spline_alpha)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:54
    else:
        a=0.5
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:56
    
    if (nargin < 6):
        extrapval=copy(NaN)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:60
    
    if (isa(x,'single') or isa(y,'single') or isa(z,'single') or isa(xi,'single') or isa(yi,'single')):
        myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:65
    else:
        myeps=eps()
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:67
    
    if (nargin <= 2):
        ## bicubic (z) or bicubic (z, 2)
        if (nargin == 1):
            n=1
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:73
        else:
            n=copy(y)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:75
        z=copy(x)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:77
        x=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:78
        rz,cz=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:79
        s=linspace(1,cz,dot((cz - 1),pow2(n)) + 1)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:80
        t=linspace(1,rz,dot((rz - 1),pow2(n)) + 1)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:81
    else:
        if (nargin == 3):
            if (logical_not(isvector(x)) or logical_not(isvector(y))):
                error('bicubic: XI and YI must be vector')
            s=copy(y)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:86
            t=copy(z)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:87
            z=copy(x)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:88
            rz,cz=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:89
        else:
            if (nargin == 5 or nargin == 6):
                rz,cz=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:91
                if (isvector(x) and isvector(y)):
                    if (rz != length(y) or cz != length(x)):
                        error('bicubic: length of X and Y must match the size of Z')
                else:
                    if (size_equal(x,y) and size_equal(x,z)):
                        x=x[1,:]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:97
                        y=y[:,1]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:98
                    else:
                        error('bicubic: X, Y and Z must be equal size matrices of same size')
                if (all(diff(x) < 0)):
                    flipx=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:104
                    x=fliplr(x)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:105
                else:
                    if (all(diff(x) > 0)):
                        flipx=copy(false)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:107
                    else:
                        error('bicubic:nonmonotonic','bicubic: X values must be monotonic')
                if (all(diff(y) < 0)):
                    flipy=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:112
                    y=flipud(y)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:113
                else:
                    if (all(diff(y) > 0)):
                        flipy=copy(false)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:115
                    else:
                        error('bicubic:nonmonotonic','bicubic: Y values must be monotonic')
                ## Mark values outside the lookup table.
                xfirst_ind=find(xi < x[1])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:121
                xlast_ind=find(xi > x[cz])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:122
                yfirst_ind=find(yi < y[1])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:123
                ylast_ind=find(yi > y[rz])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:124
                xi[xfirst_ind]=x[1]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:126
                xi[xlast_ind]=x[cz]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:127
                yi[yfirst_ind]=y[1]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:128
                yi[ylast_ind]=y[rz]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:129
                x=reshape(x,1,cz)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:131
                x[cz] *= 1 + dot(sign(x[cz]),myeps)
                if (x[cz] == 0):
                    x[cz]=myeps
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:134
                xi=reshape(xi,1,length(xi))
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:136
                m,i=sort(cat(x,xi),nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:137
                o=cumsum(i <= cz)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:138
                xidx=o[find(i > cz)]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:139
                y=reshape(y,rz,1)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:141
                y[rz] *= 1 + dot(sign(y[rz]),myeps)
                if (y[rz] == 0):
                    y[rz]=myeps
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:144
                yi=reshape(yi,length(yi),1)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:146
                m,i=sort(cat([y],[yi]),nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:147
                o=cumsum(i <= rz)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:148
                yidx=o[cat(find(i > rz))]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:149
                s=xidx + ((xi- x[xidx]) / (x[xidx + 1]- x[xidx]))
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:152
                t=yidx + ((yi - y[yidx]) / (y[yidx + 1] - y[yidx]))
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:153
                if (flipx):
                    s=fliplr(s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:156
                if (flipy):
                    t=flipud(t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:159
            else:
                print_usage()
    
    if (rz < 3 or cz < 3):
        error('bicubic: Z at least a 3 by 3 matrices')
    
    inds=floor(s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:169
    d=find(s == cz)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:170
    s=s - floor(s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:171
    inds[d]=cz - 1
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:172
    s[d]=1.0
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:173
    d=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:175
    indt=floor(t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:176
    d=find(t == rz)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:177
    t=t - floor(t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:178
    indt[d]=rz - 1
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:179
    t[d]=1.0
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:180
    d=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:181
    p=zeros(size(z) + 2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:183
    p[2:rz + 1,2:cz + 1]=z
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:184
    p[1,:]=dot((dot(6,(1 - a))),p[2,:]) - dot(3,p[3,:]) + dot((dot(6,a) - 2),p[4,:])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:185
    p[rz + 2,:]=dot((dot(6,(1 - a))),p[rz + 1,:]) - dot(3,p[rz,:]) + dot((dot(6,a) - 2),p[rz - 1,:])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:186
    p[:,1]=dot((dot(6,(1 - a))),p[:,2]) - dot(3,p[:,3]) + dot((dot(6,a) - 2),p[:,4])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:187
    p[:,cz + 2]=dot((dot(6,(1 - a))),p[:,cz + 1]) - dot(3,p[:,cz]) + dot((dot(6,a) - 2),p[:,cz - 1])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:188
    
    t2=multiply(t,t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:191
    t3=multiply(t2,t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:192
    ct0=multiply(- a,t3) + multiply((dot(2,a)),t2) - multiply(a,t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:194
    
    ct1=multiply((2 - a),t3) + multiply((- 3 + a),t2) + 1
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:195
    
    ct2=multiply((a - 2),t3) + multiply((dot(- 2,a) + 3),t2) + multiply(a,t)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:196
    
    ct3=multiply(a,t3) - multiply(a,t2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:197
    
    t=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:198
    t2=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:198
    t3=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:198
    s2=multiply(s,s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:200
    s3=multiply(s2,s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:201
    cs0=multiply(- a,s3) + multiply((dot(2,a)),s2) - multiply(a,s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:203
    
    cs1=multiply((2 - a),s3) + multiply((- 3 + a),s2) + 1
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:204
    
    cs2=multiply((a - 2),s3) + multiply((dot(- 2,a) + 3),s2) + multiply(a,s)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:205
    
    cs3=multiply(a,s3) - multiply(a,s2)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:206
    
    s=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:207
    s2=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:207
    s3=matlabarray([])
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:207
    cs0=cs0[cat(1,1,1,1),:]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:209
    cs1=cs1[cat(1,1,1,1),:]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:210
    cs2=cs2[cat(1,1,1,1),:]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:211
    cs3=cs3[cat(1,1,1,1),:]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:212
    lent=length(ct0)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:214
    lens=columns(cs0)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:215
    zi=zeros(lent,lens)
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:216
    for i in arange(1,lent).reshape(-1):
        it=indt[i]
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:219
        int_=matlabarray(cat(it,it + 1,it + 2,it + 3))
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:220
        zi[i,:]=(dot(cat(ct0[i],ct1[i],ct2[i],ct3[i]),(multiply(p[int_,inds],cs0) + multiply(p[int_,inds + 1],cs1) + multiply(p[int_,inds + 2],cs2) + multiply(p[int_,inds + 3],cs3))))
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:221
    
    ## Set points outside the table to extrapval.
    if (logical_not((isempty(xfirst_ind) and isempty(xlast_ind)))):
        zi[:,cat(xfirst_ind,xlast_ind)]=extrapval
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:228
    
    if (logical_not((isempty(yfirst_ind) and isempty(ylast_ind)))):
        zi[cat([yfirst_ind],[ylast_ind]),:]=extrapval
# /home/lei/octave-4.0.2/scripts/deprecated/bicubic.m:231
    
    return zi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{val} =} java_unsigned_conversion ()
## @deftypefnx {Built-in Function} {@var{old_val} =} java_unsigned_conversion (@var{new_val})
## @deftypefnx {Built-in Function} {} java_unsigned_conversion (@var{new_val}, "local")
## Query or set the internal variable that controls how integer classes are
## converted when Java matrix autoconversion is enabled.  When enabled, Java
## arrays of class Byte or Integer are converted to matrices of class uint8 or
## uint32 respectively.
##
## When called from inside a function with the @qcode{"local"} option, the
## variable is changed locally for the function and any subroutines it calls.
##  The original variable value is restored when exiting the function.
## @seealso{java_unsigned_autoconversion, java_convert_matrix, debug_java}
## @end deftypefn
    
    
@function
def java_unsigned_conversion(varargin=None,*args,**kwargs):
    varargin = java_unsigned_conversion.varargin
    nargin = java_unsigned_conversion.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/java_unsigned_conversion.m:38
        warning('Octave:deprecated-function','java_unsigned_conversion is obsolete and will be removed from a future version of Octave; use java_unsigned_autoconversion instead')
    
    if (nargin > 2):
        print_usage()
    
    old_val=java_unsigned_autoconversion(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/java_unsigned_conversion.m:47
    return old_val
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{yi} =} interp1q (@var{x}, @var{y}, @var{xi})
## One-dimensional linear interpolation without error checking.
## Interpolates @var{y}, defined at the points @var{x}, at the points
## @var{xi}.  The sample points @var{x} must be a strictly monotonically
## increasing column vector.  If @var{y} is a matrix or an N-dimensional
## array, the interpolation is performed on each column of @var{y}.  If
## @var{y} is a vector, it must be a column vector of the same length as
## @var{x}.
##
## Values of @var{xi} beyond the endpoints of the interpolation result
## in NA being returned.
##
## Note that the error checking is only a significant portion of the
## execution time of this @code{interp1} if the size of the input arguments
## is relatively small.  Therefore, the benefit of using @code{interp1q}
## is relatively small.
## @seealso{interp1}
## @end deftypefn
    
    
@function
def interp1q(x=None,y=None,xi=None,*args,**kwargs):
    varargin = interp1q.varargin
    nargin = interp1q.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:43
        warning('Octave:deprecated-function','interp1q is obsolete and will be removed from a future version of Octave; use interp1 instead')
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:48
    nx=rows(x)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:49
    szy=size(y)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:50
    y=y[:,:]
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:51
    ny,nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:52
    szx=size(xi)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:53
    xi=ravel(xi)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:54
    dy=diff(y)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:55
    dx=diff(x)
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:56
    idx=lookup(x,xi,'lr')
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:57
    s=(xi - x[idx]) / dx[idx]
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:58
    yi=bsxfun(times,s,dy[idx,:]) + y[idx,:]
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:59
    range_=xi < logical_or(x[1],logical_not((xi <= x[nx])))
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:60
    yi[range_,:]=NA
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:61
    if (length(szx) == 2 and any(szx == 1)):
        yi=reshape(yi,cat(max(szx),szy[2:end()]))
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:63
    else:
        yi=reshape(yi,cat(szx,szy[2:end()]))
# /home/lei/octave-4.0.2/scripts/deprecated/interp1q.m:65
    
    return yi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{ret} =} java_invoke (@var{obj}, @var{methodname})
## @deftypefnx {Built-in Function} {@var{ret} =} java_invoke (@var{obj}, @var{methodname}, @var{arg1}, @dots{})
## Invoke the method @var{methodname} on the Java object @var{obj} with the
## arguments @var{arg1}, @dots{}  For static methods, @var{obj} can be a
## string representing the fully qualified name of the corresponding class.
## The function returns the result of the method invocation.
##
## When @var{obj} is a regular Java object, structure-like indexing can be
## used as a shortcut syntax.  For instance, the two following statements are
## equivalent
##
## @example
## @group
##   ret = java_invoke (x, "method1", 1.0, "a string")
##   ret = x.method1 (1.0, "a string")
## @end group
## @end example
##
## @seealso{javaMethod, javaObject}
## @end deftypefn
    
    
@function
def java_invoke(obj=None,methodname=None,varargin=None,*args,**kwargs):
    varargin = java_invoke.varargin
    nargin = java_invoke.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/java_invoke.m:45
        warning('Octave:deprecated-function','java_invoke is obsolete and will be removed from a future version of Octave, please use javaMethod instead')
    
    if (nargin < 2):
        print_usage()
    
    retval=javaMethod(methodname,obj,varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/java_invoke.m:54
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{fname} =} octave_tmp_file_name ()
## @deftypefnx {Built-in Function} {@var{fname} =} octave_tmp_file_name (@var{dir})
## @deftypefnx {Built-in Function} {@var{fname} =} octave_tmp_file_name (@var{dir}, @var{prefix})
##
## @code{octave_tmp_file_name} is deprecated and will be removed in Octave
## version 4.4.  Use @code{tempname} for equivalent functionality.
##
## Return a unique temporary file name as a string.
##
## If @var{prefix} is omitted, a value of @qcode{"oct-"} is used.
## If @var{dir} is also omitted, the default directory for temporary files
## (@code{P_tmpdir} is used.  If @var{dir} is provided, it must exist,
## otherwise the default directory for temporary files is used.
## @seealso{tempname, tmpnam, mkstemp, tempdir, P_tmpdir, tmpfile}
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def octave_tmp_file_name(varargin=None,*args,**kwargs):
    varargin = octave_tmp_file_name.varargin
    nargin = octave_tmp_file_name.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/octave_tmp_file_name.m:42
        warning('Octave:deprecated-function','octave_tmp_file_name is obsolete and will be removed from a future version of Octave, please use tempname instead')
    
    filename=tmpnam(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/octave_tmp_file_name.m:47
    return filename
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dump_prefs ()
## @deftypefnx {Function File} {} dump_prefs (@var{fid})
##
## @code{dump_prefs} is deprecated and will be removed in Octave version 4.4.
## Please use individual preference get/set routines in all new code.
##
## Dump the current settings of all user preferences to stdout in a format that
## can be parsed by Octave later.
##
## If the optional argument @var{fid} is given then the results are written to
## the file specified by file descriptor @var{fid}.
## @seealso{octave_config_info}
## @end deftypefn
    
    ## Author: jwe
    
    ## Deprecated in 4.0
    
    
@function
def dump_prefs(fid=None,*args,**kwargs):
    varargin = dump_prefs.varargin
    nargin = dump_prefs.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:42
        warning('Octave:deprecated-function','dump_prefs is obsolete and will be removed from a future version of Octave, recode using individual preference get/set routines')
    
    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        fid=copy(stdout)
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:52
    
    ## FIXME: It would be nice to be able to get the list of built-in variables
  ## directly from Octave so that we wouldn't have to remember to update it
  ## each time the list of preference variables changes
    
    ## FIXME: Update this list for 4.2.0 release
  ##        Example, 'gnuplot_command_end' is no longer valid.
    
    pref_list=cellarray(['EDITOR','EXEC_PATH','IMAGE_PATH','PAGER','PS1','PS2','PS4','beep_on_error','completion_append_char','crash_dumps_octave_core','echo_executing_commands','fixed_point_format','gnuplot_binary','gnuplot_command_end','gnuplot_command_plot','gnuplot_command_replot','gnuplot_command_splot','gnuplot_command_title','gnuplot_command_using','gnuplot_command_with','history_file','history_size','ignore_function_time_stamp','info_file','info_program','makeinfo_program','max_recursion_depth','output_max_field_width','output_precision','page_output_immediately','page_screen_output','print_answer_id_name','print_empty_dimensions','save_precision','saving_history','sighup_dumps_octave_core','sigterm_dumps_octave_core','silent_functions','split_long_rows','string_fill_char','struct_levels_to_print','suppress_verbose_help_message'])
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:62
    for i in arange(1,rows(pref_list)).reshape(-1):
        pref=pref_list[i]
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:106
        try:
            val=feval(pref)
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:108
            if (isnumeric(val)):
                val=sprintf('%g',val)
# /home/lei/octave-4.0.2/scripts/deprecated/dump_prefs.m:110
            fprintf(fid,'  %s = %s\n',pref,val)
        finally:
            pass
    
    return
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2014-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Built-in Function} {@var{x} =} syl (@var{A}, @var{B}, @var{C})
##
## @code{syl} is deprecated and will be removed in Octave version 4.4.
## Use @code{sylvester} for the equivalent functionality.
##
## Solve the Sylvester equation
## @tex
## $$
##  A X + X B + C = 0
## $$
## @end tex
## @ifnottex
##
## @example
## A X + X B + C = 0
## @end example
##
## @end ifnottex
## using standard @sc{lapack} subroutines.  For example:
##
## @example
## @group
## syl ([1, 2; 3, 4], [5, 6; 7, 8], [9, 10; 11, 12])
##    @result{} [ -0.50000, -0.66667; -0.66667, -0.50000 ]
## @end group
## @end example
## @end deftypefn
    
    ## Deprecated in version 4.0
    
    
@function
def syl(A=None,B=None,C=None,*args,**kwargs):
    varargin = syl.varargin
    nargin = syl.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/syl.m:54
        warning('Octave:deprecated-function','syl is obsolete and will be removed from a future version of Octave, please use sylvester instead')
    
    if (nargin != 3 or nargout > 1):
        print_usage()
    
    x=- sylvester(A,B,C)
# /home/lei/octave-4.0.2/scripts/deprecated/syl.m:63
    return x
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{val} =} saving_history ()
## @deftypefnx {Built-in Function} {@var{old_val} =} saving_history (@var{new_val})
## @deftypefnx {Built-in Function} {} saving_history (@var{new_val}, "local")
## This function has been deprecated.  Use @code{@file{history_save}} instead.
## @seealso{history_save}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def saving_history(varargin=None,*args,**kwargs):
    varargin = saving_history.varargin
    nargin = saving_history.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/saving_history.m:33
        warning('Octave:deprecated-function','saving_history is obsolete and will be removed from a future version of Octave, please use history_save instead')
    
    retval=save_default_options(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/saving_history.m:38
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} gen_doc_cache (@var{out_file}, @var{directory})
## This function has been deprecated.  Use @code{doc_cache_create} instead.
## @seealso{doc_cache_create}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def gen_doc_cache(varargin=None,*args,**kwargs):
    varargin = gen_doc_cache.varargin
    nargin = gen_doc_cache.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/gen_doc_cache.m:31
        warning('Octave:deprecated-function','gen_doc_cache is obsolete and will be removed from a future version of Octave, please use doc_cache_create instead')
    
    doc_cache_create(varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Built-in Function} {} re_read_readline_init_file (@var{file})
## This function has been deprecated.  Use
## @code{@file{readline_re_read_init_file}} instead.
## @seealso{readline_read_init_file}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def re_read_readline_init_file(varargin=None,*args,**kwargs):
    varargin = re_read_readline_init_file.varargin
    nargin = re_read_readline_init_file.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/re_read_readline_init_file.m:32
        warning('Octave:deprecated-function','re_read_readline_init_file is obsolete and will be removed from a future version of Octave, please use readline_re_read_init_file instead')
    
    readline_re_read_init_file(varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 William Poetra Yoga Hadisoeseno
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isequalwithequalnans (@var{x1}, @var{x2}, @dots{})
## This function has been deprecated.  Use @code{@file{isequaln}} instead.
## @seealso{isequaln}
## @end deftypefn
    
    ## Deprecated in 3.8
    
    
@function
def isequalwithequalnans(varargin=None,*args,**kwargs):
    varargin = isequalwithequalnans.varargin
    nargin = isequalwithequalnans.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/isequalwithequalnans.m:31
        warning('Octave:deprecated-function','isequalwithequalnans is obsolete and will be removed from a future version of Octave, please use isequaln instead')
    
    retval=isequaln(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/isequalwithequalnans.m:36
    return retval
    
if __name__ == '__main__':
    pass
    
    ## test for equality
    
    
    ## test for inequality
    
    
    ## test for equality (struct)
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Built-in Function} {@var{val} =} java_convert_matrix ()
## @deftypefnx {Built-in Function} {@var{old_val} =} java_convert_matrix (@var{new_val})
## @deftypefnx {Built-in Function} {} java_convert_matrix (@var{new_val}, "local")
## Query or set the internal variable that controls whether Java arrays are
## automatically converted to Octave matrices.  The default value is false.
##
## When called from inside a function with the @qcode{"local"} option, the
## variable is changed locally for the function and any subroutines it calls.
##  The original variable value is restored when exiting the function.
## @seealso{java_matrix_autoconversion, java_unsigned_conversion, java_debug}
## @end deftypefn
    
    
@function
def java_convert_matrix(varargin=None,*args,**kwargs):
    varargin = java_convert_matrix.varargin
    nargin = java_convert_matrix.nargin

    
    if (logical_not(warned)):
        warned=copy(true)
# /home/lei/octave-4.0.2/scripts/deprecated/java_convert_matrix.m:36
        warning('Octave:deprecated-function','java_convert_matrix is obsolete and will be removed from a future version of Octave; use java_matrix_autoconversion instead')
    
    if (nargin > 2):
        print_usage()
    
    old_val=java_matrix_autoconversion(varargin[:])
# /home/lei/octave-4.0.2/scripts/deprecated/java_convert_matrix.m:45
    return old_val
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Julien Bect
## Copyright (C) 2008-2015 Jaroslav Hajek
## Copyright (C) 2000, 2006-2007 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by the
## Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
## for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} setxor (@var{a}, @var{b})
## @deftypefnx {Function File} {@var{c} =} setxor (@var{a}, @var{b}, "rows")
## @deftypefnx {Function File} {[@var{c}, @var{ia}, @var{ib}] =} setxor (@dots{})
##
## Return the unique elements exclusive to sets @var{a} or @var{b} sorted in
## ascending order.
##
## If @var{a} and @var{b} are both row vectors then return a row vector;
## Otherwise, return a column vector.  The inputs may also be cell arrays of
## strings.
##
## If the optional input @qcode{"rows"} is given then return the rows exclusive
## to sets @var{a} and @var{b}.  The inputs must be 2-D matrices to use this
## option.
##
## If requested, return index vectors @var{ia} and @var{ib} such that
## @code{@var{a}(@var{ia})} and @code{@var{b}(@var{ib})} are disjoint sets
## whose union is @var{c}.
##
## @seealso{unique, union, intersect, setdiff, ismember}
## @end deftypefn
    
    
@function
def setxor(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = setxor.varargin
    nargin = setxor.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    a,b=validsetargs('setxor',a,b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:50
    by_rows=nargin == 3
# /home/lei/octave-4.0.2/scripts/set/setxor.m:52
    isrowvec=isvector(a) and isvector(b) and isrow(a) and isrow(b)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:53
    
    if (nargout > 1):
        a,ia=unique(a,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:57
        b,ib=unique(b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:58
    else:
        a=unique(a,varargin[:])
# /home/lei/octave-4.0.2/scripts/set/setxor.m:60
        b=unique(b,varargin[:])
# /home/lei/octave-4.0.2/scripts/set/setxor.m:61
    
    if (isempty(a)):
        c=copy(b)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:65
    else:
        if (isempty(b)):
            c=copy(a)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:67
        else:
            ## Reject duplicates.
            if (by_rows):
                na=rows(a)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:71
                nb=rows(b)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:71
                c,i=sortrows(cat([a],[b]),nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:72
                n=rows(c)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:73
                idx=find(all(c[1:n - 1,:] == c[2:n,:],2))
# /home/lei/octave-4.0.2/scripts/set/setxor.m:74
                if (logical_not(isempty(idx))):
                    c[cat(idx,idx + 1),:]=[]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:76
                    i[cat(idx,idx + 1),:]=[]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:77
            else:
                na=numel(a)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:80
                nb=numel(b)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:80
                c,i=sort(cat([ravel(a)],[ravel(b)]),nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:81
                n=length(c)
# /home/lei/octave-4.0.2/scripts/set/setxor.m:82
                if (iscell(c)):
                    idx=find(strcmp(c[1:n - 1],c[2:n]))
# /home/lei/octave-4.0.2/scripts/set/setxor.m:84
                else:
                    idx=find(c[1:n - 1] == c[2:n])
# /home/lei/octave-4.0.2/scripts/set/setxor.m:86
                if (logical_not(isempty(idx))):
                    c[cat(idx,idx + 1)]=[]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:89
                    i[cat(idx,idx + 1)]=[]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:90
                ## Adjust output orientation for Matlab compatibility
                if (isrowvec):
                    c=c.T
# /home/lei/octave-4.0.2/scripts/set/setxor.m:95
            if (nargout > 1):
                ia=ia[i[i <= na]]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:100
                ib=ib[i[i > na] - na]
# /home/lei/octave-4.0.2/scripts/set/setxor.m:101
    
    return c,ia,ib
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test orientation of output
    
    
    
    
    
    
    
    ## Test multi-dimensional arrays
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2008-2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unique (@var{x})
## @deftypefnx {Function File} {} unique (@var{x}, "rows")
## @deftypefnx {Function File} {[@var{y}, @var{i}, @var{j}] =} unique (@dots{})
## @deftypefnx {Function File} {[@var{y}, @var{i}, @var{j}] =} unique (@dots{}, "first")
## @deftypefnx {Function File} {[@var{y}, @var{i}, @var{j}] =} unique (@dots{}, "last")
## Return the unique elements of @var{x} sorted in ascending order.
##
## If the input @var{x} is a column vector then return a column vector;
## Otherwise, return a row vector.  @var{x} may also be a cell array of strings.
##
## If the optional argument @qcode{"rows"} is given then return the unique
## rows of @var{x} sorted in ascending order.  The input must be a 2-D matrix
## to use this option.
##
## If requested, return index vectors @var{i} and @var{j} such that
## @code{@var{y} = @var{x}(@var{i})} and @code{@var{x} = @var{y}(@var{j})}.
##
## Additionally, if @var{i} is a requested output then one of @qcode{"first"} or
## @qcode{"last"} may be given as an input.  If @qcode{"last"} is specified,
## return the highest possible indices in @var{i}, otherwise, if @qcode{"first"}
## is specified, return the lowest.  The default is @qcode{"last"}.
## @seealso{union, intersect, setdiff, setxor, ismember}
## @end deftypefn
    
    
@function
def unique(x=None,varargin=None,*args,**kwargs):
    varargin = unique.varargin
    nargin = unique.nargin

    if (nargin < 1):
        print_usage()
    else:
        if (logical_not((isnumeric(x) or islogical(x) or ischar(x) or iscellstr(x)))):
            error('unique: X must be an array or cell array of strings')
    
    if (nargin > 1):
        ## parse options
        if (logical_not(iscellstr(varargin))):
            error('unique: options must be strings')
        optrows=any(strcmp('rows',varargin))
# /home/lei/octave-4.0.2/scripts/set/unique.m:59
        optfirst=any(strcmp('first',varargin))
# /home/lei/octave-4.0.2/scripts/set/unique.m:60
        optlast=any(strcmp('last',varargin))
# /home/lei/octave-4.0.2/scripts/set/unique.m:61
        if (optfirst and optlast):
            error('unique: cannot specify both "first" and "last"')
        else:
            if (optfirst + optlast + optrows != nargin - 1):
                error('unique: invalid option')
        if (optrows and iscellstr(x)):
            warning('unique: "rows" is ignored for cell arrays')
            optrows=copy(false)
# /home/lei/octave-4.0.2/scripts/set/unique.m:70
    else:
        optrows=copy(false)
# /home/lei/octave-4.0.2/scripts/set/unique.m:73
        optfirst=copy(false)
# /home/lei/octave-4.0.2/scripts/set/unique.m:74
    
    ## FIXME: The operations
  ##
  ##   match = (y(1:n-1) == y(2:n));
  ##   y(idx) = [];
  ##
  ## are very slow on sparse matrices.  Until they are fixed to be as
  ## fast as for full matrices, operate on the nonzero elements of the
  ## sparse array as long as we are not operating on rows.
    
    if (issparse(x) and logical_not(optrows) and nargout <= 1):
        if (nnz(x) < numel(x)):
            y=unique(cat([0],[nonzeros(x)]),varargin[:])
# /home/lei/octave-4.0.2/scripts/set/unique.m:88
        else:
            ## Corner case where sparse matrix is actually full
            y=unique(full(x),varargin[:])
# /home/lei/octave-4.0.2/scripts/set/unique.m:91
        return y,i,j
    
    if (optrows):
        n=rows(x)
# /home/lei/octave-4.0.2/scripts/set/unique.m:97
        dim=1
# /home/lei/octave-4.0.2/scripts/set/unique.m:98
    else:
        n=numel(x)
# /home/lei/octave-4.0.2/scripts/set/unique.m:100
        dim=(rows(x) == 1) + 1
# /home/lei/octave-4.0.2/scripts/set/unique.m:101
    
    y=copy(x)
# /home/lei/octave-4.0.2/scripts/set/unique.m:104
    
    if (n == 0):
        if (logical_not(optrows) and isempty(x) and any(size(x))):
            if (iscellstr(y)):
                y=cell(0,1)
# /home/lei/octave-4.0.2/scripts/set/unique.m:109
            else:
                y=zeros(0,1,class_(y))
# /home/lei/octave-4.0.2/scripts/set/unique.m:111
        i=j=matlabarray([])
# /home/lei/octave-4.0.2/scripts/set/unique.m:114
# /home/lei/octave-4.0.2/scripts/set/unique.m:114
        return y,i,j
    else:
        if (n == 1):
            i=j=1
# /home/lei/octave-4.0.2/scripts/set/unique.m:117
# /home/lei/octave-4.0.2/scripts/set/unique.m:117
            return y,i,j
    
    if (optrows):
        if (nargout > 1):
            y,i=sortrows(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/unique.m:123
        else:
            y=sortrows(y)
# /home/lei/octave-4.0.2/scripts/set/unique.m:125
        match=all(y[1:n - 1,:] == y[2:n,:],2)
# /home/lei/octave-4.0.2/scripts/set/unique.m:127
        y[match,:]=[]
# /home/lei/octave-4.0.2/scripts/set/unique.m:128
    else:
        if (logical_not(isvector(y))):
            y=ravel(y)
# /home/lei/octave-4.0.2/scripts/set/unique.m:131
        if (nargout > 1):
            y,i=sort(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/unique.m:134
        else:
            y=sort(y)
# /home/lei/octave-4.0.2/scripts/set/unique.m:136
        if (iscellstr(y)):
            match=strcmp(y[1:n - 1],y[2:n])
# /home/lei/octave-4.0.2/scripts/set/unique.m:139
        else:
            match=(y[1:n - 1] == y[2:n])
# /home/lei/octave-4.0.2/scripts/set/unique.m:141
        y[match]=[]
# /home/lei/octave-4.0.2/scripts/set/unique.m:143
    
    if (isargout(3)):
        j=copy(i)
# /home/lei/octave-4.0.2/scripts/set/unique.m:147
        if (dim == 1):
            j[i]=cumsum(cat([1],[logical_not(match)]))
# /home/lei/octave-4.0.2/scripts/set/unique.m:149
        else:
            j[i]=cumsum(cat(1,logical_not(match)))
# /home/lei/octave-4.0.2/scripts/set/unique.m:151
    
    if (isargout(2)):
        idx=find(match)
# /home/lei/octave-4.0.2/scripts/set/unique.m:156
        if (optfirst):
            idx += 1
        i[idx]=[]
# /home/lei/octave-4.0.2/scripts/set/unique.m:160
    
    return y,i,j
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{tf} =} ismember (@var{a}, @var{s})
## @deftypefnx {Function File} {@var{tf} =} ismember (@var{a}, @var{s}, "rows")
## @deftypefnx {Function File} {[@var{tf}, @var{s_idx}] =} ismember (@dots{})
##
## Return a logical matrix @var{tf} with the same shape as @var{a} which is
## true (1) if the element in @var{a} is found in @var{s} and false (0) if it
## is not.
##
## If a second output argument is requested then the index into @var{s} of each
## matching element is also returned.
##
## @example
## @group
## a = [3, 10, 1];
## s = [0:9];
## [tf, s_idx] = ismember (a, s)
##      @result{} tf = [1, 0, 1]
##      @result{} s_idx = [4, 0, 2]
## @end group
## @end example
##
## The inputs @var{a} and @var{s} may also be cell arrays.
##
## @example
## @group
## a = @{"abc"@};
## s = @{"abc", "def"@};
## [tf, s_idx] = ismember (a, s)
##      @result{} tf = [1, 0]
##      @result{} s_idx = [1, 0]
## @end group
## @end example
##
## If the optional third argument @qcode{"rows"} is given then compare rows
## in @var{a} with rows in @var{s}.  The inputs must be 2-D matrices with the
## same number of columns to use this option.
##
## @example
## @group
## a = [1:3; 5:7; 4:6];
## s = [0:2; 1:3; 2:4; 3:5; 4:6];
## [tf, s_idx] = ismember (a, s, "rows")
##      @result{} tf = logical ([1; 0; 1])
##      @result{} s_idx = [2; 0; 5];
## @end group
## @end example
##
## @seealso{lookup, unique, union, intersect, setdiff, setxor}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
## Author: Sren Hauberg <hauberg@gmail.com>
## Author: Ben Abbott <bpabbott@mac.com>
## Adapted-by: jwe
## Reimplemented using lookup & unique: Jaroslav Hajek <highegg@gmail.com>
    
    
@function
def ismember(a=None,s=None,varargin=None,*args,**kwargs):
    varargin = ismember.varargin
    nargin = ismember.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    ## lookup() does not handle logical values
    if (islogical(a)):
        a=uint8(a)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:85
    
    if (islogical(s)):
        s=uint8(s)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:88
    
    a,s=validsetargs('ismember',a,s,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:91
    by_rows=nargin == 3
# /home/lei/octave-4.0.2/scripts/set/ismember.m:93
    if (logical_not(by_rows)):
        s=ravel(s)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:96
        if (issorted(s)):
            is_=matlabarray([])
# /home/lei/octave-4.0.2/scripts/set/ismember.m:99
        else:
            s,is_=sort(s,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:101
        ## Remove NaNs from table because lookup can't handle them
        if (isreal(s) and logical_not(isempty(s)) and isnan(s[end()])):
            s=s[1:end() - sum(isnan(s))]
# /home/lei/octave-4.0.2/scripts/set/ismember.m:106
        if (nargout > 1):
            s_idx=lookup(s,a,'m')
# /home/lei/octave-4.0.2/scripts/set/ismember.m:110
            tf=logical(s_idx)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:111
            if (logical_not(isempty(is_))):
                s_idx[tf]=is_[s_idx[tf]]
# /home/lei/octave-4.0.2/scripts/set/ismember.m:113
        else:
            tf=lookup(s,a,'b')
# /home/lei/octave-4.0.2/scripts/set/ismember.m:116
    else:
        if (isempty(a) or isempty(s)):
            tf=false(rows(a),1)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:121
            s_idx=zeros(rows(a),1)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:122
        else:
            if (rows(s) == 1):
                tf=all(bsxfun(eq,a,s),2)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:125
                s_idx=double(tf)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:126
            else:
                ## FIXME: lookup does not support "rows", so we just use unique.
                __,ii,jj=unique(cat([a],[s]),'rows','last',nargout=3)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:129
                na=rows(a)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:130
                jj=ii[jj[1:na]]
# /home/lei/octave-4.0.2/scripts/set/ismember.m:131
                tf=jj > na
# /home/lei/octave-4.0.2/scripts/set/ismember.m:132
                if (nargout > 1):
                    s_idx=max(0,jj - na)
# /home/lei/octave-4.0.2/scripts/set/ismember.m:135
    
    return tf,s_idx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2008-2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} union (@var{a}, @var{b})
## @deftypefnx {Function File} {@var{c} =} union (@var{a}, @var{b}, "rows")
## @deftypefnx {Function File} {[@var{c}, @var{ia}, @var{ib}] =} union (@dots{})
##
## Return the unique elements that are in either @var{a} or @var{b} sorted in
## ascending order.
##
## If @var{a} and @var{b} are both row vectors then return a row vector;
## Otherwise, return a column vector.  The inputs may also be cell arrays of
## strings.
##
## If the optional input @qcode{"rows"} is given then return rows that are in
## either @var{a} or @var{b}.  The inputs must be 2-D matrices to use this
## option.
##
## The optional outputs @var{ia} and @var{ib} are index vectors such that
## @code{@var{a}(@var{ia})} and @code{@var{b}(@var{ib})} are disjoint sets
## whose union is @var{c}.
##
## @seealso{unique, intersect, setdiff, setxor, ismember}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def union(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = union.varargin
    nargin = union.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    a,b=validsetargs('union',a,b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/union.m:51
    by_rows=nargin == 3
# /home/lei/octave-4.0.2/scripts/set/union.m:53
    isrowvec=isvector(a) and isvector(b) and isrow(a) and isrow(b)
# /home/lei/octave-4.0.2/scripts/set/union.m:54
    if (by_rows):
        y=matlabarray(cat([a],[b]))
# /home/lei/octave-4.0.2/scripts/set/union.m:57
    else:
        y=matlabarray(cat([ravel(a)],[ravel(b)]))
# /home/lei/octave-4.0.2/scripts/set/union.m:59
        if (isrowvec):
            y=y.T
# /home/lei/octave-4.0.2/scripts/set/union.m:62
    
    if (nargout <= 1):
        y=unique(y,varargin[:])
# /home/lei/octave-4.0.2/scripts/set/union.m:67
    else:
        y,idx=unique(y,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/union.m:69
        na=numel(a)
# /home/lei/octave-4.0.2/scripts/set/union.m:70
        ia=idx[idx <= na]
# /home/lei/octave-4.0.2/scripts/set/union.m:71
        ib=idx[idx > na] - na
# /home/lei/octave-4.0.2/scripts/set/union.m:72
    
    return y,ia,ib
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test multi-dimensional arrays
    
    
    
    
    
    
    
    
    
    ## Test common input validation for set routines contained in validsetargs
    
    ## Copyright (C) 2010-2015 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} powerset (@var{a})
## @deftypefnx {Function File} {} powerset (@var{a}, "rows")
## Compute the powerset (all subsets) of the set @var{a}.
##
## The set @var{a} must be a numerical matrix or a cell array of strings.  The
## output will always be a cell array of either vectors or strings.
##
## With the optional argument @qcode{"rows"}, each row of the set @var{a} is
## considered one element of the set.  The input must be a 2-D numeric matrix
## to use this argument.
##
## @seealso{unique, union, intersect, setdiff, setxor, ismember}
## @end deftypefn
    
    
@function
def powerset(a=None,byrows_arg=None,*args,**kwargs):
    varargin = powerset.varargin
    nargin = powerset.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    byrows=copy(false)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:40
    if (nargin == 2):
        if (logical_not(strcmpi(byrows_arg,'rows'))):
            error('powerset: expecting second argument to be "rows"')
        else:
            if (iscell(a)):
                error('powerset: "rows" not valid for cell arrays')
            else:
                byrows=copy(true)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:47
    
    if (iscell(a) and logical_not(iscellstr(a))):
        error('powerset: cell arrays can only be used for character strings')
    
    if (byrows):
        a=unique(a,'rows')
# /home/lei/octave-4.0.2/scripts/set/powerset.m:56
        n=rows(a)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:57
    else:
        a=unique(a)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:59
        n=numel(a)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:60
    
    if (n == 0):
        p=cellarray([])
# /home/lei/octave-4.0.2/scripts/set/powerset.m:64
    else:
        if (n > 32):
            error('powerset: not implemented for more than 32 elements')
        ## Logical rep
        b=reshape(bitunpack(uint32(arange(0,2 ** n - 1))),32,2 ** n)(arange(1,n),arange())
# /home/lei/octave-4.0.2/scripts/set/powerset.m:71
        i,k=find(b,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:73
        k=sum(b,1)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:74
        if (byrows):
            p=mat2cell(a[i,:],k,columns(a))
# /home/lei/octave-4.0.2/scripts/set/powerset.m:78
        else:
            if (rows(a) == 1):
                p=mat2cell(a[i],1,k)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:81
            else:
                p=mat2cell(a[i],k,1)
# /home/lei/octave-4.0.2/scripts/set/powerset.m:83
    
    return p
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2009-2010 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## Validate arguments for binary set operation.
    
    
@function
def validsetargs(caller=None,x=None,y=None,byrows_arg=None,*args,**kwargs):
    varargin = validsetargs.varargin
    nargin = validsetargs.nargin

    isallowedarraytype=lambda x=None: isnumeric(x) or ischar(x) or islogical(x)
# /home/lei/octave-4.0.2/scripts/set/private/validsetargs.m:24
    if (nargin == 3):
        icx=iscellstr(x)
# /home/lei/octave-4.0.2/scripts/set/private/validsetargs.m:27
        icy=iscellstr(y)
# /home/lei/octave-4.0.2/scripts/set/private/validsetargs.m:28
        if (icx or icy):
            if (icx and ischar(y)):
                y=cellstr(y)
# /home/lei/octave-4.0.2/scripts/set/private/validsetargs.m:31
            else:
                if (icy and ischar(x)):
                    x=cellstr(x)
# /home/lei/octave-4.0.2/scripts/set/private/validsetargs.m:33
                else:
                    if (logical_not((icx and icy))):
                        error('%s: cell array of strings cannot be combined with a nonstring value',caller)
        else:
            if (logical_not((isallowedarraytype[x] and isallowedarraytype[y]))):
                error('%s: A and B must be arrays or cell arrays of strings',caller)
    else:
        if (nargin == 4):
            if (logical_not(strcmpi(byrows_arg,'rows'))):
                error('%s: invalid option: %s',caller,byrows_arg)
            if (iscell(x) or iscell(y)):
                error('%s: cells not supported with "rows"',caller)
            else:
                if (logical_not((isallowedarraytype[x] and isallowedarraytype[y]))):
                    error('%s: A and B must be arrays or cell arrays of strings',caller)
                else:
                    if (ndims(x) > 2 or ndims(y) > 2):
                        error('%s: A and B must be 2-dimensional matrices for "rows"',caller)
                    else:
                        if (columns(x) != columns(y) and logical_not((isempty(x) or isempty(y)))):
                            error('%s: number of columns in A and B must match',caller)
    
    return x,y
    
if __name__ == '__main__':
    pass
    
    ## #!tests for function are in union.m
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2008-2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} setdiff (@var{a}, @var{b})
## @deftypefnx {Function File} {@var{c} =} setdiff (@var{a}, @var{b}, "rows")
## @deftypefnx {Function File} {[@var{c}, @var{ia}] =} setdiff (@dots{})
## Return the unique elements in @var{a} that are not in @var{b} sorted in
## ascending order.
##
## If @var{a} is a row vector return a column vector; Otherwise, return a
## column vector.  The inputs may also be cell arrays of strings.
##
## If the optional input @qcode{"rows"} is given then return the rows in
## @var{a} that are not in @var{b}.  The inputs must be 2-D matrices to use
## this option.
##
## If requested, return the index vector @var{ia} such that
## @code{@var{c} = @var{a}(@var{ia})}.
## @seealso{unique, union, intersect, setxor, ismember}
## @end deftypefn
    
    ## Author: Paul Kienzle
## Adapted-by: jwe
    
    
@function
def setdiff(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = setdiff.varargin
    nargin = setdiff.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    a,b=validsetargs('setdiff',a,b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:48
    by_rows=nargin == 3
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:50
    isrowvec=isvector(a) and isrow(a)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:51
    if (by_rows):
        if (nargout > 1):
            c,ia=unique(a,'rows',nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:55
        else:
            c=unique(a,'rows')
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:57
        if (logical_not(isempty(c)) and logical_not(isempty(b))):
            ## Form A and B into combined set.
            b=unique(b,'rows')
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:61
            tmp,idx=sortrows(cat([c],[b]),nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:62
            dups=find(all(tmp[1:end() - 1,:] == tmp[2:end(),:],2))
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:64
            c[idx[dups],:]=[]
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:65
            if (nargout > 1):
                ia[idx[dups],:]=[]
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:67
    else:
        if (nargout > 1):
            c,ia=unique(a,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:72
        else:
            c=unique(a)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:74
        if (logical_not(isempty(c)) and logical_not(isempty(b))):
            ## Form a and b into combined set.
            b=unique(b)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:78
            tmp,idx=sort(cat([ravel(c)],[ravel(b)]),nargout=2)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:79
            if (iscellstr(tmp)):
                dups=find(strcmp(tmp[1:end() - 1],tmp[2:end()]))
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:82
            else:
                dups=find(tmp[1:end() - 1] == tmp[2:end()])
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:84
            c[idx[dups]]=[]
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:86
            if (nargout > 1):
                ia[idx[dups]]=[]
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:88
            ## Reshape if necessary for Matlab compatibility.
            if (isrowvec):
                c=ravel(c).T
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:92
            else:
                c=ravel(c)
# /home/lei/octave-4.0.2/scripts/set/setdiff.m:94
    
    return c,ia
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test output orientation compatibility (bug #42577)
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2008-2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} intersect (@var{a}, @var{b})
## @deftypefnx {Function File} {@var{c} =} intersect (@var{a}, @var{b}, "rows")
## @deftypefnx {Function File} {[@var{c}, @var{ia}, @var{ib}] =} intersect (@dots{})
##
## Return the unique elements common to both @var{a} and @var{b} sorted in
## ascending order.
##
## If @var{a} and @var{b} are both row vectors then return a row vector;
## Otherwise, return a column vector.  The inputs may also be cell arrays of
## strings.
##
## If the optional input @qcode{"rows"} is given then return the common rows of
## @var{a} and @var{b}.  The inputs must be 2-D matrices to use this option.
##
## If requested, return index vectors @var{ia} and @var{ib} such that
## @code{@var{c} = @var{a}(@var{ia})} and @code{@var{c} = @var{b}(@var{ib})}.
##
## @end deftypefn
## @seealso{unique, union, setdiff, setxor, ismember}
    
    
@function
def intersect(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = intersect.varargin
    nargin = intersect.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    a,b=validsetargs('intersect',a,b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:47
    if (isempty(a) or isempty(b)):
        c=ia=ib=matlabarray([])
# /home/lei/octave-4.0.2/scripts/set/intersect.m:50
# /home/lei/octave-4.0.2/scripts/set/intersect.m:50
# /home/lei/octave-4.0.2/scripts/set/intersect.m:50
    else:
        by_rows=nargin == 3
# /home/lei/octave-4.0.2/scripts/set/intersect.m:52
        isrowvec=isvector(a) and isvector(b) and isrow(a) and isrow(b)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:53
        if (nargout > 1):
            a,ja=unique(a,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:57
            b,jb=unique(b,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:58
        else:
            a=unique(a,varargin[:])
# /home/lei/octave-4.0.2/scripts/set/intersect.m:60
            b=unique(b,varargin[:])
# /home/lei/octave-4.0.2/scripts/set/intersect.m:61
        if (by_rows):
            c=matlabarray(cat([a],[b]))
# /home/lei/octave-4.0.2/scripts/set/intersect.m:65
            c,ic=sortrows(c,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:66
            ii=find(all(c[1:end() - 1,:] == c[2:end(),:],2))
# /home/lei/octave-4.0.2/scripts/set/intersect.m:67
            c=c[ii,:]
# /home/lei/octave-4.0.2/scripts/set/intersect.m:68
            len_a=rows(a)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:69
        else:
            c=matlabarray(cat([ravel(a)],[ravel(b)]))
# /home/lei/octave-4.0.2/scripts/set/intersect.m:71
            c,ic=sort(c,nargout=2)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:72
            if (iscellstr(c)):
                ii=find(strcmp(c[1:end() - 1],c[2:end()]))
# /home/lei/octave-4.0.2/scripts/set/intersect.m:74
            else:
                ii=find(c[1:end() - 1] == c[2:end()])
# /home/lei/octave-4.0.2/scripts/set/intersect.m:76
            c=c[ii]
# /home/lei/octave-4.0.2/scripts/set/intersect.m:78
            len_a=length(a)
# /home/lei/octave-4.0.2/scripts/set/intersect.m:79
        if (nargout > 1):
            ia=ja[ic[ii]]
# /home/lei/octave-4.0.2/scripts/set/intersect.m:83
            ib=jb[ic[ii + 1] - len_a]
# /home/lei/octave-4.0.2/scripts/set/intersect.m:84
        ## Adjust output orientation for Matlab compatibility
        if (logical_not(by_rows) and isrowvec):
            c=c.T
# /home/lei/octave-4.0.2/scripts/set/intersect.m:89
    
    return c,ia,ib
    
if __name__ == '__main__':
    pass
    
    ## Test orientation of output
    
    
    
    
    
    
    
    ## Test multi-dimensional arrays
    
    
    
    
    ## Test the routine for index vectors ia and ib
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Peter Ekberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} wilkinson (@var{n})
## Return the Wilkinson matrix of order @var{n}.
##
## Wilkinson matrices are symmetric and tridiagonal with pairs of nearly, but
## not exactly, equal eigenvalues.  They are useful in testing the behavior and
## performance of eigenvalue solvers.
##
## @seealso{rosser, eig}
## @end deftypefn
    
    ## Author: Peter Ekberg
##         (peda)
    
    
@function
def wilkinson(n=None,*args,**kwargs):
    varargin = wilkinson.varargin
    nargin = wilkinson.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isscalar(n) and n >= 0 and (n == fix(n))))):
        error('wilkinson: N must be a non-negative integer')
    
    side=ones(n - 1,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/wilkinson.m:43
    center=abs(arange(- (n - 1) / 2,(n - 1) / 2))
# /home/lei/octave-4.0.2/scripts/special-matrix/wilkinson.m:44
    retval=diag(side,- 1) + diag(center) + diag(side,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/wilkinson.m:45
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1999-2015 Peter Ekberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rosser ()
## Return the Rosser matrix.
##
## This is a difficult test case used to evaluate eigenvalue algorithms.
## @seealso{wilkinson, eig}
## @end deftypefn
    
    ## Author: Peter Ekberg
##         (peda)
    
    
@function
def rosser(*args,**kwargs):
    varargin = rosser.varargin
    nargin = rosser.nargin

    if (nargin != 0):
        print_usage()
    
    retval=matlabarray(cat([611,196,- 192,407,- 8,- 52,- 49,29],[196,899,113,- 192,- 71,- 43,- 8,- 44],[- 192,113,899,196,61,49,8,52],[407,- 192,196,611,8,44,59,- 23],[- 8,- 71,61,8,411,- 599,208,208],[- 52,- 43,49,44,- 599,411,208,208],[- 49,- 8,8,59,208,208,99,- 911],[29,- 44,52,- 23,208,208,- 911,99]))
# /home/lei/octave-4.0.2/scripts/special-matrix/rosser.m:36
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 1989-1995 Nicholas .J. Higham
## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} gallery (@var{name})
## @deftypefnx {Function File} {} gallery (@var{name}, @var{args})
## Create interesting matrices for testing.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{c} =} gallery ("cauchy", @var{x})
## @deftypefnx {Function File} {@var{c} =} gallery ("cauchy", @var{x}, @var{y})
## Create a Cauchy matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{c} =} gallery ("chebspec", @var{n})
## @deftypefnx {Function File} {@var{c} =} gallery ("chebspec", @var{n}, @var{k})
## Create a Chebyshev spectral differentiation matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{c} =} gallery ("chebvand", @var{p})
## @deftypefnx {Function File} {@var{c} =} gallery ("chebvand", @var{m}, @var{p})
## Create a Vandermonde-like matrix for the Chebyshev polynomials.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("chow", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("chow", @var{n}, @var{alpha})
## @deftypefnx {Function File} {@var{a} =} gallery ("chow", @var{n}, @var{alpha}, @var{delta})
## Create a Chow matrix -- a singular Toeplitz lower Hessenberg matrix.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{c} =} gallery ("circul", @var{v})
## Create a circulant matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("clement", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("clement", @var{n}, @var{k})
## Create a tridiagonal matrix with zero diagonal entries.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{c} =} gallery ("compar", @var{a})
## @deftypefnx {Function File} {@var{c} =} gallery ("compar", @var{a}, @var{k})
## Create a comparison matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("condex", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("condex", @var{n}, @var{k})
## @deftypefnx {Function File} {@var{a} =} gallery ("condex", @var{n}, @var{k}, @var{theta})
## Create a `counterexample' matrix to a condition estimator.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("cycol", [@var{m} @var{n}])
## @deftypefnx {Function File} {@var{a} =} gallery ("cycol", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery (@dots{}, @var{k})
## Create a matrix whose columns repeat cyclically.
##
## @end deftypefn
##
## @deftypefn  {Function File} {[@var{c}, @var{d}, @var{e}] =} gallery ("dorr", @var{n})
## @deftypefnx {Function File} {[@var{c}, @var{d}, @var{e}] =} gallery ("dorr", @var{n}, @var{theta})
## @deftypefnx {Function File} {@var{a} =} gallery ("dorr", @dots{})
## Create a diagonally dominant, ill-conditioned, tridiagonal matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("dramadah", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("dramadah", @var{n}, @var{k})
## Create a (0, 1) matrix whose inverse has large integer entries.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("fiedler", @var{c})
## Create a symmetric @nospell{Fiedler} matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("forsythe", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("forsythe", @var{n}, @var{alpha})
## @deftypefnx {Function File} {@var{a} =} gallery ("forsythe", @var{n}, @var{alpha}, @var{lambda})
## Create a @nospell{Forsythe} matrix (a perturbed Jordan block).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{f} =} gallery ("frank", @var{n})
## @deftypefnx {Function File} {@var{f} =} gallery ("frank", @var{n}, @var{k})
## Create a Frank matrix (ill-conditioned eigenvalues).
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{c} =} gallery ("gcdmat", @var{n})
## Create a greatest common divisor matrix.
##
## @var{c} is an @var{n}-by-@var{n} matrix whose values correspond to the
## greatest common divisor of its coordinate values, i.e., @var{c}(i,j)
## correspond @code{gcd (i, j)}.
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("gearmat", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("gearmat", @var{n}, @var{i})
## @deftypefnx {Function File} {@var{a} =} gallery ("gearmat", @var{n}, @var{i}, @var{j})
## Create a Gear matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{g} =} gallery ("grcar", @var{n})
## @deftypefnx {Function File} {@var{g} =} gallery ("grcar", @var{n}, @var{k})
## Create a Toeplitz matrix with sensitive eigenvalues.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("hanowa", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("hanowa", @var{n}, @var{d})
## Create a matrix whose eigenvalues lie on a vertical line in the complex
## plane.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{v} =} gallery ("house", @var{x})
## @deftypefnx {Function File} {[@var{v}, @var{beta}] =} gallery ("house", @var{x})
## Create a householder matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("integerdata", @var{imax}, [@var{M} @var{N} @dots{}], @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("integerdata", @var{imax}, @var{M}, @var{N}, @dots{}, @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("integerdata", [@var{imin}, @var{imax}], [@var{M} @var{N} @dots{}], @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("integerdata", [@var{imin}, @var{imax}], @var{M}, @var{N}, @dots{}, @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("integerdata", @dots{}, "@var{class}")
## Create a matrix with random integers in the range [1, @var{imax}].
## If @var{imin} is given then the integers are in the range
## [@var{imin}, @var{imax}].
##
## The second input is a matrix of dimensions describing the size of the output.
## The dimensions can also be input as comma-separated arguments.
##
## The input @var{j} is an integer index in the range [0, 2^32-1].  The values
## of the output matrix are always exactly the same (reproducibility) for a
## given size input and @var{j} index.
##
## The final optional argument determines the class of the resulting matrix.
## Possible values for @var{class}: @qcode{"uint8"}, @qcode{"uint16"},
## @qcode{"uint32"}, @qcode{"int8"}, @qcode{"int16"}, int32", @qcode{"single"},
## @qcode{"double"}.  The default is @qcode{"double"}.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("invhess", @var{x})
## @deftypefnx {Function File} {@var{a} =} gallery ("invhess", @var{x}, @var{y})
## Create the inverse of an upper Hessenberg matrix.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("invol", @var{n})
## Create an involutory matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("ipjfact", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("ipjfact", @var{n}, @var{k})
## Create a Hankel matrix with factorial elements.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("jordbloc", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("jordbloc", @var{n}, @var{lambda})
## Create a Jordan block.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{u} =} gallery ("kahan", @var{n})
## @deftypefnx {Function File} {@var{u} =} gallery ("kahan", @var{n}, @var{theta})
## @deftypefnx {Function File} {@var{u} =} gallery ("kahan", @var{n}, @var{theta}, @var{pert})
## Create a @nospell{Kahan} matrix (upper trapezoidal).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("kms", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("kms", @var{n}, @var{rho})
## Create a @nospell{Kac-Murdock-Szego} Toeplitz matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{b} =} gallery ("krylov", @var{a})
## @deftypefnx {Function File} {@var{b} =} gallery ("krylov", @var{a}, @var{x})
## @deftypefnx {Function File} {@var{b} =} gallery ("krylov", @var{a}, @var{x}, @var{j})
## Create a Krylov matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("lauchli", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("lauchli", @var{n}, @var{mu})
## Create a @nospell{Lauchli} matrix (rectangular).
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("lehmer", @var{n})
## Create a @nospell{Lehmer} matrix (symmetric positive definite).
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{t} =} gallery ("lesp", @var{n})
## Create a tridiagonal matrix with real, sensitive eigenvalues.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("lotkin", @var{n})
## Create a @nospell{Lotkin} matrix.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("minij", @var{n})
## Create a symmetric positive definite matrix MIN(i,j).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("moler", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("moler", @var{n}, @var{alpha})
## Create a @nospell{Moler} matrix (symmetric positive definite).
##
## @end deftypefn
##
## @deftypefn {Function File} {[@var{a}, @var{t}] =} gallery ("neumann", @var{n})
## Create a singular matrix from the discrete Neumann problem (sparse).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("normaldata", [@var{M} @var{N} @dots{}], @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("normaldata", @var{M}, @var{N}, @dots{}, @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("normaldata", @dots{}, "@var{class}")
## Create a matrix with random samples from the standard normal distribution
## (mean = 0, std = 1).
##
## The first input is a matrix of dimensions describing the size of the output.
## The dimensions can also be input as comma-separated arguments.
##
## The input @var{j} is an integer index in the range [0, 2^32-1].  The values
## of the output matrix are always exactly the same (reproducibility) for a
## given size input and @var{j} index.
##
## The final optional argument determines the class of the resulting matrix.
## Possible values for @var{class}: @qcode{"single"}, @qcode{"double"}.
## The default is @qcode{"double"}.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{q} =} gallery ("orthog", @var{n})
## @deftypefnx {Function File} {@var{q} =} gallery ("orthog", @var{n}, @var{k})
## Create orthogonal and nearly orthogonal matrices.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("parter", @var{n})
## Create a @nospell{Parter} matrix (a Toeplitz matrix with singular values
## near pi).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{p} =} gallery ("pei", @var{n})
## @deftypefnx {Function File} {@var{p} =} gallery ("pei", @var{n}, @var{alpha})
## Create a Pei matrix.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("Poisson", @var{n})
## Create a block tridiagonal matrix from Poisson's equation (sparse).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("prolate", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("prolate", @var{n}, @var{w})
## Create a prolate matrix (symmetric, ill-conditioned Toeplitz matrix).
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{h} =} gallery ("randhess", @var{x})
## Create a random, orthogonal upper Hessenberg matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("rando", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("rando", @var{n}, @var{k})
## Create a random matrix with elements -1, 0 or 1.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("randsvd", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("randsvd", @var{n}, @var{kappa})
## @deftypefnx {Function File} {@var{a} =} gallery ("randsvd", @var{n}, @var{kappa}, @var{mode})
## @deftypefnx {Function File} {@var{a} =} gallery ("randsvd", @var{n}, @var{kappa}, @var{mode}, @var{kl})
## @deftypefnx {Function File} {@var{a} =} gallery ("randsvd", @var{n}, @var{kappa}, @var{mode}, @var{kl}, @var{ku})
## Create a random matrix with pre-assigned singular values.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("redheff", @var{n})
## Create a zero and ones matrix of @nospell{Redheffer} associated with the
## Riemann hypothesis.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("riemann", @var{n})
## Create a matrix associated with the Riemann hypothesis.
##
## @end deftypefn
##
## @deftypefn {Function File} {@var{a} =} gallery ("ris", @var{n})
## Create a symmetric Hankel matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("smoke", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("smoke", @var{n}, @var{k})
## Create a complex matrix, with a `smoke ring' pseudospectrum.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{t} =} gallery ("toeppd", @var{n})
## @deftypefnx {Function File} {@var{t} =} gallery ("toeppd", @var{n}, @var{m})
## @deftypefnx {Function File} {@var{t} =} gallery ("toeppd", @var{n}, @var{m}, @var{w})
## @deftypefnx {Function File} {@var{t} =} gallery ("toeppd", @var{n}, @var{m}, @var{w}, @var{theta})
## Create a symmetric positive definite Toeplitz matrix.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{p} =} gallery ("toeppen", @var{n})
## @deftypefnx {Function File} {@var{p} =} gallery ("toeppen", @var{n}, @var{a})
## @deftypefnx {Function File} {@var{p} =} gallery ("toeppen", @var{n}, @var{a}, @var{b})
## @deftypefnx {Function File} {@var{p} =} gallery ("toeppen", @var{n}, @var{a}, @var{b}, @var{c})
## @deftypefnx {Function File} {@var{p} =} gallery ("toeppen", @var{n}, @var{a}, @var{b}, @var{c}, @var{d})
## @deftypefnx {Function File} {@var{p} =} gallery ("toeppen", @var{n}, @var{a}, @var{b}, @var{c}, @var{d}, @var{e})
## Create a pentadiagonal Toeplitz matrix (sparse).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("tridiag", @var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {@var{a} =} gallery ("tridiag", @var{n})
## @deftypefnx {Function File} {@var{a} =} gallery ("tridiag", @var{n}, @var{c}, @var{d}, @var{e})
## Create a tridiagonal matrix (sparse).
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{t} =} gallery ("triw", @var{n})
## @deftypefnx {Function File} {@var{t} =} gallery ("triw", @var{n}, @var{alpha})
## @deftypefnx {Function File} {@var{t} =} gallery ("triw", @var{n}, @var{alpha}, @var{k})
## Create an upper triangular matrix discussed by
## @nospell{Kahan, Golub, and Wilkinson}.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("uniformdata", [@var{M} @var{N} @dots{}], @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("uniformdata", @var{M}, @var{N}, @dots{}, @var{j})
## @deftypefnx {Function File} {@var{a} =} gallery ("uniformdata", @dots{}, "@var{class}")
## Create a matrix with random samples from the standard uniform distribution
## (range [0,1]).
##
## The first input is a matrix of dimensions describing the size of the output.
## The dimensions can also be input as comma-separated arguments.
##
## The input @var{j} is an integer index in the range [0, 2^32-1].  The values
## of the output matrix are always exactly the same (reproducibility) for a
## given size input and @var{j} index.
##
## The final optional argument determines the class of the resulting matrix.
## Possible values for @var{class}: @qcode{"single"}, @qcode{"double"}.
## The default is @qcode{"double"}.
##
## @end deftypefn
##
## @deftypefn  {Function File} {@var{a} =} gallery ("wathen", @var{nx}, @var{ny})
## @deftypefnx {Function File} {@var{a} =} gallery ("wathen", @var{nx}, @var{ny}, @var{k})
## Create the @nospell{Wathen} matrix.
##
## @end deftypefn
##
## @deftypefn {Function File} {[@var{a}, @var{b}] =} gallery ("wilk", @var{n})
## Create various specific matrices devised/discussed by Wilkinson.
##
## @end deftypefn
    
    ## Code for most of the individual matrices (except binomial, gcdmat,
## integerdata, leslie, normaldata, randcolu, randcorr, randjorth, sampling,
## uniformdata) by Nicholas .J. Higham <Nicholas.J.Higham@manchester.ac.uk>
## Adapted for Octave and into single gallery function by Carn Draug
    
    
@function
def gallery(name=None,varargin=None,*args,**kwargs):
    varargin = gallery.varargin
    nargin = gallery.nargin

    if (nargin < 1):
        print_usage()
    else:
        if (logical_not(ischar(name))):
            error('gallery: NAME must be a string.')
    
    ## NOTE: there isn't a lot of input check in the individual functions
  ## that actually build the functions.  This is by design. The original
  ## code by Higham did not perform it and was propagated to Matlab, so
  ## for compatibility, we also don't make it. For example, arguments
  ## that behave as switches, and in theory accepting a value of 0 or 1,
  ## will use a value of 0, for any value other than 1 (only check made
  ## is if the value is equal to 1). It will often also accept string
  ## values instead of numeric. Only input check added was where it
  ## would be causing an error anyway.
    
    ## we will always want to return at least 1 output
    n_out=copy(nargout)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:428
    if (n_out == 0):
        n_out=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:430
    
    if 'binomial' == (tolower(name)):
        error('gallery: matrix %s not implemented.',name)
    else:
        if 'cauchy' == (tolower(name)):
            varargout[1:n_out]=cauchy(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:436
        else:
            if 'chebspec' == (tolower(name)):
                varargout[1:n_out]=chebspec(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:437
            else:
                if 'chebvand' == (tolower(name)):
                    varargout[1:n_out]=chebvand(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:438
                else:
                    if 'chow' == (tolower(name)):
                        varargout[1:n_out]=chow(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:439
                    else:
                        if 'circul' == (tolower(name)):
                            varargout[1:n_out]=circul(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:440
                        else:
                            if 'clement' == (tolower(name)):
                                varargout[1:n_out]=clement(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:441
                            else:
                                if 'compar' == (tolower(name)):
                                    varargout[1:n_out]=compar(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:442
                                else:
                                    if 'condex' == (tolower(name)):
                                        varargout[1:n_out]=condex(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:443
                                    else:
                                        if 'cycol' == (tolower(name)):
                                            varargout[1:n_out]=cycol(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:444
                                        else:
                                            if 'dorr' == (tolower(name)):
                                                varargout[1:n_out]=dorr(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:445
                                            else:
                                                if 'dramadah' == (tolower(name)):
                                                    varargout[1:n_out]=dramadah(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:446
                                                else:
                                                    if 'fiedler' == (tolower(name)):
                                                        varargout[1:n_out]=fiedler(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:447
                                                    else:
                                                        if 'forsythe' == (tolower(name)):
                                                            varargout[1:n_out]=forsythe(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:448
                                                        else:
                                                            if 'frank' == (tolower(name)):
                                                                varargout[1:n_out]=frank(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:449
                                                            else:
                                                                if 'gearmat' == (tolower(name)):
                                                                    varargout[1:n_out]=gearmat(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:450
                                                                else:
                                                                    if 'gcdmat' == (tolower(name)):
                                                                        varargout[1:n_out]=gcdmat(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:451
                                                                    else:
                                                                        if 'grcar' == (tolower(name)):
                                                                            varargout[1:n_out]=grcar(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:452
                                                                        else:
                                                                            if 'hanowa' == (tolower(name)):
                                                                                varargout[1:n_out]=hanowa(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:453
                                                                            else:
                                                                                if 'house' == (tolower(name)):
                                                                                    varargout[1:n_out]=house(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:454
                                                                                else:
                                                                                    if 'integerdata' == (tolower(name)):
                                                                                        varargout[1:n_out]=integerdata(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:455
                                                                                    else:
                                                                                        if 'invhess' == (tolower(name)):
                                                                                            varargout[1:n_out]=invhess(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:456
                                                                                        else:
                                                                                            if 'invol' == (tolower(name)):
                                                                                                varargout[1:n_out]=invol(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:457
                                                                                            else:
                                                                                                if 'ipjfact' == (tolower(name)):
                                                                                                    varargout[1:n_out]=ipjfact(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:458
                                                                                                else:
                                                                                                    if 'jordbloc' == (tolower(name)):
                                                                                                        varargout[1:n_out]=jordbloc(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:459
                                                                                                    else:
                                                                                                        if 'kahan' == (tolower(name)):
                                                                                                            varargout[1:n_out]=kahan(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:460
                                                                                                        else:
                                                                                                            if 'kms' == (tolower(name)):
                                                                                                                varargout[1:n_out]=kms(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:461
                                                                                                            else:
                                                                                                                if 'krylov' == (tolower(name)):
                                                                                                                    varargout[1:n_out]=krylov(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:462
                                                                                                                else:
                                                                                                                    if 'lauchli' == (tolower(name)):
                                                                                                                        varargout[1:n_out]=lauchli(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:463
                                                                                                                    else:
                                                                                                                        if 'lehmer' == (tolower(name)):
                                                                                                                            varargout[1:n_out]=lehmer(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:464
                                                                                                                        else:
                                                                                                                            if 'leslie' == (tolower(name)):
                                                                                                                                error('gallery: matrix %s not implemented.',name)
                                                                                                                            else:
                                                                                                                                if 'lesp' == (tolower(name)):
                                                                                                                                    varargout[1:n_out]=lesp(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:467
                                                                                                                                else:
                                                                                                                                    if 'lotkin' == (tolower(name)):
                                                                                                                                        varargout[1:n_out]=lotkin(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:468
                                                                                                                                    else:
                                                                                                                                        if 'minij' == (tolower(name)):
                                                                                                                                            varargout[1:n_out]=minij(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:469
                                                                                                                                        else:
                                                                                                                                            if 'moler' == (tolower(name)):
                                                                                                                                                varargout[1:n_out]=moler(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:470
                                                                                                                                            else:
                                                                                                                                                if 'neumann' == (tolower(name)):
                                                                                                                                                    varargout[1:n_out]=neumann(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:471
                                                                                                                                                else:
                                                                                                                                                    if 'normaldata' == (tolower(name)):
                                                                                                                                                        varargout[1:n_out]=normaldata(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:472
                                                                                                                                                    else:
                                                                                                                                                        if 'orthog' == (tolower(name)):
                                                                                                                                                            varargout[1:n_out]=orthog(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:473
                                                                                                                                                        else:
                                                                                                                                                            if 'parter' == (tolower(name)):
                                                                                                                                                                varargout[1:n_out]=parter(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:474
                                                                                                                                                            else:
                                                                                                                                                                if 'pei' == (tolower(name)):
                                                                                                                                                                    varargout[1:n_out]=pei(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:475
                                                                                                                                                                else:
                                                                                                                                                                    if 'poisson' == (tolower(name)):
                                                                                                                                                                        varargout[1:n_out]=poisson(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:476
                                                                                                                                                                    else:
                                                                                                                                                                        if 'prolate' == (tolower(name)):
                                                                                                                                                                            varargout[1:n_out]=prolate(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:477
                                                                                                                                                                        else:
                                                                                                                                                                            if 'randcolu' == (tolower(name)):
                                                                                                                                                                                error('gallery: matrix %s not implemented.',name)
                                                                                                                                                                            else:
                                                                                                                                                                                if 'randcorr' == (tolower(name)):
                                                                                                                                                                                    error('gallery: matrix %s not implemented.',name)
                                                                                                                                                                                else:
                                                                                                                                                                                    if 'randhess' == (tolower(name)):
                                                                                                                                                                                        varargout[1:n_out]=randhess(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:482
                                                                                                                                                                                    else:
                                                                                                                                                                                        if 'randjorth' == (tolower(name)):
                                                                                                                                                                                            error('gallery: matrix %s not implemented.',name)
                                                                                                                                                                                        else:
                                                                                                                                                                                            if 'rando' == (tolower(name)):
                                                                                                                                                                                                varargout[1:n_out]=rando(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:485
                                                                                                                                                                                            else:
                                                                                                                                                                                                if 'randsvd' == (tolower(name)):
                                                                                                                                                                                                    varargout[1:n_out]=randsvd(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:486
                                                                                                                                                                                                else:
                                                                                                                                                                                                    if 'redheff' == (tolower(name)):
                                                                                                                                                                                                        varargout[1:n_out]=redheff(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:487
                                                                                                                                                                                                    else:
                                                                                                                                                                                                        if 'riemann' == (tolower(name)):
                                                                                                                                                                                                            varargout[1:n_out]=riemann(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:488
                                                                                                                                                                                                        else:
                                                                                                                                                                                                            if 'ris' == (tolower(name)):
                                                                                                                                                                                                                varargout[1:n_out]=ris(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:489
                                                                                                                                                                                                            else:
                                                                                                                                                                                                                if 'sampling' == (tolower(name)):
                                                                                                                                                                                                                    error('gallery: matrix %s not implemented.',name)
                                                                                                                                                                                                                else:
                                                                                                                                                                                                                    if 'smoke' == (tolower(name)):
                                                                                                                                                                                                                        varargout[1:n_out]=smoke(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:492
                                                                                                                                                                                                                    else:
                                                                                                                                                                                                                        if 'toeppd' == (tolower(name)):
                                                                                                                                                                                                                            varargout[1:n_out]=toeppd(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:493
                                                                                                                                                                                                                        else:
                                                                                                                                                                                                                            if 'toeppen' == (tolower(name)):
                                                                                                                                                                                                                                varargout[1:n_out]=toeppen(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:494
                                                                                                                                                                                                                            else:
                                                                                                                                                                                                                                if 'tridiag' == (tolower(name)):
                                                                                                                                                                                                                                    varargout[1:n_out]=tridiag(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:495
                                                                                                                                                                                                                                else:
                                                                                                                                                                                                                                    if 'triw' == (tolower(name)):
                                                                                                                                                                                                                                        varargout[1:n_out]=triw(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:496
                                                                                                                                                                                                                                    else:
                                                                                                                                                                                                                                        if 'uniformdata' == (tolower(name)):
                                                                                                                                                                                                                                            varargout[1:n_out]=uniformdata(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:497
                                                                                                                                                                                                                                        else:
                                                                                                                                                                                                                                            if 'wathen' == (tolower(name)):
                                                                                                                                                                                                                                                varargout[1:n_out]=wathen(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:498
                                                                                                                                                                                                                                            else:
                                                                                                                                                                                                                                                if 'wilk' == (tolower(name)):
                                                                                                                                                                                                                                                    varargout[1:n_out]=wilk(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:499
                                                                                                                                                                                                                                                else:
                                                                                                                                                                                                                                                    error('gallery: unknown matrix with NAME %s',name)
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def cauchy(x=None,y=None,*args,**kwargs):
    varargin = cauchy.varargin
    nargin = cauchy.nargin

    ##CAUCHY  Cauchy matrix.
  ##  C = CAUCHY(X, Y), where X, Y are N-vectors, is the N-by-N matrix
  ##  with C(i,j) = 1/(X(i)+Y(j)).   By default, Y = X.
  ##  Special case: if X is a scalar CAUCHY(X) is the same as CAUCHY(1:X).
  ##  Explicit formulas are known for DET(C) (which is nonzero if X and Y
  ##  both have distinct elements) and the elements of INV(C).
  ##  C is totally positive if 0 < X(1) < ... < X(N) and
  ##  0 < Y(1) < ... < Y(N).
  ##
  ##  References:
  ##  N.J. Higham, Accuracy and Stability of Numerical Algorithms,
  ##    Society for Industrial and Applied Mathematics, Philadelphia, PA,
  ##    USA, 1996; sec. 26.1.
  ##  D.E. Knuth, The Art of Computer Programming, Volume 1,
  ##    Fundamental Algorithms, second edition, Addison-Wesley, Reading,
  ##    Massachusetts, 1973, p. 36.
  ##  E.E. Tyrtyshnikov, Cauchy-Toeplitz matrices and some applications,
  ##    Linear Algebra and Appl., 149 (1991), pp. 1-18.
  ##    O. Taussky and M. Marcus, Eigenvalues of finite matrices, in
  ##    Survey of Numerical Analysis, J. Todd, ed., McGraw-Hill, New York,
  ##    pp. 279-313, 1962. (States the totally positive property on p. 295.)
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for cauchy matrix.')
    else:
        if (logical_not(isnumeric(x))):
            error('gallery: X must be numeric for cauchy matrix.')
        else:
            if (nargin == 2 and logical_not(isnumeric(y))):
                error('gallery: Y must be numeric for cauchy matrix.')
    
    n=numel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:537
    if (isscalar(x) and fix(x) == x):
        n=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:539
        x=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:540
    else:
        if (n > 1 and isvector(x)):
            ## do nothing
            pass
        else:
            error('gallery: X be an integer or a vector for cauchy matrix.')
    
    if (nargin == 1):
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:548
    
    ## Ensure x and y are column vectors
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:552
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:553
    if (numel(x) != numel(y)):
        error('gallery: X and Y must be vectors of same length for cauchy matrix.')
    
    C=dot(x,ones(1,n)) + dot(ones(n,1),y.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:558
    C=ones(n) / C
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:559
    return C
    
if __name__ == '__main__':
    pass
    
    
@function
def chebspec(n=None,k=0,*args,**kwargs):
    varargin = chebspec.varargin
    nargin = chebspec.nargin

    ## CHEBSPEC  Chebyshev spectral differentiation matrix.
  ##   C = CHEBSPEC(N, K) is a Chebyshev spectral differentiation
  ##   matrix of order N.  K = 0 (the default) or 1.
  ##   For K = 0 (`no boundary conditions'), C is nilpotent, with
  ##       C^N = 0 and it has the null vector ONES(N,1).
  ##       C is similar to a Jordan block of size N with eigenvalue zero.
  ##   For K = 1, C is nonsingular and well-conditioned, and its eigenvalues
  ##       have negative real parts.
  ##   For both K, the computed eigenvector matrix X from EIG is
  ##       ill-conditioned (MESH(REAL(X)) is interesting).
  ##
  ##   References:
  ##   C. Canuto, M.Y. Hussaini, A. Quarteroni and T.A. Zang, Spectral
  ##      Methods in Fluid Dynamics, Springer-Verlag, Berlin, 1988; p. 69.
  ##   L.N. Trefethen and M.R. Trummer, An instability phenomenon in
  ##      spectral methods, SIAM J. Numer. Anal., 24 (1987), pp. 1008-1023.
  ##   D. Funaro, Computing the inverse of the Chebyshev collocation
  ##      derivative, SIAM J. Sci. Stat. Comput., 9 (1988), pp. 1050-1057.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for chebspec matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for chebspec matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a scalar for chebspec matrix.')
    
    ## k = 1 case obtained from k = 0 case with one bigger n.
    if (0) == (k):
        pass
    else:
        if (1) == (k):
            n=n + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:593
        else:
            error('gallery: unknown K \'%d\' for chebspec matrix.',k)
    
    n=n - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:598
    C=zeros(n + 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:599
    one=ones(n + 1,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:601
    x=cos(dot((arange(0,n)).T,(pi / n)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:602
    d=ones(n + 1,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:603
    d[1]=2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:604
    d[n + 1]=2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:605
    
    C=(dot(d,(one / d).T)) / (dot(x,one.T) - dot(one,x.T) + eye(size(C)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:608
    
    C[1,1]=(dot(2,n ** 2) + 1) / 6
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:611
    for i in arange(2,n + 1).reshape(-1):
        if (rem(i,2) == 0):
            C[:,i]=- C[:,i]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:614
            C[i,:]=- C[i,:]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:615
        if (i < n + 1):
            C[i,i]=- x[i] / (dot(2,(1 - x[i] ** 2)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:618
        else:
            C[n + 1,n + 1]=- C[1,1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:620
    
    if (k == 1):
        C=C[2:n + 1,2:n + 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:625
    
    return C
    
if __name__ == '__main__':
    pass
    
    
@function
def chebvand(m=None,p=None,*args,**kwargs):
    varargin = chebvand.varargin
    nargin = chebvand.nargin

    ## CHEBVAND Vandermonde-like matrix for the Chebyshev polynomials.
  ##   C = CHEBVAND(P), where P is a vector, produces the (primal)
  ##   Chebyshev Vandermonde matrix based on the points P,
  ##   i.e., C(i,j) = T_{i-1}(P(j)), where T_{i-1} is the Chebyshev
  ##   polynomial of degree i-1.
  ##   CHEBVAND(M,P) is a rectangular version of CHEBVAND(P) with M rows.
  ##   Special case: If P is a scalar then P equally spaced points on
  ##                 [0,1] are used.
  ##
  ##   Reference:
  ##   N.J. Higham, Stability analysis of algorithms for solving confluent
  ##     Vandermonde-like systems, SIAM J. Matrix Anal. Appl., 11 (1990),
  ##     pp. 23-41.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for chebvand matrix.')
    
    ## because the order of the arguments changes if nargin is 1 or 2 ...
    
    if (nargin == 1):
        p=copy(m)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:651
    
    n=numel(p)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:654
    if (logical_not(isnumeric(p))):
        error('gallery: P must be numeric for chebvand matrix.')
    else:
        if (isscalar(p) and fix(p) == p):
            n=copy(p)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:658
            p=linspace(0,1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:659
        else:
            if (n > 1 and isvector(p)):
                ## do nothing
                pass
    
    p=ravel(p).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:663
    
    if (nargin == 1):
        m=copy(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:666
    else:
        if (logical_not(isnumeric(m)) or logical_not(isscalar(m))):
            error('gallery: M must be a scalar for chebvand matrix.')
    
    C=ones(m,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:671
    if (m != 1):
        C[2,:]=p
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:673
        for i in arange(3,m).reshape(-1):
            C[i,:]=multiply(dot(2.0,p),C[i - 1,:]) - C[i - 2,:]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:676
    
    return C
    
if __name__ == '__main__':
    pass
    
    
@function
def chow(n=None,alpha=1,delta=0,*args,**kwargs):
    varargin = chow.varargin
    nargin = chow.nargin

    ## CHOW    Chow matrix - a singular Toeplitz lower Hessenberg matrix.
  ##   A = CHOW(N, ALPHA, DELTA) is a Toeplitz lower Hessenberg matrix
  ##   A = H(ALPHA) + DELTA*EYE, where H(i,j) = ALPHA^(i-j+1).
  ##   H(ALPHA) has p = FLOOR(N/2) zero eigenvalues, the rest being
  ##   4*ALPHA*COS( k*PI/(N+2) )^2, k=1:N-p.
  ##   Defaults: ALPHA = 1, DELTA = 0.
  ##
  ##   References:
  ##   T.S. Chow, A class of Hessenberg matrices with known
  ##      eigenvalues and inverses, SIAM Review, 11 (1969), pp. 391-395.
  ##   G. Fairweather, On the eigenvalues and eigenvectors of a class of
  ##      Hessenberg matrices, SIAM Review, 13 (1971), pp. 220-221.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for chow matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for chow matrix.')
        else:
            if (logical_not(isnumeric(alpha)) or logical_not(isscalar(alpha))):
                error('gallery: ALPHA must be a scalar for chow matrix.')
            else:
                if (logical_not(isnumeric(delta)) or logical_not(isscalar(delta))):
                    error('gallery: DELTA must be a scalar for chow matrix.')
    
    A=toeplitz(alpha ** (arange(1,n)),cat(alpha,1,zeros(1,n - 2))) + dot(delta,eye(n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:705
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def circul(v=None,*args,**kwargs):
    varargin = circul.varargin
    nargin = circul.nargin

    ## CIRCUL  Circulant matrix.
  ##   C = CIRCUL(V) is the circulant matrix whose first row is V.
  ##   (A circulant matrix has the property that each row is obtained
  ##   from the previous one by cyclically permuting the entries one step
  ##   forward; it is a special Toeplitz matrix in which the diagonals
  ##   `wrap round'.)
  ##   Special case: if V is a scalar then C = CIRCUL(1:V).
  ##   The eigensystem of C (N-by-N) is known explicitly.   If t is an Nth
  ##   root of unity, then the inner product of V with W = [1 t t^2 ... t^N]
  ##   is an eigenvalue of C, and W(N:-1:1) is an eigenvector of C.
  ##
  ##   Reference:
  ##   P.J. Davis, Circulant Matrices, John Wiley, 1977.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for circul matrix.')
    else:
        if (logical_not(isnumeric(v))):
            error('gallery: V must be numeric for circul matrix.')
    
    n=numel(v)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:729
    if (isscalar(v) and fix(v) == v):
        n=copy(v)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:731
        v=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:732
    else:
        if (n > 1 and isvector(v)):
            ## do nothing
            pass
        else:
            error('gallery: X must be a scalar or a vector for circul matrix.')
    
    v=ravel(v).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:739
    
    C=toeplitz(cat(v[1],v[n:- 1:2]),v)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:740
    return C
    
if __name__ == '__main__':
    pass
    
    
@function
def clement(n=None,k=0,*args,**kwargs):
    varargin = clement.varargin
    nargin = clement.nargin

    ## CLEMENT   Clement matrix - tridiagonal with zero diagonal entries.
  ##   CLEMENT(N, K) is a tridiagonal matrix with zero diagonal entries
  ##   and known eigenvalues.  It is singular if N is odd.  About 64
  ##   percent of the entries of the inverse are zero.  The eigenvalues
  ##   are plus and minus the numbers N-1, N-3, N-5, ..., (1 or 0).
  ##   For K = 0 (the default) the matrix is unsymmetric, while for
  ##   K = 1 it is symmetric.
  ##   CLEMENT(N, 1) is diagonally similar to CLEMENT(N).
  ##
  ##   Similar properties hold for TRIDIAG(X,Y,Z) where Y = ZEROS(N,1).
  ##   The eigenvalues still come in plus/minus pairs but they are not
  ##   known explicitly.
  ##
  ##   References:
  ##   P.A. Clement, A class of triple-diagonal matrices for test
  ##      purposes, SIAM Review, 1 (1959), pp. 50-52.
  ##   A. Edelman and E. Kostlan, The road from Kac's matrix to Kac's
  ##      random polynomials. In John~G. Lewis, editor, Proceedings of
  ##      the Fifth SIAM Conference on Applied Linear Algebra Society
  ##      for Industrial and Applied Mathematics, Philadelphia, 1994,
  ##      pp. 503-507.
  ##   O. Taussky and J. Todd, Another look at a matrix of Mark Kac,
  ##      Linear Algebra and Appl., 150 (1991), pp. 341-360.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for clement matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for clement matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for clement matrix.')
    
    n=n - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:776
    x=arange(n,1,- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:777
    z=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:778
    if (k == 0):
        A=diag(x,- 1) + diag(z,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:781
    else:
        if (k == 1):
            y=sqrt(multiply(x,z))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:783
            A=diag(y,- 1) + diag(y,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:784
        else:
            error('gallery: K must have a value of 0 or 1 for clement matrix.')
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def compar(A=None,k=0,*args,**kwargs):
    varargin = compar.varargin
    nargin = compar.nargin

    ## COMP    Comparison matrices.
  ##   COMP(A) is DIAG(B) - TRIL(B,-1) - TRIU(B,1), where B = ABS(A).
  ##   COMP(A, 1) is A with each diagonal element replaced by its
  ##   absolute value, and each off-diagonal element replaced by minus
  ##   the absolute value of the largest element in absolute value in
  ##   its row.  However, if A is triangular COMP(A, 1) is too.
  ##   COMP(A, 0) is the same as COMP(A).
  ##   COMP(A) is often denoted by M(A) in the literature.
  ##
  ##   Reference (e.g.):
  ##   N.J. Higham, A survey of condition number estimation for
  ##   triangular matrices, SIAM Review, 29 (1987), pp. 575-596.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for compar matrix.')
    else:
        if (logical_not(isnumeric(A)) or ndims(A) != 2):
            error('gallery: A must be a 2-D matrix for compar matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for compar matrix.')
    
    m,n=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:812
    p=min(m,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:813
    if (k == 0):
        ## This code uses less temporary storage than
    ## the `high level' definition above.
        C=- abs(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:818
        for j in arange(1,p).reshape(-1):
            C[j,j]=abs(A[j,j])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:820
    else:
        if (k == 1):
            C=A.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:824
            for j in arange(1,p).reshape(-1):
                C[k,k]=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:826
            mx=max(abs(C))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:828
            C=dot(- mx.T,ones(1,n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:829
            for j in arange(1,p).reshape(-1):
                C[j,j]=abs(A[j,j])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:831
            if (all(A == tril(A))):
                C=tril(C)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:833
            if (all(A == triu(A))):
                C=triu(C)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:834
        else:
            error('gallery: K must have a value of 0 or 1 for compar matrix.')
    
    return C
    
if __name__ == '__main__':
    pass
    
    
@function
def condex(n=None,k=4,theta=100,*args,**kwargs):
    varargin = condex.varargin
    nargin = condex.nargin

    ## CONDEX   `Counterexamples' to matrix condition number estimators.
  ##   CONDEX(N, K, THETA) is a `counterexample' matrix to a condition
  ##   estimator.  It has order N and scalar parameter THETA (default 100).
  ##   If N is not equal to the `natural' size of the matrix then
  ##   the matrix is padded out with an identity matrix to order N.
  ##   The matrix, its natural size, and the estimator to which it applies
  ##   are specified by K (default K = 4) as follows:
  ##       K = 1:   4-by-4,     LINPACK (RCOND)
  ##       K = 2:   3-by-3,     LINPACK (RCOND)
  ##       K = 3:   arbitrary,  LINPACK (RCOND) (independent of THETA)
  ##       K = 4:   N >= 4,     SONEST (Higham 1988)
  ##   (Note that in practice the K = 4 matrix is not usually a
  ##    counterexample because of the rounding errors in forming it.)
  ##
  ##   References:
  ##   A.K. Cline and R.K. Rew, A set of counter-examples to three
  ##      condition number estimators, SIAM J. Sci. Stat. Comput.,
  ##      4 (1983), pp. 602-611.
  ##   N.J. Higham, FORTRAN codes for estimating the one-norm of a real or
  ##      complex matrix, with applications to condition estimation
  ##      (Algorithm 674), ACM Trans. Math. Soft., 14 (1988), pp. 381-396.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for condex matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for condex matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for condex matrix.')
            else:
                if (logical_not(isnumeric(theta)) or logical_not(isscalar(theta))):
                    error('gallery: THETA must be a numeric scalar for condex matrix.')
    
    if (k == 1):
        A=matlabarray(cat(1,- 1,dot(- 2,theta),0,0,1,theta,- theta,0,1,1 + theta,- (theta + 1),0,0,0,theta))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:876
    else:
        if (k == 2):
            A=matlabarray(cat(1,1 - 2 / theta ** 2,- 2,0,1 / theta,- 1 / theta,0,0,1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:882
        else:
            if (k == 3):
                A=gallery('triw',n,- 1).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:887
                A[n,n]=- 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:888
            else:
                if (k == 4):
                    x=ones(n,3)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:891
                    x[2:n,2]=zeros(n - 1,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:892
                    ## Third col is special vector b in SONEST
                    x[:,3]=multiply((- 1) ** cat(arange(0,n - 1)).T,(1 + cat(arange(0,n - 1)).T / (n - 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:895
                    Q=orth(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:897
                    P=eye(n) - dot(Q,Q.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:898
                    A=eye(n) + dot(theta,P)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:899
                else:
                    error('gallery: unknown estimator K \'%d\' for condex matrix.',k)
    
    ## Pad out with identity as necessary.
    m=columns(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:906
    if (m < n):
        for i in arange(n,m + 1,- 1).reshape(-1):
            A[i,i]=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:909
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def cycol(n=None,k=None,*args,**kwargs):
    varargin = cycol.varargin
    nargin = cycol.nargin

    ## CYCOL   Matrix whose columns repeat cyclically.
  ##   A = CYCOL([M N], K) is an M-by-N matrix of the form A = B(1:M,1:N)
  ##   where B = [C C C...] and C = RANDN(M, K).  Thus A's columns repeat
  ##   cyclically, and A has rank at most K.   K need not divide N.
  ##   K defaults to ROUND(N/4).
  ##   CYCOL(N, K), where N is a scalar, is the same as CYCOL([N N], K).
  ##
  ##   This type of matrix can lead to underflow problems for Gaussian
  ##   elimination: see NA Digest Volume 89, Issue 3 (January 22, 1989).
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for cycol matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2)) or fix(n) != n):
            error('gallery: N must be a 1 or 2 element integer for cycol matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a scalar for cycol matrix.')
    
    ## Parameter n specifies dimension: m-by-n
    m=n[1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:934
    n=n[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:935
    if (nargin < 2):
        k=max(round(n / 4),1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:938
    
    A=randn(m,k)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:941
    for i in arange(2,ceil(n / k)).reshape(-1):
        A=matlabarray(cat(A,A[:,1:k]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:943
    
    A=A[:,1:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:945
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def dorr(n=None,theta=0.01,*args,**kwargs):
    varargin = dorr.varargin
    nargin = dorr.nargin

    ## DORR  Dorr matrix - diagonally dominant, ill conditioned, tridiagonal.
  ##   [C, D, E] = DORR(N, THETA) returns the vectors defining a row diagonally
  ##   dominant, tridiagonal M-matrix that is ill conditioned for small
  ##   values of the parameter THETA >= 0.
  ##   If only one output parameter is supplied then
  ##   C = FULL(TRIDIAG(C,D,E)), i.e., the matrix iself is returned.
  ##   The columns of INV(C) vary greatly in norm.  THETA defaults to 0.01.
  ##   The amount of diagonal dominance is given by (ignoring rounding errors):
  ##         COMP(C)*ONES(N,1) = THETA*(N+1)^2 * [1 0 0 ... 0 1]'.
  ##
  ##   Reference:
  ##   F.W. Dorr, An example of ill-conditioning in the numerical
  ##   solution of singular perturbation problems, Math. Comp., 25 (1971),
  ##   pp. 271-283.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 or 2 arguments are required for dorr matrix.')
    else:
        if (logical_not(isscalar(n)) or logical_not(isnumeric(n)) or fix(n) != n):
            error('gallery: N must be an integer for dorr matrix.')
        else:
            if (logical_not(isscalar(theta)) or logical_not(isnumeric(theta))):
                error('gallery: THETA must be a numeric scalar for dorr matrix.')
    
    c=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:972
    e=copy(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:973
    d=copy(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:974
    
    h=1 / (n + 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:977
    m=floor((n + 1) / 2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:978
    term=theta / h ** 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:979
    i=(arange(1,m)).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:981
    c[i]=dot(- term,ones(m,1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:982
    e[i]=c[i] - (0.5 - dot(i,h)) / h
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:983
    d[i]=- (c[i] + e[i])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:984
    i=(arange(m + 1,n)).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:986
    e[i]=dot(- term,ones(n - m,1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:987
    c[i]=e[i] + (0.5 - dot(i,h)) / h
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:988
    d[i]=- (c[i] + e[i])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:989
    c=c[2:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:991
    e=e[1:n - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:992
    if (nargout <= 1):
        c=tridiag(c,d,e)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:995
    
    return c,d,e
    
if __name__ == '__main__':
    pass
    
    
@function
def dramadah(n=None,k=1,*args,**kwargs):
    varargin = dramadah.varargin
    nargin = dramadah.nargin

    ## DRAMADAH  A (0,1) matrix whose inverse has large integer entries.
  ##   An anti-Hadamard matrix A is a matrix with elements 0 or 1 for
  ##   which MU(A) := NORM(INV(A),'FRO') is maximal.
  ##   A = DRAMADAH(N, K) is an N-by-N (0,1) matrix for which MU(A) is
  ##   relatively large, although not necessarily maximal.
  ##   Available types (the default is K = 1):
  ##   K = 1: A is Toeplitz, with ABS(DET(A)) = 1, and MU(A) > c(1.75)^N,
  ##          where c is a constant.
  ##   K = 2: A is upper triangular and Toeplitz.
  ##   The inverses of both types have integer entries.
  ##
  ##   Another interesting (0,1) matrix:
  ##   K = 3: A has maximal determinant among (0,1) lower Hessenberg
  ##   matrices: det(A) = the n'th Fibonacci number.  A is Toeplitz.
  ##   The eigenvalues have an interesting distribution in the complex
  ##   plane.
  ##
  ##   References:
  ##   R.L. Graham and N.J.A. Sloane, Anti-Hadamard matrices,
  ##      Linear Algebra and Appl., 62 (1984), pp. 113-137.
  ##   L. Ching, The maximum determinant of an nxn lower Hessenberg
  ##      (0,1) matrix, Linear Algebra and Appl., 183 (1993), pp. 147-153.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for dramadah matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for dramadah matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for dramadah matrix.')
    
    if (1) == (k):
        c=ones(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1033
        for i in arange(2,n,4).reshape(-1):
            m=min(1,n - i)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1035
            c[i:i + m]=zeros(m + 1,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1036
        r=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1038
        r[1:4]=cat(1,1,0,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1039
        if (n < 4):
            r=r[1:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1041
        A=toeplitz(c,r)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1043
    else:
        if (2) == (k):
            c=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1046
            c[1]=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1047
            r=ones(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1048
            for i in arange(3,n,2).reshape(-1):
                r[i]=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1050
            A=toeplitz(c,r)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1052
        else:
            if (3) == (k):
                c=ones(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1055
                for i in arange(2,n,2).reshape(-1):
                    c[i]=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1057
                A=toeplitz(c,cat(1,1,zeros(1,n - 2)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1059
            else:
                error('gallery: unknown K \'%d\' for dramadah matrix.',k)
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def fiedler(c=None,*args,**kwargs):
    varargin = fiedler.varargin
    nargin = fiedler.nargin

    ## FIEDLER  Fiedler matrix - symmetric.
  ##   FIEDLER(C), where C is an n-vector, is the n-by-n symmetric
  ##   matrix with elements ABS(C(i)-C(j)).
  ##   Special case: if C is a scalar, then A = FIEDLER(1:C)
  ##               (i.e. A(i,j) = ABS(i-j)).
  ##   Properties:
  ##   FIEDLER(N) has a dominant positive eigenvalue and all the other
  ##              eigenvalues are negative (Szego, 1936).
  ##   Explicit formulas for INV(A) and DET(A) are given by Todd (1977)
  ##   and attributed to Fiedler.  These indicate that INV(A) is
  ##   tridiagonal except for nonzero (1,n) and (n,1) elements.
  ##   [I think these formulas are valid only if the elements of
  ##   C are in increasing or decreasing order---NJH.]
  ##
  ##   References:
  ##   G. Szego, Solution to problem 3705, Amer. Math. Monthly,
  ##      43 (1936), pp. 246-259.
  ##   J. Todd, Basic Numerical Mathematics, Vol. 2: Numerical Algebra,
  ##      Birkhauser, Basel, and Academic Press, New York, 1977, p. 159.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for fiedler matrix.')
    else:
        if (logical_not(isnumeric(c))):
            error('gallery: C must be numeric for fiedler matrix.')
    
    n=numel(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1093
    if (isscalar(c) and fix(c) == c):
        n=copy(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1095
        c=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1096
    else:
        if (n > 1 and isvector(c)):
            ## do nothing
            pass
        else:
            error('gallery: C must be an integer or a vector for fiedler matrix.')
    
    c=ravel(c).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1102
    
    A=dot(ones(n,1),c)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1104
    A=abs(A - A.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1105
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def forsythe(n=None,alpha=sqrt(eps),lambda_=0,*args,**kwargs):
    varargin = forsythe.varargin
    nargin = forsythe.nargin

    ## FORSYTHE  Forsythe matrix - a perturbed Jordan block.
  ##   FORSYTHE(N, ALPHA, LAMBDA) is the N-by-N matrix equal to
  ##   JORDBLOC(N, LAMBDA) except it has an ALPHA in the (N,1) position.
  ##   It has the characteristic polynomial
  ##           DET(A-t*EYE) = (LAMBDA-t)^N - (-1)^N ALPHA.
  ##   ALPHA defaults to SQRT(EPS) and LAMBDA to 0.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for forsythe matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for forsythe matrix.')
        else:
            if (logical_not(isnumeric(alpha)) or logical_not(isscalar(alpha))):
                error('gallery: ALPHA must be a numeric scalar for forsythe matrix.')
            else:
                if (logical_not(isnumeric(lambda_)) or logical_not(isscalar(lambda_))):
                    error('gallery: LAMBDA must be a numeric scalar for forsythe matrix.')
    
    A=jordbloc(n,lambda_)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1126
    A[n,1]=alpha
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1127
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def frank(n=None,k=0,*args,**kwargs):
    varargin = frank.varargin
    nargin = frank.nargin

    ## FRANK   Frank matrix---ill conditioned eigenvalues.
  ##   F = FRANK(N, K) is the Frank matrix of order N.  It is upper
  ##   Hessenberg with determinant 1.  K = 0 is the default; if K = 1 the
  ##   elements are reflected about the anti-diagonal (1,N)--(N,1).
  ##   F has all positive eigenvalues and they occur in reciprocal pairs
  ##   (so that 1 is an eigenvalue if N is odd).
  ##   The eigenvalues of F may be obtained in terms of the zeros of the
  ##   Hermite polynomials.
  ##   The FLOOR(N/2) smallest eigenvalues of F are ill conditioned,
  ##   the more so for bigger N.
  ##
  ##   DET(FRANK(N)') comes out far from 1 for large N---see Frank (1958)
  ##   and Wilkinson (1960) for discussions.
  ##
  ##   This version incorporates improvements suggested by W. Kahan.
  ##
  ##   References:
  ##   W.L. Frank, Computing eigenvalues of complex matrices by determinant
  ##      evaluation and by methods of Danilewski and Wielandt, J. Soc.
  ##      Indust. Appl. Math., 6 (1958), pp. 378-392 (see pp. 385, 388).
  ##   G.H. Golub and J.H. Wilkinson, Ill-conditioned eigensystems and the
  ##      computation of the Jordan canonical form, SIAM Review, 18 (1976),
  ##        pp. 578-619 (Section 13).
  ##   H. Rutishauser, On test matrices, Programmation en Mathematiques
  ##      Numeriques, Editions Centre Nat. Recherche Sci., Paris, 165,
  ##      1966, pp. 349-365.  Section 9.
  ##   J.H. Wilkinson, Error analysis of floating-point computation,
  ##      Numer. Math., 2 (1960), pp. 319-340 (Section 8).
  ##   J.H. Wilkinson, The Algebraic Eigenvalue Problem, Oxford University
  ##      Press, 1965 (pp. 92-93).
  ##   The next two references give details of the eigensystem, as does
  ##   Rutishauser (see above).
  ##   P.J. Eberlein, A note on the matrices denoted by B_n, SIAM J. Appl.
  ##      Math., 20 (1971), pp. 87-92.
  ##   J.M. Varah, A generalization of the Frank matrix, SIAM J. Sci. Stat.
  ##      Comput., 7 (1986), pp. 835-839.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for frank matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for frank matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for frank matrix.')
    
    p=arange(n,1,- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1176
    F=triu(p[ones(n,1),:] - diag(ones(n - 1,1),- 1),- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1177
    if (0) == (k):
        pass
    else:
        if (1) == (k):
            F=F[p,p].T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1181
        else:
            error('gallery: K must have a value of 0 or 1 for frank matrix.')
    
    return F
    
if __name__ == '__main__':
    pass
    
    
@function
def gcdmat(n=None,*args,**kwargs):
    varargin = gcdmat.varargin
    nargin = gcdmat.nargin

    if (nargin != 1):
        error('gallery: 1 argument is required for gcdmat matrix.')
    else:
        if (logical_not(isscalar(n)) or logical_not(isnumeric(n)) or fix(n) != n):
            error('gallery: N must be an integer for gcdmat matrix.')
    
    c=gcd(repmat((arange(1,n)).T,cat(1,n)),repmat(arange(1,n),cat(n,1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1193
    return c
    
if __name__ == '__main__':
    pass
    
    
@function
def gearmat(n=None,i=n,j=- n,*args,**kwargs):
    varargin = gearmat.varargin
    nargin = gearmat.nargin

    ## NOTE: this function was named gearm in the original Test Matrix Toolbox
  ## GEARMAT   Gear matrix.
  ##   A = GEARMAT(N,I,J) is the N-by-N matrix with ones on the sub- and
  ##   super-diagonals, SIGN(I) in the (1,ABS(I)) position, SIGN(J)
  ##   in the (N,N+1-ABS(J)) position, and zeros everywhere else.
  ##   Defaults: I = N, j = -N.
  ##   All eigenvalues are of the form 2*COS(a) and the eigenvectors
  ##   are of the form [SIN(w+a), SIN(w+2a), ..., SIN(w+Na)].
  ##   The values of a and w are given in the reference below.
  ##   A can have double and triple eigenvalues and can be defective.
  ##   GEARMAT(N) is singular.
  ##
  ##   (GEAR is a Simulink function, hence GEARMAT for Gear matrix.)
  ##   Reference:
  ##   C.W. Gear, A simple set of test matrices for eigenvalue programs,
  ##   Math. Comp., 23 (1969), pp. 119-125.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for gearmat matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for gearmat matrix.')
        else:
            if (logical_not(isnumeric(i)) or logical_not(isscalar(i)) or i == 0 or abs(i) <= n):
                error('gallery: I must be a nonzero scalar, and abs (I) <= N for gearmat matrix.')
            else:
                if (logical_not(isnumeric(j)) or logical_not(isscalar(j)) or i == 0 or abs(j) <= n):
                    error('gallery: J must be a nonzero scalar, and abs (J) <= N for gearmat matrix.')
    
    A=diag(ones(n - 1,1),- 1) + diag(ones(n - 1,1),1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1224
    A[1,abs(i)]=sign(i)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1225
    A[n,n + 1 - abs(j)]=sign(j)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1226
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def grcar(n=None,k=3,*args,**kwargs):
    varargin = grcar.varargin
    nargin = grcar.nargin

    ## GRCAR     Grcar matrix - a Toeplitz matrix with sensitive eigenvalues.
  ##   GRCAR(N, K) is an N-by-N matrix with -1s on the
  ##   subdiagonal, 1s on the diagonal, and K superdiagonals of 1s.
  ##   The default is K = 3.  The eigenvalues of this matrix form an
  ##   interesting pattern in the complex plane (try PS(GRCAR(32))).
  ##
  ##   References:
  ##   J.F. Grcar, Operator coefficient methods for linear equations,
  ##        Report SAND89-8691, Sandia National Laboratories, Albuquerque,
  ##        New Mexico, 1989 (Appendix 2).
  ##   N.M. Nachtigal, L. Reichel and L.N. Trefethen, A hybrid GMRES
  ##        algorithm for nonsymmetric linear systems, SIAM J. Matrix Anal.
  ##        Appl., 13 (1992), pp. 796-825.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for grcar matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for grcar matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for grcar matrix.')
    
    G=tril(triu(ones(n)),k) - diag(ones(n - 1,1),- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1252
    return G
    
if __name__ == '__main__':
    pass
    
    
@function
def hanowa(n=None,d=- 1,*args,**kwargs):
    varargin = hanowa.varargin
    nargin = hanowa.nargin

    ## HANOWA  A matrix whose eigenvalues lie on a vertical line in the complex plane.
  ##   HANOWA(N, d) is the N-by-N block 2x2 matrix (thus N = 2M must be even)
  ##                 [d*EYE(M)   -DIAG(1:M)
  ##                  DIAG(1:M)   d*EYE(M)]
  ##   It has complex eigenvalues lambda(k) = d +/- k*i  (1 <= k <= M).
  ##   Parameter d defaults to -1.
  ##
  ##   Reference:
  ##   E. Hairer, S.P. Norsett and G. Wanner, Solving Ordinary
  ##   Differential Equations I: Nonstiff Problems, Springer-Verlag,
  ##   Berlin, 1987. (pp. 86-87)
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for hanowa matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for hanowa matrix.')
        else:
            if (rem(n,2) != 0):
                error('gallery: N must be even for hanowa matrix.')
            else:
                if (logical_not(isnumeric(lambda_)) or logical_not(isscalar(lambda_))):
                    error('gallery: D must be a numeric scalar for hanowa matrix.')
    
    m=n / 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1278
    A=matlabarray(cat(dot(d,eye(m)),- diag(arange(1,m)),diag(arange(1,m)),dot(d,eye(m))))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1279
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def house(x=None,*args,**kwargs):
    varargin = house.varargin
    nargin = house.nargin

    ## HOUSE   Householder matrix.
  ##   If [v, beta] = HOUSE(x) then H = EYE - beta*v*v' is a Householder
  ##   matrix such that Hx = -sign(x(1))*norm(x)*e_1.
  ##   NB: If x = 0 then v = 0, beta = 1 is returned.
  ##       x can be real or complex.
  ##       sign(x) := exp(i*arg(x)) ( = x./abs(x) when x ~= 0).
  ##
  ##   Theory: (textbook references Golub & Van Loan 1989, 38-43;
  ##            Stewart 1973, 231-234, 262; Wilkinson 1965, 48-50).
  ##   Hx = y: (I - beta*v*v')x = -s*e_1.
  ##   Must have |s| = norm(x), v = x+s*e_1, and
  ##   x'y = x'Hx =(x'Hx)' real => arg(s) = arg(x(1)).
  ##   So take s = sign(x(1))*norm(x) (which avoids cancellation).
  ##   v'v = (x(1)+s)^2 + x(2)^2 + ... + x(n)^2
  ##       = 2*norm(x)*(norm(x) + |x(1)|).
  ##
  ##   References:
  ##   G.H. Golub and C.F. Van Loan, Matrix Computations, second edition,
  ##      Johns Hopkins University Press, Baltimore, Maryland, 1989.
  ##   G.W. Stewart, Introduction to Matrix Computations, Academic Press,
  ##      New York, 1973,
  ##   J.H. Wilkinson, The Algebraic Eigenvalue Problem, Oxford University
  ##      Press, 1965.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for house matrix.')
    else:
        if (logical_not(isnumeric(x)) or logical_not(isvector(x)) or numel(x) <= 1):
            error('gallery: X must be a vector for house matrix.')
    
    ## must be a column vector
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1315
    s=dot(norm(x),(sign(x[1]) + (x[1] == 0)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1317
    
    v=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1318
    if (s == 0):
        ## Quit if x is the zero vector.
        beta=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1321
    else:
        v[1]=v[1] + s
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1323
        beta=1 / (dot(s.T,v[1]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1324
        ##  beta = 1/(abs (s) * (abs (s) +abs(x(1)) would guarantee beta real.
    ##  But beta as above can be non-real (due to rounding) only when x is complex.
    
    return v,beta
    
if __name__ == '__main__':
    pass
    
    
@function
def integerdata(varargin=None,*args,**kwargs):
    varargin = integerdata.varargin
    nargin = integerdata.nargin

    if (nargin < 3):
        error('gallery: At least 3 arguments required for integerdata matrix.')
    
    if (isnumeric(varargin[end()])):
        jidx=varargin[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1337
        svec=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1338
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1339
    else:
        if (ischar(varargin[end()])):
            if (nargin < 4):
                error(cat('gallery: CLASS argument requires 4 inputs ','for integerdata matrix.'))
            jidx=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1345
            svec=matlabarray(cat(varargin[1:end() - 1]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1346
            varargin[end() - 1]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1347
        else:
            error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for integerdata matrix'))
    
    if (logical_not((isnumeric(jidx) and isscalar(jidx) and jidx == fix(jidx) and jidx >= 0 and jidx <= 4294967295))):
        error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for integerdata matrix'))
    
    ## Save and restore random state.  Initialization done so that reproducible
  ## data is available from gallery depending on the jidx and size vector.
    randstate=rand('state')
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1362
    try:
        rand('state',svec)
        A=randi(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1365
    finally:
        rand('state',randstate)
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def invhess(x=None,y=None,*args,**kwargs):
    varargin = invhess.varargin
    nargin = invhess.nargin

    ## INVHESS  Inverse of an upper Hessenberg matrix.
  ##   INVHESS(X, Y), where X is an N-vector and Y an N-1 vector,
  ##   is the matrix whose lower triangle agrees with that of
  ##   ONES(N,1)*X' and whose strict upper triangle agrees with
  ##   that of [1 Y]*ONES(1,N).
  ##   The matrix is nonsingular if X(1) ~= 0 and X(i+1) ~= Y(i)
  ##   for all i, and its inverse is an upper Hessenberg matrix.
  ##   If Y is omitted it defaults to -X(1:N-1).
  ##   Special case: if X is a scalar INVHESS(X) is the same as
  ##   INVHESS(1:X).
  ##
  ##   References:
  ##   F.N. Valvi and V.S. Geroyannis, Analytic inverses and
  ##       determinants for a class of matrices, IMA Journal of Numerical
  ##       Analysis, 7 (1987), pp. 123-128.
  ##   W.-L. Cao and W.J. Stewart, A note on inverses of Hessenberg-like
  ##       matrices, Linear Algebra and Appl., 76 (1986), pp. 233-240.
  ##   Y. Ikebe, On inverses of Hessenberg matrices, Linear Algebra and
  ##       Appl., 24 (1979), pp. 93-97.
  ##   P. Rozsa, On the inverse of band matrices, Integral Equations and
  ##       Operator Theory, 10 (1987), pp. 82-95.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for invhess matrix.')
    else:
        if (logical_not(isnumeric(x))):
            error('gallery: X must be numeric for invhess matrix.')
    
    if (isscalar(x) and fix(x) == x):
        n=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1402
        x=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1403
    else:
        if (logical_not(isscalar(x)) and isvector(x)):
            n=numel(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1405
        else:
            error('gallery: X must be an integer scalar, or a vector for invhess matrix.')
    
    if (nargin < 2):
        y=- x[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1411
    else:
        if (logical_not(isvector(y)) or numel(y) != numel(x) - 1):
            error('gallery: Y must be a vector of length -1 than X for invhess matrix.')
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1416
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1417
    
    A=dot(ones(n,1),x.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1420
    for j in arange(2,n).reshape(-1):
        A[1:j - 1,j]=y[1:j - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1422
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def invol(n=None,*args,**kwargs):
    varargin = invol.varargin
    nargin = invol.nargin

    ## INVOL   An involutory matrix.
  ##   A = INVOL(N) is an N-by-N involutory (A*A = EYE(N)) and
  ##   ill-conditioned matrix.
  ##   It is a diagonally scaled version of HILB(N).
  ##   NB: B = (EYE(N)-A)/2 and B = (EYE(N)+A)/2 are idempotent (B*B = B).
  ##
  ##   Reference:
  ##   A.S. Householder and J.A. Carpenter, The singular values
  ##   of involutory and of idempotent matrices, Numer. Math. 5 (1963),
  ##   pp. 234-237.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for invol matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for invol matrix.')
    
    A=hilb(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1444
    d=- n
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1446
    A[:,1]=dot(d,A[:,1])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1447
    for i in arange(1,n - 1).reshape(-1):
        d=dot(dot(- (n + i),(n - i)),d) / (dot(i,i))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1450
        A[i + 1,:]=dot(d,A[i + 1,:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1451
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def ipjfact(n=None,k=0,*args,**kwargs):
    varargin = ipjfact.varargin
    nargin = ipjfact.nargin

    ## IPJFACT   A Hankel matrix with factorial elements.
  ##   A = IPJFACT(N, K) is the matrix with
  ##             A(i,j) = (i+j)!    (K = 0, default)
  ##             A(i,j) = 1/(i+j)!  (K = 1)
  ##   Both are Hankel matrices.
  ##   The determinant and inverse are known explicitly.
  ##   If a second output argument is present, d = DET(A) is returned:
  ##   [A, d] = IPJFACT(N, K);
  ##
  ##   Suggested by P. R. Graves-Morris.
  ##
  ##   Reference:
  ##   M.J.C. Gover, The explicit inverse of factorial Hankel matrices,
  ##   Dept. of Mathematics, University of Bradford, 1993.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for ipjfact matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for ipjfact matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for ipjfact matrix.')
    
    c=cumprod(arange(2,n + 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1479
    d=dot(cumprod(arange(n + 1,dot(2,n))),c[n - 1])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1480
    A=hankel(c,d)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1482
    if (0) == (k):
        pass
    else:
        if (1) == (k):
            A=ones(n) / A
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1486
        else:
            error('gallery: K must have a value of 0 or 1 for ipjfact matrix.')
    
    if (nargout == 2):
        d=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1492
        if (k == 0):
            for i in arange(1,n - 1).reshape(-1):
                d=dot(dot(d,prod(arange(1,i + 1))),prod(arange(1,n - i)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1496
            d=dot(d,prod(arange(1,n + 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1498
        else:
            if (k == 1):
                for i in arange(0,n - 1).reshape(-1):
                    d=dot(d,prod(arange(1,i))) / prod(arange(1,n + 1 + i))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1502
                if (rem(dot(n,(n - 1)) / 2,2)):
                    d=- d
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1505
            else:
                error('gallery: K must have a value of 0 or 1 for ipjfact matrix.')
        detA=copy(d)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1512
    
    return A,detA
    
if __name__ == '__main__':
    pass
    
    
@function
def jordbloc(n=None,lambda_=1,*args,**kwargs):
    varargin = jordbloc.varargin
    nargin = jordbloc.nargin

    ## JORDBLOC  Jordan block.
  ##   JORDBLOC(N, LAMBDA) is the N-by-N Jordan block with eigenvalue
  ##   LAMBDA.  LAMBDA = 1 is the default.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for jordbloc matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for jordbloc matrix.')
        else:
            if (logical_not(isnumeric(lambda_)) or logical_not(isscalar(lambda_))):
                error('gallery: LAMBDA must be a numeric scalar for jordbloc matrix.')
    
    J=dot(lambda_,eye(n)) + diag(ones(n - 1,1),1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1529
    return J
    
if __name__ == '__main__':
    pass
    
    
@function
def kahan(n=None,theta=1.2,pert=25,*args,**kwargs):
    varargin = kahan.varargin
    nargin = kahan.nargin

    ## KAHAN  Kahan matrix - upper trapezoidal.
  ##   KAHAN(N, THETA) is an upper trapezoidal matrix
  ##   that has some interesting properties regarding estimation of
  ##   condition and rank.
  ##   The matrix is N-by-N unless N is a 2-vector, in which case it
  ##   is N(1)-by-N(2).
  ##   The parameter THETA defaults to 1.2.
  ##   The useful range of THETA is 0 < THETA < PI.
  ##
  ##   To ensure that the QR factorization with column pivoting does not
  ##   interchange columns in the presence of rounding errors, the diagonal
  ##   is perturbed by PERT*EPS*diag( [N:-1:1] ).
  ##   The default is PERT = 25, which ensures no interchanges for KAHAN(N)
  ##   up to at least N = 90 in IEEE arithmetic.
  ##   KAHAN(N, THETA, PERT) uses the given value of PERT.
  ##
  ##   The inverse of KAHAN(N, THETA) is known explicitly: see
  ##   Higham (1987, p. 588), for example.
  ##   The diagonal perturbation was suggested by Christian Bischof.
  ##
  ##   References:
  ##   W. Kahan, Numerical linear algebra, Canadian Math. Bulletin,
  ##      9 (1966), pp. 757-801.
  ##   N.J. Higham, A survey of condition number estimation for
  ##      triangular matrices, SIAM Review, 29 (1987), pp. 575-596.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for kahan matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2)) or fix(n) != n):
            error('gallery: N must be a 1 or 2 element integer for kahan matrix.')
        else:
            if (logical_not(isnumeric(theta)) or logical_not(isscalar(theta))):
                error('gallery: THETA must be a numeric scalar for kahan matrix.')
            else:
                if (logical_not(isnumeric(pert)) or logical_not(isscalar(pert))):
                    error('gallery: PERT must be a numeric scalar for kahan matrix.')
    
    ## Parameter n specifies dimension: r-by-n
    r=n[1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1570
    n=n[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1571
    s=sin(theta)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1573
    c=cos(theta)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1574
    U=eye(n) - dot(c,triu(ones(n),1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1576
    U=dot(diag(s ** cat(arange(0,n - 1))),U) + dot(dot(pert,eps),diag(cat(arange(n,1,- 1))))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1577
    if (r > n):
        U[r,n]=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1579
    else:
        U=U[1:r,:]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1581
    
    return U
    
if __name__ == '__main__':
    pass
    
    
@function
def kms(n=None,rho=0.5,*args,**kwargs):
    varargin = kms.varargin
    nargin = kms.nargin

    ## KMS   Kac-Murdock-Szego Toeplitz matrix.
  ##   A = KMS(N, RHO) is the N-by-N Kac-Murdock-Szego Toeplitz matrix with
  ##   A(i,j) = RHO^(ABS((i-j))) (for real RHO).
  ##   If RHO is complex, then the same formula holds except that elements
  ##   below the diagonal are conjugated.
  ##   RHO defaults to 0.5.
  ##   Properties:
  ##      A has an LDL' factorization with
  ##               L = INV(TRIW(N,-RHO,1)'),
  ##               D(i,i) = (1-ABS(RHO)^2)*EYE(N) except D(1,1) = 1.
  ##      A is positive definite if and only if 0 < ABS(RHO) < 1.
  ##      INV(A) is tridiagonal.
  ##
  ##    Reference:
  ##    W.F. Trench, Numerical solution of the eigenvalue problem
  ##    for Hermitian Toeplitz matrices, SIAM J. Matrix Analysis and Appl.,
  ##    10 (1989), pp. 135-146 (and see the references therein).
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for lauchli matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for lauchli matrix.')
        else:
            if (logical_not(isscalar(mu))):
                error('gallery: MU must be a scalar for lauchli matrix.')
    
    A=dot((arange(1,n)).T,ones(1,n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1612
    A=abs(A - A.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1613
    A=rho ** A
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1614
    if (imag(rho)):
        A=conj(tril(A,- 1)) + triu(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1616
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def krylov(A=None,x=None,j=None,*args,**kwargs):
    varargin = krylov.varargin
    nargin = krylov.nargin

    ## KRYLOV    Krylov matrix.
  ##   KRYLOV(A, x, j) is the Krylov matrix
  ##        [x, Ax, A^2x, ..., A^(j-1)x],
  ##   where A is an n-by-n matrix and x is an n-vector.
  ##   Defaults: x = ONES(n,1), j = n.
  ##   KRYLOV(n) is the same as KRYLOV(RANDN(n)).
  ##
  ##   Reference:
  ##   G.H. Golub and C.F. Van Loan, Matrix Computations, second edition,
  ##   Johns Hopkins University Press, Baltimore, Maryland, 1989, p. 369.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for krylov matrix.')
    else:
        if (logical_not(isnumeric(A)) or logical_not(issquare(A)) or ndims(A) != 2):
            error('gallery: A must be a square 2-D matrix for krylov matrix.')
    
    n=length(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1638
    if (isscalar(A)):
        n=copy(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1640
        A=randn(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1641
    
    if (nargin < 2):
        x=ones(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1645
    else:
        if (logical_not(isvector(x)) or numel(x) != n):
            error('gallery: X must be a vector of length equal to A for krylov matrix.')
    
    if (nargin < 3):
        j=copy(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1651
    else:
        if (logical_not(isnumeric(j)) or logical_not(isscalar(j)) or fix(j) != j):
            error('gallery: J must be an integer for krylov matrix.')
    
    B=ones(n,j)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1656
    B[:,1]=ravel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1657
    for i in arange(2,j).reshape(-1):
        B[:,i]=dot(A,B[:,i - 1])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1659
    
    return B
    
if __name__ == '__main__':
    pass
    
    
@function
def lauchli(n=None,mu=sqrt(eps),*args,**kwargs):
    varargin = lauchli.varargin
    nargin = lauchli.nargin

    ## LAUCHLI   Lauchli matrix - rectangular.
  ##   LAUCHLI(N, MU) is the (N+1)-by-N matrix [ONES(1,N); MU*EYE(N))].
  ##   It is a well-known example in least squares and other problems
  ##   that indicates the dangers of forming A'*A.
  ##   MU defaults to SQRT(EPS).
  ##
  ##   Reference:
  ##   P. Lauchli, Jordan-Elimination und Ausgleichung nach
  ##   kleinsten Quadraten, Numer. Math, 3 (1961), pp. 226-240.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for lauchli matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for lauchli matrix.')
        else:
            if (logical_not(isscalar(mu))):
                error('gallery: MU must be a scalar for lauchli matrix.')
    
    A=matlabarray(cat(ones(1,n),dot(mu,eye(n))))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1682
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def lehmer(n=None,*args,**kwargs):
    varargin = lehmer.varargin
    nargin = lehmer.nargin

    ## LEHMER  Lehmer matrix - symmetric positive definite.
  ##   A = LEHMER(N) is the symmetric positive definite N-by-N matrix with
  ##                    A(i,j) = i/j for j >= i.
  ##   A is totally nonnegative.  INV(A) is tridiagonal, and explicit
  ##   formulas are known for its entries.
  ##   N <= COND(A) <= 4*N*N.
  ##
  ##   References:
  ##   M. Newman and J. Todd, The evaluation of matrix inversion
  ##      programs, J. Soc. Indust. Appl. Math., 6 (1958), pp. 466-476.
  ##   Solutions to problem E710 (proposed by D.H. Lehmer): The inverse
  ##      of a matrix, Amer. Math. Monthly, 53 (1946), pp. 534-535.
  ##   J. Todd, Basic Numerical Mathematics, Vol. 2: Numerical Algebra,
  ##      Birkhauser, Basel, and Academic Press, New York, 1977, p. 154.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for lehmer matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for lehmer matrix.')
    
    A=dot(ones(n,1),(arange(1,n)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1708
    A=A / A.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1709
    A=tril(A) + tril(A,- 1).T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1710
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def lesp(n=None,*args,**kwargs):
    varargin = lesp.varargin
    nargin = lesp.nargin

    ## LESP   A tridiagonal matrix with real, sensitive eigenvalues.
  ##   LESP(N) is an N-by-N matrix whose eigenvalues are real and smoothly
  ##   distributed in the interval approximately [-2*N-3.5, -4.5].
  ##   The sensitivities of the eigenvalues increase exponentially as
  ##   the eigenvalues grow more negative.
  ##   The matrix is similar to the symmetric tridiagonal matrix with
  ##   the same diagonal entries and with off-diagonal entries 1,
  ##   via a similarity transformation with D = diag(1!,2!,...,N!).
  ##
  ##   References:
  ##   H.W.J. Lenferink and M.N. Spijker, On the use of stability regions in
  ##        the numerical analysis of initial value problems,
  ##        Math. Comp., 57 (1991), pp. 221-237.
  ##   L.N. Trefethen, Pseudospectra of matrices, in Numerical Analysis 1991,
  ##        Proceedings of the 14th Dundee Conference,
  ##        D.F. Griffiths and G.A. Watson, eds, Pitman Research Notes in
  ##        Mathematics, volume 260, Longman Scientific and Technical, Essex,
  ##        UK, 1992, pp. 234-266.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for lesp matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for lesp matrix.')
    
    x=arange(2,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1739
    T=full(tridiag(ones(size(x)) / x,- (dot(2,cat(x,n + 1)) + 1),x))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1740
    return T
    
if __name__ == '__main__':
    pass
    
    
@function
def lotkin(n=None,*args,**kwargs):
    varargin = lotkin.varargin
    nargin = lotkin.nargin

    ## LOTKIN  Lotkin matrix.
  ##   A = LOTKIN(N) is the Hilbert matrix with its first row altered to
  ##   all ones.  A is unsymmetric, ill-conditioned, and has many negative
  ##   eigenvalues of small magnitude.
  ##   The inverse has integer entries and is known explicitly.
  ##
  ##   Reference:
  ##   M. Lotkin, A set of test matrices, MTAC, 9 (1955), pp. 153-161.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for lotkin matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for lotkin matrix.')
    
    A=hilb(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1759
    A[1,:]=ones(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1760
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def minij(n=None,*args,**kwargs):
    varargin = minij.varargin
    nargin = minij.nargin

    ## MINIJ   Symmetric positive definite matrix MIN(i,j).
  ##   A = MINIJ(N) is the N-by-N symmetric positive definite matrix with
  ##   A(i,j) = MIN(i,j).
  ##   Properties, variations:
  ##   INV(A) is tridiagonal: it is minus the second difference matrix
  ##               except its (N,N) element is 1.
  ##   2*A-ONES(N) (Givens' matrix) has tridiagonal inverse and
  ##               eigenvalues .5*sec^2([2r-1)PI/4N], r=1:N.
  ##   (N+1)*ONES(N)-A also has a tridiagonal inverse.
  ##
  ##   References:
  ##   J. Todd, Basic Numerical Mathematics, Vol. 2: Numerical Algebra,
  ##      Birkhauser, Basel, and Academic Press, New York, 1977, p. 158.
  ##   D.E. Rutherford, Some continuant determinants arising in physics and
  ##      chemistry---II, Proc. Royal Soc. Edin., 63, A (1952), pp. 232-241.
  ##      (For the eigenvalues of Givens' matrix.)
    
    if (nargin != 1):
        error('gallery: 1 argument is required for minij matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for minij matrix.')
    
    A=bsxfun(min,arange(1,n),(arange(1,n)).T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1787
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def moler(n=None,alpha=- 1,*args,**kwargs):
    varargin = moler.varargin
    nargin = moler.nargin

    ## MOLER   Moler matrix - symmetric positive definite.
  ##   A = MOLER(N, ALPHA) is the symmetric positive definite N-by-N matrix
  ##   U'*U where U = TRIW(N, ALPHA).
  ##   For ALPHA = -1 (the default) A(i,j) = MIN(i,j)-2, A(i,i) = i.
  ##   A has one small eigenvalue.
  ##
  ##   Nash (1990) attributes the ALPHA = -1 matrix to Moler.
  ##
  ##   Reference:
  ##   J.C. Nash, Compact Numerical Methods for Computers: Linear
  ##   Algebra and Function Minimisation, second edition, Adam Hilger,
  ##   Bristol, 1990 (Appendix 1).
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for moler matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for moler matrix.')
        else:
            if (logical_not(isscalar(alpha))):
                error('gallery: ALPHA must be a scalar for moler matrix.')
    
    A=dot(triw(n,alpha).T,triw(n,alpha))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1812
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def neumann(n=None,*args,**kwargs):
    varargin = neumann.varargin
    nargin = neumann.nargin

    ## NEUMANN  Singular matrix from the discrete Neumann problem (sparse).
  ##   NEUMANN(N) is the singular, row diagonally dominant matrix resulting
  ##   from discretizing the Neumann problem with the usual five point
  ##   operator on a regular mesh.
  ##   It has a one-dimensional null space with null vector ONES(N,1).
  ##   The dimension N should be a perfect square, or else a 2-vector,
  ##   in which case the dimension of the matrix is N(1)*N(2).
  ##
  ##   Reference:
  ##   R.J. Plemmons, Regular splittings and the discrete Neumann
  ##   problem, Numer. Math., 25 (1976), pp. 153-161.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for neumann matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2)) or fix(n) != n):
            error('gallery: N must be a 1 or 2 element integer for neumann matrix.')
    
    if (isscalar(n)):
        m=sqrt(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1835
        if (m ** 2 != n):
            error('gallery: N must be a perfect square for neumann matrix.')
        n[1]=m
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1839
        n[2]=m
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1840
    
    T=tridiag(n[1],- 1,2,- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1843
    T[1,2]=- 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1844
    T[n[1],n[1] - 1]=- 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1845
    A=kron(T,eye(n[2])) + kron(eye(n[2]),T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1847
    return A,T
    
if __name__ == '__main__':
    pass
    
    
@function
def normaldata(varargin=None,*args,**kwargs):
    varargin = normaldata.varargin
    nargin = normaldata.nargin

    if (nargin < 2):
        error('gallery: At least 2 arguments required for normaldata matrix.')
    
    if (isnumeric(varargin[end()])):
        jidx=varargin[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1856
        svec=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1857
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1858
    else:
        if (ischar(varargin[end()])):
            if (nargin < 3):
                error(cat('gallery: CLASS argument requires 3 inputs ','for normaldata matrix.'))
            jidx=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1864
            svec=matlabarray(cat(varargin[1:end() - 1]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1865
            varargin[end() - 1]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1866
        else:
            error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for normaldata matrix'))
    
    if (logical_not((isnumeric(jidx) and isscalar(jidx) and jidx == fix(jidx) and jidx >= 0 and jidx <= 4294967295))):
        error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for normaldata matrix'))
    
    ## Save and restore random state.  Initialization done so that reproducible
  ## data is available from gallery depending on the jidx and size vector.
    randstate=randn('state')
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1881
    try:
        randn('state',svec)
        A=randn(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1884
    finally:
        randn('state',randstate)
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def orthog(n=None,k=1,*args,**kwargs):
    varargin = orthog.varargin
    nargin = orthog.nargin

    ## ORTHOG Orthogonal and nearly orthogonal matrices.
  ##   Q = ORTHOG(N, K) selects the K'th type of matrix of order N.
  ##   K > 0 for exactly orthogonal matrices, K < 0 for diagonal scalings of
  ##   orthogonal matrices.
  ##   Available types: (K = 1 is the default)
  ##   K = 1:  Q(i,j) = SQRT(2/(n+1)) * SIN( i*j*PI/(n+1) )
  ##           Symmetric eigenvector matrix for second difference matrix.
  ##   K = 2:  Q(i,j) = 2/SQRT(2*n+1)) * SIN( 2*i*j*PI/(2*n+1) )
  ##           Symmetric.
  ##   K = 3:  Q(r,s) = EXP(2*PI*i*(r-1)*(s-1)/n) / SQRT(n)  (i=SQRT(-1))
  ##           Unitary, the Fourier matrix.  Q^4 is the identity.
  ##           This is essentially the same matrix as FFT(EYE(N))/SQRT(N)!
  ##   K = 4:  Helmert matrix: a permutation of a lower Hessenberg matrix,
  ##           whose first row is ONES(1:N)/SQRT(N).
  ##   K = 5:  Q(i,j) = SIN( 2*PI*(i-1)*(j-1)/n ) + COS( 2*PI*(i-1)*(j-1)/n ).
  ##           Symmetric matrix arising in the Hartley transform.
  ##   K = -1: Q(i,j) = COS( (i-1)*(j-1)*PI/(n-1) )
  ##           Chebyshev Vandermonde-like matrix, based on extrema of T(n-1).
  ##   K = -2: Q(i,j) = COS( (i-1)*(j-1/2)*PI/n) )
  ##           Chebyshev Vandermonde-like matrix, based on zeros of T(n).
  ##
  ##   References:
  ##   N.J. Higham and D.J. Higham, Large growth factors in Gaussian
  ##        elimination with pivoting, SIAM J. Matrix Analysis and  Appl.,
  ##        10 (1989), pp. 155-164.
  ##   P. Morton, On the eigenvectors of Schur's matrix, J. Number Theory,
  ##        12 (1980), pp. 122-127. (Re. ORTHOG(N, 3))
  ##   H.O. Lancaster, The Helmert Matrices, Amer. Math. Monthly, 72 (1965),
  ##        pp. 4-12.
  ##   D. Bini and P. Favati, On a matrix algebra related to the discrete
  ##        Hartley transform, SIAM J. Matrix Anal. Appl., 14 (1993),
  ##        pp. 500-507.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for orthog matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for orthog matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for orthog matrix.')
    
    if (1) == (k):
        ## E'vectors second difference matrix
        m=dot(dot((arange(1,n)).T,(arange(1,n))),(pi / (n + 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1936
        Q=dot(sin(m),sqrt(2 / (n + 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1937
    else:
        if (2) == (k):
            m=dot(dot((arange(1,n)).T,(arange(1,n))),(dot(2,pi) / (dot(2,n) + 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1940
            Q=dot(sin(m),(2 / sqrt(dot(2,n) + 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1941
        else:
            if (3) == (k):
                ## Vandermonde based on roots of unity
                m=arange(0,n - 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1945
                Q=exp(dot(dot(dot(dot(m.T,m),2),pi),sqrt(- 1)) / n) / sqrt(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1946
            else:
                if (4) == (k):
                    ## Helmert matrix
                    Q=tril(ones(n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1950
                    Q[1,2:n]=ones(1,n - 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1951
                    for i in arange(2,n).reshape(-1):
                        Q[i,i]=- (i - 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1953
                    Q=numpy.linalg.solve(diag(sqrt(multiply(cat(n,arange(1,n - 1)),cat(arange(1,n))))),Q)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1955
                else:
                    if (5) == (k):
                        ## Hartley matrix
                        m=dot(dot((arange(0,n - 1)).T,(arange(0,n - 1))),(dot(2,pi) / n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1959
                        Q=(cos(m) + sin(m)) / sqrt(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1960
                    else:
                        if (- 1) == (k):
                            ##  extrema of T(n-1)
                            m=dot(dot((arange(0,n - 1)).T,(arange(0,n - 1))),(pi / (n - 1)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1964
                            Q=cos(m)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1965
                        else:
                            if (- 2) == (k):
                                ## zeros of T(n)
                                m=dot(dot((arange(0,n - 1)).T,(arange(0.5,n - 0.5))),(pi / n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1969
                                Q=cos(m)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:1970
                            else:
                                error('gallery: unknown K \'%d\' for orthog matrix.',k)
    
    return Q
    
if __name__ == '__main__':
    pass
    
    
@function
def parter(n=None,*args,**kwargs):
    varargin = parter.varargin
    nargin = parter.nargin

    ## PARTER    Parter matrix - a Toeplitz matrix with singular values near PI.
  ##   PARTER(N) is the matrix with (i,j) element 1/(i-j+0.5).
  ##   It is a Cauchy matrix and a Toeplitz matrix.
  ##
  ##   At the Second SIAM Conference on Linear Algebra, Raleigh, N.C.,
  ##   1985, Cleve Moler noted that most of the singular values of
  ##   PARTER(N) are very close to PI.  An explanation of the phenomenon
  ##   was given by Parter; see also the paper by Tyrtyshnikov.
  ##
  ##   References:
  ##   The MathWorks Newsletter, Volume 1, Issue 1, March 1986, page 2.
  ##   S.V. Parter, On the distribution of the singular values of Toeplitz
  ##        matrices, Linear Algebra and Appl., 80 (1986), pp. 115-130.
  ##   E.E. Tyrtyshnikov, Cauchy-Toeplitz matrices and some applications,
  ##        Linear Algebra and Appl., 149 (1991), pp. 1-18.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for parter matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for parter matrix.')
    
    A=cauchy((arange(1,n)) + 0.5,- (arange(1,n)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2000
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def pei(n=None,alpha=1,*args,**kwargs):
    varargin = pei.varargin
    nargin = pei.nargin

    ## PEI    Pei matrix.
  ##   PEI(N, ALPHA), where ALPHA is a scalar, is the symmetric matrix
  ##   ALPHA*EYE(N) + ONES(N).
  ##   If ALPHA is omitted then ALPHA = 1 is used.
  ##   The matrix is singular for ALPHA = 0, -N.
  ##
  ##   Reference:
  ##   M.L. Pei, A test matrix for inversion procedures,
  ##   Comm. ACM, 5 (1962), p. 508.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for pei matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for pei matrix.')
        else:
            if (logical_not(isnumeric(w)) or logical_not(isscalar(w))):
                error('gallery: ALPHA must be a scalar for pei matrix.')
    
    P=dot(alpha,eye(n)) + ones(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2022
    return P
    
if __name__ == '__main__':
    pass
    
    
@function
def poisson(n=None,*args,**kwargs):
    varargin = poisson.varargin
    nargin = poisson.nargin

    ## POISSON   Block tridiagonal matrix from Poisson's equation (sparse).
  ##   POISSON(N) is the block tridiagonal matrix of order N^2
  ##   resulting from discretizing Poisson's equation with the
  ##   5-point operator on an N-by-N mesh.
  ##
  ##   Reference:
  ##   G.H. Golub and C.F. Van Loan, Matrix Computations, second edition,
  ##   Johns Hopkins University Press, Baltimore, Maryland, 1989
  ##   (Section 4.5.4).
    
    if (nargin != 1):
        error('gallery: 1 argument is required for poisson matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for poisson matrix.')
    
    S=tridiag(n,- 1,2,- 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2042
    I=speye(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2043
    A=kron(I,S) + kron(S,I)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2044
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def prolate(n=None,w=0.25,*args,**kwargs):
    varargin = prolate.varargin
    nargin = prolate.nargin

    ## PROLATE   Prolate matrix - symmetric, ill-conditioned Toeplitz matrix.
  ##   A = PROLATE(N, W) is the N-by-N prolate matrix with parameter W.
  ##   It is a symmetric Toeplitz matrix.
  ##   If 0 < W < 0.5 then
  ##      - A is positive definite
  ##      - the eigenvalues of A are distinct, lie in (0, 1), and
  ##        tend to cluster around 0 and 1.
  ##   W defaults to 0.25.
  ##
  ##   Reference:
  ##   J.M. Varah. The Prolate matrix. Linear Algebra and Appl.,
  ##   187:269--278, 1993.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for prolate matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for prolate matrix.')
        else:
            if (logical_not(isnumeric(w)) or logical_not(isscalar(w))):
                error('gallery: W must be a scalar for prolate matrix.')
    
    a=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2069
    a[1]=dot(2,w)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2070
    a[2:n]=sin(dot(dot(dot(2,pi),w),(arange(1,n - 1)))) / (dot(pi,(arange(1,n - 1))))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2071
    A=toeplitz(a)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2073
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def randhess(x=None,*args,**kwargs):
    varargin = randhess.varargin
    nargin = randhess.nargin

    ## NOTE: this function was named ohess in the original Test Matrix Toolbox
  ## RANDHESS  Random, orthogonal upper Hessenberg matrix.
  ##   H = RANDHESS(N) is an N-by-N real, random, orthogonal
  ##   upper Hessenberg matrix.
  ##   Alternatively, H = RANDHESS(X), where X is an arbitrary real
  ##   N-vector (N > 1) constructs H non-randomly using the elements
  ##   of X as parameters.
  ##   In both cases H is constructed via a product of N-1 Givens rotations.
  ##
  ##   Note: See Gragg (1986) for how to represent an N-by-N (complex)
  ##   unitary Hessenberg matrix with positive subdiagonal elements in terms
  ##   of 2N-1 real parameters (the Schur parametrization).
  ##   This M-file handles the real case only and is intended simply as a
  ##   convenient way to generate random or non-random orthogonal Hessenberg
  ##   matrices.
  ##
  ##   Reference:
  ##   W.B. Gragg, The QR algorithm for unitary Hessenberg matrices,
  ##   J. Comp. Appl. Math., 16 (1986), pp. 1-8.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for randhess matrix.')
    else:
        if (logical_not(isnumeric(x)) or logical_not(isreal(x))):
            error('gallery: N or X must be numeric real values for randhess matrix.')
    
    if (isscalar(x)):
        n=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2104
        x=dot(dot(rand(n - 1,1),2),pi)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2105
        H=eye(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2106
        H[n,n]=sign(randn)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2107
    else:
        if (isvector(x)):
            n=numel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2109
            H=eye(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2110
            H[n,n]=sign(x[n]) + (x[n] == 0)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2111
        else:
            error('gallery: N or X must be a scalar or a vector for randhess matrix.')
    
    for i in arange(n,2,- 1).reshape(-1):
        ## Apply Givens rotation through angle x(i-1).
        theta=x[i - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2118
        c=cos(theta)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2119
        s=sin(theta)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2120
        H[cat(i - 1,i),:]=cat(dot(c,H[i - 1,:]) + dot(s,H[i,:]),dot(- s,H[i - 1,:]) + dot(c,H[i,:]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2121
    
    return H
    
if __name__ == '__main__':
    pass
    
    
@function
def rando(n=None,k=1,*args,**kwargs):
    varargin = rando.varargin
    nargin = rando.nargin

    ## RANDO   Random matrix with elements -1, 0 or 1.
  ##   A = RANDO(N, K) is a random N-by-N matrix with elements from
  ##   one of the following discrete distributions (default K = 1):
  ##     K = 1:  A(i,j) =  0 or 1    with equal probability,
  ##     K = 2:  A(i,j) = -1 or 1    with equal probability,
  ##     K = 3:  A(i,j) = -1, 0 or 1 with equal probability.
  ##   N may be a 2-vector, in which case the matrix is N(1)-by-N(2).
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for rando matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2)) or fix(n) != n):
            error('gallery: N must be an integer for rando matrix.')
        else:
            if (logical_not(isnumeric(k)) or logical_not(isscalar(k))):
                error('gallery: K must be a numeric scalar for smoke matrix.')
    
    ## Parameter n specifies dimension: m-by-n.
    m=n[1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2144
    n=n[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2145
    if (1) == (k):
        A=floor(rand(m,n) + 0.5)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2148
    else:
        if (2) == (k):
            A=dot(2,floor(rand(m,n) + 0.5)) - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2149
        else:
            if (3) == (k):
                A=round(dot(3,rand(m,n)) - 1.5)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2150
            else:
                error('gallery: unknown K \'%d\' for smoke matrix.',k)
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def randsvd(n=None,kappa=sqrt(1 / eps),mode=3,kl=n - 1,ku=kl,*args,**kwargs):
    varargin = randsvd.varargin
    nargin = randsvd.nargin

    ## RANDSVD  Random matrix with pre-assigned singular values.
  ##   RANDSVD(N, KAPPA, MODE, KL, KU) is a (banded) random matrix of order N
  ##   with COND(A) = KAPPA and singular values from the distribution MODE.
  ##   N may be a 2-vector, in which case the matrix is N(1)-by-N(2).
  ##   Available types:
  ##          MODE = 1:   one large singular value,
  ##          MODE = 2:   one small singular value,
  ##          MODE = 3:   geometrically distributed singular values,
  ##          MODE = 4:   arithmetically distributed singular values,
  ##          MODE = 5:   random singular values with unif. dist. logarithm.
  ##   If omitted, MODE defaults to 3, and KAPPA defaults to SQRT(1/EPS).
  ##   If MODE < 0 then the effect is as for ABS(MODE) except that in the
  ##   original matrix of singular values the order of the diagonal entries
  ##   is reversed: small to large instead of large to small.
  ##   KL and KU are the lower and upper bandwidths respectively; if they
  ##   are omitted a full matrix is produced.
  ##   If only KL is present, KU defaults to KL.
  ##   Special case: if KAPPA < 0 then a random full symmetric positive
  ##                 definite matrix is produced with COND(A) = -KAPPA and
  ##                 eigenvalues distributed according to MODE.
  ##                 KL and KU, if present, are ignored.
  ##
  ##   Reference:
  ##   N.J. Higham, Accuracy and Stability of Numerical Algorithms,
  ##      Society for Industrial and Applied Mathematics, Philadelphia, PA,
  ##      USA, 1996; sec. 26.3.
  ##
  ##   This routine is similar to the more comprehensive Fortran routine xLATMS
  ##   in the following reference:
  ##   J.W. Demmel and A. McKenney, A test matrix generation suite,
  ##   LAPACK Working Note #9, Courant Institute of Mathematical Sciences,
  ##   New York, 1989.
    
    if (nargin < 1 or nargin > 5):
        error('gallery: 1 to 5 arguments are required for randsvd matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2)) or fix(n) != n):
            error('gallery: N must be a 1 or 2 element integer vector for randsvd matrix.')
        else:
            if (logical_not(isnumeric(kappa)) or logical_not(isscalar(kappa))):
                error('gallery: KAPPA must be a numeric scalar for randsvd matrix.')
            else:
                if (abs(kappa) < 1):
                    error('gallery: KAPPA must larger than or equal to 1 for randsvd matrix.')
                else:
                    if (logical_not(isnumeric(mode)) or logical_not(isscalar(mode))):
                        error('gallery: MODE must be a numeric scalar for randsvd matrix.')
                    else:
                        if (logical_not(isnumeric(kl)) or logical_not(isscalar(kl))):
                            error('gallery: KL must be a numeric scalar for randsvd matrix.')
                        else:
                            if (logical_not(isnumeric(ku)) or logical_not(isscalar(ku))):
                                error('gallery: KU must be a numeric scalar for randsvd matrix.')
    
    posdef=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2207
    if (kappa < 0):
        posdef=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2209
        kappa=- kappa
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2210
    
    ## Parameter n specifies dimension: m-by-n.
    m=n[1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2214
    n=n[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2215
    p=min(cat(m,n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2216
    
    if (p == 1):
        A=randn(m,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2220
        A=A / norm(A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2221
        return A
    
    ##  Set up vector sigma of singular values.
    if (1) == (abs(mode)):
        sigma=ones(p,1) / kappa
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2228
        sigma[1]=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2229
    else:
        if (2) == (abs(mode)):
            sigma=ones(p,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2231
            sigma[p]=1 / kappa
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2232
        else:
            if (3) == (abs(mode)):
                factor=kappa ** (- 1 / (p - 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2234
                sigma=factor ** cat(arange(0,p - 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2235
            else:
                if (4) == (abs(mode)):
                    sigma=ones(p,1) - dot((arange(0,p - 1)).T / (p - 1),(1 - 1 / kappa))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2237
                else:
                    if (5) == (abs(mode)):
                        ## In this case cond (A) <= kappa.
                        rand('uniform')
                        sigma=exp(dot(- rand(p,1),log(kappa)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2241
                    else:
                        error('gallery: unknown MODE \'%d\' for randsvd matrix.',mode)
    
    ##  Convert to diagonal matrix of singular values.
    if (mode < 0):
        sigma=sigma[p:- 1:1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2248
    
    sigma=diag(sigma)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2250
    if (posdef):
        ## handle case where KAPPA was negative
        Q=qmult(p)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2254
        A=dot(dot(Q.T,sigma),Q)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2255
        A=(A + A.T) / 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2256
        return A
    
    if (m != n):
        ## Expand to m-by-n diagonal matrix
        sigma[m,n]=0
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2262
    
    if (kl == 0 and ku == 0):
        ## Diagonal matrix requested - nothing more to do.
        A=copy(sigma)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2267
    else:
        ##  A = U*sigma*V, where U, V are random orthogonal matrices from the
    ##  Haar distribution.
        A=qmult(sigma.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2271
        A=qmult(A.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2272
        if (kl < n - 1 or ku < n - 1):
            ## Bandwidth reduction
            A=bandred(A,kl,ku)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2276
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def redheff(n=None,*args,**kwargs):
    varargin = redheff.varargin
    nargin = redheff.nargin

    ## REDHEFF    A (0,1) matrix of Redheffer associated with the Riemann hypothesis.
  ##   A = REDHEFF(N) is an N-by-N matrix of 0s and 1s defined by
  ##       A(i,j) = 1 if j = 1 or if i divides j,
  ##       A(i,j) = 0 otherwise.
  ##   It has N - FLOOR(LOG2(N)) - 1 eigenvalues equal to 1,
  ##   a real eigenvalue (the spectral radius) approximately SQRT(N),
  ##   a negative eigenvalue approximately -SQRT(N),
  ##   and the remaining eigenvalues are provably ``small''.
  ##   Barrett and Jarvis (1992) conjecture that
  ##     ``the small eigenvalues all lie inside the unit circle
  ##       ABS(Z) = 1'',
  ##   and a proof of this conjecture, together with a proof that some
  ##   eigenvalue tends to zero as N tends to infinity, would yield
  ##   a new proof of the prime number theorem.
  ##   The Riemann hypothesis is true if and only if
  ##   DET(A) = O( N^(1/2+epsilon) ) for every epsilon > 0
  ##                                     (`!' denotes factorial).
  ##   See also RIEMANN.
  ##
  ##   Reference:
  ##   W.W. Barrett and T.J. Jarvis,
  ##   Spectral Properties of a Matrix of Redheffer,
  ##   Linear Algebra and Appl., 162 (1992), pp. 673-683.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for redheff matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for redheff matrix.')
    
    i=dot((arange(1,n)).T,ones(1,n))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2312
    A=logical_not(rem(i.T,i))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2313
    A[:,1]=ones(n,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2314
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def riemann(n=None,*args,**kwargs):
    varargin = riemann.varargin
    nargin = riemann.nargin

    ## RIEMANN    A matrix associated with the Riemann hypothesis.
  ##   A = RIEMANN(N) is an N-by-N matrix for which the
  ##   Riemann hypothesis is true if and only if
  ##   DET(A) = O( N! N^(-1/2+epsilon) ) for every epsilon > 0
  ##                                     (`!' denotes factorial).
  ##   A = B(2:N+1, 2:N+1), where
  ##   B(i,j) = i-1 if i divides j and -1 otherwise.
  ##   Properties include, with M = N+1:
  ##      Each eigenvalue E(i) satisfies ABS(E(i)) <= M - 1/M.
  ##      i <= E(i) <= i+1 with at most M-SQRT(M) exceptions.
  ##      All integers in the interval (M/3, M/2] are eigenvalues.
  ##
  ##   See also REDHEFF.
  ##
  ##   Reference:
  ##   F. Roesler, Riemann's hypothesis as an eigenvalue problem,
  ##   Linear Algebra and Appl., 81 (1986), pp. 153-198.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for riemann matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for riemann matrix.')
    
    n=n + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2342
    i=dot((arange(2,n)).T,ones(1,n - 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2343
    j=i.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2344
    A=multiply(i,(logical_not(rem(j,i)))) - ones(n - 1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2345
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def ris(n=None,*args,**kwargs):
    varargin = ris.varargin
    nargin = ris.nargin

    ## NOTE: this function was named dingdong in the original Test Matrix Toolbox
  ## RIS       Dingdong matrix - a symmetric Hankel matrix.
  ##   A = RIS(N) is the symmetric N-by-N Hankel matrix with
  ##                  A(i,j) = 0.5/(N-i-j+1.5).
  ##   The eigenvalues of A cluster around PI/2 and -PI/2.
  ##
  ##   Invented by F.N. Ris.
  ##
  ##   Reference:
  ##   J.C. Nash, Compact Numerical Methods for Computers: Linear
  ##   Algebra and Function Minimisation, second edition, Adam Hilger,
  ##   Bristol, 1990 (Appendix 1).
    
    if (nargin != 1):
        error('gallery: 1 argument is required for ris matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for ris matrix.')
    
    p=dot(- 2,(arange(1,n))) + (n + 1.5)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2368
    A=cauchy(p)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2369
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def smoke(n=None,k=0,*args,**kwargs):
    varargin = smoke.varargin
    nargin = smoke.nargin

    ## SMOKE     Smoke matrix - complex, with a `smoke ring' pseudospectrum.
  ##   SMOKE(N) is an N-by-N matrix with 1s on the
  ##   superdiagonal, 1 in the (N,1) position, and powers of
  ##   roots of unity along the diagonal.
  ##   SMOKE(N, 1) is the same except for a zero (N,1) element.
  ##   The eigenvalues of SMOKE(N, 1) are the N'th roots of unity;
  ##   those of SMOKE(N) are the N'th roots of unity times 2^(1/N).
  ##
  ##   Try PS(SMOKE(32)).  For SMOKE(N, 1) the pseudospectrum looks
  ##   like a sausage folded back on itself.
  ##   GERSH(SMOKE(N, 1)) is interesting.
  ##
  ##   Reference:
  ##   L. Reichel and L.N. Trefethen, Eigenvalues and pseudo-eigenvalues of
  ##   Toeplitz matrices, Linear Algebra and Appl., 162-164:153-185, 1992.
    
    if (nargin < 1 or nargin > 2):
        error('gallery: 1 to 2 arguments are required for smoke matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be an integer for smoke matrix.')
        else:
            if (logical_not(isnumeric(n)) or logical_not(isscalar(n))):
                error('gallery: K must be a numeric scalar for smoke matrix.')
    
    w=exp(dot(dot(2,pi),i) / n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2397
    A=diag(cat(w ** (arange(1,n - 1)),1)) + diag(ones(n - 1,1),1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2398
    if (0) == (k):
        A[n,1]=1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2401
    else:
        if (1) == (k):
            pass
        else:
            error('gallery: K must have a value of 0 or 1 for smoke matrix.')
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def toeppd(n=None,m=n,w=rand(m,1),theta=rand(m,1),*args,**kwargs):
    varargin = toeppd.varargin
    nargin = toeppd.nargin

    ## NOTE: this function was named pdtoep in the original Test Matrix Toolbox
  ## TOEPPD   Symmetric positive definite Toeplitz matrix.
  ##   TOEPPD(N, M, W, THETA) is an N-by-N symmetric positive (semi-)
  ##   definite (SPD) Toeplitz matrix, comprised of the sum of M rank 2
  ##   (or, for certain THETA, rank 1) SPD Toeplitz matrices.
  ##   Specifically,
  ##           T = W(1)*T(THETA(1)) + ... + W(M)*T(THETA(M)),
  ##   where T(THETA(k)) has (i,j) element COS(2*PI*THETA(k)*(i-j)).
  ##   Defaults: M = N, W = RAND(M,1), THETA = RAND(M,1).
  ##
  ##   Reference:
  ##   G. Cybenko and C.F. Van Loan, Computing the minimum eigenvalue of
  ##   a symmetric positive definite Toeplitz matrix, SIAM J. Sci. Stat.
  ##   Comput., 7 (1986), pp. 123-131.
    
    if (nargin < 1 or nargin > 4):
        error('gallery: 1 to 4 arguments are required for toeppd matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be a numeric integer for toeppd matrix.')
        else:
            if (logical_not(isnumeric(m)) or logical_not(isscalar(m)) or fix(m) != m):
                error('gallery: M must be a numeric integer for toeppd matrix.')
            else:
                if (numel(w) != m or numel(theta) != m):
                    error('gallery: W and THETA must be vectors of length M for toeppd matrix.')
    
    T=zeros(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2434
    E=dot(dot(2,pi),(dot((arange(1,n)).T,ones(1,n)) - dot(ones(n,1),(arange(1,n)))))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2435
    for i in arange(1,m).reshape(-1):
        T=T + dot(w[i],cos(dot(theta[i],E)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2438
    
    return T
    
if __name__ == '__main__':
    pass
    
    
@function
def toeppen(n=None,a=1,b=- 10,c=0,d=10,e=1,*args,**kwargs):
    varargin = toeppen.varargin
    nargin = toeppen.nargin

    ## NOTE: this function was named pentoep in the original Test Matrix Toolbox
  ## TOEPPEN   Pentadiagonal Toeplitz matrix (sparse).
  ##   P = TOEPPEN(N, A, B, C, D, E) is the N-by-N pentadiagonal
  ##   Toeplitz matrix with diagonals composed of the numbers
  ##   A =: P(3,1), B =: P(2,1), C =: P(1,1), D =: P(1,2), E =: P(1,3).
  ##   Default: (A,B,C,D,E) = (1,-10,0,10,1) (a matrix of Rutishauser).
  ##             This matrix has eigenvalues lying approximately on
  ##             the line segment 2*cos(2*t) + 20*i*sin(t).
  ##
  ##   Interesting plots are
  ##   PS(FULL(TOEPPEN(32,0,1,0,0,1/4)))  - `triangle'
  ##   PS(FULL(TOEPPEN(32,0,1/2,0,0,1)))  - `propeller'
  ##   PS(FULL(TOEPPEN(32,0,1/2,1,1,1)))  - `fish'
  ##
  ##   References:
  ##   R.M. Beam and R.F. Warming, The asymptotic spectra of
  ##      banded Toeplitz and quasi-Toeplitz matrices, SIAM J. Sci.
  ##      Comput. 14 (4), 1993, pp. 971-1006.
  ##   H. Rutishauser, On test matrices, Programmation en Mathematiques
  ##      Numeriques, Editions Centre Nat. Recherche Sci., Paris, 165,
  ##      1966, pp. 349-365.
    
    if (nargin < 1 or nargin > 6):
        error('gallery: 1 to 6 arguments are required for toeppen matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n)) or fix(n) != n):
            error('gallery: N must be a numeric integer for toeppen matrix.')
        else:
            if (any(logical_not(cellfun('isnumeric',cellarray([a,b,c,d,e])))) or any(cellfun('numel',cellarray([a,b,c,d,e])) != 1)):
                error('gallery: A, B, C, D and E must be numeric scalars for toeppen matrix.')
    
    P=spdiags(cat(dot(a,ones(n,1)),dot(b,ones(n,1)),dot(c,ones(n,1)),dot(d,ones(n,1)),dot(e,ones(n,1))),arange(- 2,2),n,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2473
    return P
    
if __name__ == '__main__':
    pass
    
    
@function
def tridiag(n=None,x=- 1,y=2,z=- 1,*args,**kwargs):
    varargin = tridiag.varargin
    nargin = tridiag.nargin

    ## TRIDIAG  Tridiagonal matrix (sparse).
  ##   TRIDIAG(X, Y, Z) is the tridiagonal matrix with subdiagonal X,
  ##   diagonal Y, and superdiagonal Z.
  ##   X and Z must be vectors of dimension one less than Y.
  ##   Alternatively TRIDIAG(N, C, D, E), where C, D, and E are all
  ##   scalars, yields the Toeplitz tridiagonal matrix of order N
  ##   with subdiagonal elements C, diagonal elements D, and superdiagonal
  ##   elements E.   This matrix has eigenvalues (Todd 1977)
  ##            D + 2*SQRT(C*E)*COS(k*PI/(N+1)), k=1:N.
  ##   TRIDIAG(N) is the same as TRIDIAG(N,-1,2,-1), which is
  ##   a symmetric positive definite M-matrix (the negative of the
  ##   second difference matrix).
  ##
  ##   References:
  ##   J. Todd, Basic Numerical Mathematics, Vol. 2: Numerical Algebra,
  ##     Birkhauser, Basel, and Academic Press, New York, 1977, p. 155.
  ##   D.E. Rutherford, Some continuant determinants arising in physics and
  ##     chemistry---II, Proc. Royal Soc. Edin., 63, A (1952), pp. 232-241.
    
    if (nargin != 1 and nargin != 3 and nargin != 4):
        error('gallery: 1, 3, or 4 arguments are required for tridiag matrix.')
    else:
        if (nargin == 3):
            z=copy(y)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2500
            y=copy(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2501
            x=copy(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2502
    
    ## Force column vectors
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2506
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2507
    z=ravel(z)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2508
    if (isscalar(x) and isscalar(y) and isscalar(z)):
        x *= ones(n - 1,1)
        z *= ones(n - 1,1)
        y *= ones(n,1)
    else:
        if (numel(y) != numel(x) + 1):
            error('gallery: X must have one element less than Y for tridiag matrix.')
        else:
            if (numel(y) != numel(z) + 1):
                error('gallery: Z must have one element less than Y for tridiag matrix.')
    
    ##  T = diag (x, -1) + diag (y) + diag (z, 1);  # For non-sparse matrix.
    n=numel(y)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2521
    T=spdiags(cat(cat([x],[0]),y,cat([0],[z])),arange(- 1,1),n,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2522
    return T
    
if __name__ == '__main__':
    pass
    
    
@function
def triw(n=None,alpha=- 1,k=n(end()) - 1,*args,**kwargs):
    varargin = triw.varargin
    nargin = triw.nargin

    ## TRIW   Upper triangular matrix discussed by Wilkinson and others.
  ##   TRIW(N, ALPHA, K) is the upper triangular matrix with ones on
  ##   the diagonal and ALPHAs on the first K >= 0 superdiagonals.
  ##   N may be a 2-vector, in which case the matrix is N(1)-by-N(2) and
  ##   upper trapezoidal.
  ##   Defaults: ALPHA = -1,
  ##             K = N - 1     (full upper triangle).
  ##   TRIW(N) is a matrix discussed by Kahan, Golub and Wilkinson.
  ##
  ##   Ostrowski (1954) shows that
  ##     COND(TRIW(N,2)) = COT(PI/(4*N))^2,
  ##   and for large ABS(ALPHA),
  ##     COND(TRIW(N,ALPHA)) is approximately ABS(ALPHA)^N*SIN(PI/(4*N-2)).
  ##
  ##   Adding -2^(2-N) to the (N,1) element makes TRIW(N) singular,
  ##   as does adding -2^(1-N) to all elements in the first column.
  ##
  ##   References:
  ##   G.H. Golub and J.H. Wilkinson, Ill-conditioned eigensystems and the
  ##      computation of the Jordan canonical form, SIAM Review,
  ##      18(4), 1976, pp. 578-619.
  ##   W. Kahan, Numerical linear algebra, Canadian Math. Bulletin,
  ##      9 (1966), pp. 757-801.
  ##   A.M. Ostrowski, On the spectrum of a one-parametric family of
  ##      matrices, J. Reine Angew. Math., 193 (3/4), 1954, pp. 143-160.
  ##   J.H. Wilkinson, Singular-value decomposition---basic aspects,
  ##      in D.A.H. Jacobs, ed., Numerical Software---Needs and Availability,
  ##      Academic Press, London, 1978, pp. 109-135.
    
    if (nargin < 1 or nargin > 3):
        error('gallery: 1 to 3 arguments are required for triw matrix.')
    else:
        if (logical_not(isnumeric(n)) or all(numel(n) != cat(1,2))):
            error('gallery: N must be a 1 or 2 elements vector for triw matrix.')
        else:
            if (logical_not(isscalar(alpha))):
                error('gallery: ALPHA must be a scalar for triw matrix.')
            else:
                if (logical_not(isscalar(k)) or logical_not(isnumeric(k)) or fix(k) != k or k < 0):
                    error('gallery: K must be a numeric integer >= 0 for triw matrix.')
    
    m=n[1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2565
    
    n=n[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2566
    t=tril(eye(m,n) + dot(alpha,triu(ones(m,n),1)),k)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2568
    return t
    
if __name__ == '__main__':
    pass
    
    
@function
def uniformdata(varargin=None,*args,**kwargs):
    varargin = uniformdata.varargin
    nargin = uniformdata.nargin

    if (nargin < 2):
        error('gallery: At least 2 arguments required for uniformdata matrix.')
    
    if (isnumeric(varargin[end()])):
        jidx=varargin[end()]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2577
        svec=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2578
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2579
    else:
        if (ischar(varargin[end()])):
            if (nargin < 3):
                error(cat('gallery: CLASS argument requires 3 inputs ','for uniformdata matrix.'))
            jidx=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2585
            svec=matlabarray(cat(varargin[1:end() - 1]))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2586
            varargin[end() - 1]=[]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2587
        else:
            error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for uniformdata matrix'))
    
    if (logical_not((isnumeric(jidx) and isscalar(jidx) and jidx == fix(jidx) and jidx >= 0 and jidx <= 4294967295))):
        error(cat('gallery: J must be an integer in the range [0, 2^32-1] ','for uniformdata matrix'))
    
    ## Save and restore random state.  Initialization done so that reproducible
  ## data is available from gallery depending on the jidx and size vector.
    randstate=rand('state')
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2602
    try:
        rand('state',svec)
        A=rand(varargin[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2605
    finally:
        rand('state',randstate)
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def wathen(nx=None,ny=None,k=0,*args,**kwargs):
    varargin = wathen.varargin
    nargin = wathen.nargin

    ## WATHEN returns the Wathen matrix.
  ##
  ## Discussion:
  ##
  ##   The Wathen matrix is a finite element matrix which is sparse.
  ##
  ##   The entries of the matrix depend in part on a physical quantity
  ##   related to density.  That density is here assigned random values between
  ##   0 and 100.
  ##
  ##   A = WATHEN ( NX, NY ) is a sparse random N-by-N finite element matrix
  ##   where N = 3*NX*NY + 2*NX + 2*NY + 1.
  ##
  ##   A is the consistent mass matrix for a regular NX-by-NY
  ##   grid of 8-node (serendipity) elements in 2 space dimensions.
  ##
  ##   Here is an illustration for NX = 3, NX = 2:
  ##
  ##    23-24-25-26-27-28-29
  ##     |     |     |     |
  ##    19    20    21    22
  ##     |     |     |     |
  ##    12-13-14-15-16-17-18
  ##     |     |     |     |
  ##     8     9    10    11
  ##     |     |     |     |
  ##     1--2--3--4--5--6--7
  ##
  ##   For this example, the total number of nodes is, as expected,
  ##
  ##     N = 3 * 3 * 2 + 2 * 2 + 2 * 3 + 1 = 29.
  ##
  ##   A is symmetric positive definite for any (positive) values of
  ##   the density, RHO(NX,NY), which is chosen randomly in this routine.
  ##
  ##   In particular, if D = DIAG(DIAG(A)), then
  ##     0.25 <= EIG(INV(D)*A) <= 4.5
  ##   for any positive integers NX and NY and any densities RHO(NX,NY).
  ##
  ##   A = WATHEN ( NX, NY, 1 ) returns the diagonally scaled matrix.
  ##
  ## Modified:
  ##
  ##   17 September 2007
  ##
  ## Author:
  ##
  ##   Nicholas Higham
  ##
  ## Reference:
  ##
  ##   Nicholas Higham,
  ##   Algorithm 694: A Collection of Test Matrices in MATLAB,
  ##   ACM Transactions on Mathematical Software,
  ##   Volume 17, Number 3, September 1991, pages 289-305.
  ##
  ##   Andrew Wathen,
  ##   Realistic eigenvalue bounds for the Galerkin mass matrix,
  ##   IMA Journal of Numerical Analysis,
  ##   Volume 7, 1987, pages 449-457.
  ##
  ## Parameters:
  ##
  ##   Input, integer NX, NY, the number of elements in the X and Y directions
  ##   of the finite element grid.  NX and NY must each be at least 1.
  ##
  ##   Optional input, integer K, is used to request that the diagonally scaled
  ##   version of the matrix be returned.  This happens if K is specified with
  ##   the value 1.
  ##
  ##   Output, sparse real A(N,N), the matrix.  The dimension N is determined by
  ##   NX and NY, as described above.  A is stored in the MATLAB sparse matrix
  ##   format.
    
    if (nargin < 2 or nargin > 3):
        error('gallery: 2 or 3 arguments are required for wathen matrix.')
    else:
        if (logical_not(isnumeric(nx)) or logical_not(isscalar(nx)) or nx < 1):
            error('gallery: NX must be a positive scalar for wathen matrix.')
        else:
            if (logical_not(isnumeric(ny)) or logical_not(isscalar(ny)) or ny < 1):
                error('gallery: NY must be a positive scalar for wathen matrix.')
            else:
                if (logical_not(isscalar(k))):
                    error('gallery: K must be a scalar for wathen matrix.')
    
    e1=matlabarray(cat(6,- 6,2,- 8,- 6,32,- 6,20,2,- 6,6,- 6,- 8,20,- 6,32))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2697
    e2=matlabarray(cat(3,- 8,2,- 6,- 8,16,- 8,20,2,- 8,3,- 8,- 6,20,- 8,16))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2702
    e=cat(e1,e2,e2.T,e1) / 45
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2707
    n=dot(dot(3,nx),ny) + dot(2,nx) + dot(2,ny) + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2710
    A=sparse(n,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2712
    rho=dot(100,rand(nx,ny))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2714
    for j in arange(1,ny).reshape(-1):
        for i in arange(1,nx).reshape(-1):
            ##
      ##   For the element (I,J), determine the indices of the 8 nodes.
      ##
            nn[1]=dot(dot(3,j),nx) + dot(2,i) + dot(2,j) + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2721
            nn[2]=nn[1] - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2722
            nn[3]=nn[2] - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2723
            nn[4]=dot((dot(3,j) - 1),nx) + dot(2,j) + i - 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2724
            nn[5]=dot(dot(3,(j - 1)),nx) + dot(2,i) + dot(2,j) - 3
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2725
            nn[6]=nn[5] + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2726
            nn[7]=nn[6] + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2727
            nn[8]=nn[4] + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2728
            em=dot(e,rho[i,j])
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2730
            for krow in arange(1,8).reshape(-1):
                for kcol in arange(1,8).reshape(-1):
                    A[nn[krow],nn[kcol]]=A[nn[krow],nn[kcol]] + em[krow,kcol]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2734
    
    ## If requested, return A with diagonal scaling.
    if (k):
        A=numpy.linalg.solve(diag(diag(A)),A)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2743
    
    return A
    
if __name__ == '__main__':
    pass
    
    
@function
def wilk(n=None,*args,**kwargs):
    varargin = wilk.varargin
    nargin = wilk.nargin

    ## WILK   Various specific matrices devised/discussed by Wilkinson.
  ##   [A, b] = WILK(N) is the matrix or system of order N.
  ##   N = 3: upper triangular system Ux=b illustrating inaccurate solution.
  ##   N = 4: lower triangular system Lx=b, ill-conditioned.
  ##   N = 5: HILB(6)(1:5,2:6)*1.8144.  Symmetric positive definite.
  ##   N = 21: W21+, tridiagonal.   Eigenvalue problem.
  ##
  ##   References:
  ##   J.H. Wilkinson, Error analysis of direct methods of matrix inversion,
  ##      J. Assoc. Comput. Mach., 8 (1961),  pp. 281-330.
  ##   J.H. Wilkinson, Rounding Errors in Algebraic Processes, Notes on Applied
  ##      Science No. 32, Her Majesty's Stationery Office, London, 1963.
  ##   J.H. Wilkinson, The Algebraic Eigenvalue Problem, Oxford University
  ##      Press, 1965.
    
    if (nargin != 1):
        error('gallery: 1 argument is required for wilk matrix.')
    else:
        if (logical_not(isnumeric(n)) or logical_not(isscalar(n))):
            error('gallery: N must be a numeric scalar for wilk matrix.')
    
    if (n == 3):
        ## Wilkinson (1961) p.323.
        A=matlabarray(cat(1e-10,0.9,- 0.4,0,0.9,- 0.4,0,0,1e-10))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2771
        b=matlabarray(cat(0,0,1))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2775
    else:
        if (n == 4):
            ## Wilkinson (1963) p.105.
            A=matlabarray(cat(9.143e-05,0,0,0,0.8762,7.156e-05,0,0,0.7943,0.8143,9.504e-05,0,0.8017,0.6123,0.7165,7.123e-05))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2781
            b=matlabarray(cat(0.6524,0.3127,0.4186,0.7853))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2786
        else:
            if (n == 5):
                ## Wilkinson (1965), p.234.
                A=hilb(6)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2793
                A=dot(A[1:5,2:6],1.8144)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2794
            else:
                if (n == 21):
                    ## Wilkinson (1965), p.308.
                    E=diag(ones(n - 1,1),1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2798
                    m=(n - 1) / 2
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2799
                    A=diag(abs(arange(- m,m))) + E + E.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2800
                else:
                    error('gallery: unknown N \'%d\' for wilk matrix.',n)
    
    return A,b
    
if __name__ == '__main__':
    pass
    
    ## NOTE: bandred is part of the Test Matrix Toolbox and is used by randsvd()
    
@function
def bandred(A=None,kl=None,ku=None,*args,**kwargs):
    varargin = bandred.varargin
    nargin = bandred.nargin

    ## BANDRED  Band reduction by two-sided unitary transformations.
  ##   B = BANDRED(A, KL, KU) is a matrix unitarily equivalent to A
  ##   with lower bandwidth KL and upper bandwidth KU
  ##   (i.e. B(i,j) = 0 if i > j+KL or j > i+KU).
  ##   The reduction is performed using Householder transformations.
  ##   If KU is omitted it defaults to KL.
  ##
  ##   Called by RANDSVD.
  ##   This is a `standard' reduction.  Cf. reduction to bidiagonal form
  ##   prior to computing the SVD.  This code is a little wasteful in that
  ##   it computes certain elements which are immediately set to zero!
  ##
  ##   Reference:
  ##   G.H. Golub and C.F. Van Loan, Matrix Computations, second edition,
  ##   Johns Hopkins University Press, Baltimore, Maryland, 1989.
  ##   Section 5.4.3.
    
    ##  Check for special case where order of left/right transformations matters.
  ##  Easiest approach is to work on the transpose, flipping back at the end.
    flip=copy(false)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2828
    if (ku == 0):
        flip=copy(true)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2830
        A=A.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2831
        ku,kl=deal(kl,ku,nargout=2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2832
    
    m,n=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2835
    for j in arange(1,min(min(m,n),max(m - kl - 1,n - ku - 1))).reshape(-1):
        if (j + kl + 1 <= m):
            v,beta=house(A[j + kl:m,j],nargout=2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2839
            temp=A[j + kl:m,j:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2840
            A[j + kl:m,j:n]=temp - dot(dot(beta,v),(dot(v.T,temp)))
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2841
            A[j + kl + 1:m,j]=zeros(m - j - kl,1)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2842
        if (j + ku + 1 <= n):
            v,beta=house(A[j,j + ku:n].T,nargout=2)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2846
            temp=A[j:m,j + ku:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2847
            A[j:m,j + ku:n]=temp - dot(dot(beta,(dot(temp,v))),v.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2848
            A[j,j + ku + 1:n]=zeros(1,n - j - ku)
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2849
    
    if (flip):
        A=A.T
# /home/lei/octave-4.0.2/scripts/special-matrix/gallery.m:2854
    
    return A
    
if __name__ == '__main__':
    pass
    
    ## BIST testing for just a few functions to verify that the main gallery
## dispatch function works.
#assert (gallery ("clement", 3), [0 1 0; 2 0 2; 0 1 0])
#assert (gallery ("invhess", 2), [1 -1; 1 2])
    
    ## Test input validation of main dispatch function only
    
    
    
    
    
    ## Copyright (C) 1999-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} magic (@var{n})
##
## Create an @var{n}-by-@var{n} magic square.
##
## A magic square is an arrangement of the integers @code{1:n^2} such that the
## row sums, column sums, and diagonal sums are all equal to the same value.
##
## Note: @var{n} must be greater than 2 for the magic square to exist.
## @end deftypefn
    
    
@function
def magic(n=None,*args,**kwargs):
    varargin = magic.varargin
    nargin = magic.nargin

    if (nargin != 1):
        print_usage()
    
    if (n != fix(n) or n < 0 or n == 2):
        error('magic: N must be a positive integer not equal to 2')
    
    if (n == 0):
        A=matlabarray([])
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:42
    else:
        if (mod(n,2) == 1):
            shift=floor((arange(0,dot(n,n) - 1)) / n)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:46
            c=mod(cat(arange(1,dot(n,n))) - shift + (n - 3) / 2,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:47
            r=mod(cat(arange(dot(n,n),1,- 1)) + dot(2,shift),n)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:48
            A[dot(c,n) + r + 1]=arange(1,dot(n,n))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:49
            A=reshape(A,n,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:50
        else:
            if (mod(n,4) == 0):
                A=reshape(arange(1,dot(n,n)),n,n).T
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:54
                I=matlabarray(cat(arange(1,n,4),arange(4,n,4)))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:55
                J=fliplr(I)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:56
                A[I,I]=A[J,J]
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:57
                I=matlabarray(cat(arange(2,n,4),arange(3,n,4)))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:58
                J=fliplr(I)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:59
                A[I,I]=A[J,J]
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:60
            else:
                if (mod(n,4) == 2):
                    m=n / 2
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:64
                    A=magic(m)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:65
                    A=matlabarray(cat([A,A + dot(dot(2,m),m)],[A + dot(dot(3,m),m),A + dot(m,m)]))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:66
                    k=(m - 1) / 2
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:67
                    if (k > 1):
                        I=arange(1,m)
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:69
                        J=matlabarray(cat(arange(2,k),arange(n - k + 2,n)))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:70
                        A[cat(I,I + m),J]=A[cat(I + m,I),J]
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:71
                    I=matlabarray(cat(arange(1,k),arange(k + 2,m)))
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:73
                    A[cat(I,I + m),1]=A[cat(I + m,I),1]
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:74
                    I=k + 1
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:75
                    A[cat(I,I + m),I]=A[cat(I + m,I),I]
# /home/lei/octave-4.0.2/scripts/special-matrix/magic.m:76
    
    return A
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hadamard (@var{n})
## Construct a Hadamard matrix (@nospell{Hn}) of size @var{n}-by-@var{n}.
##
## The size @var{n} must be of the form @math{2^k * p} in which p is one of
## 1, 12, 20 or 28.  The returned matrix is normalized, meaning
## @w{@code{Hn(:,1) == 1}} and @w{@code{Hn(1,:) == 1}}.
##
## Some of the properties of Hadamard matrices are:
##
## @itemize @bullet
## @item
## @code{kron (Hm, Hn)} is a Hadamard matrix of size @var{m}-by-@var{n}.
##
## @item
## @code{Hn * Hn' = @var{n} * eye (@var{n})}.
##
## @item
## The rows of @nospell{Hn} are orthogonal.
##
## @item
## @code{det (@var{A}) <= abs (det (Hn))} for all @var{A} with
## @w{@code{abs (@var{A}(i, j)) <= 1}}.
##
## @item
## Multiplying any row or column by -1 and the matrix will remain a Hadamard
## matrix.
## @end itemize
## @seealso{compan, hankel, toeplitz}
## @end deftypefn
    
    ## Reference [1] contains a list of Hadamard matrices up to n=256.
## See code for h28 in hadamard.m for an example of how to extend
## this function for additional p.
##
## References:
## [1] A Library of Hadamard Matrices, N. J. A. Sloane
##     http://www.research.att.com/~njas/hadamard/
    
    
@function
def hadamard(n=None,*args,**kwargs):
    varargin = hadamard.varargin
    nargin = hadamard.nargin

    if (nargin != 1):
        print_usage()
    
    ## Find k if n = 2^k*p.
    k=0
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:69
    while (n > 1 and fix(n / 2) == n / 2):

        k
        n /= 2

    
    ## Find base hadamard.
  ## Except for n=2^k, need a multiple of 4.
    if (n != 1):
        k -= 2
    
    ## Trigger error if not a multiple of 4.
    if (k < 0):
        n=- 1
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:83
    
    if 1 == (n):
        h=1
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:88
    else:
        if 3 == (n):
            h=h12()
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:90
        else:
            if 5 == (n):
                h=h20()
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:92
            else:
                if 7 == (n):
                    h=h28()
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:94
                else:
                    error('hadamard: N must be 2^k*p, for p = 1, 12, 20 or 28')
    
    ## Build H(2^k*n) from kron(H(2^k),H(n)).
    h2=matlabarray(cat([1,1],[1,- 1]))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:100
    while (true):

        if (fix(k / 2) != k / 2):
            h=kron(h2,h)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:103
        k=fix(k / 2)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:105
        if (k == 0):
            break
        h2=kron(h2,h2)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:109

    
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def h12(*args,**kwargs):
    varargin = h12.varargin
    nargin = h12.nargin

    tu=matlabarray(cat(- 1,+ 1,- 1,+ 1,+ 1,+ 1,- 1,- 1,- 1,+ 1,- 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:115
    tl=matlabarray(cat(- 1,- 1,+ 1,- 1,- 1,- 1,+ 1,+ 1,+ 1,- 1,+ 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:116
    
    h=ones(12)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:118
    h[2:end(),2:end()]=toeplitz(tu,tl)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:119
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def h20(*args,**kwargs):
    varargin = h20.varargin
    nargin = h20.nargin

    tu=matlabarray(cat(+ 1,- 1,- 1,+ 1,+ 1,+ 1,+ 1,- 1,+ 1,- 1,+ 1,- 1,- 1,- 1,- 1,+ 1,+ 1,- 1,- 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:123
    tl=matlabarray(cat(+ 1,- 1,- 1,+ 1,+ 1,- 1,- 1,- 1,- 1,+ 1,- 1,+ 1,- 1,+ 1,+ 1,+ 1,+ 1,- 1,- 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:124
    
    h=ones(20)
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:126
    h[2:end(),2:end()]=fliplr(toeplitz(tu,tl))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:127
    return h
    
if __name__ == '__main__':
    pass
    
    
@function
def h28(*args,**kwargs):
    varargin = h28.varargin
    nargin = h28.nargin

    ## Williamson matrix construction from
  ## http://www.research.att.com/~njas/hadamard/had.28.will.txt
  ## Normalized so that each row and column starts with +1
    h=matlabarray(cat(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,1,- 1,- 1,- 1,1,1,1,1,1,- 1,1,1,1,1,- 1,1,- 1,1,- 1,1,- 1,1,- 1,- 1,- 1,- 1,1,- 1,1,1,- 1,- 1,1,- 1,- 1,- 1,- 1,1,1,- 1,1,- 1,1,1,1,1,1,1,- 1,- 1,1,- 1,- 1,- 1,1,1,1,1,1,- 1,1,1,1,1,1,- 1,- 1,- 1,- 1,- 1,- 1,- 1,1,- 1,1,1,- 1,- 1,- 1,1,- 1,- 1,1,1,- 1,1,1,1,1,1,- 1,- 1,- 1,1,1,1,- 1,1,- 1,1,- 1,- 1,- 1,1,- 1,- 1,- 1,- 1,1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,1,1,- 1,- 1,- 1,1,1,1,1,1,1,- 1,1,- 1,- 1,- 1,- 1,- 1,1,- 1,1,- 1,- 1,- 1,1,- 1,1,1,1,- 1,1,1,1,1,- 1,1,- 1,1,- 1,1,1,- 1,1,1,1,1,- 1,- 1,1,- 1,- 1,- 1,- 1,1,1,1,- 1,- 1,- 1,- 1,1,- 1,- 1,1,1,1,1,- 1,1,- 1,- 1,1,1,1,1,1,- 1,- 1,- 1,- 1,- 1,1,- 1,- 1,- 1,1,- 1,1,1,1,1,- 1,- 1,1,- 1,1,1,1,1,1,- 1,- 1,- 1,- 1,- 1,- 1,1,1,1,- 1,1,- 1,- 1,- 1,- 1,- 1,1,1,1,- 1,- 1,1,1,1,1,- 1,1,1,1,- 1,- 1,- 1,- 1,1,- 1,1,1,- 1,- 1,- 1,1,1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,1,1,1,- 1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,1,- 1,1,1,- 1,- 1,1,- 1,- 1,1,1,- 1,1,- 1,- 1,- 1,1,1,1,- 1,- 1,1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,- 1,- 1,1,1,1,1,- 1,- 1,1,1,1,1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,- 1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,1,1,- 1,1,1,- 1,1,- 1,1,- 1,1,1,- 1,1,- 1,- 1,1,- 1,- 1,1,- 1,1,- 1,1,- 1,- 1,1,- 1,1,1,- 1,1,- 1,- 1,1,- 1,1,1,1,- 1,- 1,- 1,- 1,- 1,- 1,1,1,- 1,1,- 1,1,1,1,1,- 1,- 1,1,1,- 1,1,- 1,1,1,1,1,1,- 1,- 1,1,- 1,1,- 1,- 1,- 1,- 1,1,- 1,- 1,- 1,- 1,1,- 1,1,1,1,1,- 1,1,- 1,1,- 1,1,- 1,1,- 1,1,1,1,- 1,1,- 1,- 1,1,- 1,1,1,- 1,1,- 1,- 1,- 1,- 1,1,- 1,1,- 1,1,- 1,1,1,1,1,1,- 1,1,- 1,- 1,1,- 1,1,- 1,- 1,1,1,- 1,- 1,- 1,- 1,1,- 1,1,1,1,- 1,1,- 1,1,1,- 1,1,- 1,- 1,1,1,1,- 1,1,- 1,- 1,- 1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,1,- 1,- 1,1,- 1,1,- 1,- 1,- 1,- 1,1,1,1,- 1,1,- 1,1,1,- 1,- 1,- 1,- 1,- 1,1,1,1,1,1,1,1,- 1,- 1,1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,- 1,- 1,- 1,1,- 1,1,1,1,- 1,1,- 1,- 1,1,- 1,- 1,1,1,1,- 1,1,- 1,- 1,1,1,- 1,1,1,- 1,1,- 1,1,- 1,- 1,1,- 1,1,- 1,1,- 1,1,- 1,- 1,- 1,1,1,1,1,1,- 1,1,1,- 1,- 1,1,1,- 1,1,- 1,- 1,1,- 1,- 1,1,1,1,- 1,1,- 1,- 1,- 1,1,- 1,- 1,1,- 1,1,1,- 1,1,1,- 1,- 1,- 1,1,- 1,1,1,1,- 1,1,1,1,- 1,- 1,1,- 1,- 1,1,- 1,- 1,- 1,1,1,1,- 1,- 1,1,- 1,- 1,1,- 1,1,- 1,1,1,- 1,1,- 1,1,- 1,1,- 1,- 1,1,1,- 1,- 1,- 1,1,1,- 1,1,1,- 1,- 1,1,1,- 1,- 1,- 1,1,- 1,- 1,1,1,- 1,1,1,1,- 1,- 1,1,1,- 1,- 1,1,- 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hadamard.m:134
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Peter Ekberg
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pascal (@var{n})
## @deftypefnx {Function File} {} pascal (@var{n}, @var{t})
## Return the Pascal matrix of order @var{n} if @code{@var{t} = 0}.
##
## The default value of @var{t} is 0.
##
## When @code{@var{t} = 1}, return the pseudo-lower triangular
## Cholesky@tie{}factor of the Pascal matrix (The sign of some columns may be
## negative).  This matrix is its own inverse, that is
## @code{pascal (@var{n}, 1) ^ 2 == eye (@var{n})}.
##
## If @code{@var{t} = -1}, return the true Cholesky@tie{}factor with strictly
## positive values on the diagonal.
##
## If @code{@var{t} = 2}, return a transposed and permuted version of
## @code{pascal (@var{n}, 1)}, which is the cube root of the identity matrix.
## That is, @code{pascal (@var{n}, 2) ^ 3 == eye (@var{n})}.
##
## @seealso{chol}
## @end deftypefn
    
    ## Author: Peter Ekberg
##         (peda)
    
    
@function
def pascal(n=None,t=0,*args,**kwargs):
    varargin = pascal.varargin
    nargin = pascal.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not((isscalar(n) and isscalar(t)))):
            error('pascal: N and T must be scalars')
        else:
            if (logical_not(any(t == cat(- 1,0,1,2)))):
                error('pascal: expecting T to be -1, 0, 1, or 2, found %d',t)
    
    retval=zeros(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:55
    if (n > 0):
        retval[:,1]=1
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:57
    
    if (t == - 1):
        for j in arange(2,n).reshape(-1):
            retval[j:n,j]=cumsum(retval[j - 1:n - 1,j - 1])
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:62
    else:
        for j in arange(2,n).reshape(-1):
            retval[j:n,j]=- cumsum(retval[j - 1:n - 1,j - 1])
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:66
    
    if (t == 0):
        retval=dot(retval,retval.T)
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:71
    else:
        if (t == 2):
            retval=rot90(retval,3)
# /home/lei/octave-4.0.2/scripts/special-matrix/pascal.m:73
            if (rem(n,2) != 1):
                retval *= - 1
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 Dirk Laurie
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} invhilb (@var{n})
## Return the inverse of the Hilbert matrix of order @var{n}.
##
## This can be computed exactly using
## @tex
## $$\eqalign{
##   A_{ij} &= -1^{i+j} (i+j-1)
##              \left( \matrix{n+i-1 \cr n-j } \right)
##              \left( \matrix{n+j-1 \cr n-i } \right)
##              \left( \matrix{i+j-2 \cr i-2 } \right)^2 \cr
##          &= { p(i)p(j) \over (i+j-1) }
## }$$
## where
## $$
##   p(k) = -1^k \left( \matrix{ k+n-1 \cr k-1 } \right)
##               \left( \matrix{ n \cr k } \right)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##
##            (i+j)         /n+i-1\  /n+j-1\   /i+j-2\ 2
## A(i,j) = -1      (i+j-1)(       )(       ) (       )
##                          \ n-j /  \ n-i /   \ i-2 /
##
##        = p(i) p(j) / (i+j-1)
##
## @end group
## @end example
##
## @noindent
## where
##
## @example
## @group
##          k  /k+n-1\   /n\
## p(k) = -1  (       ) (   )
##             \ k-1 /   \k/
## @end group
## @end example
##
## @end ifnottex
## The validity of this formula can easily be checked by expanding the binomial
## coefficients in both formulas as factorials.  It can be derived more
## directly via the theory of Cauchy matrices.  See @nospell{J. W. Demmel},
## @cite{Applied Numerical Linear Algebra}, p. 92.
##
## Compare this with the numerical calculation of @code{inverse (hilb (n))},
## which suffers from the ill-conditioning of the Hilbert matrix, and the
## finite precision of your computer's floating point arithmetic.
## @seealso{hilb}
## @end deftypefn
    
    ## Author: Dirk Laurie <dlaurie@na-net.ornl.gov>
    
    
@function
def invhilb(n=None,*args,**kwargs):
    varargin = invhilb.varargin
    nargin = invhilb.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('invhilb: N must be a scalar integer')
    
    ## The point about the second formula above is that when vectorized,
  ## p(k) is evaluated for k=1:n which involves O(n) calls to bincoeff
  ## instead of O(n^2).
  ##
  ## We evaluate the expression as (-1)^(i+j)*(p(i)*p(j))/(i+j-1) except
  ## when p(i)*p(j) would overflow.  In cases where p(i)*p(j) is an exact
  ## machine number, the result is also exact.  Otherwise we calculate
  ## (-1)^(i+j)*p(i)*(p(j)/(i+j-1)).
  ##
  ## The Octave bincoeff routine uses transcendental functions (gammaln
  ## and exp) rather than multiplications, for the sake of speed.
  ## However, it rounds the answer to the nearest integer, which
  ## justifies the claim about exactness made above.
    
    retval=zeros(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:99
    k=matlabarray(cat(arange(1,n)))
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:100
    p=multiply(multiply(k,bincoeff(k + n - 1,k - 1)),bincoeff(n,k))
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:101
    p[2:2:n]=- p[2:2:n]
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:102
    if (n < 203):
        for l in arange(1,n).reshape(-1):
            retval[l,:]=(dot(p[l],p)) / cat(arange(l,l + n - 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:105
    else:
        for l in arange(1,n).reshape(-1):
            retval[l,:]=dot(p[l],(p / cat(arange(l,l + n - 1))))
# /home/lei/octave-4.0.2/scripts/special-matrix/invhilb.m:109
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hankel (@var{c})
## @deftypefnx {Function File} {} hankel (@var{c}, @var{r})
## Return the Hankel matrix constructed from the first column @var{c}, and
## (optionally) the last row @var{r}.
##
## If the last element of @var{c} is not the same as the first element of
## @var{r}, the last element of @var{c} is used.  If the second argument is
## omitted, it is assumed to be a vector of zeros with the same size as @var{c}.
##
## A Hankel matrix formed from an m-vector @var{c}, and an n-vector @var{r},
## has the elements
## @tex
## $$
## H(i, j) = \cases{c_{i+j-1},&$i+j-1\le m$;\cr r_{i+j-m},&otherwise.\cr}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## H(i,j) = c(i+j-1),  i+j-1 <= m;
## H(i,j) = r(i+j-m),  otherwise
## @end group
## @end example
##
## @end ifnottex
## @seealso{hadamard, toeplitz}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def hankel(c=None,r=None,*args,**kwargs):
    varargin = hankel.varargin
    nargin = hankel.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        if (logical_not(isvector(c))):
            error('hankel: C must be a vector')
        nr=length(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:63
        nc=copy(nr)
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:64
        data=matlabarray(cat([ravel(c)],[zeros(nr,1)]))
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:65
    else:
        if (logical_not((isvector(c) and isvector(r)))):
            error('hankel: C and R must be vectors')
        else:
            if (r[1] != c[end()]):
                warning('hankel: column wins anti-diagonal conflict')
        nr=length(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:75
        nc=length(r)
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:76
        data=matlabarray(cat([ravel(c)],[ravel(r[2:end()])]))
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:77
    
    slices=cellslices(data,arange(1,nc),arange(nr,nc + nr - 1,1))
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:81
    retval=horzcat(slices[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/hankel.m:82
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} vander (@var{c})
## @deftypefnx {Function File} {} vander (@var{c}, @var{n})
## Return the Vandermonde matrix whose next to last column is @var{c}.
##
## If @var{n} is specified, it determines the number of columns; otherwise,
## @var{n} is taken to be equal to the length of @var{c}.
##
## A Vandermonde matrix has the form:
## @tex
## $$
## \left[\matrix{c_1^{n-1}  & \cdots & c_1^2  & c_1    & 1      \cr
##               c_2^{n-1}  & \cdots & c_2^2  & c_2    & 1      \cr
##               \vdots     & \ddots & \vdots & \vdots & \vdots \cr
##               c_n^{n-1}  & \cdots & c_n^2  & c_n    & 1      }\right]
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## c(1)^(n-1) @dots{} c(1)^2  c(1)  1
## c(2)^(n-1) @dots{} c(2)^2  c(2)  1
##     .     .      .      .    .
##     .       .    .      .    .
##     .         .  .      .    .
## c(n)^(n-1) @dots{} c(n)^2  c(n)  1
## @end group
## @end example
##
## @end ifnottex
## @seealso{polyfit}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def vander(c=None,n=None,*args,**kwargs):
    varargin = vander.varargin
    nargin = vander.nargin

    if (nargin == 1):
        n=length(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/vander.m:59
    else:
        if (nargin != 2):
            print_usage()
    
    if (logical_not(isvector(c))):
        error('vander: polynomial C must be a vector')
    
    ## avoiding many ^s appears to be faster for n >= 100.
    retval=zeros(length(c),n,class_(c))
# /home/lei/octave-4.0.2/scripts/special-matrix/vander.m:69
    d=1
# /home/lei/octave-4.0.2/scripts/special-matrix/vander.m:70
    c=ravel(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/vander.m:71
    for i in arange(n,1,- 1).reshape(-1):
        retval[:,i]=d
# /home/lei/octave-4.0.2/scripts/special-matrix/vander.m:73
        d * c
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} toeplitz (@var{c})
## @deftypefnx {Function File} {} toeplitz (@var{c}, @var{r})
## Return the Toeplitz matrix constructed from the first column @var{c},
## and (optionally) the first row @var{r}.
##
## If the first element of @var{r} is not the same as the first element of
## @var{c}, the first element of @var{c} is used.  If the second argument is
## omitted, the first row is taken to be the same as the first column.
##
## A square Toeplitz matrix has the form:
## @tex
## $$
## \left[\matrix{c_0    & r_1     & r_2      & \cdots & r_n\cr
##               c_1    & c_0     & r_1      & \cdots & r_{n-1}\cr
##               c_2    & c_1     & c_0      & \cdots & r_{n-2}\cr
##               \vdots & \vdots  & \vdots   & \ddots & \vdots\cr
##               c_n    & c_{n-1} & c_{n-2} & \ldots & c_0}\right]
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## c(0)  r(1)   r(2)  @dots{}  r(n)
## c(1)  c(0)   r(1)  @dots{} r(n-1)
## c(2)  c(1)   c(0)  @dots{} r(n-2)
##  .     .      .   .      .
##  .     .      .     .    .
##  .     .      .       .  .
## c(n) c(n-1) c(n-2) @dots{}  c(0)
## @end group
## @end example
##
## @end ifnottex
## @seealso{hankel}
## @end deftypefn
    
    ## Author: jwe && jh
    
    
@function
def toeplitz(c=None,r=None,*args,**kwargs):
    varargin = toeplitz.varargin
    nargin = toeplitz.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        if (logical_not(isvector(c))):
            error('toeplitz: C must be a vector')
        r=copy(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:71
        nr=length(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:72
        nc=copy(nr)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:73
    else:
        if (logical_not((isvector(c) and isvector(r)))):
            error('toeplitz: C and R must be vectors')
        else:
            if (r[1] != c[1]):
                warning('toeplitz: column wins diagonal conflict')
        nr=length(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:81
        nc=length(r)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:82
    
    if (nr == 0 or nc == 0):
        ## Empty matrix.
        retval=zeros(nr,nc,class_(c))
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:87
        return retval
    
    ## If we have a single complex argument, we want to return a
  ## Hermitian-symmetric matrix (actually, this will really only be
  ## Hermitian-symmetric if the first element of the vector is real).
    if (nargin == 1 and iscomplex(c)):
        c=conj(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:95
        c[1]=conj(c[1])
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:96
    
    if (issparse(c) and issparse(r)):
        c=ravel(c).T
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:100
        r=ravel(r).T
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:101
        cidx=find(c)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:102
        ridx=find(r)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:103
        ridx=ridx[ridx > 1]
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:106
        retval=spdiags(repmat(c[cidx],nr,1),1 - cidx,nr,nc) + spdiags(repmat(r[ridx],nr,1),ridx - 1,nr,nc)
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:109
    else:
        ## Concatenate data into a single column vector.
        data=matlabarray(cat([ravel(r[end():- 1:2])],[ravel(c)]))
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:113
        slices=cellslices(data,arange(nc,1,- 1),arange(nc + nr - 1,nr,- 1))
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:116
        retval=horzcat(slices[:])
# /home/lei/octave-4.0.2/scripts/special-matrix/toeplitz.m:119
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hilb (@var{n})
## Return the Hilbert matrix of order @var{n}.
##
## The @math{i,j} element of a Hilbert matrix is defined as
## @tex
## $$
## H(i, j) = {1 \over (i + j - 1)}
## $$
## @end tex
## @ifnottex
##
## @example
## H(i, j) = 1 / (i + j - 1)
## @end example
##
## @end ifnottex
##
## Hilbert matrices are close to being singular which make them difficult to
## invert with numerical routines.  Comparing the condition number of a random
## matrix 5x5 matrix with that of a Hilbert matrix of order 5 reveals just how
## difficult the problem is.
##
## @example
## @group
## cond (rand (5))
##    @result{} 14.392
## cond (hilb (5))
##    @result{} 4.7661e+05
## @end group
## @end example
##
## @seealso{invhilb}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def hilb(n=None,*args,**kwargs):
    varargin = hilb.varargin
    nargin = hilb.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(isscalar(n))):
            error('hilb: N must be a scalar integer')
    
    retval=zeros(n)
# /home/lei/octave-4.0.2/scripts/special-matrix/hilb.m:64
    tmp=arange(1,n)
# /home/lei/octave-4.0.2/scripts/special-matrix/hilb.m:65
    for i in arange(1,n).reshape(-1):
        retval[i,:]=1.0 / tmp
# /home/lei/octave-4.0.2/scripts/special-matrix/hilb.m:67
        tmp
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} delete (@var{f}, @var{file})
## Delete the remote file @var{file} over the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def delete(f=None,file=None,*args,**kwargs):
    varargin = delete.varargin
    nargin = delete.nargin

    __ftp_delete__(f.curlhandle,file)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    
@function
def loadobj(a=None,*args,**kwargs):
    varargin = loadobj.varargin
    nargin = loadobj.nargin

    b=copy(a)
# /home/lei/octave-4.0.2/scripts/@ftp/loadobj.m:20
    if (isfield(b,'jobject')):
        b=rmfield(b,'jobject')
# /home/lei/octave-4.0.2/scripts/@ftp/loadobj.m:22
    
    b.curlhandle = copy(__ftp__(b.host,b.username,b.password))
# /home/lei/octave-4.0.2/scripts/@ftp/loadobj.m:24
    if (isfield(b,'dir')):
        if (logical_not(isempty(b.dir))):
            __ftp_cwd__(b.curlhandle,b.dir)
        b=rmfield(b,'dir')
# /home/lei/octave-4.0.2/scripts/@ftp/loadobj.m:29
    else:
        if (isfield(b,'remotePwd')):
            ## FIXME: Can we read matlab java stringBuffer objects?
            warning('can not change remote directory in loaded FTP object')
            b=rmfield(b,'remotePwd')
# /home/lei/octave-4.0.2/scripts/@ftp/loadobj.m:33
    
    return b
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} mkdir (@var{f}, @var{path})
## Create the remote directory @var{path}, over the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def mkdir(f=None,path=None,*args,**kwargs):
    varargin = mkdir.varargin
    nargin = mkdir.nargin

    __ftp_mkdir__(f.curlhandle,path)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{lst} =} dir (@var{f})
## List the current directory in verbose form for the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def dir(f=None,*args,**kwargs):
    varargin = dir.varargin
    nargin = dir.nargin

    if (nargout == 0):
        __ftp_dir__(f.curlhandle)
    else:
        lst=__ftp_dir__(f.curlhandle)
# /home/lei/octave-4.0.2/scripts/@ftp/dir.m:30
    
    return lst
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} mget (@var{f}, @var{file})
## @deftypefnx {Function File} {} mget (@var{f}, @var{dir})
## @deftypefnx {Function File} {} mget (@var{f}, @var{remote_name}, @var{target})
## Download a remote file @var{file} or directory @var{dir} to the local
## directory on the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
##
## The arguments @var{file} and @var{dir} can include wildcards and any
## files or directories on the remote server that match will be downloaded.
##
## If a third argument @var{target} is given, then a single file or
## directory will be downloaded to the local directory and the local name
## will be changed to @var{target}.
## @end deftypefn
    
    
@function
def mget(f=None,file=None,*args,**kwargs):
    varargin = mget.varargin
    nargin = mget.nargin

    __ftp_mget__(f.curlhandle,file)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} mput (@var{f}, @var{file})
## Upload the local file @var{file} into the current remote directory on the
## FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the ftp function.
##
## The argument @var{file} is passed through the @code{glob} function and any
## files that match the wildcards in @var{file} will be uploaded.
## @end deftypefn
    
    
@function
def mput(f=None,file=None,*args,**kwargs):
    varargin = mput.varargin
    nargin = mput.nargin

    if (nargout == 0):
        __ftp_mput__(f.curlhandle,file)
    else:
        retval=__ftp_mput__(f.curlhandle,file)
# /home/lei/octave-4.0.2/scripts/@ftp/mput.m:34
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    
@function
def display(obj=None,*args,**kwargs):
    varargin = display.varargin
    nargin = display.nargin

    printf('FTP Object\n')
    printf(' host: %s\n',obj.host)
    printf(' user: %s\n',obj.username)
    printf('  dir: %s\n',__ftp_pwd__(obj.curlhandle))
    printf(' mode: %s\n',__ftp_mode__(obj.curlhandle))
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{f} =} ftp (@var{host})
## @deftypefnx {Function File} {@var{f} =} ftp (@var{host}, @var{username}, @var{password})
## Connect to the FTP server @var{host} with @var{username} and @var{password}.
##
## If @var{username} and @var{password} are not specified, user
## @qcode{"anonymous"} with no password is used.  The returned FTP object
## @var{f} represents the established FTP connection.
##
## The list of actions for an FTP object are shown below.  All functions
## require an FTP object as the first argument.
##
## @multitable @columnfractions 0.15 0.8
## @headitem Method @tab Description
## @item ascii @tab Set transfer type to ascii
## @item binary @tab Set transfer type to binary
## @item cd @tab Change remote working directory
## @item close @tab Close FTP connection
## @item delete @tab Delete remote file
## @item dir @tab List remote directory contents
## @item mget @tab Download remote files
## @item mkdir @tab Create remote directory
## @item mput @tab Upload local files
## @item rename @tab Rename remote file or directory
## @item rmdir @tab Remove remote directory
## @end multitable
##
## @end deftypefn
    
    
@function
def ftp(host='',username='anonymous',password='',*args,**kwargs):
    varargin = ftp.varargin
    nargin = ftp.nargin

    if (nargin == 1 and isa(host,'ftp')):
        obj=copy(host)
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:50
    else:
        p.host = copy(host)
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:52
        p.username = copy(username)
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:53
        p.password = copy(password)
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:54
        p.curlhandle = copy(tempname('ftp-'))
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:55
        if (nargin > 0):
            p.curlhandle = copy(__ftp__(host,username,password))
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:57
        obj=class_(p,'ftp')
# /home/lei/octave-4.0.2/scripts/@ftp/ftp.m:59
    
    return obj
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rename (@var{f}, @var{oldname}, @var{newname})
## Rename or move the remote file or directory @var{oldname} to @var{newname},
## over the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the ftp function.
## @end deftypefn
    
    
@function
def rename(f=None,oldname=None,newname=None,*args,**kwargs):
    varargin = rename.varargin
    nargin = rename.nargin

    __ftp_rename__(f.curlhandle,oldname,newname)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ascii (@var{f})
## Set the FTP connection @var{f} to use ASCII mode for transfers.
##
## ASCII mode is only appropriate for text files as it will convert the
## remote host's newline representation to the local host's newline
## representation.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def ascii(f=None,*args,**kwargs):
    varargin = ascii.varargin
    nargin = ascii.nargin

    __ftp_ascii__(f.curlhandle)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    
@function
def saveobj(a=None,*args,**kwargs):
    varargin = saveobj.varargin
    nargin = saveobj.nargin

    b=copy(a)
# /home/lei/octave-4.0.2/scripts/@ftp/saveobj.m:20
    b=rmfield(b,'curlhandle')
# /home/lei/octave-4.0.2/scripts/@ftp/saveobj.m:21
    b.dir = copy(__ftp_pwd__(a.curlhandle))
# /home/lei/octave-4.0.2/scripts/@ftp/saveobj.m:22
    return b
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rmdir (@var{f}, @var{path})
## Remove the remote directory @var{path}, over the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def rmdir(f=None,path=None,*args,**kwargs):
    varargin = rmdir.varargin
    nargin = rmdir.nargin

    __ftp_rmdir__(f.curlhandle,path)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cd (@var{f})
## @deftypefnx {Function File} {} cd (@var{f}, @var{path})
## Get or set the remote directory on the FTP connection @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
##
## If @var{path} is not specified, return the remote current working
## directory.  Otherwise, set the remote directory to @var{path} and return
## the new remote working directory.
##
## If the directory does not exist, an error message is printed and the
## working directory is not changed.
## @end deftypefn
    
    
@function
def cd(f=None,path=None,*args,**kwargs):
    varargin = cd.varargin
    nargin = cd.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (nargin == 2):
        __ftp_cwd__(f.curlhandle,path)
    
    path=__ftp_pwd__(f.curlhandle)
# /home/lei/octave-4.0.2/scripts/@ftp/cd.m:42
    return path
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} close (@var{f})
## Close the FTP connection represented by the FTP object @var{f}.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def close_(f=None,*args,**kwargs):
    varargin = close_.varargin
    nargin = close_.nargin

    __ftp_close__(f.curlhandle)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2009-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} binary (@var{f})
## Set the FTP connection @var{f} to use binary mode for transfers.
##
## In binary mode there is no conversion of newlines from the remote
## representation to the local representation.
##
## @var{f} is an FTP object returned by the @code{ftp} function.
## @end deftypefn
    
    
@function
def binary(f=None,*args,**kwargs):
    varargin = binary.varargin
    nargin = binary.nargin

    __ftp_binary__(f.curlhandle)
    return
    
if __name__ == '__main__':
    pass
    
    ## No test possible for interactive function.
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{idx} =} dsearch (@var{x}, @var{y}, @var{tri}, @var{xi}, @var{yi})
## @deftypefnx {Function File} {@var{idx} =} dsearch (@var{x}, @var{y}, @var{tri}, @var{xi}, @var{yi}, @var{s})
## Return the index @var{idx} of the closest point in @code{@var{x}, @var{y}}
## to the elements @code{[@var{xi}(:), @var{yi}(:)]}.
##
## The variable @var{s} is accepted for compatibility but is ignored.
## @seealso{dsearchn, tsearch}
## @end deftypefn
    
    
@function
def dsearch(x=None,y=None,tri=None,xi=None,yi=None,s=None,*args,**kwargs):
    varargin = dsearch.varargin
    nargin = dsearch.nargin

    if (nargin < 5 or nargin > 6):
        print_usage()
    
    idx=__dsearchn__(cat(ravel(x),ravel(y)),cat(ravel(xi),ravel(yi)))
# /home/lei/octave-4.0.2/scripts/geometry/dsearch.m:33
    return idx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{yi} =} griddatan (@var{x}, @var{y}, @var{xi})
## @deftypefnx {Function File} {@var{yi} =} griddatan (@var{x}, @var{y}, @var{xi}, @var{method})
## @deftypefnx {Function File} {@var{yi} =} griddatan (@var{x}, @var{y}, @var{xi}, @var{method}, @var{options})
##
## Generate a regular mesh from irregular data using interpolation.
##
## The function is defined by @code{@var{y} = f (@var{x})}.
## The interpolation points are all @var{xi}.
##
## The interpolation method can be @qcode{"nearest"} or @qcode{"linear"}.
## If method is omitted it defaults to @qcode{"linear"}.
##
## The optional argument @var{options} is passed directly to Qhull when
## computing the Delaunay triangulation used for interpolation.  See
## @code{delaunayn} for information on the defaults and how to pass different
## values.
## @seealso{griddata, griddata3, delaunayn}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def griddatan(x=None,y=None,xi=None,method='linear',varargin=None,*args,**kwargs):
    varargin = griddatan.varargin
    nargin = griddatan.nargin

    if (nargin < 3):
        print_usage()
    
    if (ischar(method)):
        method=tolower(method)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:48
    
    m,n=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:51
    mi,ni=size(xi,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:52
    if (n != ni or rows(y) != m or columns(y) != 1):
        error('griddatan: dimensional mismatch')
    
    ## triangulate data
    tri=delaunayn(x,varargin[:])
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:59
    yi=NaN(mi,1)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:61
    if (strcmp(method,'nearest')):
        ## search index of nearest point
        idx=dsearchn(x,tri,xi)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:65
        valid=logical_not(isnan(idx))
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:66
        yi[valid]=y[idx[valid]]
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:67
    else:
        if (strcmp(method,'linear')):
            ## search for every point the enclosing triangle
            tri_list,bary_list=tsearchn(x,tri,xi,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:71
            valid=logical_not(isnan(tri_list))
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:74
            tri_list=tri_list[logical_not(isnan(tri_list))]
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:75
            bary_list=bary_list[logical_not(isnan(tri_list)),:]
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:76
            nr_t=rows(tri_list)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:77
            xt=reshape(x[tri[tri_list,:],:],cat(nr_t,n + 1,n))
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:80
            yt=y[tri[tri_list,:]]
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:81
            yi[valid]=sum(multiply(y[tri[tri_list,:]],bary_list),2)
# /home/lei/octave-4.0.2/scripts/geometry/griddatan.m:84
        else:
            error('griddatan: unknown interpolation METHOD')
    
    return yi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{idx} =} dsearchn (@var{x}, @var{tri}, @var{xi})
## @deftypefnx {Function File} {@var{idx} =} dsearchn (@var{x}, @var{tri}, @var{xi}, @var{outval})
## @deftypefnx {Function File} {@var{idx} =} dsearchn (@var{x}, @var{xi})
## @deftypefnx {Function File} {[@var{idx}, @var{d}] =} dsearchn (@dots{})
## Return the index @var{idx} of the closest point in @var{x} to the elements
## @var{xi}.
##
## If @var{outval} is supplied, then the values of @var{xi} that are not
## contained within one of the simplices @var{tri} are set to @var{outval}.
## Generally, @var{tri} is returned from @code{delaunayn (@var{x})}.
## @seealso{dsearch, tsearch}
## @end deftypefn
    
    
@function
def dsearchn(x=None,tri=None,xi=None,outval=None,*args,**kwargs):
    varargin = dsearchn.varargin
    nargin = dsearchn.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (nargin == 2):
        idx,d=__dsearchn__(x,tri,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/dsearchn.m:39
    else:
        idx,d=__dsearchn__(x,xi,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/dsearchn.m:41
        if (nargin == 4):
            idx2=isnan(tsearchn(x,tri,xi))
# /home/lei/octave-4.0.2/scripts/geometry/dsearchn.m:43
            idx[idx2]=outval
# /home/lei/octave-4.0.2/scripts/geometry/dsearchn.m:44
            d[idx2]=outval
# /home/lei/octave-4.0.2/scripts/geometry/dsearchn.m:45
    
    return idx,d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{tri} =} delaunay (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{tetr} =} delaunay (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {@var{tri} =} delaunay (@var{x})
## @deftypefnx {Function File} {@var{tri} =} delaunay (@dots{}, @var{options})
## Compute the Delaunay triangulation for a 2-D or 3-D set of points.
##
## For 2-D sets, the return value @var{tri} is a set of triangles which
## satisfies the Delaunay circum-circle criterion, i.e., only a single data
## point from [@var{x}, @var{y}] is within the circum-circle of the defining
## triangle.  The set of triangles @var{tri} is a matrix of size [n, 3].  Each
## row defines a triangle and the three columns are the three vertices of the
## triangle.  The value of @code{@var{tri}(i,j)} is an index into @var{x} and
## @var{y} for the location of the j-th vertex of the i-th triangle.
##
## For 3-D sets, the return value @var{tetr} is a set of tetrahedrons which
## satisfies the Delaunay circum-circle criterion, i.e., only a single data
## point from [@var{x}, @var{y}, @var{z}] is within the circum-circle of the
## defining tetrahedron.  The set of tetrahedrons is a matrix of size [n, 4].
## Each row defines a tetrahedron and the four columns are the four vertices of
## the tetrahedron.  The value of @code{@var{tetr}(i,j)} is an index into
## @var{x}, @var{y}, @var{z} for the location of the j-th vertex of the i-th
## tetrahedron.
##
## The input @var{x} may also be a matrix with two or three columns where the
## first column contains x-data, the second y-data, and the optional third
## column contains z-data.
##
## The optional last argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
## The default options are @code{@{"Qt", "Qbb", "Qc", "Qz"@}}.
##
## If @var{options} is not present or @code{[]} then the default arguments are
## used.  Otherwise, @var{options} replaces the default argument list.
## To append user options to the defaults it is necessary to repeat the
## default arguments in @var{options}.  Use a null string to pass no arguments.
##
## @example
## @group
## x = rand (1, 10);
## y = rand (1, 10);
## tri = delaunay (x, y);
## triplot (tri, x, y);
## hold on;
## plot (x, y, "r*");
## axis ([0,1,0,1]);
## @end group
## @end example
## @seealso{delaunayn, convhull, voronoi, triplot, trimesh, tetramesh, trisurf}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def delaunay(varargin=None,*args,**kwargs):
    varargin = delaunay.varargin
    nargin = delaunay.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    z=matlabarray([])
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:80
    options=matlabarray([])
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:81
    if 1 == (nargin):
        if (logical_not(ismatrix(varargin[1])) or (columns(varargin[1]) != 2 and columns(varargin[1]) != 3)):
            error('delaunay: X must be a matrix with 2 or 3 columns')
        else:
            x=varargin[1](arange(),1)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:90
            y=varargin[1](arange(),2)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:91
            if (columns(varargin[1]) == 3):
                z=varargin[1](arange(),3)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:93
    else:
        if 2 == (nargin):
            if (isnumeric(varargin[2])):
                x=varargin[1]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:99
                y=varargin[2]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:100
            else:
                if (logical_not((ischar(varargin[2]) or iscellstr(varargin[2])))):
                    error('delaunay: OPTIONS must be a string or cell array of strings')
                else:
                    options=varargin[2]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:104
                    ncols=columns(varargin[1])
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:105
                    if (logical_not(ismatrix(varargin[1])) or (ncols != 2 and ncols != 3)):
                        error('delaunay: X must be a matrix with 2 or 3 columns')
                    else:
                        x=varargin[1](arange(),1)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:110
                        y=varargin[1](arange(),2)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:111
                        if (ncols == 3):
                            z=varargin[1](arange(),3)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:113
        else:
            if 3 == (nargin):
                if (isnumeric(varargin[3])):
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:120
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:121
                    z=varargin[3]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:122
                else:
                    if (logical_not((ischar(varargin[3]) or iscellstr(varargin[3])))):
                        error('delaunay: OPTIONS must be a string or cell array of strings')
                    else:
                        x=varargin[1]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:126
                        y=varargin[2]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:127
                        options=varargin[3]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:128
            else:
                if 4 == (nargin):
                    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:132
                    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:133
                    z=varargin[3]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:134
                    options=varargin[4]
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:135
                    if (logical_not((ischar(options) or iscellstr(options)))):
                        error('delaunay: OPTIONS must be a string or cell array of strings')
    
    if (isempty(z)):
        if (logical_not(size_equal(x,y))):
            error('delaunay: X and Y must be the same size')
        tri=delaunayn(cat(ravel(x),ravel(y)),options)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:147
    else:
        if (logical_not(size_equal(x,y,z))):
            error('delaunay: X, Y, and Z must be the same size')
        tri=delaunayn(cat(ravel(x),ravel(y),ravel(z)),options)
# /home/lei/octave-4.0.2/scripts/geometry/delaunay.m:152
    
    return tri
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test 3-D input
    
    
    ## Input validation tests
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} voronoi (@var{x}, @var{y})
## @deftypefnx {Function File} {} voronoi (@var{x}, @var{y}, @var{options})
## @deftypefnx {Function File} {} voronoi (@dots{}, "linespec")
## @deftypefnx {Function File} {} voronoi (@var{hax}, @dots{})
## @deftypefnx {Function File} {@var{h} =} voronoi (@dots{})
## @deftypefnx {Function File} {[@var{vx}, @var{vy}] =} voronoi (@dots{})
## Plot the Voronoi diagram of points @code{(@var{x}, @var{y})}.
##
## The Voronoi facets with points at infinity are not drawn.
##
## The @var{options} argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
##
## If @qcode{"linespec"} is given it is used to set the color and line style of
## the plot.
##
## If an axis graphics handle @var{hax} is supplied then the Voronoi diagram is
## drawn on the specified axis rather than in a new figure.
##
## If a single output argument is requested then the Voronoi diagram will be
## plotted and a graphics handle @var{h} to the plot is returned.
##
## [@var{vx}, @var{vy}] = voronoi (@dots{}) returns the Voronoi vertices
## instead of plotting the diagram.
##
## @example
## @group
## x = rand (10, 1);
## y = rand (size (x));
## h = convhull (x, y);
## [vx, vy] = voronoi (x, y);
## plot (vx, vy, "-b", x, y, "o", x(h), y(h), "-g");
## legend ("", "points", "hull");
## @end group
## @end example
##
## @seealso{voronoin, delaunay, convhull}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## First Release: 20/08/2000
    
    ## 2002-01-04 Paul Kienzle <pkienzle@users.sf.net>
## * limit the default graph to the input points rather than the whole diagram
## * provide example
## * use unique(x,"rows") rather than __unique_rows__
    
    ## 2003-12-14 Rafael Laboissiere <rafael@laboissiere.net>
## Added optional fourth argument to pass options to the underlying
## qhull command
    
    
@function
def voronoi(varargin=None,*args,**kwargs):
    varargin = voronoi.varargin
    nargin = voronoi.nargin

    if (nargin < 1):
        print_usage()
    
    narg=1
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:79
    hax=copy(NaN)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:80
    if (isscalar(varargin[1]) and ishandle(varargin[1])):
        hax=varargin[1]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:82
        if (logical_not(isaxes(hax))):
            error('voronoi: HAX argument must be an axes object')
        narg
    
    if (nargin < 1 + narg or nargin > 3 + narg):
        print_usage()
    
    x=varargin[narg]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:93
    y=varargin[narg]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:94
    opts=cellarray([])
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:96
    if (narg <= nargin):
        if (iscell(varargin[narg])):
            opts=varargin[narg]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:99
        else:
            if (isnumeric(varargin[narg])):
                ## Accept, but ignore, the triangulation
                narg
    
    linespec=cellarray(['b'])
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:106
    if (narg <= nargin and ischar(varargin[narg])):
        linespec=varargin[narg]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:108
    
    if (length(x) != length(y)):
        error('voronoi: X and Y must be vectors of the same length')
    else:
        if (length(x) < 2):
            error('voronoi: minimum of 2 points needed')
    
    ## Add box to approximate rays to infinity. For Voronoi diagrams the
  ## box can (and should) be close to the points themselves. To make the
  ## job of finding the exterior edges it should be at least two times the
  ## delta below however
    xmax=max(ravel(x))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:121
    xmin=min(ravel(x))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:122
    ymax=max(ravel(y))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:123
    ymin=min(ravel(y))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:124
    xdelta=xmax - xmin
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:125
    ydelta=ymax - ymin
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:126
    scale=2
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:127
    xbox=matlabarray(cat([xmin - dot(scale,xdelta)],[xmin - dot(scale,xdelta)],[xmax + dot(scale,xdelta)],[xmax + dot(scale,xdelta)]))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:129
    ybox=matlabarray(cat([ymin - dot(scale,ydelta)],[ymax + dot(scale,ydelta)],[ymax + dot(scale,ydelta)],[ymin - dot(scale,ydelta)]))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:131
    p,c,infi=__voronoi__('voronoi',cat(cat([ravel(x)],[ravel(xbox)]),cat([ravel(y)],[ravel(ybox)])),opts[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:134
    c=c[logical_not(infi)].T
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:138
    
    c[cellfun('isempty',c)]=[]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:140
    edges=cell2mat(cellfun(lambda x=None: cat([x],[cat(x[end()],x[1:end() - 1])]),c,'uniformoutput',false))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:141
    
    edges=sortrows(sort(edges).T).T
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:145
    edges=edges[:,cat((edges[1,1:end() - 1] != logical_or(edges[1,2:end()],edges[2,1:end() - 1]) != edges[2,2:end()]),true)]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:146
    if (numel(x) > 2):
        ## Eliminate the edges of the diagram representing the box
        poutside=(arange(1,rows(p)))(p[:,1] < logical_or(xmin - xdelta,p[:,1]) > logical_or(xmax + xdelta,p[:,2]) < logical_or(ymin - ydelta,p[:,2]) > ymax + ydelta)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:151
        edgeoutside=logical_and(ismember(edges[1,:],poutside),ismember(edges[2,:],poutside))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:154
        edges[:,edgeoutside]=[]
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:156
    else:
        ## look for the edge between the two given points
        for edge in edges[1:2,:].reshape(-1):
            if (dot(det(cat([cat(cat([1],[1]),p[edge,1:2])],[1,x[1],y[1]])),det(cat([cat(cat([1],[1]),p[edge,1:2])],[1,x[2],y[2]]))) < 0):
                edges=copy(edge)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:162
                break
        ## Use larger plot limits to make it more likely single bisector is shown.
        xdelta=ydelta=max(xdelta,ydelta)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:167
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:167
    
    ## Get points of the diagram
    Vvx=reshape(p[edges,1],size(edges))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:171
    Vvy=reshape(p[edges,2],size(edges))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:172
    if (nargout < 2):
        if (isnan(hax)):
            hax=gca()
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:176
        h=plot(hax,Vvx,Vvy,linespec[:],x,y,'+')
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:178
        lim=matlabarray(cat(xmin,xmax,ymin,ymax))
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:179
        axis(lim + dot(0.1,cat(dot(cat(- 1,1),xdelta),dot(cat(- 1,1),ydelta))))
        if (nargout == 1):
            vx=copy(h)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:182
    else:
        vx=copy(Vvx)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:185
        vy=copy(Vvy)
# /home/lei/octave-4.0.2/scripts/geometry/voronoi.m:186
    
    return vx,vy
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Input validation tests
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{H} =} convhull (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{H} =} convhull (@var{x}, @var{y}, @var{options})
## Compute the convex hull of the set of points defined by the
## arrays @var{x} and @var{y}.  The hull @var{H} is an index vector into
## the set of points and specifies which points form the enclosing hull.
##
## An optional third argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
## The default option is @code{@{"Qt"@}}.
##
## If @var{options} is not present or @code{[]} then the default arguments are
## used.  Otherwise, @var{options} replaces the default argument list.
## To append user options to the defaults it is necessary to repeat the
## default arguments in @var{options}.  Use a null string to pass no arguments.
##
## @seealso{convhulln, delaunay, voronoi}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def convhull(x=None,y=None,options=None,*args,**kwargs):
    varargin = convhull.varargin
    nargin = convhull.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    ## convhulln expects column vectors
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:49
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:50
    if (length(x) != length(y)):
        error('convhull: X and Y must have the same size')
    else:
        if (nargin == 3 and logical_not((ischar(options) or iscellstr(options)))):
            error('convhull: OPTIONS must be a string or cell array of strings')
    
    if (nargin == 2):
        i=convhulln(cat(x,y))
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:59
    else:
        i=convhulln(cat(x,y),options)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:61
    
    n=rows(i)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:64
    i=ravel(i.T)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:65
    H=zeros(n + 1,1)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:66
    H[1]=i[1]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:68
    next_i=i[2]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:69
    i[2]=0
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:70
    for k in arange(2,n).reshape(-1):
        next_idx=find(i == next_i)
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:72
        if (rem(next_idx,2) == 0):
            H[k]=i[next_idx]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:75
            next_i=i[next_idx - 1]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:76
            i[next_idx - 1]=0
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:77
        else:
            H[k]=i[next_idx]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:79
            next_i=i[next_idx + 1]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:80
            i[next_idx + 1]=0
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:81
    
    H[n + 1]=H[1]
# /home/lei/octave-4.0.2/scripts/geometry/convhull.m:85
    return H
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: Need input validation tests
    
    ## Copyright (C) 2006-2016 Frederick (Rick) A Niles
##               and Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{in} =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
## @deftypefnx {Function File} {[@var{in}, @var{on}] =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
##
## For a polygon defined by vertex points @code{(@var{xv}, @var{yv})}, return
## true if the points @code{(@var{x}, @var{y})} are inside (or on the boundary)
## of the polygon; Otherwise, return false.
##
## The input variables @var{x} and @var{y}, must have the same dimension.
##
## The optional output @var{on} returns true if the points are exactly on the
## polygon edge, and false otherwise.
## @seealso{delaunay}
## @end deftypefn
    
    ## Author: Frederick (Rick) A Niles <niles@rickniles.com>
## Created: 14 November 2006
    
    ## Vectorized by Sren Hauberg <soren@hauberg.org>
    
    ## The method for determining if a point is in in a polygon is based on
## the algorithm shown on
## http://local.wasp.uwa.edu.au/~pbourke/geometry/insidepoly/
## and is credited to Randolph Franklin.
    
    
@function
def inpolygon(x=None,y=None,xv=None,yv=None,*args,**kwargs):
    varargin = inpolygon.varargin
    nargin = inpolygon.nargin

    if (nargin != 4):
        print_usage()
    
    if (logical_not((isreal(x) and isreal(y) and isnumeric(x) and isnumeric(y) and size_equal(x,y)))):
        error('inpolygon: X and Y must be real arrays of the same size')
    else:
        if (logical_not((isreal(xv) and isreal(yv) and isvector(xv) and isvector(yv) and size_equal(xv,yv)))):
            error('inpolygon: XV and YV must be real vectors of the same size')
    
    npol=length(xv)
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:59
    in_=on=false(size(x))
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:61
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:61
    j=copy(npol)
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:63
    for i in arange(1,npol).reshape(-1):
        delta_xv=xv[j] - xv[i]
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:65
        delta_yv=yv[j] - yv[i]
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:66
        distance=multiply(delta_xv,(y - yv[i])) - multiply((x - xv[i]),delta_yv)
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:68
        idx1=(logical_and((logical_or((yv[i] <= logical_and(y,y) < yv[j]),(yv[j] <= logical_and(y,y) < yv[i]))),0) < multiply(distance,delta_yv))
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:71
        in_[idx1]=logical_not(in_[idx1])
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:73
        idx2=(logical_and(logical_and((logical_or((yv[i] <= logical_and(y,y) <= yv[j]),(yv[j] <= logical_and(y,y) <= yv[i]))),(logical_or((xv[i] <= logical_and(x,x) <= xv[j]),(xv[j] <= logical_and(x,x) <= xv[i])))),(0 == logical_or(distance,logical_not(delta_xv)))))
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:76
        on[idx2]=true
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:79
        j=copy(i)
# /home/lei/octave-4.0.2/scripts/geometry/inpolygon.m:81
    
    ## Matlab definition include both in polygon and on polygon points.
    in_ |= on
    return in_,on
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## 3D array input
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{C}, @var{F}] =} voronoin (@var{pts})
## @deftypefnx {Function File} {[@var{C}, @var{F}] =} voronoin (@var{pts}, @var{options})
## Compute N-dimensional Voronoi facets.
##
## The input matrix @var{pts} of size [n, dim] contains n points in a space of
## dimension dim.
##
## @var{C} contains the points of the Voronoi facets.  The list @var{F}
## contains, for each facet, the indices of the Voronoi points.
##
## An optional second argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
##
## The default options depend on the dimension of the input:
##
## @itemize
## @item 2-D and 3-D: @var{options} = @code{@{"Qbb"@}}
##
## @item 4-D and higher: @var{options} = @code{@{"Qbb", "Qx"@}}
## @end itemize
##
## If @var{options} is not present or @code{[]} then the default arguments are
## used.  Otherwise, @var{options} replaces the default argument list.
## To append user options to the defaults it is necessary to repeat the
## default arguments in @var{options}.  Use a null string to pass no arguments.
##
## @seealso{voronoi, convhulln, delaunayn}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## First Release: 20/08/2000
    
    ## 2003-12-14 Rafael Laboissiere <rafael@laboissiere.net>
## Added optional second argument to pass options to the underlying
## qhull command
    
    
@function
def voronoin(pts=None,options=None,*args,**kwargs):
    varargin = voronoin.varargin
    nargin = voronoin.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    np,dim=size(pts,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/voronoin.m:64
    if (np <= dim):
        error('voronoin: number of points must be greater than their dimension')
    
    caller='voronoin'
# /home/lei/octave-4.0.2/scripts/geometry/voronoin.m:70
    if (nargin == 1):
        C,F=__voronoi__(caller,pts,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/voronoin.m:73
    else:
        C,F=__voronoi__(caller,pts,options,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/voronoin.m:75
    
    return C,F
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Need functional tests
    
    
    ## Copyright (C) 2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{area} =} rectint (@var{a}, @var{b})
## Compute area or volume of intersection of rectangles or N-D boxes.
##
## Compute the area of intersection of rectangles in @var{a} and rectangles in
## @var{b}.  N-dimensional boxes are supported in which case the volume, or
## hypervolume is computed according to the number of dimensions.
##
## 2-dimensional rectangles are defined as @code{[xpos ypos width height]}
## where xpos and ypos are the position of the bottom left corner.  Higher
## dimensions are supported where the coordinates for the minimum value of each
## dimension follow the length of the box in that dimension, e.g.,
## @code{[xpos ypos zpos kpos @dots{} width height depth k_length @dots{}]}.
##
## Each row of @var{a} and @var{b} define a rectangle, and if both define
## multiple rectangles, then the output, @var{area}, is a matrix where the i-th
## row corresponds to the i-th row of a and the j-th column corresponds to the
## j-th row of b.
##
## @seealso{polyarea}
## @end deftypefn
    
    ## Author: 2015 Carn Draug <carandraug@octave.org>
    
    
@function
def rectint(a=None,b=None,*args,**kwargs):
    varargin = rectint.varargin
    nargin = rectint.nargin

    if (nargin != 2):
        print_usage()
    else:
        if (columns(a) != columns(b)):
            error('rectint: A and B must have same number of columns')
        else:
            if (ndims(a) > 2):
                error('rectint: A and B must be 2-d arrays')
            else:
                if (mod(columns(a),2)):
                    error('rectint: number of columns of A and B must be a multiple of two')
    
    nd=columns(a) / 2
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:55
    na=rows(a)
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:56
    nb=rows(b)
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:57
    a_start=a[:,1:nd]
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:59
    b_start=b[:,1:nd]
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:60
    a_end=a_start + a[:,nd + 1:end()]
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:62
    b_end=b_start + b[:,nd + 1:end()]
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:63
    a_start=reshape(a_start,cat(na,1,nd))
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:65
    b_start=reshape(b_start,cat(1,nb,nd))
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:66
    a_end=reshape(a_end,cat(na,1,nd))
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:68
    b_end=reshape(b_end,cat(1,nb,nd))
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:69
    
    dists=bsxfun(min,a_end,b_end) - bsxfun(max,a_start,b_start)
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:72
    dists[dists < 0]=0
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:73
    dists=prod(dists,3)
# /home/lei/octave-4.0.2/scripts/geometry/rectint.m:74
    return dists
    
if __name__ == '__main__':
    pass
    
    ## Exactly overlapping
    
    ## rect2 completely enclosed by rect1
    
    ## rect1 completely enclosed by rect2
    
    ## rect1 right and top in rect2
    
    ## rect2 right and top in rect1
    
    ## no overlap - shared corner
    
    ## no overlap - shared edge
    
    ## Correct orientation of output
    
    
    ## bug #44904
    
    
    
    
    ## Test volumes
    
    
    
    
    
    
    
    
    
    ## Test multiple volumes in both A and B
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{T} =} delaunayn (@var{pts})
## @deftypefnx {Function File} {@var{T} =} delaunayn (@var{pts}, @var{options})
## Compute the Delaunay triangulation for an N-dimensional set of points.
##
## The Delaunay triangulation is a tessellation of the convex hull of a set of
## points such that no N-sphere defined by the N-triangles contains any other
## points from the set.
##
## The input matrix @var{pts} of size [n, dim] contains n points in a space of
## dimension dim.  The return matrix @var{T} has size [m, dim+1].  Each row of
## @var{T} contains a set of indices back into the original set of points
## @var{pts} which describes a simplex of dimension dim.  For example, a 2-D
## simplex is a triangle and 3-D simplex is a tetrahedron.
##
## An optional second argument, which must be a string or cell array of strings,
## contains options passed to the underlying qhull command.
## See the documentation for the Qhull library for details
## @url{http://www.qhull.org/html/qh-quick.htm#options}.
## The default options depend on the dimension of the input:
##
## @itemize
## @item 2-D and 3-D: @var{options} = @code{@{"Qt", "Qbb", "Qc", "Qz"@}}
##
## @item 4-D and higher: @var{options} = @code{@{"Qt", "Qbb", "Qc", "Qx"@}}
## @end itemize
##
## If @var{options} is not present or @code{[]} then the default arguments are
## used.  Otherwise, @var{options} replaces the default argument list.
## To append user options to the defaults it is necessary to repeat the
## default arguments in @var{options}.  Use a null string to pass no arguments.
##
## @seealso{delaunay, convhulln, voronoin, trimesh, tetramesh}
## @end deftypefn
    
    
@function
def delaunayn(pts=None,varargin=None,*args,**kwargs):
    varargin = delaunayn.varargin
    nargin = delaunayn.nargin

    if (nargin < 1):
        print_usage()
    
    T=__delaunayn__(pts,varargin[:])
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:60
    if (isa(pts,'single')):
        tol=dot(1000.0,eps('single'))
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:63
    else:
        tol=dot(1000.0,eps)
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:65
    
    ## Try to remove the zero volume simplices.  The volume of the i-th simplex is
  ## given by abs(det(pts(T(i,1:end-1),:)-pts(T(i,2:end),:)))/prod(1:n)
  ## (reference http://en.wikipedia.org/wiki/Simplex).  Any simplex with a
  ## relative volume less than some arbitrary criteria is rejected.  The
  ## criteria we use is the volume of the simplex corresponding to an
  ## orthogonal simplex is equal edge length all equal to the edge length of
  ## the original simplex.  If the relative volume is 1e3*eps then the simplex
  ## is rejected.  Note division of the two volumes means that the factor
  ## prod(1:n) is dropped.
    idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:77
    nt,n=size(T,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:78
    
    for i in arange(1,nt).reshape(-1):
        X=pts[T[i,1:end() - 1],:] - pts[T[i,2:end()],:]
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:81
        if (abs(det(X)) / sqrt(sumsq(X,2)) < tol):
            idx[end() + 1]=i
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:83
    
    T[idx,:]=[]
# /home/lei/octave-4.0.2/scripts/geometry/delaunayn.m:86
    return T
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test 3-D input
    
    
    ## FIXME: Need tests for delaunayn
    
    ## Input validation tests
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{vi} =} griddata3 (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi})
## @deftypefnx {Function File} {@var{vi} =} griddata3 (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi}, @var{method})
## @deftypefnx {Function File} {@var{vi} =} griddata3 (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi}, @var{method}, @var{options})
##
## Generate a regular mesh from irregular data using interpolation.
##
## The function is defined by @code{@var{v} = f (@var{x}, @var{y}, @var{z})}.
## The interpolation points are specified by @var{xi}, @var{yi}, @var{zi}.
##
## The interpolation method can be @qcode{"nearest"} or @qcode{"linear"}.
## If method is omitted it defaults to @qcode{"linear"}.
##
## The optional argument @var{options} is passed directly to Qhull when
## computing the Delaunay triangulation used for interpolation.  See
## @code{delaunayn} for information on the defaults and how to pass different
## values.
## @seealso{griddata, griddatan, delaunayn}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def griddata3(x=None,y=None,z=None,v=None,xi=None,yi=None,zi=None,method=None,varargin=None,*args,**kwargs):
    varargin = griddata3.varargin
    nargin = griddata3.nargin

    if (nargin < 7):
        print_usage()
    
    if (isvector(x) and isvector(y) and isvector(z) and isvector(v)):
        if (logical_not(isequal(length(x),length(y),length(z),length(v)))):
            error('griddata: X, Y, Z, and V must be vectors of the same length')
    else:
        if (logical_not(size_equal(x,y,z,v))):
            error('griddata: X, Y, Z, and V must have equal sizes')
    
    ## meshgrid xi, yi and zi if they are vectors unless
  ## they are vectors of the same length.
    if (isvector(xi) and isvector(yi) and isvector(zi)):
        if (logical_not(isequal(length(xi),length(yi),length(zi)))):
            xi,yi,zi=meshgrid(xi,yi,zi,nargout=3)
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:59
        else:
            ## Otherwise, convert to column vectors
            xi=ravel(xi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:62
            yi=ravel(yi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:63
            zi=ravel(zi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:64
    
    if (logical_not(size_equal(xi,yi,zi))):
        error('griddata3: XI, YI, and ZI must be vectors or matrices of the same size')
    
    vi=griddatan(cat(ravel(x),ravel(y),ravel(z)),ravel(v),cat(ravel(xi),ravel(yi),ravel(zi)),varargin[:])
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:72
    vi=reshape(vi,size(xi))
# /home/lei/octave-4.0.2/scripts/geometry/griddata3.m:73
    return vi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1999-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{zi} =} griddata (@var{x}, @var{y}, @var{z}, @var{xi}, @var{yi})
## @deftypefnx {Function File} {@var{zi} =} griddata (@var{x}, @var{y}, @var{z}, @var{xi}, @var{yi}, @var{method})
## @deftypefnx {Function File} {[@var{xi}, @var{yi}, @var{zi}] =} griddata (@dots{})
##
## Generate a regular mesh from irregular data using interpolation.
##
## The function is defined by @code{@var{z} = f (@var{x}, @var{y})}.  Inputs
## @code{@var{x}, @var{y}, @var{z}} are vectors of the same length or
## @code{@var{x}, @var{y}} are vectors and @code{@var{z}} is matrix.
##
## The interpolation points are all @code{(@var{xi}, @var{yi})}.  If @var{xi},
## @var{yi} are vectors then they are made into a 2-D mesh.
##
## The interpolation method can be @qcode{"nearest"}, @qcode{"cubic"} or
## @qcode{"linear"}.  If method is omitted it defaults to @qcode{"linear"}.
## @seealso{griddata3, griddatan, delaunay}
## @end deftypefn
    
    ## Author:      Kai Habel <kai.habel@gmx.de>
## Adapted-by:  Alexander Barth <barth.alexander@gmail.com>
##              xi and yi are not "meshgridded" if both are vectors
##              of the same size (for compatibility)
    
    
@function
def griddata(x=None,y=None,z=None,xi=None,yi=None,method='linear',*args,**kwargs):
    varargin = griddata.varargin
    nargin = griddata.nargin

    if (nargin < 5 or nargin > 7):
        print_usage()
    
    if (ischar(method)):
        method=tolower(method)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:50
    
    ## Meshgrid if x and y are vectors but z is matrix
    if (isvector(x) and isvector(y) and all(cat(numel(y),numel(x)) == size(z))):
        x,y=meshgrid(x,y,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:55
    
    if (isvector(x) and isvector(y) and isvector(z)):
        if (logical_not(isequal(length(x),length(y),length(z)))):
            error('griddata: X, Y, and Z must be vectors of the same length')
    else:
        if (logical_not(size_equal(x,y,z))):
            error('griddata: lengths of X, Y must match the columns and rows of Z')
    
    ## Meshgrid xi and yi if they are a row and column vector.
    if (rows(xi) == 1 and columns(yi) == 1):
        xi,yi=meshgrid(xi,yi,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:68
    else:
        if (isvector(xi) and isvector(yi)):
            ## Otherwise, convert to column vectors
            xi=ravel(xi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:71
            yi=ravel(yi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:72
    
    if (logical_not(size_equal(xi,yi))):
        error('griddata: XI and YI must be vectors or matrices of same size')
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:79
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:80
    z=ravel(z)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:81
    
    tri=delaunay(x,y)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:84
    zi=NaN(size(xi))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:85
    if (strcmp(method,'cubic')):
        error('griddata: cubic interpolation not yet implemented')
    else:
        if (strcmp(method,'nearest')):
            ## Search index of nearest point.
            idx=dsearch(x,y,tri,xi,yi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:92
            valid=logical_not(isnan(idx))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:93
            zi[valid]=z[idx[valid]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:94
        else:
            if (strcmp(method,'linear')):
                ## Search for every point the enclosing triangle.
                tri_list=tsearch(x,y,tri,ravel(xi),ravel(yi))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:98
                valid=logical_not(isnan(tri_list))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:101
                tri_list=tri_list[valid]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:102
                nr_t=rows(tri_list)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:103
                tri=tri[tri_list,:]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:105
                x1=x[tri[:,1]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:108
                x2=x[tri[:,2]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:109
                x3=x[tri[:,3]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:110
                y1=y[tri[:,1]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:112
                y2=y[tri[:,2]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:113
                y3=y[tri[:,3]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:114
                z1=z[tri[:,1]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:116
                z2=z[tri[:,2]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:117
                z3=z[tri[:,3]]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:118
                N=cross(cat(x2 - x1,y2 - y1,z2 - z1),cat(x3 - x1,y3 - y1,z3 - z1))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:121
                N=numpy.linalg.solve(diag(norm(N,'rows')),N)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:123
                ## Ax+By+Cz+D = 0;
                D=- (multiply(N[:,1],x1) + multiply(N[:,2],y1) + multiply(N[:,3],z1))
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:127
                zi[valid]=- (multiply(N[:,1],ravel(xi)(valid)) + multiply(N[:,2],ravel(yi)(valid)) + D) / N[:,3]
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:130
            else:
                error('griddata: unknown interpolation METHOD')
    
    if (nargout == 3):
        rx=copy(xi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:137
        ry=copy(yi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:138
        rz=copy(zi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:139
    else:
        if (nargout == 1):
            rx=copy(zi)
# /home/lei/octave-4.0.2/scripts/geometry/griddata.m:141
        else:
            if (nargout == 0):
                mesh(xi,yi,zi)
    
    return rx,ry,rz
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{idx} =} tsearchn (@var{x}, @var{t}, @var{xi})
## @deftypefnx {Function File} {[@var{idx}, @var{p}] =} tsearchn (@var{x}, @var{t}, @var{xi})
## Search for the enclosing Delaunay convex hull.
##
## For @code{@var{t} = delaunayn (@var{x})}, finds the index in @var{t}
## containing the points @var{xi}.  For points outside the convex hull,
## @var{idx} is NaN.
##
## If requested @code{tsearchn} also returns the Barycentric coordinates @var{p}
## of the enclosing triangles.
## @seealso{delaunay, delaunayn}
## @end deftypefn
    
    
@function
def tsearchn(x=None,t=None,xi=None,*args,**kwargs):
    varargin = tsearchn.varargin
    nargin = tsearchn.nargin

    if (nargin != 3):
        print_usage()
    
    nt=rows(t)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:38
    m,n=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:39
    mi=rows(xi)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:40
    idx=NaN(mi,1)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:41
    p=NaN(mi,n + 1)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:42
    ni=cat(arange(1,mi)).T
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:44
    for i in arange(1,nt).reshape(-1):
        ## Only calculate the Barycentric coordinates for points that have not
    ## already been found in a triangle.
        b=cart2bary(x[t[i,:],:],xi[ni,:])
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:48
        ## (all (b >= 0) && all (b <= 1)). However as we impose that
    ## sum (b,2) == 1 we only need to test all(b>=0). Note need to add
    ## a small margin for rounding errors
        intri=all(b >= - 1e-12,2)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:54
        idx[ni[intri]]=i
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:55
        p[ni[intri],:]=b[intri,:]
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:56
        ni[intri]=[]
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:57
    
    return idx,p
    
if __name__ == '__main__':
    pass
    
    
@function
def cart2bary(T=None,P=None,*args,**kwargs):
    varargin = cart2bary.varargin
    nargin = cart2bary.nargin

    ## Conversion of Cartesian to Barycentric coordinates.
  ## Given a reference simplex in N dimensions represented by a
  ## (N+1)-by-(N) matrix, and arbitrary point P in cartesion coordinates,
  ## represented by a N-by-1 row vector can be written as
  ##
  ## P = Beta * T
  ##
  ## Where Beta is a N+1 vector of the barycentric coordinates. A criteria
  ## on Beta is that
  ##
  ## sum (Beta) == 1
  ##
  ## and therefore we can write the above as
  ##
  ## P - T(end, :) = Beta(1:end-1) * (T(1:end-1,:) - ones (N,1) * T(end,:))
  ##
  ## and then we can solve for Beta as
  ##
  ## Beta(1:end-1) = (P - T(end,:)) / (T(1:end-1,:) - ones (N,1) * T(end,:))
  ## Beta(end) = sum (Beta)
  ##
  ## Note below is generalize for multiple values of P, one per row.
    M,N=size(P,nargout=2)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:84
    Beta=(P - dot(ones(M,1),T[end(),:])) / (T[1:end() - 1,:] - dot(ones(N,1),T[end(),:]))
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:85
    Beta[:,end() + 1]=1 - sum(Beta,2)
# /home/lei/octave-4.0.2/scripts/geometry/tsearchn.m:86
    return Beta
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cotd (@var{x})
## Compute the cotangent for each element of @var{x} in degrees.
## @seealso{acotd, cot}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def cotd(x=None,*args,**kwargs):
    varargin = cotd.varargin
    nargin = cotd.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / tand(x)
# /home/lei/octave-4.0.2/scripts/elfun/cotd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} acot (@var{x})
## Compute the inverse cotangent in radians for each element of @var{x}.
## @seealso{cot, acotd}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def acot(x=None,*args,**kwargs):
    varargin = acot.varargin
    nargin = acot.nargin

    if (nargin != 1):
        print_usage()
    
    y=atan(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/acot.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} sec (@var{x})
## Compute the secant for each element of @var{x} in radians.
## @seealso{asec, secd, sech}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def sec(x=None,*args,**kwargs):
    varargin = sec.varargin
    nargin = sec.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / cos(x)
# /home/lei/octave-4.0.2/scripts/elfun/sec.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} tand (@var{x})
## Compute the tangent for each element of @var{x} in degrees.
##
## Returns zero for elements where @code{@var{x}/180} is an integer and
## @code{Inf} for elements where @code{(@var{x}-90)/180} is an integer.
## @seealso{atand, tan}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def tand(x=None,*args,**kwargs):
    varargin = tand.varargin
    nargin = tand.nargin

    if (nargin != 1):
        print_usage()
    
    I0=x / 180
# /home/lei/octave-4.0.2/scripts/elfun/tand.m:36
    I90=(x - 90) / 180
# /home/lei/octave-4.0.2/scripts/elfun/tand.m:37
    y=tan(multiply(I0,pi))
# /home/lei/octave-4.0.2/scripts/elfun/tand.m:38
    y[I0 == logical_and(fix(I0),isfinite(I0))]=0
# /home/lei/octave-4.0.2/scripts/elfun/tand.m:39
    y[I90 == logical_and(fix(I90),isfinite(I90))]=Inf
# /home/lei/octave-4.0.2/scripts/elfun/tand.m:40
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cosd (@var{x})
## Compute the cosine for each element of @var{x} in degrees.
##
## Returns zero for elements where @code{(@var{x}-90)/180} is an integer.
## @seealso{acosd, cos}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def cosd(x=None,*args,**kwargs):
    varargin = cosd.varargin
    nargin = cosd.nargin

    if (nargin != 1):
        print_usage()
    
    I=x / 180
# /home/lei/octave-4.0.2/scripts/elfun/cosd.m:35
    y=cos(multiply(I,pi))
# /home/lei/octave-4.0.2/scripts/elfun/cosd.m:36
    I=I + 0.5
# /home/lei/octave-4.0.2/scripts/elfun/cosd.m:37
    y[I == logical_and(fix(I),isfinite(I))]=0
# /home/lei/octave-4.0.2/scripts/elfun/cosd.m:38
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} coth (@var{x})
## Compute the hyperbolic cotangent of each element of @var{x}.
## @seealso{acoth}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def coth(x=None,*args,**kwargs):
    varargin = coth.varargin
    nargin = coth.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / tanh(x)
# /home/lei/octave-4.0.2/scripts/elfun/coth.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} acsch (@var{x})
## Compute the inverse hyperbolic cosecant of each element of @var{x}.
## @seealso{csch}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def acsch(x=None,*args,**kwargs):
    varargin = acsch.varargin
    nargin = acsch.nargin

    if (nargin != 1):
        print_usage()
    
    y=asinh(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/acsch.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} sind (@var{x})
## Compute the sine for each element of @var{x} in degrees.
##
## Returns zero for elements where @code{@var{x}/180} is an integer.
## @seealso{asind, sin}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def sind(x=None,*args,**kwargs):
    varargin = sind.varargin
    nargin = sind.nargin

    if (nargin != 1):
        print_usage()
    
    I=x / 180
# /home/lei/octave-4.0.2/scripts/elfun/sind.m:35
    y=sin(multiply(I,pi))
# /home/lei/octave-4.0.2/scripts/elfun/sind.m:36
    y[I == logical_and(fix(I),isfinite(I))]=0
# /home/lei/octave-4.0.2/scripts/elfun/sind.m:37
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} acoth (@var{x})
## Compute the inverse hyperbolic cotangent of each element of @var{x}.
## @seealso{coth}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def acoth(x=None,*args,**kwargs):
    varargin = acoth.varargin
    nargin = acoth.nargin

    if (nargin != 1):
        print_usage()
    
    y=atanh(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/acoth.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} asec (@var{x})
## Compute the inverse secant in radians for each element of @var{x}.
## @seealso{sec, asecd}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def asec(x=None,*args,**kwargs):
    varargin = asec.varargin
    nargin = asec.nargin

    if (nargin != 1):
        print_usage()
    
    y=acos(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/asec.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cscd (@var{x})
## Compute the cosecant for each element of @var{x} in degrees.
## @seealso{acscd, csc}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def cscd(x=None,*args,**kwargs):
    varargin = cscd.varargin
    nargin = cscd.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / sind(x)
# /home/lei/octave-4.0.2/scripts/elfun/cscd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} csch (@var{x})
## Compute the hyperbolic cosecant of each element of @var{x}.
## @seealso{acsch}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def csch(x=None,*args,**kwargs):
    varargin = csch.varargin
    nargin = csch.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / sinh(x)
# /home/lei/octave-4.0.2/scripts/elfun/csch.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} acotd (@var{x})
## Compute the inverse cotangent in degrees for each element of @var{x}.
## @seealso{cotd, acot}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def acotd(x=None,*args,**kwargs):
    varargin = acotd.varargin
    nargin = acotd.nargin

    if (nargin != 1):
        print_usage()
    
    y=atand(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/acotd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} acsc (@var{x})
## Compute the inverse cosecant in radians for each element of @var{x}.
## @seealso{csc, acscd}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def acsc(x=None,*args,**kwargs):
    varargin = acsc.varargin
    nargin = acsc.nargin

    if (nargin != 1):
        print_usage()
    
    y=asin(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/acsc.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} csc (@var{x})
## Compute the cosecant for each element of @var{x} in radians.
## @seealso{acsc, cscd, csch}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def csc(x=None,*args,**kwargs):
    varargin = csc.varargin
    nargin = csc.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / sin(x)
# /home/lei/octave-4.0.2/scripts/elfun/csc.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} asind (@var{x})
## Compute the inverse sine in degrees for each element of @var{x}.
## @seealso{sind, asin}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def asind(x=None,*args,**kwargs):
    varargin = asind.varargin
    nargin = asind.nargin

    if (nargin != 1):
        print_usage()
    
    y=multiply(asin(x),180) / pi
# /home/lei/octave-4.0.2/scripts/elfun/asind.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} acscd (@var{x})
## Compute the inverse cosecant in degrees for each element of @var{x}.
## @seealso{cscd, acsc}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def acscd(x=None,*args,**kwargs):
    varargin = acscd.varargin
    nargin = acscd.nargin

    if (nargin != 1):
        print_usage()
    
    y=multiply(acsc(x),180) / pi
# /home/lei/octave-4.0.2/scripts/elfun/acscd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} cot (@var{x})
## Compute the cotangent for each element of @var{x} in radians.
## @seealso{acot, cotd, coth}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def cot(x=None,*args,**kwargs):
    varargin = cot.varargin
    nargin = cot.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / tan(x)
# /home/lei/octave-4.0.2/scripts/elfun/cot.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} asech (@var{x})
## Compute the inverse hyperbolic secant of each element of @var{x}.
## @seealso{sech}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def asech(x=None,*args,**kwargs):
    varargin = asech.varargin
    nargin = asech.nargin

    if (nargin != 1):
        print_usage()
    
    y=acosh(1 / x)
# /home/lei/octave-4.0.2/scripts/elfun/asech.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} secd (@var{x})
## Compute the secant for each element of @var{x} in degrees.
## @seealso{asecd, sec}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def secd(x=None,*args,**kwargs):
    varargin = secd.varargin
    nargin = secd.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / cosd(x)
# /home/lei/octave-4.0.2/scripts/elfun/secd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} atand (@var{x})
## Compute the inverse tangent in degrees for each element of @var{x}.
## @seealso{tand, atan}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def atand(x=None,*args,**kwargs):
    varargin = atand.varargin
    nargin = atand.nargin

    if (nargin != 1):
        print_usage()
    
    y=multiply(180 / pi,atan(x))
# /home/lei/octave-4.0.2/scripts/elfun/atand.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} asecd (@var{x})
## Compute the inverse secant in degrees for each element of @var{x}.
## @seealso{secd, asec}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def asecd(x=None,*args,**kwargs):
    varargin = asecd.varargin
    nargin = asecd.nargin

    if (nargin != 1):
        print_usage()
    
    y=multiply(asec(x),180) / pi
# /home/lei/octave-4.0.2/scripts/elfun/asecd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2013-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} atan2d (@var{y}, @var{x})
## Compute atan2 (@var{y} / @var{x}) in degrees for corresponding elements
## from @var{y} and @var{x}.
## @seealso{tand, atan2}
## @end deftypefn
    
    
@function
def atan2d(y=None,x=None,*args,**kwargs):
    varargin = atan2d.varargin
    nargin = atan2d.nargin

    if (nargin != 2):
        print_usage()
    
    retval=multiply(180 / pi,atan2(y,x))
# /home/lei/octave-4.0.2/scripts/elfun/atan2d.m:32
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} acosd (@var{x})
## Compute the inverse cosine in degrees for each element of @var{x}.
## @seealso{cosd, acos}
## @end deftypefn
    
    ## Author: David Bateman <dbateman@free.fr>
    
    
@function
def acosd(x=None,*args,**kwargs):
    varargin = acosd.varargin
    nargin = acosd.nargin

    if (nargin != 1):
        print_usage()
    
    y=multiply(acos(x),180) / pi
# /home/lei/octave-4.0.2/scripts/elfun/acosd.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} sech (@var{x})
## Compute the hyperbolic secant of each element of @var{x}.
## @seealso{asech}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def sech(x=None,*args,**kwargs):
    varargin = sech.varargin
    nargin = sech.nargin

    if (nargin != 1):
        print_usage()
    
    y=1 / cosh(x)
# /home/lei/octave-4.0.2/scripts/elfun/sech.m:33
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} date ()
## Return the current date as a character string in the form DD-MMM-YYYY@.
##
## For example:
##
## @example
## @group
## date ()
##   @result{} "20-Aug-1993"
## @end group
## @end example
## @seealso{now, clock, datestr, localtime}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def date(*args,**kwargs):
    varargin = date.varargin
    nargin = date.nargin

    retval=strftime('%d-%b-%Y',localtime(time()))
# /home/lei/octave-4.0.2/scripts/time/date.m:38
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} etime (@var{t2}, @var{t1})
## Return the difference in seconds between two time values returned from
## @code{clock} (@math{@var{t2} - @var{t1}}).
##
## For example:
##
## @example
## @group
## t0 = clock ();
## # many computations later@dots{}
## elapsed_time = etime (clock (), t0);
## @end group
## @end example
##
## @noindent
## will set the variable @code{elapsed_time} to the number of seconds since the
## variable @code{t0} was set.
## @seealso{tic, toc, clock, cputime, addtodate}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def etime(t2=None,t1=None,*args,**kwargs):
    varargin = etime.varargin
    nargin = etime.nargin

    if (nargin != 2):
        print_usage()
    
    __,s2=datenum(t2,nargout=2)
# /home/lei/octave-4.0.2/scripts/time/etime.m:48
    __,s1=datenum(t1,nargout=2)
# /home/lei/octave-4.0.2/scripts/time/etime.m:49
    secs=s2 - s1
# /home/lei/octave-4.0.2/scripts/time/etime.m:51
    return secs
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} clock ()
## Return the current local date and time as a date vector.
##
## The date vector contains the following fields: current year, month (1-12),
## day (1-31), hour (0-23), minute (0-59), and second (0-61).  The seconds
## field has a fractional part after the decimal point for extended accuracy.
##
## For example:
##
## @example
## @group
## fix (clock ())
##      @result{} [ 1993, 8, 20, 4, 56, 1 ]
## @end group
## @end example
##
## @code{clock} is more accurate on systems that have the @code{gettimeofday}
## function.
## @seealso{now, date, datevec}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def clock(*args,**kwargs):
    varargin = clock.varargin
    nargin = clock.nargin

    tm=localtime(time())
# /home/lei/octave-4.0.2/scripts/time/clock.m:45
    retval=zeros(1,6)
# /home/lei/octave-4.0.2/scripts/time/clock.m:47
    retval[1]=tm.year + 1900
# /home/lei/octave-4.0.2/scripts/time/clock.m:49
    retval[2]=tm.mon + 1
# /home/lei/octave-4.0.2/scripts/time/clock.m:50
    retval[3]=tm.mday
# /home/lei/octave-4.0.2/scripts/time/clock.m:51
    retval[4]=tm.hour
# /home/lei/octave-4.0.2/scripts/time/clock.m:52
    retval[5]=tm.min
# /home/lei/octave-4.0.2/scripts/time/clock.m:53
    retval[6]=tm.sec + tm.usec / 1000000.0
# /home/lei/octave-4.0.2/scripts/time/clock.m:54
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{v} =} datevec (@var{date})
## @deftypefnx {Function File} {@var{v} =} datevec (@var{date}, @var{f})
## @deftypefnx {Function File} {@var{v} =} datevec (@var{date}, @var{p})
## @deftypefnx {Function File} {@var{v} =} datevec (@var{date}, @var{f}, @var{p})
## @deftypefnx {Function File} {[@var{y}, @var{m}, @var{d}, @var{h}, @var{mi}, @var{s}] =} datevec (@dots{})
## Convert a serial date number (see @code{datenum}) or date string (see
## @code{datestr}) into a date vector.
##
## A date vector is a row vector with six members, representing the year,
## month, day, hour, minute, and seconds respectively.
##
## @var{f} is the format string used to interpret date strings
## (see @code{datestr}).  If @var{date} is a string, but no format is
## specified, then a relatively slow search is performed through various
## formats.  It is always preferable to specify the format string @var{f} if it
## is known.  Formats which do not specify a particular time component will
## have the value set to zero.  Formats which do not specify a date will
## default to January 1st of the current year.
##
## @var{p} is the year at the start of the century to which two-digit years
## will be referenced.  If not specified, it defaults to the current year minus
## 50.
## @seealso{datenum, datestr, clock, now, date}
## @end deftypefn
    
    ## Algorithm: Peter Baum (http://vsg.cape.com/~pbaum/date/date0.htm)
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Modified: bdenney <bill@givebillmoney.com>
## Created: 10 October 2001 (CVS)
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    ## The function __date_str2vec__ is based on datesplit by Bill Denney.
    
    
@function
def datevec(date=None,f=[],p=[],*args,**kwargs):
    varargin = datevec.varargin
    nargin = datevec.nargin

    
    if (isempty(std_formats)):
        std_formats=cell()
# /home/lei/octave-4.0.2/scripts/time/datevec.m:59
        nfmt=0
# /home/lei/octave-4.0.2/scripts/time/datevec.m:60
        ## The '# XX' refers to the datestr numerical format code
        std_formats[++ nfmt]='dd-mmm-yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:63
        std_formats[++ nfmt]='dd-mmm-yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:64
        std_formats[++ nfmt]='mm/dd/yy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:65
        std_formats[++ nfmt]='mm/dd'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:66
        std_formats[++ nfmt]='HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:67
        std_formats[++ nfmt]='HH:MM:SS PM'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:68
        std_formats[++ nfmt]='HH:MM'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:69
        std_formats[++ nfmt]='HH:MM PM'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:70
        std_formats[++ nfmt]='mm/dd/yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:71
        ## These formats are undocumented but parsed by Matlab
        std_formats[++ nfmt]='mmmyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:74
        std_formats[++ nfmt]='mmm.dd,yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:75
        std_formats[++ nfmt]='mmm.dd,yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:76
        std_formats[++ nfmt]='yyyy/mm/dd'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:77
        std_formats[++ nfmt]='yyyy-mm-dd'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:78
        std_formats[++ nfmt]='yyyy-mm-dd HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:79
        ## These are other formats that Octave tries
        std_formats[++ nfmt]='mmm-dd-yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:82
        std_formats[++ nfmt]='mmm-dd-yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:83
        std_formats[++ nfmt]='dd mmm yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:84
        std_formats[++ nfmt]='dd mmm yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:85
        std_formats[++ nfmt]='mmm dd yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:86
        std_formats[++ nfmt]='mmm dd yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:87
        std_formats[++ nfmt]='dd.mmm.yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:88
        std_formats[++ nfmt]='dd.mmm.yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:89
        std_formats[++ nfmt]='mmm.dd.yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:90
        std_formats[++ nfmt]='mmm.dd.yyyy'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:91
        std_formats[++ nfmt]='mm/dd/yyyy HH:MM'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:92
    
    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (ischar(date)):
        date=cellstr(date)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:100
    
    if (isnumeric(f)):
        p=copy(f)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:104
        f=matlabarray([])
# /home/lei/octave-4.0.2/scripts/time/datevec.m:105
    
    if (isempty(f)):
        f=- 1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:109
    
    if (isempty(p)):
        p=(localtime(time())).year + 1900 - 50
# /home/lei/octave-4.0.2/scripts/time/datevec.m:113
    
    do_resize=copy(false)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:116
    if (iscell(date)):
        nd=numel(date)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:120
        y=m=d=h=mi=s=zeros(nd,1)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
# /home/lei/octave-4.0.2/scripts/time/datevec.m:122
        if (f == - 1):
            for k in arange(1,nd).reshape(-1):
                found=copy(false)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:126
                for l in arange(1,nfmt).reshape(-1):
                    f,rY,ry,fy,fm,fd,fh,fmi,fs=__date_vfmt2sfmt__(std_formats[l],nargout=9)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:128
                    found,y[k],m[k],d[k],h[k],mi[k],s[k]=__date_str2vec__(date[k],p,f,rY,ry,fy,fm,fd,fh,fmi,fs,nargout=7)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:130
                    if (found):
                        break
                if (logical_not(found)):
                    error('datevec: none of the standard formats match the DATE string')
        else:
            ## Decipher the format string just once for speed.
            f,rY,ry,fy,fm,fd,fh,fmi,fs=__date_vfmt2sfmt__(f,nargout=9)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:142
            for k in arange(1,nd).reshape(-1):
                found,y[k],m[k],d[k],h[k],mi[k],s[k]=__date_str2vec__(date[k],p,f,rY,ry,fy,fm,fd,fh,fmi,fs,nargout=7)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:144
                if (logical_not(found)):
                    error('datevec: DATE not parsed correctly with given format')
    else:
        if (logical_not(iscolumn(date))):
            date_sz=size(date)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:155
            do_resize=copy(true)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:156
        date=ravel(date)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:158
        z=double(floor(date) - 60)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:161
        a=floor((z - 0.25) / 36524.25)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:163
        b=z - 0.25 + a - floor(a / 4)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:165
        y=floor(b / 365.25)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:167
        c=fix(b - floor(dot(365.25,y))) + 1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:169
        m=fix((dot(5,c) + 456) / 153)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:171
        d=c - fix((dot(153,m) - 457) / 5)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:172
        ++ y(m > 12)
        m[m > 12] -= 12
        ## datenum format.
        fracd=date - floor(date)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:180
        tmps=abs(dot(dot(eps,86400),date))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:181
        tmps[tmps == 0]=1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:182
        srnd=2 ** floor(- log2(tmps))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:183
        s=round(multiply(dot(86400,fracd),srnd)) / srnd
# /home/lei/octave-4.0.2/scripts/time/datevec.m:184
        h=floor(s / 3600)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:185
        s=s - dot(3600,h)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:186
        mi=floor(s / 60)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:187
        s=s - dot(60,mi)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:188
    
    if (nargout <= 1):
        y=matlabarray(cat(y,m,d,h,mi,s))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:193
    else:
        if (do_resize):
            y=reshape(y,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:195
            m=reshape(m,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:196
            d=reshape(d,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:197
            h=reshape(h,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:198
            mi=reshape(mi,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:199
            s=reshape(s,date_sz)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:200
    
    return y,m,d,h,mi,s
    
if __name__ == '__main__':
    pass
    
    
@function
def __date_vfmt2sfmt__(f=None,*args,**kwargs):
    varargin = __date_vfmt2sfmt__.varargin
    nargin = __date_vfmt2sfmt__.nargin

    ## Play safe with percent signs.
    f=strrep(f,'%','%%')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:208
    if (logical_not(isempty(strfind(f,'PM'))) or logical_not(isempty(strfind(f,'AM')))):
        ampm=copy(true)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:211
    else:
        ampm=copy(false)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:213
    
    ## Date part.
    f=regexprep(f,'[Yy][Yy][Yy][Yy]','%Y')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:217
    f=regexprep(f,'[Yy][Yy]','%y')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:218
    f=strrep(f,'mmmm','%B')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:219
    f=strrep(f,'mmm','%b')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:220
    f=strrep(f,'mm','%m')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:221
    f=regexprep(f,'[Dd][Dd][Dd][Dd]','%A')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:222
    f=regexprep(f,'[Dd][Dd][Dd]','%a')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:223
    f=regexprep(f,'[Dd][Dd]','%d')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:224
    
    if (ampm):
        f=strrep(f,'HH','%I')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:228
        f=strrep(f,'PM','%p')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:229
        f=strrep(f,'AM','%p')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:230
    else:
        f=strrep(f,'HH','%H')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:232
    
    f=strrep(f,'MM','%M')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:234
    f=regexprep(f,'[Ss][Ss]','%S')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:235
    rY=rindex(f,'%Y')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:237
    ry=rindex(f,'%y')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:238
    
    ## Possible error when string contains "##".
    fy=rY or ry
# /home/lei/octave-4.0.2/scripts/time/datevec.m:242
    fm=index(f,'%m') or index(f,'%b') or index(f,'%B')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:243
    fd=index(f,'%d') or index(f,'%a') or index(f,'%A')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:244
    fh=index(f,'%H') or index(f,'%I')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:245
    fmi=index(f,'%M')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:246
    fs=index(f,'%S')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:247
    return f,rY,ry,fy,fm,fd,fh,fmi,fs
    
if __name__ == '__main__':
    pass
    
    
@function
def __date_str2vec__(ds=None,p=None,f=None,rY=None,ry=None,fy=None,fm=None,fd=None,fh=None,fmi=None,fs=None,*args,**kwargs):
    varargin = __date_str2vec__.varargin
    nargin = __date_str2vec__.nargin

    idx=strfind(f,'FFF')
# /home/lei/octave-4.0.2/scripts/time/datevec.m:253
    if (logical_not(isempty(idx))):
        ## Kludge to handle FFF millisecond format since strptime does not.
        ## Find location of FFF in ds.
    ## Might not match idx because of things like yyyy -> #y.
        __,nc=strptime(ds,f[1:idx - 1],nargout=2)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:259
        msec=ds[nc:min(nc + 2,end())]
# /home/lei/octave-4.0.2/scripts/time/datevec.m:261
        msec_idx=find(logical_not(isdigit(msec)),1)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:262
        if (logical_not(isempty(msec_idx))):
            msec=msec[1:msec_idx - 1]
# /home/lei/octave-4.0.2/scripts/time/datevec.m:265
            msec[end() + 1:3]='0'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:266
            ds=matlabarray(cat(ds[1:(nc - 1)],msec,ds[(nc - 1) + msec_idx:end()]))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:267
        else:
            if (numel(msec) < 3):
                m_len=numel(msec)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:269
                msec[end() + 1:3]='0'
# /home/lei/octave-4.0.2/scripts/time/datevec.m:270
                ds=matlabarray(cat(ds[1:(nc - 1)],msec,ds[nc + m_len:end()]))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:271
        ## replace FFF with digits to guarantee match in strptime.
        f[idx:idx + 2]=msec
# /home/lei/octave-4.0.2/scripts/time/datevec.m:275
        if (nc > 0):
            tm,nc=strptime(ds,f,nargout=2)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:278
            tm.usec = copy(dot(1000,str2double(msec)))
# /home/lei/octave-4.0.2/scripts/time/datevec.m:279
    else:
        tm,nc=strptime(ds,f,nargout=2)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:283
    
    if (nc == columns(ds) + 1):
        found=copy(true)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:287
        y=tm.year + 1900
# /home/lei/octave-4.0.2/scripts/time/datevec.m:288
        m=tm.mon + 1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:288
        d=tm.mday
# /home/lei/octave-4.0.2/scripts/time/datevec.m:288
        h=tm.hour
# /home/lei/octave-4.0.2/scripts/time/datevec.m:289
        mi=tm.min
# /home/lei/octave-4.0.2/scripts/time/datevec.m:289
        s=tm.sec + tm.usec / 1000000.0
# /home/lei/octave-4.0.2/scripts/time/datevec.m:289
        if (rY < ry):
            if (y > 1999):
                y -= 2000
            else:
                y -= 1900
            y += p - mod(p,100)
            if (y < p):
                y += 100
        if (logical_not(fy) and logical_not(fm) and logical_not(fd)):
            tmp=localtime(time())
# /home/lei/octave-4.0.2/scripts/time/datevec.m:302
            y=tmp.year + 1900
# /home/lei/octave-4.0.2/scripts/time/datevec.m:304
            m=1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:305
            d=1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:306
        else:
            if (logical_not(fy) and fm and fd):
                tmp=localtime(time())
# /home/lei/octave-4.0.2/scripts/time/datevec.m:308
                y=tmp.year + 1900
# /home/lei/octave-4.0.2/scripts/time/datevec.m:309
            else:
                if (fy and fm and logical_not(fd)):
                    d=1
# /home/lei/octave-4.0.2/scripts/time/datevec.m:311
        if (logical_not(fh) and logical_not(fmi) and logical_not(fs)):
            h=mi=s=0
# /home/lei/octave-4.0.2/scripts/time/datevec.m:314
# /home/lei/octave-4.0.2/scripts/time/datevec.m:314
# /home/lei/octave-4.0.2/scripts/time/datevec.m:314
        else:
            if (fh and fmi and logical_not(fs)):
                s=0
# /home/lei/octave-4.0.2/scripts/time/datevec.m:316
    else:
        y=m=d=h=mi=s=0
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
# /home/lei/octave-4.0.2/scripts/time/datevec.m:319
        found=copy(false)
# /home/lei/octave-4.0.2/scripts/time/datevec.m:320
    
    return found,y,m,d,h,mi,s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## tests for standard formats: 0, 1, 2, 6, 13, 14, 15, 16, 23
    
    
    
    
    
    
    
    
    
    ## Test millisecond format FFF
    
    
    
    ## Test millisecond format FFF with AM/PM, and 1,2, or 3 FFF digits
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test structure of return value (bug #42334)
    
    
    ## Other tests
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {t =} now ()
## Return the current local date/time as a serial day number
## (see @code{datenum}).
##
## The integral part, @code{floor (now)} corresponds to the number of days
## between today and Jan 1, 0000.
##
## The fractional part, @code{rem (now, 1)} corresponds to the current time.
## @seealso{clock, date, datenum}
## @end deftypefn
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Created: 10 October 2001 (CVS)
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def now(*args,**kwargs):
    varargin = now.varargin
    nargin = now.nargin

    if (nargin != 0):
        print_usage()
    
    t=datenum(clock())
# /home/lei/octave-4.0.2/scripts/time/now.m:41
    
    ##
  ##   seconds since 1970-1-1 corrected by seconds from GMT to local time
  ##   divided by 86400 sec/day plus day num for 1970-1-1
  ##   t = (time - mktime(gmtime(0)))/86400 + 719529;
  ##
  ## mktime (gmtime (0)) does indeed return the offset from Greenwich to the
  ## local time zone, but we need to account for daylight savings time
  ## changing by an hour the offset from CUT for part of the year.
    
    return t
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{e} =} eomday (@var{y}, @var{m})
## Return the last day of the month @var{m} for the year @var{y}.
## @seealso{weekday, datenum, datevec, is_leap_year, calendar}
## @end deftypefn
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Created: 25 July 2004
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def eomday(y=None,m=None,*args,**kwargs):
    varargin = eomday.varargin
    nargin = eomday.nargin

    if (nargin != 2):
        print_usage()
    
    eom=matlabarray(cat(31,28,31,30,31,30,31,31,30,31,30,31))
# /home/lei/octave-4.0.2/scripts/time/eomday.m:35
    e=reshape(eom[m],size(m))
# /home/lei/octave-4.0.2/scripts/time/eomday.m:36
    e += logical_and((m == 2),(mod(y,4) == logical_and(0,(mod(y,100) != logical_or(0,mod(y,400)) == 0))))
    return e
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{n}, @var{s}] =} weekday (@var{d})
## @deftypefnx {Function File} {[@var{n}, @var{s}] =} weekday (@var{d}, @var{format})
## Return the day of the week as a number in @var{n} and as a string in @var{s}.
##
## The days of the week are numbered 1--7 with the first day being Sunday.
##
## @var{d} is a serial date number or a date string.
##
## If the string @var{format} is not present or is equal to @qcode{"short"}
## then @var{s} will contain the abbreviated name of the weekday.  If
## @var{format} is @qcode{"long"} then @var{s} will contain the full name.
##
## Table of return values based on @var{format}:
##
## @multitable @columnfractions .06 .13 .16
## @headitem @var{n} @tab @qcode{"short"} @tab @qcode{"long"}
## @item 1 @tab Sun @tab Sunday
## @item 2 @tab Mon @tab Monday
## @item 3 @tab Tue @tab Tuesday
## @item 4 @tab Wed @tab Wednesday
## @item 5 @tab Thu @tab Thursday
## @item 6 @tab Fri @tab Friday
## @item 7 @tab Sat @tab Saturday
## @end multitable
##
## @seealso{eomday, is_leap_year, calendar, datenum, datevec}
## @end deftypefn
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Created: 10 October 2001 (CVS)
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def weekday(d=None,format='short',*args,**kwargs):
    varargin = weekday.varargin
    nargin = weekday.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (iscellstr(d) or isnumeric(d)):
        endsize=size(d)
# /home/lei/octave-4.0.2/scripts/time/weekday.m:59
    else:
        if (ischar(d)):
            endsize=matlabarray(cat(rows(d),1))
# /home/lei/octave-4.0.2/scripts/time/weekday.m:61
    
    if (ischar(d) or iscellstr(d)):
        ## Make sure the date is numeric
        d=datenum(d)
# /home/lei/octave-4.0.2/scripts/time/weekday.m:65
    
    ## Find the offset from a known Sunday (2008-Jan-6), mod 7.
    d=floor(reshape(mod(d - 733048,7),endsize))
# /home/lei/octave-4.0.2/scripts/time/weekday.m:68
    
    d[logical_not(d)]=7
# /home/lei/octave-4.0.2/scripts/time/weekday.m:70
    if (isargout(2)):
        if (strcmpi(format,'long')):
            names=cellarray(['Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday'])
# /home/lei/octave-4.0.2/scripts/time/weekday.m:74
        else:
            names=cellarray(['Sun','Mon','Tue','Wed','Thu','Fri','Sat'])
# /home/lei/octave-4.0.2/scripts/time/weekday.m:77
        s=strvcat(names[d])
# /home/lei/octave-4.0.2/scripts/time/weekday.m:79
    
    return d,s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test vector inputs for both directions
    
    
    ## Test a full week before our reference day
    
    
    
    
    
    
    
    ## Test our reference day
    
    ## Test a full week after our reference day
    
    
    
    
    
    
    
    ## Test fractional dates
    
    ## Test "long" option
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{str} =} datestr (@var{date})
## @deftypefnx {Function File} {@var{str} =} datestr (@var{date}, @var{f})
## @deftypefnx {Function File} {@var{str} =} datestr (@var{date}, @var{f}, @var{p})
## Format the given date/time according to the format @code{f} and return
## the result in @var{str}.
##
## @var{date} is a serial date number (see @code{datenum}) or a date vector
## (see @code{datevec}).  The value of @var{date} may also be a string or cell
## array of strings.
##
## @var{f} can be an integer which corresponds to one of the codes in the table
## below, or a date format string.
##
## @var{p} is the year at the start of the century in which two-digit years are
## to be interpreted in.  If not specified, it defaults to the current year
## minus 50.
##
## For example, the date 730736.65149 (2000-09-07 15:38:09.0934) would be
## formatted as follows:
##
## @multitable @columnfractions 0.1 0.45 0.35
## @headitem Code @tab Format @tab Example
## @item 0 @tab dd-mmm-yyyy HH:MM:SS    @tab 07-Sep-2000 15:38:09
## @item 1 @tab dd-mmm-yyyy             @tab 07-Sep-2000
## @item 2 @tab mm/dd/yy                @tab 09/07/00
## @item 3 @tab mmm                     @tab Sep
## @item 4 @tab m                       @tab S
## @item 5 @tab mm                      @tab 09
## @item 6 @tab mm/dd                   @tab 09/07
## @item 7 @tab dd                      @tab 07
## @item 8 @tab ddd                     @tab Thu
## @item 9 @tab d                       @tab T
## @item 10 @tab yyyy                   @tab 2000
## @item 11 @tab yy                     @tab 00
## @item 12 @tab mmmyy                  @tab Sep00
## @item 13 @tab HH:MM:SS               @tab 15:38:09
## @item 14 @tab HH:MM:SS PM            @tab 03:38:09 PM
## @item 15 @tab HH:MM                  @tab 15:38
## @item 16 @tab HH:MM PM               @tab 03:38 PM
## @item 17 @tab QQ-YY                  @tab Q3-00
## @item 18 @tab QQ                     @tab Q3
## @item 19 @tab dd/mm                  @tab 07/09
## @item 20 @tab dd/mm/yy               @tab 07/09/00
## @item 21 @tab mmm.dd,yyyy HH:MM:SS   @tab Sep.07,2000 15:38:08
## @item 22 @tab mmm.dd,yyyy            @tab Sep.07,2000
## @item 23 @tab mm/dd/yyyy             @tab 09/07/2000
## @item 24 @tab dd/mm/yyyy             @tab 07/09/2000
## @item 25 @tab yy/mm/dd               @tab 00/09/07
## @item 26 @tab yyyy/mm/dd             @tab 2000/09/07
## @item 27 @tab QQ-YYYY                @tab Q3-2000
## @item 28 @tab mmmyyyy                @tab Sep2000
## @item 29 @tab yyyy-mm-dd             @tab 2000-09-07
## @item 30 @tab yyyymmddTHHMMSS        @tab 20000907T153808
## @item 31 @tab yyyy-mm-dd HH:MM:SS    @tab 2000-09-07 15:38:08
## @end multitable
##
## If @var{f} is a format string, the following symbols are recognized:
##
## @multitable @columnfractions 0.1 0.7 0.2
## @headitem Symbol @tab Meaning @tab Example
## @item yyyy @tab Full year                                    @tab 2005
## @item yy   @tab Two-digit year                               @tab 05
## @item mmmm @tab Full month name                              @tab December
## @item mmm  @tab Abbreviated month name                       @tab Dec
## @item mm   @tab Numeric month number (padded with zeros)     @tab 01, 08, 12
## @item m    @tab First letter of month name (capitalized)     @tab D
## @item dddd @tab Full weekday name                            @tab Sunday
## @item ddd  @tab Abbreviated weekday name                     @tab Sun
## @item dd   @tab Numeric day of month (padded with zeros)     @tab 11
## @item d    @tab First letter of weekday name (capitalized)   @tab S
## @item HH   @tab Hour of day, padded with zeros if PM is set  @tab 09:00
## @item      @tab and not padded with zeros otherwise          @tab 9:00 AM
## @item MM   @tab Minute of hour (padded with zeros)           @tab 10:05
## @item SS   @tab Second of minute (padded with zeros)         @tab 10:05:03
## @item FFF  @tab Milliseconds of second (padded with zeros)   @tab 10:05:03.012
## @item AM   @tab Use 12-hour time format                      @tab 11:30 AM
## @item PM   @tab Use 12-hour time format                      @tab 11:30 PM
## @end multitable
##
## If @var{f} is not specified or is @code{-1}, then use 0, 1 or 16, depending
## on whether the date portion or the time portion of @var{date} is empty.
##
## If @var{p} is nor specified, it defaults to the current year minus 50.
##
## If a matrix or cell array of dates is given, a column vector of date strings
## is returned.
##
## @seealso{datenum, datevec, date, now, clock}
## @end deftypefn
    
    ## FIXME: parse arbitrary code strings.
## e.g., for  Wednesday 2001-03-05 09:04:06 AM, use
##     yy    01
##     yyyy  2001
##     m     M
##     mm    03
##     mmm   Mar
##     d     W
##     dd    05
##     ddd   Wed
##     HH    09
##     MM    04
##     SS    06
##     PM    AM
## FIXME: Vectorize.  It is particularly easy since all the codes are
##    fixed width.  Just generate the parts in separate arrays and
##    concatenate.
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Created: 10 October 2001 (CVS)
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def datestr(date=None,f=[],p=[],*args,**kwargs):
    varargin = datestr.varargin
    nargin = datestr.nargin

    
    if (isempty(dateform)):
        dateform=cell(32,1)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:137
        dateform[1]='dd-mmm-yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:138
        dateform[2]='dd-mmm-yyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:139
        dateform[3]='mm/dd/yy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:140
        dateform[4]='mmm'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:141
        dateform[5]='m'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:142
        dateform[6]='mm'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:143
        dateform[7]='mm/dd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:144
        dateform[8]='dd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:145
        dateform[9]='ddd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:146
        dateform[10]='d'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:147
        dateform[11]='yyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:148
        dateform[12]='yy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:149
        dateform[13]='mmmyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:150
        dateform[14]='HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:151
        dateform[15]='HH:MM:SS PM'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:152
        dateform[16]='HH:MM'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:153
        dateform[17]='HH:MM PM'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:154
        dateform[18]='QQ-YY'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:155
        dateform[19]='QQ'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:156
        dateform[20]='dd/mm'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:157
        dateform[21]='dd/mm/yy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:158
        dateform[22]='mmm.dd,yyyy HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:159
        dateform[23]='mmm.dd,yyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:160
        dateform[24]='mm/dd/yyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:161
        dateform[25]='dd/mm/yyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:162
        dateform[26]='yy/mm/dd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:163
        dateform[27]='yyyy/mm/dd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:164
        dateform[28]='QQ-YYYY'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:165
        dateform[29]='mmmyyyy'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:166
        dateform[30]='yyyy-mm-dd'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:167
        dateform[31]='yyyymmddTHHMMSS'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:168
        dateform[32]='yyyy-mm-dd HH:MM:SS'
# /home/lei/octave-4.0.2/scripts/time/datestr.m:169
        names_m=cellarray(['J','F','M','A','M','J','J','A','S','O','N','D'])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:171
        names_d=cellarray(['S','M','T','W','T','F','S'])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:172
    
    if (nargin < 1 or nargin > 3):
        print_usage()
    
    ## Guess input type.  We might be wrong.
    if (ischar(date) or iscellstr(date) or columns(date) != 6):
        v=datevec(date,p)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:181
    else:
        v=matlabarray([])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:183
        if (columns(date) == 6):
            ## Make sure that the input really is a datevec.
            maxdatevec=matlabarray(cat(Inf,12,31,23,59,60))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:186
            if (any(max(date,1) > maxdatevec) or any(date[:,1:5] != floor(date[:,1:5]))):
                v=datevec(date,p)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:189
        if (isempty(v)):
            v=copy(date)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:193
    
    retval=''
# /home/lei/octave-4.0.2/scripts/time/datestr.m:197
    for i in arange(1,rows(v)).reshape(-1):
        if (isempty(f)):
            if (v[i,4:6] == 0):
                f=1
# /home/lei/octave-4.0.2/scripts/time/datestr.m:202
            else:
                if (v[i,1:3] == cat(- 1,12,31)):
                    f=16
# /home/lei/octave-4.0.2/scripts/time/datestr.m:204
                else:
                    f=0
# /home/lei/octave-4.0.2/scripts/time/datestr.m:206
        if (isnumeric(f)):
            df=dateform[f + 1]
# /home/lei/octave-4.0.2/scripts/time/datestr.m:211
        else:
            df=copy(f)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:213
        df_orig=copy(df)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:216
        df=strrep(df,'AM','%p')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:217
        df=strrep(df,'PM','%p')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:218
        if (strcmp(df,df_orig)):
            ## PM not set.
            df=strrep(df,'HH','%H')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:221
        else:
            df=strrep(df,'HH',sprintf('%2d',v[i,4]))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:223
        df=regexprep(df,'[Yy][Yy][Yy][Yy]','%Y')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:226
        df=regexprep(df,'[Yy][Yy]','%y')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:228
        df=regexprep(df,'[Dd][Dd][Dd][Dd]','%A')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:230
        df=regexprep(df,'[Dd][Dd][Dd]','%a')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:232
        df=regexprep(df,'[Dd][Dd]','%d')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:234
        wday=weekday(datenum(v[i,1],v[i,2],v[i,3]))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:236
        tmp=names_d[wday]
# /home/lei/octave-4.0.2/scripts/time/datestr.m:237
        df=regexprep(df,'([^%])[Dd]',sprintf('$1%s',tmp))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:238
        df=regexprep(df,'^[Dd]',sprintf('%s',tmp))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:239
        df=strrep(df,'mmmm','%B')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:241
        df=strrep(df,'mmm','%b')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:243
        df=strrep(df,'mm','%m')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:245
        tmp=names_m[v[i,2]]
# /home/lei/octave-4.0.2/scripts/time/datestr.m:247
        pos=regexp(df,'[^%]m') + 1
# /home/lei/octave-4.0.2/scripts/time/datestr.m:248
        df[pos]=tmp
# /home/lei/octave-4.0.2/scripts/time/datestr.m:249
        df=regexprep(df,'^m',tmp)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:250
        df=strrep(df,'MM','%M')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:252
        df=regexprep(df,'[Ss][Ss]','%S')
# /home/lei/octave-4.0.2/scripts/time/datestr.m:254
        df=strrep(df,'FFF',sprintf('%03d',round(dot(1000,(v[i,6] - fix(v[i,6]))))))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:256
        df=strrep(df,'QQ',sprintf('Q%d',fix((v[i,2] + 2) / 3)))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:259
        vi=v[i,:]
# /home/lei/octave-4.0.2/scripts/time/datestr.m:261
        tm.year = copy(vi[1] - 1900)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:262
        tm.mon = copy(vi[2] - 1)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:263
        tm.mday = copy(vi[3])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:264
        tm.hour = copy(vi[4])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:265
        tm.min = copy(vi[5])
# /home/lei/octave-4.0.2/scripts/time/datestr.m:266
        sec=vi[6]
# /home/lei/octave-4.0.2/scripts/time/datestr.m:267
        tm.sec = copy(fix(sec))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:268
        tm.usec = copy(fix(dot((sec - tm.sec),1000000.0)))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:269
        tm.wday = copy(wday - 1)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:270
        ## We don't want to use "localtime (mktime (tm))" because that
    ## doesn't correctly handle dates before 1970-01-01 on some systems.
    ## tm.yday = ?;
    ## tm.isdst = ?;
        str=strftime(df,tm)
# /home/lei/octave-4.0.2/scripts/time/datestr.m:277
        retval=matlabarray(cat([retval],[str]))
# /home/lei/octave-4.0.2/scripts/time/datestr.m:279
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Mac OS X interprets #p parameter to strftime as lower case am/pm indicator.
## Accomodate this, although no other UNIX-based OS does this.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test possible bug where input is a vector of datenums that is exactly 6 wide
    
    ## Test fractional millisecond time extension
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} asctime (@var{tm_struct})
## Convert a time structure to a string using the following
## format: @qcode{"ddd mmm mm HH:MM:SS yyyy@xbackslashchar{}n"}.
##
## For example:
##
## @example
## @group
## asctime (localtime (time ()))
##      @result{} "Mon Feb 17 01:15:06 1997@xbackslashchar{}n"
## @end group
## @end example
##
## This is equivalent to @code{ctime (time ())}.
## @seealso{ctime, localtime, time}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def asctime(tm_struct=None,*args,**kwargs):
    varargin = asctime.varargin
    nargin = asctime.nargin

    if (nargin != 1):
        print_usage()
    
    retval=strftime('%a %b %d %H:%M:%S %Y\n',tm_struct)
# /home/lei/octave-4.0.2/scripts/time/asctime.m:45
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2008-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{d} =} addtodate (@var{d}, @var{q}, @var{f})
## Add @var{q} amount of time (with units @var{f}) to the serial datenum,
## @var{d}.
##
## @var{f} must be one of @qcode{"year"}, @qcode{"month"}, @qcode{"day"},
## @qcode{"hour"}, @qcode{"minute"}, @qcode{"second"}, or
## @qcode{"millisecond"}.
## @seealso{datenum, datevec, etime}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
    
    
@function
def addtodate(d=None,q=None,f=None,*args,**kwargs):
    varargin = addtodate.varargin
    nargin = addtodate.nargin

    
    if (nargin != 3):
        print_usage()
    else:
        if (logical_not((ischar(f) and isrow(f)))):
            error('addtodate: F must be a single character string')
    
    if (isscalar(d) and logical_not(isscalar(q))):
        ## expand d to size of q to make later addition easier.
        d=repmat(d,size(q))
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:45
    
    ## in case the user gives f as a plural, remove the 's'
    if ('s' == f[end()]):
        f[end()]=[]
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:50
    
    if (any(strcmpi(cellarray(['year','month']),f))):
        dtmp=datevec(d)
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:54
        if (strcmpi('year',f)):
            dtmp[:,1] += ravel(q)
        else:
            if (strcmpi('month',f)):
                dtmp[:,2] += ravel(q)
                dtmp[:,1] += floor((dtmp[:,2] - 1) / 12)
                dtmp[:,2]=mod(dtmp[:,2] - 1,12) + 1
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:61
        dnew=datenum(dtmp)
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:63
        if (numel(d) == numel(dnew)):
            d=reshape(dnew,size(d))
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:66
        else:
            d=reshape(dnew,size(q))
# /home/lei/octave-4.0.2/scripts/time/addtodate.m:68
    else:
        if (any(strcmpi(cellarray(['day','hour','minute','second','millisecond']),f))):
            d += multiply(q,getattr(mult,(f)))
        else:
            error('addtodate: Invalid time unit: %s',f)
    
    return d
    
if __name__ == '__main__':
    pass
    
    ## tests
    
    
    ## Identity
    
    
    
    
    
    
    
    ## Add one of each
## leap year
    
    
    
    
    
    
    
    ## substract one of each
    
    
    
    
    
    
    
    ## rollover
    
    
    ## multiple inputs and output orientation
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ctime (@var{t})
## Convert a value returned from @code{time} (or any other non-negative
## integer), to the local time and return a string of the same form as
## @code{asctime}.
##
## The function @code{ctime (time)} is equivalent to
## @code{asctime (localtime (time))}.  For example:
##
## @example
## @group
## ctime (time ())
##    @result{} "Mon Feb 17 01:15:06 1997@xbackslashchar{}n"
## @end group
## @end example
## @seealso{asctime, time, localtime}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def ctime(t=None,*args,**kwargs):
    varargin = ctime.varargin
    nargin = ctime.nargin

    if (nargin != 1):
        print_usage()
    
    retval=asctime(localtime(t))
# /home/lei/octave-4.0.2/scripts/time/ctime.m:45
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} is_leap_year ()
## @deftypefnx {Function File} {} is_leap_year (@var{year})
## Return true if @var{year} is a leap year and false otherwise.
##
## If no year is specified, @code{is_leap_year} uses the current year.
##
## For example:
##
## @example
## @group
## is_leap_year (2000)
##    @result{} 1
## @end group
## @end example
## @seealso{weekday, eomday, calendar}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def is_leap_year(year=None,*args,**kwargs):
    varargin = is_leap_year.varargin
    nargin = is_leap_year.nargin

    if (nargin > 1):
        print_usage()
    
    if (nargin == 0):
        t=clock()
# /home/lei/octave-4.0.2/scripts/time/is_leap_year.m:46
        year=t[1]
# /home/lei/octave-4.0.2/scripts/time/is_leap_year.m:47
    
    retval=logical_or((rem(year,4) == logical_and(0,rem(year,100)) != 0),(rem(year,400) == 0))
# /home/lei/octave-4.0.2/scripts/time/is_leap_year.m:50
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} calendar ()
## @deftypefnx {Function File} {@var{c} =} calendar (@var{d})
## @deftypefnx {Function File} {@var{c} =} calendar (@var{y}, @var{m})
## @deftypefnx {Function File} {} calendar (@dots{})
## Return the current monthly calendar in a 6x7 matrix.
##
## If @var{d} is specified, return the calendar for the month containing the
## date @var{d}, which must be a serial date number or a date string.
##
## If @var{y} and @var{m} are specified, return the calendar for year @var{y}
## and month @var{m}.
##
## If no output arguments are specified, print the calendar on the screen
## instead of returning a matrix.
## @seealso{datenum, datestr}
## @end deftypefn
    
    ## Author: pkienzle <pkienzle@users.sf.net>
## Created: 25 July 2004
## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
    
    
@function
def calendar(varargin=None,*args,**kwargs):
    varargin = calendar.varargin
    nargin = calendar.nargin

    if 0 == (nargin):
        v=clock()
# /home/lei/octave-4.0.2/scripts/time/calendar.m:45
        y=v[1]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:46
        m=v[2]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:47
        d=v[3]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:48
    else:
        if 1 == (nargin):
            v=datevec(varargin[1])
# /home/lei/octave-4.0.2/scripts/time/calendar.m:50
            y=v[1]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:51
            m=v[2]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:52
            d=v[3]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:53
        else:
            if 2 == (nargin):
                y=varargin[1]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:55
                m=varargin[2]
# /home/lei/octave-4.0.2/scripts/time/calendar.m:56
                d=matlabarray([])
# /home/lei/octave-4.0.2/scripts/time/calendar.m:57
            else:
                print_usage()
    
    c=zeros(7,6)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:62
    dayone=datenum(y,m,1)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:63
    ndays=eomday(y,m)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:64
    c[weekday(dayone) - 1 + cat(arange(1,ndays))]=arange(1,ndays)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:65
    if (nargout > 0):
        varargout[1]=c.T
# /home/lei/octave-4.0.2/scripts/time/calendar.m:68
    else:
        ## Layout the calendar days, 6 columns per day, 7 days per row.
        str=sprintf('    %2d    %2d    %2d    %2d    %2d    %2d    %2d\n',c)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:71
        if (logical_not(isempty(d))):
            pos=weekday(dayone) + d - 1
# /home/lei/octave-4.0.2/scripts/time/calendar.m:75
            idx=dot(6,pos) + fix(pos / 7.1) - ifelse(d < 10,1,2)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:76
            str[idx]='*'
# /home/lei/octave-4.0.2/scripts/time/calendar.m:77
        ## Display the calendar.
        s.year = copy(y - 1900)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:81
        s.mon = copy(m - 1)
# /home/lei/octave-4.0.2/scripts/time/calendar.m:82
        puts(strftime('                    %b %Y\n',s))
        puts('     S     M    Tu     W    Th     F     S\n')
        puts(str)
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{r} =} spones (@var{S})
## Replace the nonzero entries of @var{S} with ones.
##
## This creates a sparse matrix with the same structure as @var{S}.
## @seealso{sparse, sprand, sprandn, sprandsym, spfun, spy}
## @end deftypefn
    
    
@function
def spones(S=None,*args,**kwargs):
    varargin = spones.varargin
    nargin = spones.nargin

    if (nargin != 1):
        print_usage()
    
    i,j,v=find(S,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/spones.m:33
    m,n=size(S,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spones.m:34
    r=sparse(i,j,1,m,n)
# /home/lei/octave-4.0.2/scripts/sparse/spones.m:36
    return r
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2014-2015 Eduardo Ramos Fernndez <eduradical951@gmail.com>
## Copyright (C) 2013-2015 Kai T. Ohlhus <k.ohlhus@gmail.com>
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{L} =} ichol (@var{A})
## @deftypefnx {Function File} {@var{L} =} ichol (@var{A}, @var{opts})
##
## Compute the incomplete Cholesky factorization of the sparse square matrix
## @var{A}.
##
## By default, @code{ichol} uses only the lower triangle of @var{A} and
## produces a lower triangular factor @var{L} such that @tcode{L*L'}
## approximates @var{A}.
##
## The factor given by this routine may be useful as a preconditioner for a
## system of linear equations being solved by iterative methods such as
## PCG (Preconditioned Conjugate Gradient).
##
## The factorization may be modified by passing options in a structure
## @var{opts}.  The option name is a field of the structure and the setting
## is the value of field.  Names and specifiers are case sensitive.
##
## @table @asis
## @item type
## Type of factorization.
##
## @table @asis
## @item @qcode{"nofill"} (default)
## Incomplete Cholesky factorization with no fill-in (@nospell{IC(0)}).
##
## @item @qcode{"ict"}
## Incomplete Cholesky factorization with threshold dropping (@nospell{ICT}).
## @end table
##
## @item diagcomp
## A non-negative scalar @var{alpha} for incomplete Cholesky factorization of
## @code{@var{A} + @var{alpha} * diag (diag (@var{A}))} instead of @var{A}.
## This can be useful when @var{A} is not positive definite.  The default value
## is 0.
##
## @item droptol
## A non-negative scalar specifying the drop tolerance for factorization if
## performing @nospell{ICT}@.  The default value is 0 which produces the
## complete Cholesky factorization.
##
## Non-diagonal entries of @var{L} are set to 0 unless
##
## @code{abs (@var{L}(i,j)) >= droptol * norm (@var{A}(j:end, j), 1)}.
##
## @item michol
## Modified incomplete Cholesky factorization:
##
## @table @asis
## @item @qcode{"off"} (default)
## Row and column sums are not necessarily preserved.
##
## @item @qcode{"on"}
## The diagonal of @var{L} is modified so that row (and column) sums are
## preserved even when elements have been dropped during the factorization.
## The relationship preserved is: @code{@var{A} * e = @var{L} * @var{L}' * e},
## where e is a vector of ones.
## @end table
##
## @item shape
##
## @table @asis
## @item @qcode{"lower"} (default)
## Use only the lower triangle of @var{A} and return a lower triangular factor
## @var{L} such that @tcode{L*L'} approximates @var{A}.
##
## @item @qcode{"upper"}
## Use only the upper triangle of @var{A} and return an upper triangular factor
## @var{U} such that @code{U'*U} approximates @var{A}.
## @end table
## @end table
##
## EXAMPLES
##
## The following problem demonstrates how to factorize a sample symmetric
## positive definite matrix with the full Cholesky decomposition and with the
## incomplete one.
##
## @example
## @group
## A = [ 0.37, -0.05,  -0.05,  -0.07;
##      -0.05,  0.116,  0.0,   -0.05;
##      -0.05,  0.0,    0.116, -0.05;
##      -0.07, -0.05,  -0.05,   0.202];
## A = sparse (A);
## nnz (tril (A))
## ans =  9
## L = chol (A, "lower");
## nnz (L)
## ans =  10
## norm (A - L * L', "fro") / norm (A, "fro")
## ans =  1.1993e-16
## opts.type = "nofill";
## L = ichol (A, opts);
## nnz (L)
## ans =  9
## norm (A - L * L', "fro") / norm (A, "fro")
## ans =  0.019736
## @end group
## @end example
##
## Another example for decomposition is a finite difference matrix used to
## solve a boundary value problem on the unit square.
##
## @example
## @group
## nx = 400; ny = 200;
## hx = 1 / (nx + 1); hy = 1 / (ny + 1);
## Dxx = spdiags ([ones(nx, 1), -2*ones(nx, 1), ones(nx, 1)],
##                [-1 0 1 ], nx, nx) / (hx ^ 2);
## Dyy = spdiags ([ones(ny, 1), -2*ones(ny, 1), ones(ny, 1)],
##                [-1 0 1 ], ny, ny) / (hy ^ 2);
## A = -kron (Dxx, speye (ny)) - kron (speye (nx), Dyy);
## nnz (tril (A))
## ans =  239400
## opts.type = "nofill";
## L = ichol (A, opts);
## nnz (tril (A))
## ans =  239400
## norm (A - L * L', "fro") / norm (A, "fro")
## ans =  0.062327
## @end group
## @end example
##
## References for implemented algorithms:
##
## [1] @nospell{Y. Saad}. "Preconditioning Techniques." @cite{Iterative
## Methods for Sparse Linear Systems}, @nospell{PWS} Publishing Company, 1996.
##
## [2] @nospell{M. Jones, P. Plassmann}: @cite{An Improved Incomplete
## Cholesky Factorization}, 1992.
## @seealso{chol, ilu, pcg}
## @end deftypefn
    
    
@function
def ichol(A=None,opts=struct(),*args,**kwargs):
    varargin = ichol.varargin
    nargin = ichol.nargin

    if (nargin < 1 or nargin > 2 or nargout > 1):
        print_usage()
    
    if (logical_not((issparse(A) and issquare(A)))):
        error('ichol: A must be a sparse square matrix')
    
    if (logical_not(isstruct(opts))):
        error('ichol: OPTS must be a structure.')
    
    ## If A is empty then return empty L for Matlab compatibility
    if (isempty(A)):
        L=copy(A)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:171
        return L
    
    ## Parse input options
    if (logical_not(isfield(opts,'type'))):
        opts.type = copy('nofill')
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:177
    else:
        type_=tolower(getfield(opts,'type'))
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:179
        if (logical_not(strcmp(type_,'nofill')) and logical_not(strcmp(type_,'ict'))):
            error('ichol: TYPE must be "nofill" or "ict"')
        opts.type = copy(type_)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:183
    
    if (logical_not(isfield(opts,'droptol'))):
        opts.droptol = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:187
    else:
        if (logical_not((isreal(opts.droptol) and isscalar(opts.droptol) and opts.droptol >= 0))):
            error('ichol: DROPTOL must be a non-negative real scalar')
    
    michol=''
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:195
    if (logical_not(isfield(opts,'michol'))):
        opts.michol = copy('off')
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:197
    else:
        michol=tolower(getfield(opts,'michol'))
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:199
        if (logical_not(strcmp(michol,'off')) and logical_not(strcmp(michol,'on'))):
            error('ichol: MICHOL must be "on" or "off"')
        opts.michol = copy(michol)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:203
    
    if (logical_not(isfield(opts,'diagcomp'))):
        opts.diagcomp = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:207
    else:
        if (logical_not((isreal(opts.diagcomp) and isscalar(opts.diagcomp) and opts.diagcomp >= 0))):
            error('ichol: DIAGCOMP must be a non-negative real scalar')
    
    if (logical_not(isfield(opts,'shape'))):
        opts.shape = copy('lower')
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:216
    else:
        shape=tolower(getfield(opts,'shape'))
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:218
        if (logical_not(strcmp(shape,'lower')) and logical_not(strcmp(shape,'upper'))):
            error('ichol: SHAPE must be "lower" or "upper"')
        opts.shape = copy(shape)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:222
    
    ## Prepare input for specialized ICHOL
    A_in=matlabarray([])
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:226
    if (opts.diagcomp > 0):
        A += dot(opts.diagcomp,diag(diag(A)))
    
    if (strcmp(opts.shape,'upper')):
        A_in=triu(A)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:231
        A_in=A_in.T
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:232
    else:
        A_in=tril(A)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:234
    
    ## Delegate to specialized ICHOL
    if 'nofill' == (opts.type):
        L=__ichol0__(A_in,opts.michol)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:240
    else:
        if 'ict' == (opts.type):
            L=__icholt__(A_in,opts.droptol,opts.michol)
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:242
    
    if (strcmp(opts.shape,'upper')):
        L=L.T
# /home/lei/octave-4.0.2/scripts/sparse/ichol.m:246
    
    return L
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ICHOL0 tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Negative pivot
    ## Complex entry in the diagonal
    
    ## ICHOLT tests
    
    ##!test
    
    
    
    
    
    
    
    
    
    
    
    
    ##!test
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
## Copyright (C) 2012 Jordi Gutirrez Hermoso
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sprandsym (@var{n}, @var{d})
## @deftypefnx {Function File} {} sprandsym (@var{s})
## Generate a symmetric random sparse matrix.
##
## The size of the matrix will be @var{n}x@var{n}, with a density of values
## given by @var{d}.  @var{d} must be between 0 and 1 inclusive.  Values will
## be normally distributed with a mean of zero and a variance of 1.
##
## If called with a single matrix argument, a random sparse matrix is generated
## wherever the matrix @var{s} is nonzero in its lower triangular part.
## @seealso{sprand, sprandn, spones, sparse}
## @end deftypefn
    
    
@function
def sprandsym(n=None,d=None,*args,**kwargs):
    varargin = sprandsym.varargin
    nargin = sprandsym.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (nargin == 1):
        i,j=find(tril(n),nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:41
        nr,nc=size(n,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:42
        S=sparse(i,j,randn(size(i)),nr,nc)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:43
        S=S + tril(S,- 1).T
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:44
        return S
    
    if (logical_not((isscalar(n) and n == fix(n) and n > 0))):
        error('sprandsym: N must be an integer greater than 0')
    
    if (d < 0 or d > 1):
        error('sprandsym: density D must be between 0 and 1')
    
    ## Actual number of nonzero entries
    k=round(dot(n ** 2,d))
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:57
    
    r=pick_rand_diag(n,k)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:60
    
    m=(k - r) / 2
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:63
    ondiag=randperm(n,r)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:65
    offdiag=randperm(dot(n,(n - 1)) / 2,m)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:66
    
    i=lookup(cumsum(arange(0,n)),offdiag - 1) + 1
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:69
    
    j=offdiag - multiply((i - 1),(i - 2)) / 2
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:72
    diagvals=randn(1,r)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:74
    offdiagvals=randn(1,m)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:75
    S=sparse(cat(ondiag,i,j),cat(ondiag,j,i),cat(diagvals,offdiagvals,offdiagvals),n,n)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:77
    return S
    
if __name__ == '__main__':
    pass
    
    
@function
def pick_rand_diag(n=None,k=None,*args,**kwargs):
    varargin = pick_rand_diag.varargin
    nargin = pick_rand_diag.nargin

    ## Pick a random number R of entries for the diagonal of a sparse NxN
  ## symmetric square matrix with exactly K nonzero entries, ensuring
  ## that this R is chosen uniformly over all such matrices.
  ##
  ## Let D be the number of diagonal entries and M the number of
  ## off-diagonal entries. Then K = D + 2*M. Let A = N*(N-1)/2 be the
  ## number of available entries in the upper triangle of the matrix.
  ## Then, by a simple counting argument, there is a total of
  ##
  ##     T = nchoosek (N, D) * nchoosek (A, M)
  ##
  ## symmetric NxN matrices with a total of K nonzero entries and D on
  ## the diagonal. Letting D range from mod (K,2) through min (N,K), and
  ## dividing by this sum, we obtain the probability P for D to be each
  ## of those values.
  ##
  ## However, we cannot use this form for computation, as the binomial
  ## coefficients become unmanageably large. Instead, we use the
  ## successive quotients Q(i) = T(i+1)/T(i), which we easily compute to
  ## be
  ##
  ##               (N - D)*(N - D - 1)*M
  ##     Q =  -------------------------------
  ##            (D + 2)*(D + 1)*(A - M + 1)
  ##
  ## Then, after prepending 1, the cumprod of these quotients is
  ##
  ##      C = [ T(1)/T(1), T(2)/T(1), T(3)/T(1), ..., T(N)/T(1) ]
  ##
  ## Their sum is thus S = sum (T)/T(1), and then C(i)/S is the desired
  ## probability P(i) for i=1:N. The cumsum will finally give the
  ## distribution function for computing the random number of entries on
  ## the diagonal R.
  ##
  ## Thanks to Zsbn Ambrus <ambrus@math.bme.hu> for most of the ideas
  ## of the implementation here, especially how to do the computation
  ## numerically to avoid overflow.
    
    ## Degenerate case
    if (k == 1):
        r=1
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:123
        return r
    
    ## Compute the stuff described above
    a=dot(n,(n - 1)) / 2
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:128
    d=matlabarray(cat(arange(mod(k,2),min(n,k) - 2,2)))
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:129
    m=(k - d) / 2
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:130
    q=multiply(multiply((n - d),(n - d - 1)),m) / (d + 2) / (d + 1) / (a - m + 1)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:131
    
    ## order to avoid overflow (underflow is fine, just means effectively
  ## zero probabilities).
    __,midx=max(cumsum(log(q)),nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:136
    midx
    lc=fliplr(cumprod(1.0 / q[midx - 1:- 1:1]))
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:138
    rc=cumprod(q[midx:end()])
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:139
    
    c=matlabarray(cat(lc,1,rc))
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:142
    s=sum(c)
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:143
    p=c / s
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:144
    
    d[end() + 1]=d[end()] + 2
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:147
    
    r=d[sum(cumsum(p) < rand) + 1]
# /home/lei/octave-4.0.2/scripts/sparse/sprandsym.m:150
    return r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test 1-input calling form
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sprand (@var{m}, @var{n}, @var{d})
## @deftypefnx {Function File} {} sprand (@var{m}, @var{n}, @var{d}, @var{rc})
## @deftypefnx {Function File} {} sprand (@var{s})
## Generate a sparse matrix with uniformly distributed random values.
##
## The size of the matrix is @var{m}x@var{n} with a density of values @var{d}.
## @var{d} must be between 0 and 1.  Values will be uniformly distributed on
## the interval (0, 1).
##
## If called with a single matrix argument, a sparse matrix is generated with
## random values wherever the matrix @var{s} is nonzero.
##
## If called with a scalar fourth argument @var{rc}, a random sparse matrix
## with reciprocal condition number @var{rc} is generated.  If @var{rc} is
## a vector, then it specifies the first singular values of the generated
## matrix (@code{length (@var{rc}) <= min (@var{m}, @var{n})}).
##
## @seealso{sprandn, sprandsym, rand}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
##
## Changelog:
##
## Piotr Krzyzanowski <przykry2004@users.sf.net>
##      2004-09-27      use Paul's hint to allow larger random matrices
##                      at the price of sometimes lower density than desired
## David Bateman
##      2004-10-20      Texinfo help and copyright message
    
    
@function
def sprand(m=None,n=None,d=None,rc=None,*args,**kwargs):
    varargin = sprand.varargin
    nargin = sprand.nargin

    if (nargin == 1):
        s=__sprand_impl__(m,rand)
# /home/lei/octave-4.0.2/scripts/sparse/sprand.m:56
    else:
        if (nargin == 3):
            s=__sprand_impl__(m,n,d,'sprand',rand)
# /home/lei/octave-4.0.2/scripts/sparse/sprand.m:58
        else:
            if (nargin == 4):
                s=__sprand_impl__(m,n,d,rc,'sprand',rand)
# /home/lei/octave-4.0.2/scripts/sparse/sprand.m:60
            else:
                print_usage()
    
    return s
    
if __name__ == '__main__':
    pass
    
    ## Test 3-input calling form
    
    
    
    ## Test 4-input calling form
    
    
    
    
    
    
    
    
    
    
    ## Test 1-input calling form
    
    
    
    
    
    ## Test very large, very low density matrix doesn't fail
    
    ## Test input validation
    
    ## Copyright (C) 1998-2015 Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} spy (@var{x})
## @deftypefnx {Function File} {} spy (@dots{}, @var{markersize})
## @deftypefnx {Function File} {} spy (@dots{}, @var{line_spec})
## Plot the sparsity pattern of the sparse matrix @var{x}.
##
## If the argument @var{markersize} is given as a scalar value, it is used to
## determine the point size in the plot.
##
## If the string @var{line_spec} is given it is passed to @code{plot} and
## determines the appearance of the plot.
## @seealso{plot, gplot}
## @end deftypefn
    
    
@function
def spy(x=None,varargin=None,*args,**kwargs):
    varargin = spy.varargin
    nargin = spy.nargin

    if (nargin < 1):
        print_usage()
    
    markersize=copy(NaN)
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:39
    if (nnz(x) < 1000):
        line_spec='*'
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:41
    else:
        line_spec='.'
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:43
    
    for i in arange(1,length(varargin)).reshape(-1):
        if (ischar(varargin[i])):
            if (length(varargin[i]) == 1):
                line_spec=matlabarray(cat(line_spec,varargin[i]))
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:48
            else:
                line_spec=varargin[i]
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:50
        else:
            if (isscalar(varargin[i])):
                markersize=varargin[i]
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:53
            else:
                error('spy: expected markersize or linespec')
    
    i,j,s=find(x,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:59
    m,n=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spy.m:60
    if (isnan(markersize)):
        plot(j,i,line_spec)
    else:
        plot(j,i,line_spec,'markersize',markersize)
    
    axis(cat(0,n + 1,0,m + 1),'ij')
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Mark graphical function as tested by demo block
    
    ## Copyright (C) 2004-2015 Piotr Krzyzanowski
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} pcr (@var{A}, @var{b}, @var{tol}, @var{maxit}, @var{m}, @var{x0}, @dots{})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}] =} pcr (@dots{})
##
## Solve the linear system of equations @code{@var{A} * @var{x} = @var{b}} by
## means of the Preconditioned Conjugate Residuals iterative method.
##
## The input arguments are
##
## @itemize
## @item
## @var{A} can be either a square (preferably sparse) matrix or a function
## handle, inline function or string containing the name of a function which
## computes @code{@var{A} * @var{x}}.  In principle @var{A} should be
## symmetric and non-singular; if @code{pcr} finds @var{A} to be numerically
## singular, you will get a warning message and the @var{flag} output
## parameter will be set.
##
## @item
## @var{b} is the right hand side vector.
##
## @item
## @var{tol} is the required relative tolerance for the residual error,
## @code{@var{b} - @var{A} * @var{x}}.  The iteration stops if
## @code{norm (@var{b} - @var{A} * @var{x}) <=
##       @var{tol} * norm (@var{b} - @var{A} * @var{x0})}.
## If @var{tol} is empty or is omitted, the function sets
## @code{@var{tol} = 1e-6} by default.
##
## @item
## @var{maxit} is the maximum allowable number of iterations; if @code{[]} is
## supplied for @code{maxit}, or @code{pcr} has less arguments, a default
## value equal to 20 is used.
##
## @item
## @var{m} is the (left) preconditioning matrix, so that the iteration is
## (theoretically) equivalent to solving by
## @code{pcr} @code{@var{P} * @var{x} = @var{m} \ @var{b}}, with
## @code{@var{P} = @var{m} \ @var{A}}.  Note that a proper choice of the
## preconditioner may dramatically improve the overall performance of the
## method.  Instead of matrix @var{m}, the user may pass a function which
## returns the results of applying the inverse of @var{m} to a vector
## (usually this is the preferred way of using the preconditioner).  If
## @code{[]} is supplied for @var{m}, or @var{m} is omitted, no
## preconditioning is applied.
##
## @item
## @var{x0} is the initial guess.  If @var{x0} is empty or omitted, the
## function sets @var{x0} to a zero vector by default.
## @end itemize
##
## The arguments which follow @var{x0} are treated as parameters, and passed
## in a proper way to any of the functions (@var{A} or @var{m}) which are
## passed to @code{pcr}.  See the examples below for further details.
##
## The output arguments are
##
## @itemize
## @item
## @var{x} is the computed approximation to the solution of
## @code{@var{A} * @var{x} = @var{b}}.
##
## @item
## @var{flag} reports on the convergence.  @code{@var{flag} = 0} means the
## solution converged and the tolerance criterion given by @var{tol} is
## satisfied.  @code{@var{flag} = 1} means that the @var{maxit} limit for the
## iteration count was reached.  @code{@var{flag} = 3} reports a @code{pcr}
## breakdown, see [1] for details.
##
## @item
## @var{relres} is the ratio of the final residual to its initial value,
## measured in the Euclidean norm.
##
## @item
## @var{iter} is the actual number of iterations performed.
##
## @item
## @var{resvec} describes the convergence history of the method, so that
## @code{@var{resvec} (i)} contains the Euclidean norms of the residual after
## the (@var{i}-1)-th iteration, @code{@var{i} = 1,2, @dots{}, @var{iter}+1}.
## @end itemize
##
## Let us consider a trivial problem with a diagonal matrix (we exploit the
## sparsity of A)
##
## @example
## @group
## n = 10;
## A = sparse (diag (1:n));
## b = rand (N, 1);
## @end group
## @end example
##
## @sc{Example 1:} Simplest use of @code{pcr}
##
## @example
## x = pcr (A, b)
## @end example
##
## @sc{Example 2:} @code{pcr} with a function which computes
## @code{@var{A} * @var{x}}.
##
## @example
## @group
## function y = apply_a (x)
##   y = [1:10]' .* x;
## endfunction
##
## x = pcr ("apply_a", b)
## @end group
## @end example
##
## @sc{Example 3:}  Preconditioned iteration, with full diagnostics.  The
## preconditioner (quite strange, because even the original matrix
## @var{A} is trivial) is defined as a function
##
## @example
## @group
## function y = apply_m (x)
##   k = floor (length (x) - 2);
##   y = x;
##   y(1:k) = x(1:k) ./ [1:k]';
## endfunction
##
## [x, flag, relres, iter, resvec] = ...
##                    pcr (A, b, [], [], "apply_m")
## semilogy ([1:iter+1], resvec);
## @end group
## @end example
##
## @sc{Example 4:} Finally, a preconditioner which depends on a
## parameter @var{k}.
##
## @example
## @group
## function y = apply_m (x, varargin)
##   k = varargin@{1@};
##   y = x;
##   y(1:k) = x(1:k) ./ [1:k]';
## endfunction
##
## [x, flag, relres, iter, resvec] = ...
##                    pcr (A, b, [], [], "apply_m"', [], 3)
## @end group
## @end example
##
## References:
##
## [1] @nospell{W. Hackbusch}, @cite{Iterative Solution of Large Sparse
## Systems of Equations}, section 9.5.4; Springer, 1994
##
## @seealso{sparse, pcg}
## @end deftypefn
    
    ## Author: Piotr Krzyzanowski <piotr.krzyzanowski@mimuw.edu.pl>
    
    
@function
def pcr(A=None,b=None,tol=None,maxit=None,m=None,x0=None,varargin=None,*args,**kwargs):
    varargin = pcr.varargin
    nargin = pcr.nargin

    breakdown=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:177
    if (nargin < 6 or isempty(x0)):
        x=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:180
    else:
        x=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:182
    
    if (nargin < 5):
        m=matlabarray([])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:186
    
    if (nargin < 4 or isempty(maxit)):
        maxit=20
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:190
    
    maxit += 2
    if (nargin < 3 or isempty(tol)):
        tol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:196
    
    if (nargin < 2):
        print_usage()
    
    ##  init
    if (isnumeric(A)):
        r=b - dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:205
    else:
        r=b - feval(A,x,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:207
    
    if (isnumeric(m)):
        if (isempty(m)):
            p=copy(r)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:212
        else:
            p=numpy.linalg.solve(m,r)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:214
    else:
        p=feval(m,r,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:217
    
    iter=2
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:220
    b_bot_old=1
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:222
    q_old=p_old=s_old=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:223
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:223
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:223
    if (isnumeric(A)):
        q=dot(A,p)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:226
    else:
        q=feval(A,p,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:228
    
    resvec[1]=abs(norm(r))
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:231
    
    while (resvec[iter - 1] > dot(tol,resvec[1]) and iter < maxit):

        if (isnumeric(m)):
            if (isempty(m)):
                s=copy(q)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:238
            else:
                s=numpy.linalg.solve(m,q)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:240
        else:
            s=feval(m,q,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:243
        b_top=dot(r.T,s)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:245
        b_bot=dot(q.T,s)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:246
        if (b_bot == 0.0):
            breakdown=copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:249
            break
        lambda_=b_top / b_bot
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:252
        x += dot(lambda_,p)
        r -= dot(lambda_,q)
        if (isnumeric(A)):
            t=dot(A,s)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:258
        else:
            t=feval(A,s,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:260
        alpha0=(dot(t.T,s)) / b_bot
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:263
        alpha1=(dot(t.T,s_old)) / b_bot_old
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:264
        p_temp=copy(p)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:266
        q_temp=copy(q)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:267
        p=s - dot(alpha0,p) - dot(alpha1,p_old)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:269
        q=t - dot(alpha0,q) - dot(alpha1,q_old)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:270
        s_old=copy(s)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:272
        p_old=copy(p_temp)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:273
        q_old=copy(q_temp)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:274
        b_bot_old=copy(b_bot)
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:275
        resvec[iter]=abs(norm(r))
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:277
        iter

    
    flag=0
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:281
    relres=resvec[iter - 1] / resvec[1]
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:282
    iter -= 2
    if (iter >= maxit - 2):
        flag=1
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:285
        if (nargout < 2):
            warning('pcr: maximum number of iterations (%d) reached\n',iter)
            warning('the initial residual norm was reduced %g times.\n',1.0 / relres)
    else:
        if (nargout < 2 and logical_not(breakdown)):
            fprintf(stderr,'pcr: converged in %d iterations. \n',iter)
            fprintf(stderr,'the initial residual norm was reduced %g times.\n',1.0 / relres)
    
    if (breakdown):
        flag=3
# /home/lei/octave-4.0.2/scripts/sparse/pcr.m:297
        if (nargout < 2):
            warning('pcr: breakdown occurred:\n')
            warning('system matrix singular or preconditioner indefinite?\n')
    
    return x,flag,relres,iter,resvec
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by the
## Free Software Foundation; either version 3 of the License, or (at your
## option) any later version.
##
## Octave is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
## for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} gmres (@var{A}, @var{b}, @var{m}, @var{rtol}, @var{maxit}, @var{M1}, @var{M2}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} gmres (@var{A}, @var{b}, @var{m}, @var{rtol}, @var{maxit}, @var{P})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}] =} gmres (@dots{})
## Solve @code{A x = b} using the Preconditioned GMRES iterative method with
## restart, a.k.a. PGMRES(m).
##
## @itemize @minus
## @item @var{rtol} is the relative tolerance,
## if not given or set to [] the default value 1e-6 is used.
##
## @item @var{maxit} is the maximum number of outer iterations, if not given or
## set to [] the default value @code{min (10, numel (b) / restart)} is used.
##
## @item @var{x0} is the initial guess,
## if not given or set to [] the default value @code{zeros (size (b))} is used.
##
## @item @var{m} is the restart parameter,
## if not given or set to [] the default value @code{numel (b)} is used.
## @end itemize
##
## Argument @var{A} can be passed as a matrix, function handle, or inline
## function @code{f} such that @code{f(x) = A*x}.
##
## The preconditioner @var{P} is given as @code{P = M1 * M2}.  Both @var{M1}
## and @var{M2} can be passed as a matrix, function handle, or inline function
## @code{g} such that @code{g(x) = M1\x} or @code{g(x) = M2\x}.
##
## Besides the vector @var{x}, additional outputs are:
##
## @itemize @minus
## @item @var{flag} indicates the exit status:
##
## @table @asis
## @item 0 : iteration converged to within the specified tolerance
##
## @item 1 : maximum number of iterations exceeded
##
## @item 2 : unused, but skipped for compatibility
##
## @item 3 : algorithm reached stagnation (no change between iterations)
## @end table
##
## @item @var{relres} is the final value of the relative residual.
##
## @item @var{iter} is a vector containing the number of outer iterations and
## total iterations performed.
##
## @item @var{resvec} is a vector containing the relative residual at each
## iteration.
## @end itemize
##
## @seealso{bicg, bicgstab, cgs, pcg, pcr, qmr}
## @end deftypefn
    
    
@function
def gmres(A=None,b=None,restart=None,rtol=None,maxit=None,M1=None,M2=None,x0=None,*args,**kwargs):
    varargin = gmres.varargin
    nargin = gmres.nargin

    if (nargin < 2 or nargin > 8):
        print_usage()
    
    if (ischar(A)):
        Ax=str2func(A)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:81
    else:
        if (isnumeric(A) and issquare(A)):
            Ax=lambda x=None: dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:83
        else:
            if (isa(A,'function_handle')):
                Ax=copy(A)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:85
            else:
                error('gmres: A must be a function or square matrix')
    
    if (nargin < 3 or isempty(restart)):
        restart=rows(b)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:91
    
    if (nargin < 4 or isempty(rtol)):
        rtol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:95
    
    if (nargin < 5 or isempty(maxit)):
        maxit=min(rows(b) / restart,10)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:99
    
    if (nargin < 6 or isempty(M1)):
        M1m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:103
    else:
        if (ischar(M1)):
            M1m1x=str2func(M1)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:105
        else:
            if (isnumeric(M1) and ismatrix(M1)):
                M1m1x=lambda x=None: numpy.linalg.solve(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:107
            else:
                if (isa(M1,'function_handle')):
                    M1m1x=copy(M1)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:109
                else:
                    error('gmres: preconditioner M1 must be a function or matrix')
    
    if (nargin < 7 or isempty(M2)):
        M2m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:115
    else:
        if (ischar(M2)):
            M2m1x=str2func(M2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:117
        else:
            if (isnumeric(M2) and ismatrix(M2)):
                M2m1x=lambda x=None: numpy.linalg.solve(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:119
            else:
                if (isa(M2,'function_handle')):
                    M2m1x=copy(M2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:121
                else:
                    error('gmres: preconditioner M2 must be a function or matrix')
    
    Pm1x=lambda x=None: M2m1x[M1m1x[x]]
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:126
    if (nargin < 8 or isempty(x0)):
        x0=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:129
    
    x_old=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:132
    x=copy(x_old)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:133
    prec_res=Pm1x[b - Ax[x_old]]
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:134
    presn=norm(prec_res,2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:135
    B=zeros(restart + 1,1)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:137
    V=zeros(rows(x),restart)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:138
    H=zeros(restart + 1,restart)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:139
    
    iter=1
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:142
    restart_it=restart + 1
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:143
    resvec=zeros(maxit,1)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:144
    resvec[1]=presn
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:145
    prec_b_norm=norm(Pm1x[b],2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:146
    flag=1
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:147
    
    while (iter <= dot(maxit,restart) and presn > dot(rtol,prec_b_norm)):

        ## restart
        if (restart_it > restart):
            restart_it=1
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:153
            x_old=copy(x)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:154
            prec_res=Pm1x[b - Ax[x_old]]
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:155
            presn=norm(prec_res,2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:156
            B[1]=presn
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:157
            ravel[H]=0
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:158
            V[:,1]=prec_res / presn
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:159
        ## basic iteration
        tmp=Pm1x[Ax[V[:,restart_it]]]
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:163
        V[:,restart_it + 1],H[1:restart_it + 1,restart_it]=mgorth(tmp,V[:,1:restart_it],nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:164
        Y=(numpy.linalg.solve(H[1:restart_it + 1,1:restart_it],B[1:restart_it + 1]))
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:167
        little_res=B[1:restart_it + 1] - dot(H[1:restart_it + 1,1:restart_it],Y[1:restart_it])
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:169
        presn=norm(little_res,2)
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:172
        x=x_old + dot(V[:,1:restart_it],Y[1:restart_it])
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:174
        resvec[iter + 1]=presn
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:176
        if (norm(x - x_old,inf) <= eps):
            flag=3
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:178
            break
        restart_it
        iter

    
    if (nargout > 1):
        ## Calculate extra outputs as requested
        relres=presn / prec_b_norm
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:188
        if (relres <= rtol):
            flag=0
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:190
        it=matlabarray(cat(floor(iter / restart),restart_it - 1))
# /home/lei/octave-4.0.2/scripts/sparse/gmres.m:193
    
    return x,flag,relres,it,resvec
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{x} =} spconvert (@var{m})
## Convert a simple sparse matrix format easily generated by other programs
## into Octave's internal sparse format.
##
## The input @var{m} is either a 3 or 4 column real matrix, containing the
## row, column, real, and imaginary parts of the elements of the sparse
## matrix.  An element with a zero real and imaginary part can be used to
## force a particular matrix size.
## @seealso{sparse}
## @end deftypefn
    
    
@function
def spconvert(m=None,*args,**kwargs):
    varargin = spconvert.varargin
    nargin = spconvert.nargin

    if (nargin != 1):
        print_usage()
    
    if (issparse(m)):
        s=copy(m)
# /home/lei/octave-4.0.2/scripts/sparse/spconvert.m:38
    else:
        sz=size(m)
# /home/lei/octave-4.0.2/scripts/sparse/spconvert.m:40
        if (logical_not(ismatrix(m)) or logical_not(isreal(m)) or length(sz) != 2 or (sz[2] != 3 and sz[2] != 4)):
            error(cat('spconvert: argument must be sparse or real matrix','with 3 or 4 columns'))
        else:
            if (sz[2] == 3):
                s=sparse(m[:,1],m[:,2],m[:,3])
# /home/lei/octave-4.0.2/scripts/sparse/spconvert.m:46
            else:
                s=sparse(m[:,1],m[:,2],m[:,3] + dot(1j,m[:,4]))
# /home/lei/octave-4.0.2/scripts/sparse/spconvert.m:48
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Ivana Varekova & Radek Salac
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} treelayout (@var{tree})
## @deftypefnx {Function File} {} treelayout (@var{tree}, @var{permutation})
## treelayout lays out a tree or a forest.
##
## The first argument @var{tree} is a vector of predecessors.
##
## The parameter @var{permutation} is an optional postorder permutation.
##
## The complexity of the algorithm is O(n) in terms of time and memory
## requirements.
## @seealso{etreeplot, gplot, treeplot}
## @end deftypefn
    
    
@function
def treelayout(tree=None,permutation=None,*args,**kwargs):
    varargin = treelayout.varargin
    nargin = treelayout.nargin

    if (nargin < 1 or nargin > 2 or nargout > 4):
        print_usage()
    else:
        if (logical_not(isvector(tree)) or rows(tree) != 1 or logical_not(isnumeric(tree)) or any(tree > length(tree)) or any(tree < 0)):
            error('treelayout: the first input argument must be a vector of predecessors')
        else:
            ## Make it a row vector.
            tree=ravel(tree).T
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:41
            num_nodes=length(tree)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:44
            num_children=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:46
            for i in arange(1,num_nodes).reshape(-1):
                if (tree[i] < i):
                    ## This part of graph was checked before.
                    continue
                ## Try to find cicle in this part of graph using modified Floyd's
      ## cycle-finding algorithm.
                tortoise=tree[i]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:57
                hare=tree[tortoise]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:58
                while (tortoise != hare):

                    ## End after finding a cicle or reaching a checked part of graph.
                    if (hare < i):
                        ## This part of graph was checked before.
                        break
                    tortoise=tree[tortoise]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:68
                    ## reach tortoise.
                    hare=tree[tree[hare]]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:71

                if (tortoise == hare):
                    ## If hare reach tortoise we found circle.
                    error('treelayout: vector of predecessors has bad format')
            ## Vector of predecessors has right format.
            for i in arange(1,num_nodes).reshape(-1):
                ## vec_of_child is helping vector which is used to speed up the
      ## choice of descendant nodes.
                num_children[tree[i] + 1]=num_children[tree[i] + 1] + 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:87
            pos=1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:90
            start=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:91
            xhelp=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:92
            stop=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:93
            for i in arange(1,num_nodes + 1).reshape(-1):
                start[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:95
                xhelp[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:96
                pos += num_children[i]
                stop[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:98
            if (nargin == 1):
                for i in arange(1,num_nodes).reshape(-1):
                    vec_of_child[xhelp[tree[i] + 1]]=i
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:103
                    xhelp[tree[i] + 1]=xhelp[tree[i] + 1] + 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:104
            else:
                vec_of_child=copy(permutation)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:107
            ## The number of "parent" (actual) node (it's descendants will be
    ## browse in the next iteration).
            par_number=0
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:112
            ## this value is increased in each leaf.
            left_most=0
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:116
            level=copy(num_nodes)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:119
            max_ht=copy(num_nodes)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:122
            ## node and the number it's of parent node on the top of stack
    ## there is "parent node".
            stk=matlabarray(cat(- 1,0))
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:127
            s=0
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:130
            top_level=1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:132
            while (par_number != - 1):

                if (start[par_number + 1] < stop[par_number + 1]):
                    idx=vec_of_child[start[par_number + 1]:stop[par_number + 1] - 1]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:136
                else:
                    idx=zeros(1,0)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:138
                ## Add to idx the vector of parent descendants.
                stk=matlabarray(cat([stk],[cat(idx.T,dot(ones(fliplr(size(idx))),par_number))]))
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:142
                ## flag is 1
                if (columns(idx) == 1 and top_level == 1):
                    s
                else:
                    ## We aren't in top level separator now.
                    top_level=0
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:150
                ## If there is not any descendant of "parent node":
                if (stk[end(),2] != par_number):
                    left_most
                    x_coordinate_r[par_number]=left_most
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:155
                    max_ht=min(max_ht,level)
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:156
                    if (length(stk) > 1 and find((shift(stk,1) - stk) == 0) > 1 and stk[end(),2] != stk[end() - 1,2]):
                        ## Return to the nearest branching the position to return
          ## position is the position on the stack, where should be
          ## started further search (there are two nodes which has the
          ## same parent node).
                        position=(find((shift(stk[:,2],1) - stk[:,2]) == 0))(end()) + 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:164
                        par_number_vec=stk[position:end(),2]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:165
                        ## position to end).
                        level += length(par_number_vec)
                        x_coordinate_r[par_number_vec]=left_most
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:174
                        stk[position:end(),:]=[]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:175
                    ## Remove the next node from "searched branch".
                    stk[end(),:]=[]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:180
                    par_number=stk[end(),1]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:182
                    if (par_number != - 1):
                        y_coordinate[par_number]=level
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:185
                        x_coordinate_l[par_number]=left_most + 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:186
                else:
                    ## There were descendants of "parent nod" choose the last of
        ## them and go on through it.
                    level
                    par_number=stk[end(),1]
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:193
                    y_coordinate[par_number]=level
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:194
                    x_coordinate_l[par_number]=left_most + 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:195

            ## Calculate the x coordinates (the known values are the position
    ## of most left and most right descendants).
            x_coordinate=(x_coordinate_l + x_coordinate_r) / 2
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:201
            height=num_nodes - max_ht - 1
# /home/lei/octave-4.0.2/scripts/sparse/treelayout.m:203
    
    return x_coordinate,y_coordinate,height,s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Radek Salac
## Copyright (C) 2012 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} bicgstab (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{M1}, @var{M2}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} bicgstab (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{P})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}] =} bicgstab (@var{A}, @var{b}, @dots{})
## Solve @code{A x = b} using the stabilizied Bi-conjugate gradient iterative
## method.
##
## @itemize @minus
## @item @var{rtol} is the relative tolerance, if not given or set to [] the
## default value 1e-6 is used.
##
## @item @var{maxit} the maximum number of outer iterations, if not given or
## set to [] the default value @code{min (20, numel (b))} is used.
##
## @item @var{x0} the initial guess, if not given or set to [] the default
## value @code{zeros (size (b))} is used.
## @end itemize
##
## @var{A} can be passed as a matrix or as a function handle or inline
## function @code{f} such that @code{f(x) = A*x}.
##
## The preconditioner @var{P} is given as @code{P = M1 * M2}.  Both @var{M1}
## and @var{M2} can be passed as a matrix or as a function handle or inline
## function @code{g} such that @code{g(x) = M1 \ x} or @code{g(x) = M2 \ x}.
##
## If called with more than one output parameter
##
## @itemize @minus
## @item @var{flag} indicates the exit status:
##
## @itemize @minus
## @item 0: iteration converged to the within the chosen tolerance
##
## @item 1: the maximum number of iterations was reached before convergence
##
## @item 3: the algorithm reached stagnation
## @end itemize
##
## (the value 2 is unused but skipped for compatibility).
##
## @item @var{relres} is the final value of the relative residual.
##
## @item @var{iter} is the number of iterations performed.
##
## @item @var{resvec} is a vector containing the relative residual at each
## iteration.
## @end itemize
##
## @seealso{bicg, cgs, gmres, pcg, qmr}
##
## @end deftypefn
    
    
@function
def bicgstab(A=None,b=None,tol=None,maxit=None,M1=None,M2=None,x0=None,*args,**kwargs):
    varargin = bicgstab.varargin
    nargin = bicgstab.nargin

    if (nargin >= 2 and nargin <= 7 and isvector(full(b))):
        if (ischar(A)):
            A=str2func(A)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:78
        else:
            if (isnumeric(A) and issquare(A)):
                Ax=lambda x=None: dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:80
            else:
                if (isa(A,'function_handle')):
                    Ax=lambda x=None: feval(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:82
                else:
                    error('bicgstab: A must be a function or square matrix')
        if (nargin < 3 or isempty(tol)):
            tol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:88
        if (nargin < 4 or isempty(maxit)):
            maxit=min(rows(b),20)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:92
        if (nargin < 5 or isempty(M1)):
            M1m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:96
        else:
            if (ischar(M1)):
                M1m1x=str2func(M1)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:98
            else:
                if (isnumeric(M1) and ismatrix(M1)):
                    M1m1x=lambda x=None: numpy.linalg.solve(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:100
                else:
                    if (isa(M1,'function_handle')):
                        M1m1x=lambda x=None: feval(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:102
                    else:
                        error('bicgstab: preconditioner M1 must be a function or matrix')
        if (nargin < 6 or isempty(M2)):
            M2m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:108
        else:
            if (ischar(M2)):
                M2m1x=str2func(M2)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:110
            else:
                if (isnumeric(M2) and ismatrix(M2)):
                    M2m1x=lambda x=None: numpy.linalg.solve(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:112
                else:
                    if (isa(M2,'function_handle')):
                        M2m1x=lambda x=None: feval(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:114
                    else:
                        error('bicgstab: preconditioner M2 must be a function or matrix')
        precon=lambda x=None: M2m1x[M1m1x[x]]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:119
        if (nargin < 7 or isempty(x0)):
            x0=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:122
        ## specifies initial estimate x0
        if (nargin < 7):
            x=zeros(rows(b),1)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:127
        else:
            x=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:129
        norm_b=norm(b)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:132
        res=b - Ax[x]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:134
        rr=copy(res)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:135
        resvec=norm(res) / norm_b
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:138
        flag=1
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:141
        for iter in arange(1,maxit).reshape(-1):
            rho_1=dot(rr.T,res)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:144
            if (iter == 1):
                p=copy(res)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:147
            else:
                beta=dot((rho_1 / rho_2),(alpha / omega))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:149
                p=res + dot(beta,(p - dot(omega,v)))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:150
            phat=precon[p]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:153
            v=Ax[phat]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:155
            alpha=rho_1 / (dot(rr.T,v))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:156
            s=res - dot(alpha,v)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:157
            shat=precon[s]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:159
            t=Ax[shat]
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:161
            omega=(dot(s.T,t)) / (dot(t.T,t))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:162
            x=x + dot(alpha,phat) + dot(omega,shat)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:163
            res=s - dot(omega,t)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:164
            rho_2=copy(rho_1)
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:165
            relres=norm(res) / norm_b
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:167
            resvec=matlabarray(cat([resvec],[relres]))
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:168
            if (relres <= tol):
                ## We reach tolerance tol within maxit iterations.
                flag=0
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:172
                break
            else:
                if (resvec[end()] == resvec[end() - 1]):
                    ## The method stagnates.
                    flag=3
# /home/lei/octave-4.0.2/scripts/sparse/bicgstab.m:176
                    break
        if (nargout < 2):
            if (flag == 0):
                printf('bicgstab converged at iteration %i ',iter)
                printf('to a solution with relative residual %e\n',relres)
            else:
                if (flag == 3):
                    printf('bicgstab stopped at iteration %i ',iter)
                    printf('without converging to the desired tolerance %e\n',tol)
                    printf('because the method stagnated.\n')
                    printf('The iterate returned (number %i) ',iter)
                    printf('has relative residual %e\n',relres)
                else:
                    printf('bicgstab stopped at iteration %i ',iter)
                    printf('without converging to the desired toleranc %e\n',tol)
                    printf('because the maximum number of iterations was reached.\n')
                    printf('The iterate returned (number %i) ',iter)
                    printf('has relative residual %e\n',relres)
    else:
        print_usage()
    
    return x,flag,relres,iter,resvec
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2006 Sylvain Pelissier
## Copyright (C) 2012-2015 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; If not, see <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} bicg (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{M1}, @var{M2}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} bicg (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{P})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}] =} bicg (@var{A}, @var{b}, @dots{})
## Solve @code{A x = b} using the Bi-conjugate gradient iterative method.
##
## @itemize @minus
## @item @var{rtol} is the relative tolerance, if not given or set to [] the
## default value 1e-6 is used.
##
## @item @var{maxit} the maximum number of outer iterations, if not given or
## set to [] the default value @code{min (20, numel (b))} is used.
##
## @item @var{x0} the initial guess, if not given or set to [] the default
## value @code{zeros (size (b))} is used.
## @end itemize
##
## @var{A} can be passed as a matrix or as a function handle or inline function
## @code{f} such that @code{f(x, "notransp") = A*x} and
## @code{f(x, "transp") = A'*x}.
##
## The preconditioner @var{P} is given as @code{P = M1 * M2}.  Both @var{M1}
## and @var{M2} can be passed as a matrix or as a function handle or inline
## function @code{g} such that @code{g(x, "notransp") = M1 \ x} or
## @code{g(x, "notransp") = M2 \ x} and @code{g(x, "transp") = M1' \ x} or
## @code{g(x, "transp") = M2' \ x}.
##
## If called with more than one output parameter
##
## @itemize @minus
## @item @var{flag} indicates the exit status:
##
## @itemize @minus
## @item 0: iteration converged to the within the chosen tolerance
##
## @item 1: the maximum number of iterations was reached before convergence
##
## @item 3: the algorithm reached stagnation
## @end itemize
##
## (the value 2 is unused but skipped for compatibility).
##
## @item @var{relres} is the final value of the relative residual.
##
## @item @var{iter} is the number of iterations performed.
##
## @item @var{resvec} is a vector containing the relative residual at each
## iteration.
## @end itemize
##
## @seealso{bicgstab, cgs, gmres, pcg, qmr}
##
## @end deftypefn
    
    ## Author: Sylvain Pelissier <sylvain.pelissier@gmail.com>
## Author: Carlo de Falco
    
    
@function
def bicg(A=None,b=None,tol=None,maxit=None,M1=None,M2=None,x0=None,*args,**kwargs):
    varargin = bicg.varargin
    nargin = bicg.nargin

    if (nargin >= 2 and isvector(full(b))):
        if (ischar(A)):
            fun=str2func(A)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:81
            Ax=lambda x=None: feval(fun,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:82
            Atx=lambda x=None: feval(fun,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:83
        else:
            if (isnumeric(A) and issquare(A)):
                Ax=lambda x=None: dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:85
                Atx=lambda x=None: dot(A.T,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:86
            else:
                if (isa(A,'function_handle')):
                    Ax=lambda x=None: feval(A,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:88
                    Atx=lambda x=None: feval(A,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:89
                else:
                    error('bicg: A must be a function or square matrix')
        if (nargin < 3 or isempty(tol)):
            tol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:95
        if (nargin < 4 or isempty(maxit)):
            maxit=min(rows(b),20)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:99
        else:
            maxit=fix(maxit)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:101
        if (nargin < 5 or isempty(M1)):
            M1m1x=lambda x=None,ignore=None: x
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:105
            M1tm1x=copy(M1m1x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:106
        else:
            if (ischar(M1)):
                fun=str2func(M1)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:108
                M1m1x=lambda x=None: feval(fun,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:109
                M1tm1x=lambda x=None: feval(fun,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:110
            else:
                if (isnumeric(M1) and ismatrix(M1)):
                    M1m1x=lambda x=None: numpy.linalg.solve(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:112
                    M1tm1x=lambda x=None: numpy.linalg.solve(M1.T,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:113
                else:
                    if (isa(M1,'function_handle')):
                        M1m1x=lambda x=None: feval(M1,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:115
                        M1tm1x=lambda x=None: feval(M1,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:116
                    else:
                        error('bicg: preconditioner M1 must be a function or matrix')
        if (nargin < 6 or isempty(M2)):
            M2m1x=lambda x=None,ignore=None: x
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:122
            M2tm1x=copy(M2m1x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:123
        else:
            if (ischar(M2)):
                fun=str2func(M2)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:125
                M2m1x=lambda x=None: feval(fun,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:126
                M2tm1x=lambda x=None: feval(fun,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:127
            else:
                if (isnumeric(M2) and ismatrix(M2)):
                    M2m1x=lambda x=None: numpy.linalg.solve(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:129
                    M2tm1x=lambda x=None: numpy.linalg.solve(M2.T,x)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:130
                else:
                    if (isa(M2,'function_handle')):
                        M2m1x=lambda x=None: feval(M2,x,'notransp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:132
                        M2tm1x=lambda x=None: feval(M2,x,'transp')
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:133
                    else:
                        error('bicg: preconditioner M2 must be a function or matrix')
        Pm1x=lambda x=None: M2m1x[M1m1x[x]]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:138
        Ptm1x=lambda x=None: M1tm1x[M2tm1x[x]]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:139
        if (nargin < 7 or isempty(x0)):
            x0=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:142
        y=x=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:145
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:145
        c=copy(b)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:146
        r0=b - Ax[x]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:148
        s0=c - Atx[y]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:149
        d=Pm1x[r0]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:151
        f=Ptm1x[s0]
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:152
        bnorm=norm(b)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:154
        res0=copy(Inf)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:155
        if (any(r0 != 0)):
            for k in arange(1,maxit).reshape(-1):
                a=(dot(s0.T,Pm1x[r0])) / (dot(f.T,Ax[d]))
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:161
                x += dot(a,d)
                y += dot(conj(a),f)
                r1=r0 - dot(a,Ax[d])
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:166
                s1=s0 - dot(conj(a),Atx[f])
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:167
                beta=(dot(s1.T,Pm1x[r1])) / (dot(s0.T,Pm1x[r0]))
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:169
                d=Pm1x[r1] + dot(beta,d)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:171
                f=Ptm1x[s1] + dot(conj(beta),f)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:172
                r0=copy(r1)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:174
                s0=copy(s1)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:175
                res1=norm(b - Ax[x]) / bnorm
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:177
                if (res1 < tol):
                    flag=0
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:179
                    if (nargout < 2):
                        printf('bicg converged at iteration %i ',k)
                        printf('to a solution with relative residual %e\n',res1)
                    break
                if (res0 <= res1):
                    flag=3
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:188
                    printf('bicg stopped at iteration %i ',k)
                    printf('without converging to the desired tolerance %e\n',tol)
                    printf('because the method stagnated.\n')
                    printf('The iterate returned (number %i) ',k - 1)
                    printf('has relative residual %e\n',res0)
                    break
                res0=copy(res1)
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:196
                if (nargout > 4):
                    resvec[k]=res0
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:198
            if (k == maxit):
                flag=1
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:203
                printf('bicg stopped at iteration %i ',maxit)
                printf('without converging to the desired tolerance %e\n',tol)
                printf('because the maximum number of iterations was reached. ')
                printf('The iterate returned (number %i) has ',maxit)
                printf('relative residual %e\n',res1)
        else:
            flag=0
# /home/lei/octave-4.0.2/scripts/sparse/bicg.m:212
            if (nargout < 2):
                printf('bicg converged after 0 interations\n')
    else:
        print_usage()
    
    return x,flag,res1,k,resvec
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Ivana Varekova
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} gplot (@var{A}, @var{xy})
## @deftypefnx {Function File} {} gplot (@var{A}, @var{xy}, @var{line_style})
## @deftypefnx {Function File} {[@var{x}, @var{y}] =} gplot (@var{A}, @var{xy})
## Plot a graph defined by @var{A} and @var{xy} in the graph theory sense.
##
## @var{A} is the adjacency matrix of the array to be plotted and @var{xy} is
## an @var{n}-by-2 matrix containing the coordinates of the nodes of the graph.
##
## The optional parameter @var{line_style} defines the output style for the
## plot.  Called with no output arguments the graph is plotted directly.
## Otherwise, return the coordinates of the plot in @var{x} and @var{y}.
## @seealso{treeplot, etreeplot, spy}
## @end deftypefn
    
    
@function
def gplot(A=None,xy=None,line_style=None,*args,**kwargs):
    varargin = gplot.varargin
    nargin = gplot.nargin

    if (nargin < 2 or nargin > 3 or nargout > 2):
        print_usage()
    
    if (nargin == 2):
        line_style='-'
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:41
    
    i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:44
    xcoord=ravel(cat(xy[i,1],xy[j,1],NaN(length(i),1)).T)
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:45
    ycoord=ravel(cat(xy[i,2],xy[j,2],NaN(length(i),1)).T)
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:46
    if (nargout == 0):
        plot(xcoord,ycoord,line_style)
    else:
        x=copy(xcoord)
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:51
        y=copy(ycoord)
# /home/lei/octave-4.0.2/scripts/sparse/gplot.m:52
    
    return x,y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Mark graphical function as tested by demo block
    
    ## Copyright (C) 2006-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{s} =} svds (@var{A})
## @deftypefnx {Function File} {@var{s} =} svds (@var{A}, @var{k})
## @deftypefnx {Function File} {@var{s} =} svds (@var{A}, @var{k}, @var{sigma})
## @deftypefnx {Function File} {@var{s} =} svds (@var{A}, @var{k}, @var{sigma}, @var{opts})
## @deftypefnx {Function File} {[@var{u}, @var{s}, @var{v}] =} svds (@dots{})
## @deftypefnx {Function File} {[@var{u}, @var{s}, @var{v}, @var{flag}] =} svds (@dots{})
##
## Find a few singular values of the matrix @var{A}.
##
## The singular values are calculated using
##
## @example
## @group
## [@var{m}, @var{n}] = size (@var{A});
## @var{s} = eigs ([sparse(@var{m}, @var{m}), @var{A};
##                      @var{A}', sparse(@var{n}, @var{n})])
## @end group
## @end example
##
## The eigenvalues returned by @code{eigs} correspond to the singular values
## of @var{A}.  The number of singular values to calculate is given by @var{k}
## and defaults to 6.
##
## The argument @var{sigma} specifies which singular values to find.  When
## @var{sigma} is the string @qcode{'L'}, the default, the largest singular
## values of @var{A} are found.  Otherwise, @var{sigma} must be a real scalar
## and the singular values closest to @var{sigma} are found.  As a corollary,
## @code{@var{sigma} = 0} finds the smallest singular values.  Note that for
## relatively small values of @var{sigma}, there is a chance that the
## requested number of singular values will not be found.  In that case
## @var{sigma} should be increased.
##
## @var{opts} is a structure defining options that @code{svds} will pass
## to @code{eigs}.  The possible fields of this structure are documented in
## @code{eigs}.  By default, @code{svds} sets the following three fields:
##
## @table @code
## @item tol
## The required convergence tolerance for the singular values.  The default
## value is 1e-10.  @code{eigs} is passed @code{@var{tol} / sqrt(2)}.
##
## @item maxit
## The maximum number of iterations.  The default is 300.
##
## @item disp
## The level of diagnostic printout (0|1|2).  If @code{disp} is 0 then
## diagnostics are disabled.  The default value is 0.
## @end table
##
## If more than one output is requested then @code{svds} will return an
## approximation of the singular value decomposition of @var{A}
##
## @example
## @var{A}_approx = @var{u}*@var{s}*@var{v}'
## @end example
##
## @noindent
## where @var{A}_approx is a matrix of size @var{A} but only rank @var{k}.
##
## @var{flag} returns 0 if the algorithm has succesfully converged, and 1
## otherwise.  The test for convergence is
##
## @example
## @group
## norm (@var{A}*@var{v} - @var{u}*@var{s}, 1) <= @var{tol} * norm (@var{A}, 1)
## @end group
## @end example
##
## @code{svds} is best for finding only a few singular values from a large
## sparse matrix.  Otherwise, @code{svd (full (@var{A}))} will likely be more
## efficient.
## @end deftypefn
## @seealso{svd, eigs}
    
    
@function
def svds(A=None,k=None,sigma=None,opts=None,*args,**kwargs):
    varargin = svds.varargin
    nargin = svds.nargin

    
    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (ndims(A) > 2):
        error('svds: A must be a 2-D matrix')
    
    if (nargin < 4):
        opts.tol = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:107
        opts.disp = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:108
        opts.maxit = copy(300)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:109
    else:
        if (logical_not(isstruct(opts))):
            error('svds: OPTS must be a structure')
        if (logical_not(isfield(opts,'tol'))):
            opts.tol = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:115
        else:
            opts.tol = copy(opts.tol / root2)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:117
        if (isfield(opts,'v0')):
            if (logical_not(isvector(opts.v0)) or (length(opts.v0) != sum(size(A)))):
                error('svds: OPTS.v0 must be a vector with rows(A)+columns(A) entries')
    
    if (nargin < 3 or strcmp(sigma,'L')):
        if (isreal(A)):
            sigma='LA'
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:128
        else:
            sigma='LR'
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:130
    else:
        if (isscalar(sigma) and isnumeric(sigma) and isreal(sigma)):
            if (sigma < 0):
                error('svds: SIGMA must be a positive real value')
        else:
            error('svds: SIGMA must be a positive real value or the string \'L\'')
    
    m,n=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:140
    max_a=max(abs(nonzeros(A)))
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:141
    if (isempty(max_a)):
        max_a=0
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:143
    
    ## Must initialize variable value, otherwise it may appear to interpreter
  ## that code is trying to call flag() colormap function.
    flag=0
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:147
    if (max_a == 0):
        s=zeros(k,1)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:150
    else:
        if (nargin < 2):
            k=min(cat(6,m,n))
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:153
        else:
            k=min(cat(k,m,n))
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:155
        ## Scale everything by the 1-norm to make things more stable.
        b=A / max_a
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:159
        b_opts=copy(opts)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:160
        b_opts.issym = copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:162
        b_sigma=copy(sigma)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:163
        if (logical_not(ischar(b_sigma))):
            b_sigma=b_sigma / max_a
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:165
        if (b_sigma == 0):
            ## Find the smallest eigenvalues
      ## The eigenvalues returns by eigs for sigma=0 are symmetric about 0.
      ## As we are only interested in the positive eigenvalues, we have to
      ## double k and then throw out the k negative eigenvalues.
      ## Separately, if sigma is nonzero, but smaller than the smallest
      ## singular value, ARPACK may not return k eigenvalues. However, as
      ## computation scales with k we'd like to avoid doubling k for all
      ## scalar values of sigma.
            b_k=dot(2,k)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:177
        else:
            b_k=copy(k)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:179
        if (nargout > 1):
            V,s,flag=eigs(cat([sparse(m,m),b],[b.T,sparse(n,n)]),b_k,b_sigma,b_opts,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:183
            s=diag(s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:185
        else:
            s=eigs(cat([sparse(m,m),b],[b.T,sparse(n,n)]),b_k,b_sigma,b_opts)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:187
        if (ischar(sigma)):
            norma=max(s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:191
        else:
            norma=normest(A)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:193
        ## We wish to exclude all eigenvalues that are less than zero as these
    ## are artifacts of the way the matrix passed to eigs is formed. There
    ## is also the possibility that the value of sigma chosen is exactly
    ## a singular value, and in that case we're dead!! So have to rely on
    ## the warning from eigs. We exclude the singular values which are
    ## less than or equal to zero to within some tolerance scaled by the
    ## norm since if we don't we might end up with too many singular
    ## values.
        if (b_sigma == 0):
            if (sum(s > 0) < k):
                ## It may happen that the number of positive s is less than k.
        ## In this case, take -s (if s in an eigenvalue, so is -s),
        ## flipped upside-down.
                s=flipud(- s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:208
        tol=dot(norma,opts.tol)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:211
        ind=find(s > tol)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:212
        if (length(ind) < k):
            ## Too few eigenvalues returned.  Add in any zero eigenvalues of B,
      ## including the nominally negative ones.
            zind=find(abs(s) <= tol)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:216
            p=min(length(zind),k - length(ind))
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:217
            ind=matlabarray(cat([ind],[zind[1:p]]))
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:218
        else:
            if (length(ind) > k):
                ## Too many eigenvalues returned.  Select according to criterium.
                if (b_sigma == 0):
                    ind=ind[end() + 1 - k:end()]
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:222
                else:
                    ind=ind[1:k]
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:224
        s=s[ind]
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:227
        if (length(s) < k):
            warning('returning fewer singular values than requested')
            if (logical_not(ischar(sigma))):
                warning('try increasing the value of sigma')
        s=dot(s,max_a)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:236
    
    if (nargout < 2):
        u=copy(s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:240
    else:
        if (max_a == 0):
            u=eye(m,k)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:243
            s=diag(s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:244
            v=eye(n,k)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:245
        else:
            u=dot(root2,V[1:m,ind])
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:247
            s=diag(s)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:248
            v=dot(root2,V[m + 1:end(),ind])
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:249
        if (nargout > 3):
            flag=(flag != 0)
# /home/lei/octave-4.0.2/scripts/sparse/svds.m:253
    
    return u,s,v,flag
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{s} =} speye (@var{m}, @var{n})
## @deftypefnx {Function File} {@var{s} =} speye (@var{m})
## @deftypefnx {Function File} {@var{s} =} speye (@var{sz})
## Return a sparse identity matrix of size @var{m}x@var{n}.
##
## The implementation is significantly more efficient than
## @code{sparse (eye (@var{m}))} as the full matrix is not constructed.
##
## Called with a single argument a square matrix of size
## @var{m}-by-@var{m} is created.  If called with a single vector argument
## @var{sz}, this argument is taken to be the size of the matrix to create.
## @seealso{sparse, spdiags, eye}
## @end deftypefn
    
    
@function
def speye(m=None,n=None,*args,**kwargs):
    varargin = speye.varargin
    nargin = speye.nargin

    if (nargin == 1):
        if (isvector(m) and length(m) == 2):
            n=m[2]
# /home/lei/octave-4.0.2/scripts/sparse/speye.m:37
            m=m[1]
# /home/lei/octave-4.0.2/scripts/sparse/speye.m:38
        else:
            if (isscalar(m)):
                n=copy(m)
# /home/lei/octave-4.0.2/scripts/sparse/speye.m:40
            else:
                error('speye: invalid matrix dimension')
    else:
        if (logical_not(isscalar(m)) or logical_not(isscalar(n))):
            error('speye: invalid matrix dimension')
    
    lo=min(cat(m,n))
# /home/lei/octave-4.0.2/scripts/sparse/speye.m:50
    s=sparse(arange(1,lo),arange(1,lo),1,m,n)
# /home/lei/octave-4.0.2/scripts/sparse/speye.m:51
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sprandn (@var{m}, @var{n}, @var{d})
## @deftypefnx {Function File} {} sprandn (@var{m}, @var{n}, @var{d}, @var{rc})
## @deftypefnx {Function File} {} sprandn (@var{s})
## Generate a sparse matrix with normally distributed random values.
##
## The size of the matrix is @var{m}x@var{n} with a density of values @var{d}.
## @var{d} must be between 0 and 1.  Values will be normally distributed with a
## mean of 0 and a variance of 1.
##
## If called with a single matrix argument, a sparse matrix is generated with
## random values wherever the matrix @var{s} is nonzero.
##
## If called with a scalar fourth argument @var{rc}, a random sparse matrix
## with reciprocal condition number @var{rc} is generated.  If @var{rc} is
## a vector, then it specifies the first singular values of the generated
## matrix (@code{length (@var{rc}) <= min (@var{m}, @var{n})}).
##
## @seealso{sprand, sprandsym, randn}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
    
    
@function
def sprandn(m=None,n=None,d=None,rc=None,*args,**kwargs):
    varargin = sprandn.varargin
    nargin = sprandn.nargin

    if (nargin == 1):
        s=__sprand_impl__(m,randn)
# /home/lei/octave-4.0.2/scripts/sparse/sprandn.m:48
    else:
        if (nargin == 3):
            s=__sprand_impl__(m,n,d,'sprandn',randn)
# /home/lei/octave-4.0.2/scripts/sparse/sprandn.m:50
        else:
            if (nargin == 4):
                s=__sprand_impl__(m,n,d,rc,'sprandn',randn)
# /home/lei/octave-4.0.2/scripts/sparse/sprandn.m:52
            else:
                print_usage()
    
    return s
    
if __name__ == '__main__':
    pass
    
    ## Test 3-input calling form
    
    
    
    ## Test 4-input calling form
    
    
    
    
    
    
    
    
    
    
    ## Test 1-input calling form
    
    
    
    
    ## Test very large, very low density matrix doesn't fail
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nonzeros (@var{s})
## Return a vector of the nonzero values of the sparse matrix @var{s}.
## @seealso{find, nnz}
## @end deftypefn
    
    
@function
def nonzeros(s=None,*args,**kwargs):
    varargin = nonzeros.varargin
    nargin = nonzeros.nargin

    if (nargin != 1):
        print_usage()
    
    __,__,t=find(s,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/nonzeros.m:31
    t=ravel(t)
# /home/lei/octave-4.0.2/scripts/sparse/nonzeros.m:33
    return t
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{B} =} spdiags (@var{A})
## @deftypefnx {Function File} {[@var{B}, @var{d}] =} spdiags (@var{A})
## @deftypefnx {Function File} {@var{B} =} spdiags (@var{A}, @var{d})
## @deftypefnx {Function File} {@var{A} =} spdiags (@var{v}, @var{d}, @var{A})
## @deftypefnx {Function File} {@var{A} =} spdiags (@var{v}, @var{d}, @var{m}, @var{n})
## A generalization of the function @code{diag}.
##
## Called with a single input argument, the nonzero diagonals @var{d} of
## @var{A} are extracted.
##
## With two arguments the diagonals to extract are given by the vector @var{d}.
##
## The other two forms of @code{spdiags} modify the input matrix by replacing
## the diagonals.  They use the columns of @var{v} to replace the diagonals
## represented by the vector @var{d}.  If the sparse matrix @var{A} is
## defined then the diagonals of this matrix are replaced.  Otherwise a
## matrix of @var{m} by @var{n} is created with the diagonals given by the
## columns of @var{v}.
##
## Negative values of @var{d} represent diagonals below the main diagonal, and
## positive values of @var{d} diagonals above the main diagonal.
##
## For example:
##
## @example
## @group
## spdiags (reshape (1:12, 4, 3), [-1 0 1], 5, 4)
##    @result{} 5 10  0  0
##       1  6 11  0
##       0  2  7 12
##       0  0  3  8
##       0  0  0  4
## @end group
## @end example
##
## @seealso{diag}
## @end deftypefn
    
    
@function
def spdiags(v=None,d=None,m=None,n=None,*args,**kwargs):
    varargin = spdiags.varargin
    nargin = spdiags.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (nargin == 1 or nargin == 2):
        ## extract nonzero diagonals of A into B,d
        nr,nc=size(v,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:66
        i,j=find(v,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:67
        if (nargin == 1):
            ## d contains the active diagonals
            d=unique(j - i)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:71
        ## FIXME: Maybe this could be done faster using [i,j,v] = find (v)
    ##        and then massaging the indices i, j.  However, some
    ##        benchmarking has shown that diag() written in C++ makes
    ##        the following code faster even with the for loop.
        Brows=min(nr,nc)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:78
        B=zeros(Brows,length(d))
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:79
        for k in arange(1,length(d)).reshape(-1):
            dn=d[k]
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:81
            if (dn <= - nr or dn > nc):
                continue
            dv=diag(v,dn)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:85
            len_=rows(dv)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:86
            if (nr >= nc):
                if (dn > 0):
                    offset=Brows - len_ + 1
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:90
                    B[offset:Brows,k]=dv
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:91
                else:
                    B[1:len_,k]=dv
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:93
            else:
                if (dn < 0):
                    offset=Brows - len_ + 1
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:97
                    B[offset:Brows,k]=dv
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:98
                else:
                    B[1:len_,k]=dv
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:100
    else:
        if (nargin == 3):
            ## Replace specific diagonals d of m with v,d
            nr,nc=size(m,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:107
            A=spdiags(m,d)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:108
            B=m - spdiags(A,d,nr,nc) + spdiags(v,d,nr,nc)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:109
        else:
            ## Create new matrix of size mxn using v,d
            j,i,v=find(v,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:113
            if (m >= n):
                offset=max(min(ravel(d),n - m),0)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:115
            else:
                offset=ravel(d)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:117
            j=ravel(j) + offset[ravel(i)]
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:119
            i=j - ravel(d)(ravel(i))
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:120
            idx=i > logical_and(0,i) <= logical_and(m,j) > logical_and(0,j) <= n
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:121
            B=sparse(i[idx],j[idx],v[idx],m,n)
# /home/lei/octave-4.0.2/scripts/sparse/spdiags.m:122
    
    return B,d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test zero filling for supra- and super-diagonals
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 Piotr Krzyzanowski
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} pcg (@var{A}, @var{b}, @var{tol}, @var{maxit}, @var{m1}, @var{m2}, @var{x0}, @dots{})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}, @var{eigest}] =} pcg (@dots{})
##
## Solve the linear system of equations @w{@code{@var{A} * @var{x} = @var{b}}}
## by means of the Preconditioned Conjugate Gradient iterative method.
##
## The input arguments are
##
## @itemize
## @item
## @var{A} can be either a square (preferably sparse) matrix or a function
## handle, inline function or string containing the name of a function which
## computes @w{@code{@var{A} * @var{x}}}.  In principle, @var{A} should be
## symmetric and positive definite; if @code{pcg} finds @var{A} not to be
## positive definite, a warning is printed and the @var{flag} output will be
## set.
##
## @item
## @var{b} is the right-hand side vector.
##
## @item
## @var{tol} is the required relative tolerance for the residual error,
## @w{@code{@var{b} - @var{A} * @var{x}}}.  The iteration stops if
## @w{@code{norm (@var{b} - @var{A} * @var{x})} @leq{}
## @w{@var{tol} * norm (@var{b})}}.
## If @var{tol} is omitted or empty then a tolerance of 1e-6 is used.
##
## @item
## @var{maxit} is the maximum allowable number of iterations; if @var{maxit}
## is omitted or empty then a value of 20 is used.
##
## @item
## @var{m} = @var{m1} * @var{m2} is the (left) preconditioning matrix, so that
## the iteration is (theoretically) equivalent to solving by @code{pcg}
## @w{@code{@var{P} * @var{x} = @var{m} \ @var{b}}}, with
## @w{@code{@var{P} = @var{m} \ @var{A}}}.
## Note that a proper choice of the preconditioner may dramatically improve
## the overall performance of the method.  Instead of matrices @var{m1} and
## @var{m2}, the user may pass two functions which return the results of
## applying the inverse of @var{m1} and @var{m2} to a vector (usually this is
## the preferred way of using the preconditioner).  If @var{m1} is omitted or
## empty @code{[]} then no preconditioning is applied.  If @var{m2} is
## omitted, @var{m} = @var{m1} will be used as a preconditioner.
##
## @item
## @var{x0} is the initial guess.  If @var{x0} is omitted or empty then the
## function sets @var{x0} to a zero vector by default.
## @end itemize
##
## The arguments which follow @var{x0} are treated as parameters, and passed in
## a proper way to any of the functions (@var{A} or @var{m}) which are passed
## to @code{pcg}.  See the examples below for further details.  The output
## arguments are
##
## @itemize
## @item
## @var{x} is the computed approximation to the solution of
## @w{@code{@var{A} * @var{x} = @var{b}}}.
##
## @item
## @var{flag} reports on the convergence.  A value of 0 means the solution
## converged and the tolerance criterion given by @var{tol} is satisfied.
## A value of 1 means that the @var{maxit} limit for the iteration count was
## reached.  A value of 3 indicates that the (preconditioned) matrix was found
## not to be positive definite.
##
## @item
## @var{relres} is the ratio of the final residual to its initial value,
## measured in the Euclidean norm.
##
## @item
## @var{iter} is the actual number of iterations performed.
##
## @item
## @var{resvec} describes the convergence history of the method.
## @code{@var{resvec}(i,1)} is the Euclidean norm of the residual, and
## @code{@var{resvec}(i,2)} is the preconditioned residual norm, after the
## (@var{i}-1)-th iteration, @code{@var{i} = 1, 2, @dots{}, @var{iter}+1}.
## The preconditioned residual norm is defined as
## @code{norm (@var{r}) ^ 2 = @var{r}' * (@var{m} \ @var{r})} where
## @code{@var{r} = @var{b} - @var{A} * @var{x}}, see also the
## description of @var{m}.  If @var{eigest} is not required, only
## @code{@var{resvec}(:,1)} is returned.
##
## @item
## @var{eigest} returns the estimate for the smallest @code{@var{eigest}(1)}
## and largest @code{@var{eigest}(2)} eigenvalues of the preconditioned matrix
## @w{@code{@var{P} = @var{m} \ @var{A}}}.  In particular, if no
## preconditioning is used, the estimates for the extreme eigenvalues of
## @var{A} are returned.  @code{@var{eigest}(1)} is an overestimate and
## @code{@var{eigest}(2)} is an underestimate, so that
## @code{@var{eigest}(2) / @var{eigest}(1)} is a lower bound for
## @code{cond (@var{P}, 2)}, which nevertheless in the limit should
## theoretically be equal to the actual value of the condition number.
## The method which computes @var{eigest} works only for symmetric positive
## definite @var{A} and @var{m}, and the user is responsible for verifying this
## assumption.
## @end itemize
##
## Let us consider a trivial problem with a diagonal matrix (we exploit the
## sparsity of A)
##
## @example
## @group
## n = 10;
## A = diag (sparse (1:n));
## b = rand (n, 1);
## [l, u, p] = ilu (A, struct ("droptol", 1.e-3));
## @end group
## @end example
##
## @sc{Example 1:} Simplest use of @code{pcg}
##
## @example
## x = pcg (A, b)
## @end example
##
## @sc{Example 2:} @code{pcg} with a function which computes
## @code{@var{A} * @var{x}}
##
## @example
## @group
## function y = apply_a (x)
##   y = [1:N]' .* x;
## endfunction
##
## x = pcg ("apply_a", b)
## @end group
## @end example
##
## @sc{Example 3:} @code{pcg} with a preconditioner: @var{l} * @var{u}
##
## @example
## x = pcg (A, b, 1.e-6, 500, l*u)
## @end example
##
## @sc{Example 4:} @code{pcg} with a preconditioner: @var{l} * @var{u}.
## Faster than @sc{Example 3} since lower and upper triangular matrices are
## easier to invert
##
## @example
## x = pcg (A, b, 1.e-6, 500, l, u)
## @end example
##
## @sc{Example 5:} Preconditioned iteration, with full diagnostics.  The
## preconditioner (quite strange, because even the original matrix @var{A} is
## trivial) is defined as a function
##
## @example
## @group
## function y = apply_m (x)
##   k = floor (length (x) - 2);
##   y = x;
##   y(1:k) = x(1:k) ./ [1:k]';
## endfunction
##
## [x, flag, relres, iter, resvec, eigest] = ...
##                    pcg (A, b, [], [], "apply_m");
## semilogy (1:iter+1, resvec);
## @end group
## @end example
##
## @sc{Example 6:} Finally, a preconditioner which depends on a parameter
## @var{k}.
##
## @example
## @group
## function y = apply_M (x, varargin)
##   K = varargin@{1@};
##   y = x;
##   y(1:K) = x(1:K) ./ [1:K]';
## endfunction
##
## [x, flag, relres, iter, resvec, eigest] = ...
##      pcg (A, b, [], [], "apply_m", [], [], 3)
## @end group
## @end example
##
## References:
##
## @enumerate
## @item
## C.T. Kelley, @cite{Iterative Methods for Linear and Nonlinear Equations},
## SIAM, 1995. (the base PCG algorithm)
##
## @item
## @nospell{Y. Saad}, @cite{Iterative Methods for Sparse Linear Systems},
## @nospell{PWS} 1996. (condition number estimate from PCG)
## Revised version of this book is available online at
## @url{http://www-users.cs.umn.edu/~saad/books.html}
## @end enumerate
##
## @seealso{sparse, pcr}
## @end deftypefn
    
    ## Author: Piotr Krzyzanowski <piotr.krzyzanowski@mimuw.edu.pl>
## Modified by: Vittoria Rezzonico <vittoria.rezzonico@epfl.ch>
##  - Add the ability to provide the pre-conditioner as two separate matrices
    
    
@function
def pcg(A=None,b=None,tol=None,maxit=None,m1=None,m2=None,x0=None,varargin=None,*args,**kwargs):
    varargin = pcg.varargin
    nargin = pcg.nargin

    ## M = M1*M2
    
    if (nargin < 7 or isempty(x0)):
        x=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:224
    else:
        x=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:226
    
    if (nargin < 5 or isempty(m1)):
        exist_m1=0
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:230
    else:
        exist_m1=1
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:232
    
    if (nargin < 6 or isempty(m2)):
        exist_m2=0
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:236
    else:
        exist_m2=1
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:238
    
    if (nargin < 4 or isempty(maxit)):
        maxit=min(rows(b),20)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:242
    
    maxit += 2
    if (nargin < 3 or isempty(tol)):
        tol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:248
    
    preconditioned_residual_out=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:251
    if (nargout > 5):
        T=zeros(maxit,maxit)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:253
        preconditioned_residual_out=copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:254
    
    ## Assume A is positive definite.
    matrix_positive_definite=copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:258
    p=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:260
    oldtau=1
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:261
    if (isnumeric(A)):
        ## A is a matrix.
        r=b - dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:264
    else:
        ## A should be a function.
        r=b - feval(A,x,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:267
    
    b_norm=norm(b)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:270
    resvec[1,1]=norm(r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:271
    alpha=1
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:272
    iter=2
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:273
    while (resvec[iter - 1,1] > dot(tol,b_norm) and iter < maxit):

        if (exist_m1):
            if (isnumeric(m1)):
                y=numpy.linalg.solve(m1,r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:278
            else:
                y=feval(m1,r,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:280
        else:
            y=copy(r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:283
        if (exist_m2):
            if (isnumeric(m2)):
                z=numpy.linalg.solve(m2,y)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:287
            else:
                z=feval(m2,y,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:289
        else:
            z=copy(y)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:292
        tau=dot(z.T,r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:294
        resvec[iter - 1,2]=sqrt(tau)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:295
        beta=tau / oldtau
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:296
        oldtau=copy(tau)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:297
        p=z + dot(beta,p)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:298
        if (isnumeric(A)):
            ## A is a matrix.
            w=dot(A,p)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:301
        else:
            ## A should be a function.
            w=feval(A,p,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:304
        ## Needed only for eigest.
        oldalpha=copy(alpha)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:307
        alpha=tau / (dot(p.T,w))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:308
        if (alpha <= 0.0):
            ## Negative matrix.
            matrix_positive_definite=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:311
        x += dot(alpha,p)
        r -= dot(alpha,w)
        if (nargout > 5 and iter > 2):
            T[iter - 1:iter,iter - 1:iter]=T[iter - 1:iter,iter - 1:iter] + cat([1,sqrt(beta)],[sqrt(beta),beta]) / oldalpha
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:316
            ## fprintf (stderr,"PCG condest: #g (iteration: #d)\n", max (EVS)/min (EVS),iter);
        resvec[iter,1]=norm(r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:321
        iter

    
    if (nargout > 5):
        if (matrix_positive_definite):
            if (iter > 3):
                T=T[2:iter - 2,2:iter - 2]
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:328
                l=eig(T)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:329
                eigest=matlabarray(cat(min(l),max(l)))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:330
            else:
                eigest=matlabarray(cat(NaN,NaN))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:333
                warning('pcg: eigenvalue estimate failed: iteration converged too fast')
        else:
            eigest=matlabarray(cat(NaN,NaN))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:337
        ## Apply the preconditioner once more and finish with the precond
    ## residual.
        if (exist_m1):
            if (isnumeric(m1)):
                y=numpy.linalg.solve(m1,r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:344
            else:
                y=feval(m1,r,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:346
        else:
            y=copy(r)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:349
        if (exist_m2):
            if (isnumeric(m2)):
                z=numpy.linalg.solve(m2,y)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:353
            else:
                z=feval(m2,y,varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:355
        else:
            z=copy(y)
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:358
        resvec[iter - 1,2]=sqrt(dot(r.T,z))
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:361
    else:
        resvec=resvec[:,1]
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:363
    
    flag=0
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:366
    relres=resvec[iter - 1,1] / resvec[1,1]
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:367
    iter -= 2
    if (iter >= maxit - 2):
        flag=1
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:370
        if (nargout < 2):
            warning('pcg: maximum number of iterations (%d) reached\n',iter)
            warning('the initial residual norm was reduced %g times.\n',1.0 / relres)
    else:
        if (nargout < 2):
            fprintf(stderr,'pcg: converged in %d iterations. ',iter)
            fprintf(stderr,'the initial residual norm was reduced %g times.\n',1.0 / relres)
    
    if (logical_not(matrix_positive_definite)):
        flag=3
# /home/lei/octave-4.0.2/scripts/sparse/pcg.m:383
        if (nargout < 2):
            warning('pcg: matrix not positive definite?\n')
    
    return x,flag,relres,iter,resvec,eigest
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
## Copyright (C) 2012 Jordi Gutirrez Hermoso
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} __sprand_impl__ (@var{s}, @var{randfun})
## @deftypefnx {Function File} {} __sprand_impl__ (@var{m}, @var{n}, @var{d}, @var{fcnname}, @var{randfun})
## @deftypefnx {Function File} {} __sprand_impl__ (@var{m}, @var{n}, @var{d}, @var{rc}, @var{fcnname}, @var{randfun})
## Undocumented internal function.
## @end deftypefn
    
    ## Actual implementation of sprand and sprandn happens here.
    
    
@function
def __sprand_impl__(varargin=None,*args,**kwargs):
    varargin = __sprand_impl__.varargin
    nargin = __sprand_impl__.nargin

    if (nargin == 2):
        m,randfun=deal(varargin[1:2],nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:35
        i,j=find(m,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:36
        nr,nc=size(m,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:37
        S=sparse(i,j,randfun[size(i)],nr,nc)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:38
    else:
        if (nargin == 5):
            m,n,d,fcnname,randfun=deal(varargin[:],nargout=5)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:41
        else:
            m,n,d,rc,fcnname,randfun=deal(varargin[:],nargout=6)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:43
        if (logical_not((isscalar(m) and m == fix(m) and m > 0))):
            error('%s: M must be an integer greater than 0',fcnname)
        if (logical_not((isscalar(n) and n == fix(n) and n > 0))):
            error('%s: N must be an integer greater than 0',fcnname)
        if (d < 0 or d > 1):
            error('%s: density D must be between 0 and 1',fcnname)
        if (nargin == 5):
            mn=dot(m,n)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:57
            k=round(dot(d,mn))
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:58
            if (mn > sizemax()):
                ## randperm will overflow, so use alternative methods
                idx=unique(fix(dot(rand(dot(1.01,k),1),mn))) + 1
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:62
                ## Generate 1# more random values than necessary in order to reduce the
        ## probability that there are less than k distinct values; maybe a
        ## better strategy could be used but I don't think it's worth the price.
                ## actual number of entries in S
                k=min(length(idx),k)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:70
                j=floor((idx[1:k] - 1) / m)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:71
                i=idx[1:k] - dot(j,m)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:72
                j
            else:
                idx=randperm(mn,k)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:75
                i,j=ind2sub(cat(m,n),idx,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:76
            S=sparse(i,j,randfun[k,1],m,n)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:79
        else:
            if (nargin == 6):
                ## Create a matrix with specified reciprocal condition number.
                if (logical_not(isscalar(rc)) and logical_not(isvector(rc))):
                    error('%s: RC must be a scalar or vector',fcnname)
                ## We want to reverse singular valued decomposition A=U*S*V'.
      ## First, first S is constructed and then U = U1*U2*..Un and
      ## V' = V1*V2*..Vn are seen as Jacobi rotation matrices with angles and
      ## planes of rotation randomized.  Repeatedly apply rotations until the
      ## required density for A is achieved.
                if (isscalar(rc)):
                    if (rc < 0 or rc > 1):
                        error('%s: reciprocal condition number RC must be between 0 and 1',fcnname)
                    ## Reciprocal condition number is ratio of smallest SV to largest SV
        ## Generate singular values randomly and sort them to build S
        ## Random singular values in range [rc, 1].
                    v=dot(rand(1,min(m,n)),(1 - rc)) + rc
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:101
                    v[1]=1
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:102
                    v[end()]=rc
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:103
                    v=sort(v,'descend')
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:104
                    S=sparse(diag(v,m,n))
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:105
                else:
                    ## Only the min (m, n) greater singular values from rc vector are used.
                    if (length(rc) > min(m,n)):
                        rc=rc[1:min(m,n)]
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:109
                    S=sparse(diag(sort(rc,'descend'),m,n))
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:111
                Uinit=speye(m)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:114
                Vinit=speye(n)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:115
                k=round(dot(dot(d,m),n))
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:116
                while (nnz(S) < k):

                    if (m > 1):
                        ## Construct U randomized rotation matrix
                        rot_angleu=dot(dot(2,pi),rand())
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:120
                        cu=cos(rot_angleu)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:121
                        su=sin(rot_angleu)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:121
                        rndtmp=randperm(m,2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:122
                        i=rndtmp[1]
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:123
                        j=rndtmp[2]
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:123
                        U=copy(Uinit)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:124
                        U[i,i]=cu
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:125
                        U[i,j]=- su
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:125
                        U[j,i]=su
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:126
                        U[j,j]=cu
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:126
                        S=dot(U,S)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:127
                    if (n > 1):
                        ## Construct V' randomized rotation matrix
                        rot_anglev=dot(dot(2,pi),rand())
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:131
                        cv=cos(rot_anglev)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:132
                        sv=sin(rot_anglev)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:132
                        rndtmp=randperm(n,2)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:133
                        i=rndtmp[1]
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:134
                        j=rndtmp[2]
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:134
                        V=copy(Vinit)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:135
                        V[i,i]=cv
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:136
                        V[i,j]=sv
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:136
                        V[j,i]=- sv
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:137
                        V[j,j]=cv
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:137
                        S=dot(S,V)
# /home/lei/octave-4.0.2/scripts/sparse/private/__sprand_impl__.m:138

    
    return S
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{d} =} eigs (@var{A})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{k})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{k}, @var{sigma})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{k}, @var{sigma}, @var{opts})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{B})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{B}, @var{k})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{B}, @var{k}, @var{sigma})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{A}, @var{B}, @var{k}, @var{sigma}, @var{opts})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{B})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{k})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{B}, @var{k})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{k}, @var{sigma})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{B}, @var{k}, @var{sigma})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{k}, @var{sigma}, @var{opts})
## @deftypefnx {Function File} {@var{d} =} eigs (@var{af}, @var{n}, @var{B}, @var{k}, @var{sigma}, @var{opts})
## @deftypefnx {Function File} {[@var{V}, @var{d}] =} eigs (@var{A}, @dots{})
## @deftypefnx {Function File} {[@var{V}, @var{d}] =} eigs (@var{af}, @var{n}, @dots{})
## @deftypefnx {Function File} {[@var{V}, @var{d}, @var{flag}] =} eigs (@var{A}, @dots{})
## @deftypefnx {Function File} {[@var{V}, @var{d}, @var{flag}] =} eigs (@var{af}, @var{n}, @dots{})
## Calculate a limited number of eigenvalues and eigenvectors of @var{A},
## based on a selection criteria.
##
## The number of eigenvalues and eigenvectors to calculate is given by
## @var{k} and defaults to 6.
##
## By default, @code{eigs} solve the equation
## @tex
## $A \nu = \lambda \nu$,
## @end tex
## @ifinfo
## @code{A * v = lambda * v},
## @end ifinfo
## where
## @tex
## $\lambda$ is a scalar representing one of the eigenvalues, and $\nu$
## @end tex
## @ifinfo
## @code{lambda} is a scalar representing one of the eigenvalues, and @code{v}
## @end ifinfo
## is the corresponding eigenvector.  If given the positive definite matrix
## @var{B} then @code{eigs} solves the general eigenvalue equation
## @tex
## $A \nu = \lambda B \nu$.
## @end tex
## @ifinfo
## @code{A * v = lambda * B * v}.
## @end ifinfo
##
## The argument @var{sigma} determines which eigenvalues are returned.
## @var{sigma} can be either a scalar or a string.  When @var{sigma} is a
## scalar, the @var{k} eigenvalues closest to @var{sigma} are returned.  If
## @var{sigma} is a string, it must have one of the following values.
##
## @table @asis
## @item @qcode{"lm"}
## Largest Magnitude (default).
##
## @item @qcode{"sm"}
## Smallest Magnitude.
##
## @item @qcode{"la"}
## Largest Algebraic (valid only for real symmetric problems).
##
## @item @qcode{"sa"}
## Smallest Algebraic (valid only for real symmetric problems).
##
## @item @qcode{"be"}
## Both Ends, with one more from the high-end if @var{k} is odd (valid only for
## real symmetric problems).
##
## @item @qcode{"lr"}
## Largest Real part (valid only for complex or unsymmetric problems).
##
## @item @qcode{"sr"}
## Smallest Real part (valid only for complex or unsymmetric problems).
##
## @item @qcode{"li"}
## Largest Imaginary part (valid only for complex or unsymmetric problems).
##
## @item @qcode{"si"}
## Smallest Imaginary part (valid only for complex or unsymmetric problems).
## @end table
##
## If @var{opts} is given, it is a structure defining possible options that
## @code{eigs} should use.  The fields of the @var{opts} structure are:
##
## @table @code
## @item issym
## If @var{af} is given, then flags whether the function @var{af} defines a
## symmetric problem.  It is ignored if @var{A} is given.  The default is false.
##
## @item isreal
## If @var{af} is given, then flags whether the function @var{af} defines a
## real problem.  It is ignored if @var{A} is given.  The default is true.
##
## @item tol
## Defines the required convergence tolerance, calculated as
## @code{tol * norm (A)}.  The default is @code{eps}.
##
## @item maxit
## The maximum number of iterations.  The default is 300.
##
## @item p
## The number of Lanzcos basis vectors to use.  More vectors will result in
## faster convergence, but a greater use of memory.  The optimal value of
## @code{p} is problem dependent and should be in the range @var{k} to @var{n}.
## The default value is @code{2 * @var{k}}.
##
## @item v0
## The starting vector for the algorithm.  An initial vector close to the
## final vector will speed up convergence.  The default is for @sc{arpack}
## to randomly generate a starting vector.  If specified, @code{v0} must be
## an @var{n}-by-1 vector where @code{@var{n} = rows (@var{A})}
##
## @item disp
## The level of diagnostic printout (0|1|2).  If @code{disp} is 0 then
## diagnostics are disabled.  The default value is 0.
##
## @item cholB
## Flag if @code{chol (@var{B})} is passed rather than @var{B}.  The default is
## false.
##
## @item permB
## The permutation vector of the Cholesky@tie{}factorization of @var{B} if
## @code{cholB} is true.  That is @code{chol (@var{B}(permB, permB))}.  The
## default is @code{1:@var{n}}.
##
## @end table
##
## It is also possible to represent @var{A} by a function denoted @var{af}.
## @var{af} must be followed by a scalar argument @var{n} defining the length
## of the vector argument accepted by @var{af}.  @var{af} can be a function
## handle, an inline function, or a string.  When @var{af} is a string it
## holds the name of the function to use.
##
## @var{af} is a function of the form @code{y = af (x)} where the required
## return value of @var{af} is determined by the value of @var{sigma}.  The
## four possible forms are
##
## @table @code
## @item A * x
## if @var{sigma} is not given or is a string other than "sm".
##
## @item A \ x
## if @var{sigma} is 0 or "sm".
##
## @item (A - sigma * I) \ x
## for the standard eigenvalue problem, where @code{I} is the identity matrix
## of the same size as @var{A}.
##
## @item (A - sigma * B) \ x
## for the general eigenvalue problem.
## @end table
##
## The return arguments of @code{eigs} depend on the number of return arguments
## requested.  With a single return argument, a vector @var{d} of length @var{k}
## is returned containing the @var{k} eigenvalues that have been found.  With
## two return arguments, @var{V} is a @var{n}-by-@var{k} matrix whose columns
## are the @var{k} eigenvectors corresponding to the returned eigenvalues.  The
## eigenvalues themselves are returned in @var{d} in the form of a
## @var{n}-by-@var{k} matrix, where the elements on the diagonal are the
## eigenvalues.
##
## Given a third return argument @var{flag}, @code{eigs} returns the status
## of the convergence.  If @var{flag} is 0 then all eigenvalues have converged.
## Any other value indicates a failure to converge.
##
## This function is based on the @sc{arpack} package, written by
## @nospell{R. Lehoucq, K. Maschhoff, D. Sorensen, and C. Yang}.  For more
## information see @url{http://www.caam.rice.edu/software/ARPACK/}.
##
## @seealso{eig, svds}
## @end deftypefn
    
    
@function
def eigs(varargin=None,*args,**kwargs):
    varargin = eigs.varargin
    nargin = eigs.nargin

    ## For compatibility with Matlab, handle small matrix cases here
  ## that ARPACK does not.
    
    if (nargin == 0):
        print_usage()
    
    call_eig=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:204
    offset=0
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:205
    k=6
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:206
    sigma='lm'
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:207
    if (isnumeric(varargin[1]) and issquare(varargin[1])):
        a=varargin[1]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:210
        if (nargin > 1 and isnumeric(varargin[2]) and issquare(varargin[2]) and size_equal(a,varargin[2])):
            b=varargin[2]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:213
            offset=1
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:214
        if (rows(a) < 9):
            call_eig=copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:218
        if (nargin > 1 + offset):
            tmp=varargin[2 + offset]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:222
            if (isnumeric(tmp) and isscalar(tmp) and isreal(tmp) and round(tmp) == tmp):
                k=copy(tmp)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:225
                if (rows(a) - k < 3):
                    call_eig=copy(true)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:228
            else:
                call_eig=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:231
            if (nargin > 2 + offset):
                tmp=varargin[3 + offset]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:235
                if (ischar(tmp)):
                    sigma=tolower(tmp)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:237
                else:
                    if (isnumeric(tmp) and isscalar(tmp)):
                        sigma=copy(tmp)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:239
                    else:
                        call_eig=copy(false)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:241
    
    if (call_eig):
        varargout=cell(1,min(2,max(1,nargout)))
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:248
        if (offset):
            real_valued=isreal(a) and isreal(b)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:250
            symmetric=issymmetric(a) and issymmetric(b)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:251
            varargout[:]=eig(a,b)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:252
        else:
            real_valued=isreal(a)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:254
            symmetric=issymmetric(a)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:255
            varargout[:]=eig(a)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:256
        varargout=select(varargout,k,sigma,real_valued,symmetric)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:258
        if (nargout == 3):
            varargout[3]=0
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:260
    else:
        varargout=cell(1,max(1,nargout))
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:263
        varargout[:]=__eigs__(varargin[:])
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:264
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def select(args=None,k=None,sigma=None,real_valued=None,symmetric=None,*args,**kwargs):
    varargin = select.varargin
    nargin = select.nargin

    if (numel(args) == 1):
        d=args[1]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:272
    else:
        d=diag(args[2])
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:274
    
    if (ischar(sigma)):
        if 'lm' == (sigma):
            __,idx=sort(abs(d),'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:280
        else:
            if 'sm' == (sigma):
                __,idx=sort(abs(d),'ascend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:283
            else:
                if 'la' == (sigma):
                    if (real_valued and symmetric):
                        __,idx=sort(real(d),'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:287
                    else:
                        error('sigma = "la" requires real symmetric problem')
                else:
                    if 'sa' == (sigma):
                        if (real_valued and symmetric):
                            __,idx=sort(real(d),'ascend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:294
                        else:
                            error('sigma = "sa" requires real symmetric problem')
                    else:
                        if 'be' == (sigma):
                            if (real_valued and symmetric):
                                __,idx=sort(real(d),'ascend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:301
                            else:
                                error('sigma = "be" requires real symmetric problem')
                        else:
                            if 'lr' == (sigma):
                                if (logical_not((real_valued or symmetric))):
                                    __,idx=sort(real(d),'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:308
                                else:
                                    error('sigma = "lr" requires complex or unsymmetric problem')
                            else:
                                if 'sr' == (sigma):
                                    if (logical_not((real_valued or symmetric))):
                                        __,idx=sort(real(d),'ascend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:315
                                    else:
                                        error('sigma = "sr" requires complex or unsymmetric problem')
                                else:
                                    if 'li' == (sigma):
                                        if (logical_not((real_valued or symmetric))):
                                            __,idx=sort(imag(d),'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:322
                                        else:
                                            error('sigma = "li" requires complex or unsymmetric problem')
                                    else:
                                        if 'si' == (sigma):
                                            if (logical_not((real_valued or symmetric))):
                                                __,idx=sort(imag(d),'ascend',nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:329
                                            else:
                                                error('sigma = "si" requires complex or unsymmetric problem')
                                        else:
                                            error('unrecognized value for sigma: %s',sigma)
    else:
        ## numeric sigma, find k closest values
        __,idx=sort(abs(d - sigma),nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:339
    
    d=d[idx]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:342
    n=numel(d)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:344
    k=min(k,n)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:346
    if (strcmp(sigma,'be')):
        tmp=k / 2
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:349
        n1=floor(tmp)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:350
        n2=n - ceil(tmp) + 1
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:351
        selection=matlabarray(cat(arange(1,floor(k / 2)),arange(n2,n)))
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:352
    else:
        selection=arange(1,k)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:354
    
    d=d[selection]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:357
    if (numel(args) == 1):
        out[1]=d
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:360
    else:
        out[2]=diag(d)
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:362
        v=args[1]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:364
        v=v[:,idx]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:365
        out[1]=v[:,selection]
# /home/lei/octave-4.0.2/scripts/sparse/eigs.m:366
    
    return out
    
if __name__ == '__main__':
    pass
    
    #### SPARSE MATRIX VERSIONS ####
    
    ## Real positive definite tests, n must be even
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Real unsymmetric tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Complex hermitian tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    #### FULL MATRIX VERSIONS ####
    
    ## Real positive definite tests, n must be even
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Real unsymmetric tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Complex hermitian tests
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{p} =} colperm (@var{s})
## Return the column permutations such that the columns of
## @code{@var{s} (:, @var{p})} are ordered in terms of increasing number of
## nonzero elements.
##
## If @var{s} is symmetric, then @var{p} is chosen such that
## @code{@var{s} (@var{p}, @var{p})} orders the rows and columns with
## increasing number of nonzeros elements.
## @end deftypefn
    
    
@function
def colperm(s=None,*args,**kwargs):
    varargin = colperm.varargin
    nargin = colperm.nargin

    if (nargin != 1):
        print_usage()
    
    i,j=find(s,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/colperm.m:36
    idx=find(diff(cat([j],[Inf])) != 0)
# /home/lei/octave-4.0.2/scripts/sparse/colperm.m:37
    dummy,p=sort(idx - cat([0],[idx[1:(end() - 1)]]),nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/colperm.m:38
    return p
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2004-2015 David Bateman and Andy Adler
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{y} =} spfun (@var{f}, @var{S})
## Compute @code{f(@var{S})} for the nonzero values of @var{S}.
##
## This results in a sparse matrix with the same structure as @var{S}.  The
## function @var{f} can be passed as a string, a function handle, or an
## inline function.
## @seealso{arrayfun, cellfun, structfun}
## @end deftypefn
    
    
@function
def spfun(f=None,S=None,*args,**kwargs):
    varargin = spfun.varargin
    nargin = spfun.nargin

    if (nargin != 2):
        print_usage()
    
    i,j,v=find(S,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/spfun.m:35
    m,n=size(S,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spfun.m:36
    if (isa(f,'function_handle') or isa(f,'inline function')):
        y=sparse(i,j,f[v],m,n)
# /home/lei/octave-4.0.2/scripts/sparse/spfun.m:39
    else:
        y=sparse(i,j,feval(f,v),m,n)
# /home/lei/octave-4.0.2/scripts/sparse/spfun.m:41
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2008-2015 Radek Salac
## Copyright (C) 2012 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} cgs (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{M1}, @var{M2}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} cgs (@var{A}, @var{b}, @var{rtol}, @var{maxit}, @var{P})
## @deftypefnx {Function File} {[@var{x}, @var{flag}, @var{relres}, @var{iter}, @var{resvec}] =} cgs (@var{A}, @var{b}, @dots{})
## Solve @code{A x = b}, where @var{A} is a square matrix, using the
## Conjugate Gradients Squared method.
##
## @itemize @minus
## @item @var{rtol} is the relative tolerance, if not given or set to [] the
## default value 1e-6 is used.
##
## @item @var{maxit} the maximum number of outer iterations, if not given or
## set to [] the default value @code{min (20, numel (b))} is used.
##
## @item @var{x0} the initial guess, if not given or set to [] the default
## value @code{zeros (size (b))} is used.
## @end itemize
##
## @var{A} can be passed as a matrix or as a function handle or inline
## function @code{f} such that @code{f(x) = A*x}.
##
## The preconditioner @var{P} is given as @code{P = M1 * M2}.  Both @var{M1}
## and @var{M2} can be passed as a matrix or as a function handle or inline
## function @code{g} such that @code{g(x) = M1 \ x} or @code{g(x) = M2 \ x}.
##
## If called with more than one output parameter
##
## @itemize @minus
## @item @var{flag} indicates the exit status:
##
## @itemize @minus
## @item 0: iteration converged to the within the chosen tolerance
##
## @item 1: the maximum number of iterations was reached before convergence
##
## @item 3: the algorithm reached stagnation
## @end itemize
##
## (the value 2 is unused but skipped for compatibility).
##
## @item @var{relres} is the final value of the relative residual.
##
## @item @var{iter} is the number of iterations performed.
##
## @item @var{resvec} is a vector containing the relative residual at
## each iteration.
## @end itemize
##
## @seealso{pcg, bicgstab, bicg, gmres, qmr}
## @end deftypefn
    
    
@function
def cgs(A=None,b=None,tol=None,maxit=None,M1=None,M2=None,x0=None,*args,**kwargs):
    varargin = cgs.varargin
    nargin = cgs.nargin

    if (nargin >= 2 and nargin <= 7 and isvector(full(b))):
        if (ischar(A)):
            A=str2func(A)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:76
        else:
            if (isnumeric(A) and issquare(A)):
                Ax=lambda x=None: dot(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:78
            else:
                if (isa(A,'function_handle')):
                    Ax=lambda x=None: feval(A,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:80
                else:
                    error('cgs: A must be a function or square matrix')
        if (nargin < 3 or isempty(tol)):
            tol=1e-06
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:86
        if (nargin < 4 or isempty(maxit)):
            maxit=min(rows(b),20)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:90
        if (nargin < 5 or isempty(M1)):
            M1m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:94
        else:
            if (ischar(M1)):
                M1m1x=str2func(M1)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:96
            else:
                if (isnumeric(M1) and ismatrix(M1)):
                    M1m1x=lambda x=None: numpy.linalg.solve(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:98
                else:
                    if (isa(M1,'function_handle')):
                        M1m1x=lambda x=None: feval(M1,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:100
                    else:
                        error('cgs: preconditioner M1 must be a function or matrix')
        if (nargin < 6 or isempty(M2)):
            M2m1x=lambda x=None: x
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:106
        else:
            if (ischar(M2)):
                M2m1x=str2func(M2)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:108
            else:
                if (isnumeric(M2) and ismatrix(M2)):
                    M2m1x=lambda x=None: numpy.linalg.solve(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:110
                else:
                    if (isa(M2,'function_handle')):
                        M2m1x=lambda x=None: feval(M2,x)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:112
                    else:
                        error('cgs: preconditioner M2 must be a function or matrix')
        precon=lambda x=None: M2m1x[M1m1x[x]]
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:117
        if (nargin < 7 or isempty(x0)):
            x0=zeros(size(b))
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:120
        x=copy(x0)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:124
        res=b - Ax[x]
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:126
        norm_b=norm(b)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:127
        resvec=norm(res) / norm_b
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:129
        ro=0
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:130
        flag=1
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:132
        for iter in arange(1,maxit).reshape(-1):
            z=precon[res]
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:135
            ro_old=copy(ro)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:138
            ro=dot(res.T,z)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:139
            if (iter == 1):
                p=copy(z)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:141
            else:
                beta=ro / ro_old
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:143
                p=z + dot(beta,p)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:144
            ## Cache.
            q=Ax[p]
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:147
            alpha=ro / (dot(p.T,q))
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:148
            x=x + dot(alpha,p)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:149
            res=res - dot(alpha,q)
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:151
            relres=norm(res) / norm_b
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:152
            resvec=matlabarray(cat([resvec],[relres]))
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:153
            if (relres <= tol):
                ## We reach tolerance tol within maxit iterations.
                flag=0
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:157
                break
            else:
                if (resvec[end()] == resvec[end() - 1]):
                    ## The method stagnates.
                    flag=3
# /home/lei/octave-4.0.2/scripts/sparse/cgs.m:161
                    break
        if (nargout < 1):
            if (flag == 0):
                printf('cgs converged at iteration %i to a solution with relative residual %e\n',iter,relres)
            else:
                if (flag == 3):
                    printf(cat('cgs stopped at iteration %i without converging to the desired tolerance %e\n','because the method stagnated.\n','The iterate returned (number %i) has relative residual %e\n'),iter,tol,iter,relres)
                else:
                    printf(cat('cgs stopped at iteration %i without converging to the desired tolerance %e\n','because the maximum number of iterations was reached.\n','The iterate returned (number %i) has relative residual %e\n'),iter,tol,iter,relres)
    else:
        print_usage()
    
    return x,flag,relres,iter,resvec
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Ivana Varekova
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} etreeplot (@var{A})
## @deftypefnx {Function File} {} etreeplot (@var{A}, @var{node_style}, @var{edge_style})
## Plot the elimination tree of the matrix @var{A} or
## @tcode{@var{A}+@var{A}'} if @var{A} in not symmetric.
##
## The optional parameters @var{node_style} and @var{edge_style} define the
## output style.
## @seealso{treeplot, gplot}
## @end deftypefn
    
    
@function
def etreeplot(A=None,varargin=None,*args,**kwargs):
    varargin = etreeplot.varargin
    nargin = etreeplot.nargin

    if (nargin < 1):
        print_usage()
    
    treeplot(etree(A + A.T),varargin[:])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Eduardo Ramos Fernndez <eduradical951@gmail.com>
## Copyright (C) 2013-2015 Kai T. Ohlhus <k.ohlhus@gmail.com>
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ilu (@var{A})
## @deftypefnx {Function File} {} ilu (@var{A}, @var{opts})
## @deftypefnx {Function File} {[@var{L}, @var{U}] =} ilu (@dots{})
## @deftypefnx {Function File} {[@var{L}, @var{U}, @var{P}] =} ilu (@dots{})
##
## Compute the incomplete LU factorization of the sparse square matrix @var{A}.
##
## @code{ilu} returns a unit lower triangular matrix @var{L}, an upper
## triangular matrix @var{U}, and optionally a permutation matrix @var{P}, such
## that @code{@var{L}*@var{U}} approximates @code{@var{P}*@var{A}}.
##
## The factors given by this routine may be useful as preconditioners for a
## system of linear equations being solved by iterative methods such as BICG
## (BiConjugate Gradients) or GMRES (Generalized Minimum Residual Method).
##
## The factorization may be modified by passing options in a structure
## @var{opts}.  The option name is a field of the structure and the setting
## is the value of field.  Names and specifiers are case sensitive.
##
## @table @code
## @item type
## Type of factorization.
##
## @table @asis
## @item @qcode{"nofill"}
## ILU factorization with no fill-in (ILU(0)).
##
## Additional supported options: @code{milu}.
##
## @item @qcode{"crout"}
## Crout version of ILU factorization (@nospell{ILUC}).
##
## Additional supported options: @code{milu}, @code{droptol}.
##
## @item @qcode{"ilutp"} (default)
## ILU factorization with threshold and pivoting.
##
## Additional supported options: @code{milu}, @code{droptol}, @code{udiag},
## @code{thresh}.
## @end table
##
## @item droptol
## A non-negative scalar specifying the drop tolerance for factorization.  The
## default value is 0 which produces the complete LU factorization.
##
## Non-diagonal entries of @var{U} are set to 0 unless
##
## @code{abs (@var{U}(i,j)) >= droptol * norm (@var{A}(:,j))}.
##
## Non-diagonal entries of @var{L} are set to 0 unless
##
## @code{abs (@var{L}(i,j)) >= droptol * norm (@var{A}(:,j))/@var{U}(j,j)}.
##
## @item milu
## Modified incomplete LU factorization:
##
## @table @asis
## @item @qcode{"row"}
## Row-sum modified incomplete LU factorization.
## The factorization preserves row sums:
## @code{@var{A} * e = @var{L} * @var{U} * e}, where e is a vector of ones.
##
## @item @qcode{"col"}
## Column-sum modified incomplete LU factorization.
## The factorization preserves column sums:
## @code{e' * @var{A} = e' * @var{L} * @var{U}}.
##
## @item @qcode{"off"} (default)
## Row and column sums are not necessarily preserved.
## @end table
##
## @item udiag
## If true, any zeros on the diagonal of the upper triangular factor are
## replaced by the local drop tolerance
## @code{droptol * norm (@var{A}(:,j))/@var{U}(j,j)}.  The default is false.
##
## @item thresh
## Pivot threshold for factorization.  It can range between 0 (diagonal
## pivoting) and 1 (default), where the maximum magnitude entry in the column
## is chosen to be the pivot.
## @end table
##
## If @code{ilu} is called with just one output, the returned matrix is
## @code{@var{L} + @var{U} - speye (size (@var{A}))}, where @var{L} is unit
## lower triangular and @var{U} is upper triangular.
##
## With two outputs, @code{ilu} returns a unit lower triangular matrix @var{L}
## and an upper triangular matrix @var{U}.  For @var{opts}.type ==
## @qcode{"ilutp"}, one of the factors is permuted based on the value of
## @var{opts}.milu.  When @var{opts}.milu == @qcode{"row"}, @var{U} is a
## column permuted upper triangular factor.  Otherwise, @var{L} is a
## row-permuted unit lower triangular factor.
##
## If there are three named outputs and @var{opts}.milu != @qcode{"row"},
## @var{P} is returned such that @var{L} and @var{U} are incomplete factors
## of @code{@var{P}*@var{A}}.  When @var{opts}.milu == @qcode{"row"}, @var{P}
## is returned such that @var{L} and @var{U} are incomplete factors of
## @code{@var{A}*@var{P}}.
##
## EXAMPLES
##
## @example
## @group
## A = gallery ("neumann", 1600) + speye (1600);
## opts.type = "nofill";
## nnz (A)
## ans = 7840
##
## nnz (lu (A))
## ans = 126478
##
## nnz (ilu (A, opts))
## ans = 7840
## @end group
## @end example
##
## This shows that @var{A} has 7,840 nonzeros, the complete LU factorization
## has 126,478 nonzeros, and the incomplete LU factorization, with 0 level of
## fill-in, has 7,840 nonzeros, the same amount as @var{A}.  Taken from:
## http://www.mathworks.com/help/matlab/ref/ilu.html
##
## @example
## @group
## A = gallery ("wathen", 10, 10);
## b = sum (A, 2);
## tol = 1e-8;
## maxit = 50;
## opts.type = "crout";
## opts.droptol = 1e-4;
## [L, U] = ilu (A, opts);
## x = bicg (A, b, tol, maxit, L, U);
## norm (A * x - b, inf)
## @end group
## @end example
##
## This example uses ILU as preconditioner for a random FEM-Matrix, which has a
## large condition number.  Without @var{L} and @var{U} BICG would not converge.
##
## @seealso{lu, ichol, bicg, gmres}
## @end deftypefn
    
    
@function
def ilu(A=None,opts=struct(),*args,**kwargs):
    varargin = ilu.varargin
    nargin = ilu.nargin

    if (nargin < 1 or nargin > 2 or (nargout > 3)):
        print_usage()
    
    if (logical_not((issparse(A) and issquare(A)))):
        error('ichol: A must be a sparse square matrix')
    
    if (logical_not(isstruct(opts))):
        error('ichol: OPTS must be a structure.')
    
    ## If A is empty then return empty L, U and P for Matlab compatibility
    if (isempty(A)):
        L=U=P=copy(A)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:178
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:178
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:178
        return L,U,P
    
    ## Parse input options
    if (logical_not(isfield(opts,'type'))):
        opts.type = copy('nofill')
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:184
    else:
        type_=tolower(getfield(opts,'type'))
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:186
        if (logical_not(any(strcmp(type_,cellarray(['nofill','crout','ilutp']))))):
            error('ilu: invalid TYPE specified')
        opts.type = copy(type_)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:190
    
    if (logical_not(isfield(opts,'droptol'))):
        opts.droptol = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:194
    else:
        if (logical_not((isreal(opts.droptol) and isscalar(opts.droptol) and opts.droptol >= 0))):
            error('ilu: DROPTOL must be a non-negative real scalar')
    
    if (logical_not(isfield(opts,'milu'))):
        opts.milu = copy('off')
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:203
    else:
        milu=tolower(getfield(opts,'milu'))
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:205
        if (logical_not(any(strcmp(milu,cellarray(['off','col','row']))))):
            error('ilu: MILU must be one of "off", "col", or "row"')
        opts.milu = copy(milu)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:209
    
    if (logical_not(isfield(opts,'udiag'))):
        opts.udiag = copy(0)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:213
    else:
        if (logical_not(isscalar(opts.udiag)) or (opts.udiag != 0 and opts.udiag != 1)):
            error('ilu: UDIAG must be 0 or 1')
    
    if (logical_not(isfield(opts,'thresh'))):
        opts.thresh = copy(1)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:221
    else:
        if (logical_not((isreal(opts.thresh) and isscalar(opts.thresh))) or opts.thresh < 0 or opts.thresh > 1):
            error('ilu: THRESH must be a scalar in the range [0, 1]')
    
    n=length(A)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:229
    
    if 'nofill' == (opts.type):
        L,U=__ilu0__(A,opts.milu,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:234
        if (nargout == 3):
            P=speye(length(A))
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:236
    else:
        if 'crout' == (opts.type):
            L,U=__iluc__(A,opts.droptol,opts.milu,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:239
            if (nargout == 3):
                P=speye(length(A))
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:241
        else:
            if 'ilutp' == (opts.type):
                if (nargout == 2):
                    L,U=__ilutp__(A,opts.droptol,opts.thresh,opts.milu,opts.udiag,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:245
                else:
                    if (nargout == 3):
                        L,U,P=__ilutp__(A,opts.droptol,opts.thresh,opts.milu,opts.udiag,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:248
    
    if (nargout == 1):
        L=L + U - speye(n)
# /home/lei/octave-4.0.2/scripts/sparse/ilu.m:254
    
    return L,U,P
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## This test has been verified in both Matlab and Octave.
    
    
    
    
    
    
    
    
    
    
    ## Check if the elements in U satisfy the non-dropping condition.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Check that the complete LU factorisation with crout and ilutp algorithms
## produce the same result.
    
    
    
    
    
    
    
    
    ## Tests for real matrices of different sizes for ilu0, iluc and ilutp.
## The difference A - L*U should be not greater than eps because with droptol
## equaling 0, the LU complete factorization is performed.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests for complex matrices of different sizes for ilu0, iluc and ilutp.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Specific tests for ilutp
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests for input validation
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Ivana Varekova
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} treeplot (@var{tree})
## @deftypefnx {Function File} {} treeplot (@var{tree}, @var{node_style}, @var{edge_style})
## Produce a graph of tree or forest.
##
## The first argument is vector of predecessors.
##
## The optional parameters @var{node_style} and @var{edge_style} define the
## output plot style.
##
## The complexity of the algorithm is O(n) in terms of is time and memory
## requirements.
## @seealso{etreeplot, gplot}
## @end deftypefn
    
    
@function
def treeplot(tree=None,node_style='ko',edge_style='r',*args,**kwargs):
    varargin = treeplot.varargin
    nargin = treeplot.nargin

    if (nargin < 1 or nargin > 3 or nargout > 0):
        print_usage()
    
    if (logical_not(isnumeric(tree)) or logical_not(isrow(tree)) or any(tree > length(tree))):
        error('treeplot: TREE must be a vector of predecessors')
    
    ##  Verify node_style
    if (nargin > 1):
        if (isempty(regexp(node_style,'[ox+*]','once'))):
            node_style=matlabarray(cat(node_style,'o'))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:47
    
    ## Make it a row vector.
    tree=ravel(tree).T
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:52
    
    num_nodes=length(tree)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:55
    
    num_children=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:58
    for i in arange(1,num_nodes).reshape(-1):
        ## VEC_OF_CHILD is helping vector which is used to speed up the
    ## choose of descendant nodes.
        num_children[tree[i] + 1]=num_children[tree[i] + 1] + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:64
    
    pos=1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:66
    start=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:67
    xhelp=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:68
    stop=zeros(1,num_nodes + 1)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:69
    for i in arange(1,num_nodes + 1).reshape(-1):
        start[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:71
        xhelp[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:72
        pos += num_children[i]
        stop[i]=pos
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:74
    
    for i in arange(1,num_nodes).reshape(-1):
        vec_of_child[xhelp[tree[i] + 1]]=i
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:77
        xhelp[tree[i] + 1]=xhelp[tree[i] + 1] + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:78
    
    ## The number of "parent" (actual) node (it's descendants will be
  ## browse in the next iteration).
    par_number=0
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:83
    
    ## this value is increased in each leaf.
    left_most=0
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:87
    
    level=copy(num_nodes)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:90
    
    max_ht=copy(num_nodes)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:93
    
    ## node and the number it's of parent node on the top of stack
  ## there is "parent node".
    stk=matlabarray(cat(- 1,0))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:98
    
    ## uninterupted line).
    skelet=0
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:102
    
    while (par_number != - 1):

        if (start[par_number + 1] < stop[par_number + 1]):
            idx=vec_of_child[start[par_number + 1]:stop[par_number + 1] - 1]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:107
        else:
            idx=zeros(1,0)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:109
        ## Add to idx the vector of parent descendants.
        stk=matlabarray(cat([stk],[cat(idx.T,dot(ones(fliplr(size(idx))),par_number))]))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:112
        if (par_number != 0):
            skelet=matlabarray(cat([skelet],[ravel((cat([dot(ones(size(idx)),par_number)],[idx])))]))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:115
        ## If there is not any descendant of "parent node":
        if (stk[end(),2] != par_number):
            left_most
            x_coordinate_r[par_number]=left_most
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:121
            max_ht=min(max_ht,level)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:122
            if (length(stk) > 1 and find((shift(stk,1) - stk) == 0) > 1 and stk[end(),2] != stk[end() - 1,2]):
                ## Return to the nearest branching the position to return
        ## position is the position on the stack, where should be
        ## started further search (there are two nodes which has the
        ## same parent node).
                position=(find((shift(stk[:,2],1) - stk[:,2]) == 0))(end()) + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:129
                par_number_vec=stk[position:end(),2]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:130
                ## position to end).
                skelet=matlabarray(cat([skelet],[flipud(par_number_vec)]))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:133
                level += length(par_number_vec)
                x_coordinate_r[par_number_vec]=left_most
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:136
                stk[position:end(),:]=[]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:137
            ## Remove the next node from "searched branch".
            stk[end(),:]=[]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:140
            par_number=stk[end(),1]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:142
            if (par_number != - 1):
                skelet=matlabarray(cat([skelet],[stk[end(),2]],[par_number]))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:145
                y_coordinate[par_number]=level
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:146
                x_coordinate_l[par_number]=left_most + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:147
        else:
            ## There were descendants of "parent nod" choose the last of
      ## them and go on through it.
            level
            par_number=stk[end(),1]
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:153
            y_coordinate[par_number]=level
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:154
            x_coordinate_l[par_number]=left_most + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:155

    
    ## Calculate the x coordinates (the known values are the position
  ## of most left and most right descendants).
    x_coordinate=(x_coordinate_l + x_coordinate_r) / 2
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:161
    
    ##        array and make a single call to plot here so we can avoid
  ##        setting the hold state...
    
    hold_is_on=ishold()
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:167
    try:
        ## Plot graph nodes.
        plot(x_coordinate,y_coordinate,node_style)
        skelet=matlabarray(cat([skelet],[0]))
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:173
        idx=find(skelet == 0)
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:176
        hold('on')
        for i in arange(2,length(idx)).reshape(-1):
            ## Tree component start.
            istart=idx[i - 1] + 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:182
            istop=idx[i] - 1
# /home/lei/octave-4.0.2/scripts/sparse/treeplot.m:184
            if (istop - istart < 1):
                continue
            plot(x_coordinate[skelet[istart:istop]],y_coordinate[skelet[istart:istop]],edge_style)
        ## Set axis and graph size.
        axis(cat(0.5,left_most + 0.5,max_ht - 0.5,num_nodes - 0.5),'nolabel')
    finally:
        if (logical_not(hold_is_on)):
            hold('off')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{count}, @var{mean}, @var{var}] =} spstats (@var{S})
## @deftypefnx {Function File} {[@var{count}, @var{mean}, @var{var}] =} spstats (@var{S}, @var{j})
## Return the stats for the nonzero elements of the sparse matrix @var{S}.
##
## @var{count} is the number of nonzeros in each column, @var{mean} is the mean
## of the nonzeros in each column, and @var{var} is the variance of the
## nonzeros in each column.
##
## Called with two input arguments, if @var{S} is the data and @var{j} is the
## bin number for the data, compute the stats for each bin.  In this case,
## bins can contain data values of zero, whereas with
## @code{spstats (@var{S})} the zeros may disappear.
## @end deftypefn
    
    
@function
def spstats(S=None,j=None,*args,**kwargs):
    varargin = spstats.varargin
    nargin = spstats.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        i,j,v=find(S,nargout=3)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:41
    else:
        v=copy(S)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:43
        i=arange(1,length(v))
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:44
        S=sparse(i,j,v)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:45
    
    n,m=size(S,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:47
    count=sum(sparse(i,j,1,n,m))
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:49
    if (nargout > 1):
        mean=sum(S) / count
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:51
    
    if (nargout > 2):
        ## FIXME: Variance with count = 0 or 1?
        diff=S - sparse(i,j,mean[j],n,m)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:55
        var=sum(multiply(diff,diff)) / (count - 1)
# /home/lei/octave-4.0.2/scripts/sparse/spstats.m:56
    
    return count,mean,var
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{s} =} spaugment (@var{A}, @var{c})
## Create the augmented matrix of @var{A}.
##
## This is given by
##
## @example
## @group
## [@var{c} * eye(@var{m}, @var{m}), @var{A};
##             @var{A}', zeros(@var{n}, @var{n})]
## @end group
## @end example
##
## @noindent
## This is related to the least squares solution of
## @code{@var{A} \ @var{b}}, by
##
## @example
## @group
## @var{s} * [ @var{r} / @var{c}; x] = [ @var{b}, zeros(@var{n}, columns(@var{b})) ]
## @end group
## @end example
##
## @noindent
## where @var{r} is the residual error
##
## @example
## @var{r} = @var{b} - @var{A} * @var{x}
## @end example
##
## As the matrix @var{s} is symmetric indefinite it can be factorized with
## @code{lu}, and the minimum norm solution can therefore be found without the
## need for a @code{qr} factorization.  As the residual error will be
## @code{zeros (@var{m}, @var{m})} for underdetermined problems, and example
## can be
##
## @example
## @group
## m = 11; n = 10; mn = max (m, n);
## A = spdiags ([ones(mn,1), 10*ones(mn,1), -ones(mn,1)],
##              [-1, 0, 1], m, n);
## x0 = A \ ones (m,1);
## s = spaugment (A);
## [L, U, P, Q] = lu (s);
## x1 = Q * (U \ (L \ (P  * [ones(m,1); zeros(n,1)])));
## x1 = x1(end - n + 1 : end);
## @end group
## @end example
##
## To find the solution of an overdetermined problem needs an estimate of the
## residual error @var{r} and so it is more complex to formulate a minimum norm
## solution using the @code{spaugment} function.
##
## In general the left division operator is more stable and faster than using
## the @code{spaugment} function.
## @seealso{mldivide}
## @end deftypefn
    
    
@function
def spaugment(A=None,c=None,*args,**kwargs):
    varargin = spaugment.varargin
    nargin = spaugment.nargin

    if (nargin < 2):
        if (issparse(A)):
            c=max(max(abs(A))) / 1000
# /home/lei/octave-4.0.2/scripts/sparse/spaugment.m:80
        else:
            if (ndims(A) != 2):
                error('spaugment: expecting 2-dimenisional matrix')
            else:
                c=max(abs(ravel(A))) / 1000
# /home/lei/octave-4.0.2/scripts/sparse/spaugment.m:85
    else:
        if (logical_not(isscalar(c))):
            error('spaugment: C must be a scalar')
    
    m,n=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/sparse/spaugment.m:92
    s=matlabarray(cat([dot(c,speye(m,m)),A],[A.T,sparse(n,n)]))
# /home/lei/octave-4.0.2/scripts/sparse/spaugment.m:93
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} spectral_adf (@var{c})
## @deftypefnx {Function File} {} spectral_adf (@var{c}, @var{win})
## @deftypefnx {Function File} {} spectral_adf (@var{c}, @var{win}, @var{b})
## Return the spectral density estimator given a vector of autocovariances
## @var{c}, window name @var{win}, and bandwidth, @var{b}.
##
## The window name, e.g., @qcode{"triangle"} or @qcode{"rectangle"} is
## used to search for a function called @code{@var{win}_lw}.
##
## If @var{win} is omitted, the triangle window is used.
##
## If @var{b} is omitted, @code{1 / sqrt (length (@var{x}))} is used.
## @seealso{spectral_xdf}
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Spectral density estimation
    
    
@function
def spectral_adf(c=None,win=None,b=None,*args,**kwargs):
    varargin = spectral_adf.varargin
    nargin = spectral_adf.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    cr=length(c)
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:44
    if (columns(c) > 1):
        c=c.T
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:47
    
    if (nargin < 3):
        b=1 / ceil(sqrt(cr))
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:51
    
    if (nargin == 1):
        w=triangle_lw(cr,b)
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:55
    else:
        if (logical_not(ischar(win))):
            error('spectral_adf: WIN must be a string')
        else:
            win=str2func(cat(win,'_lw'))
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:59
            w=feval(win,cr,b)
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:60
    
    c=multiply(c,w)
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:63
    retval=dot(2,real(fft(c))) - c[1]
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:65
    retval=matlabarray(cat((zeros(cr,1)),retval))
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:66
    retval[:,1]=(arange(0,cr - 1)).T / cr
# /home/lei/octave-4.0.2/scripts/signal/spectral_adf.m:67
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} arma_rnd (@var{a}, @var{b}, @var{v}, @var{t}, @var{n})
## Return a simulation of the ARMA model.
##
## The ARMA model is defined by
##
## @example
## @group
## x(n) = a(1) * x(n-1) + @dots{} + a(k) * x(n-k)
##      + e(n) + b(1) * e(n-1) + @dots{} + b(l) * e(n-l)
## @end group
## @end example
##
## @noindent
## in which @var{k} is the length of vector @var{a}, @var{l} is the length of
## vector @var{b} and @var{e} is Gaussian white noise with variance @var{v}.
## The function returns a vector of length @var{t}.
##
## The optional parameter @var{n} gives the number of dummy @var{x}(@var{i})
## used for initialization, i.e., a sequence of length @var{t}+@var{n} is
## generated and @var{x}(@var{n}+1:@var{t}+@var{n}) is returned.  If @var{n}
## is omitted, @var{n} = 100 is used.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Simulate an ARMA process
    
    
@function
def arma_rnd(a=None,b=None,v=None,t=None,n=None,*args,**kwargs):
    varargin = arma_rnd.varargin
    nargin = arma_rnd.nargin

    if (nargin == 4):
        n=100
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:49
    else:
        if (nargin == 5):
            if (logical_not(isscalar(n))):
                error('arma_rnd: N must be a scalar')
        else:
            print_usage()
    
    if ((min(size(a)) > 1) or (min(size(b)) > 1)):
        error('arma_rnd: A and B must not be matrices')
    
    if (logical_not(isscalar(t))):
        error('arma_rnd: T must be a scalar')
    
    ar=length(a)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:66
    br=length(b)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:67
    a=reshape(a,ar,1)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:69
    b=reshape(b,br,1)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:70
    
    a=matlabarray(cat([1],[- a]))
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:73
    b=matlabarray(cat([1],[b]))
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:74
    n=min(n,ar + br)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:76
    e=dot(sqrt(v),randn(t + n,1))
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:78
    x=filter(b,a,e)
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:80
    x=x[n + 1:t + n]
# /home/lei/octave-4.0.2/scripts/signal/arma_rnd.m:81
    return x
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} sinc (@var{x})
## Compute the sinc function.
##
## Return
## @tex
## $ \sin (\pi x)/(\pi x)$.
## @end tex
## @ifnottex
## sin (pi*x) / (pi*x).
## @end ifnottex
## @end deftypefn
    
    ## Author: jwe ???
    
    
@function
def sinc(x=None,*args,**kwargs):
    varargin = sinc.varargin
    nargin = sinc.nargin

    if (nargin != 1):
        print_usage()
    
    result=ones(size(x))
# /home/lei/octave-4.0.2/scripts/signal/sinc.m:40
    i=(x != 0)
# /home/lei/octave-4.0.2/scripts/signal/sinc.m:42
    if (any(ravel(i))):
        t=dot(pi,x[i])
# /home/lei/octave-4.0.2/scripts/signal/sinc.m:45
        result[i]=sin(t) / t
# /home/lei/octave-4.0.2/scripts/signal/sinc.m:46
    
    return result
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2000-2015 Bill Lash
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{b} =} unwrap (@var{x})
## @deftypefnx {Function File} {@var{b} =} unwrap (@var{x}, @var{tol})
## @deftypefnx {Function File} {@var{b} =} unwrap (@var{x}, @var{tol}, @var{dim})
##
## Unwrap radian phases by adding multiples of 2*pi as appropriate to remove
## jumps greater than @var{tol}.
##
## @var{tol} defaults to pi.
##
## Unwrap will work along the dimension @var{dim}.  If @var{dim}
## is unspecified it defaults to the first non-singleton dimension.
## @end deftypefn
    
    ## Author: Bill Lash <lash@tellabs.com>
    
    
@function
def unwrap(x=None,tol=None,dim=None,*args,**kwargs):
    varargin = unwrap.varargin
    nargin = unwrap.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(isnumeric(x))):
        error('unwrap: X must be a numeric matrix or vector')
    
    if (nargin < 2 or isempty(tol)):
        tol=copy(pi)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:46
    
    ## Don't let anyone use a negative value for TOL.
    tol=abs(tol)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:50
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:52
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:53
    if (nargin == 3):
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('unwrap: DIM must be an integer and a valid dimension')
    else:
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:None
    
    rng=dot(2,pi)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:64
    m=sz[dim]
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:65
    
    ## one sample in the specified dimension.
    if (m == 1):
        retval=copy(x)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:70
        return retval
    
    ## Take first order difference to see so that wraps will show up
  ## as large values, and the sign will show direction.
    idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:76
    idx[dim]=cat(1,arange(1,m - 1))
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:77
    d=x[idx[:]] - x
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:78
    
    ## of ranges so that there are kronecker deltas at each wrap point
  ## multiplied by the appropriate amount of range values.
    p=multiply(multiply(ceil(abs(d) / rng),rng),(((d > tol) > 0) - ((d < - tol) > 0)))
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:83
    
    r=cumsum(p,dim)
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:86
    
    ## same shape as originally.
    retval=x + r
# /home/lei/octave-4.0.2/scripts/signal/unwrap.m:90
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1997-2015 Vincent Cautaerts
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fftshift (@var{x})
## @deftypefnx {Function File} {} fftshift (@var{x}, @var{dim})
## Perform a shift of the vector @var{x}, for use with the @code{fft} and
## @code{ifft} functions, in order the move the frequency 0 to the center of
## the vector or matrix.
##
## If @var{x} is a vector of @math{N} elements corresponding to @math{N} time
## samples spaced by @nospell{@math{dt}}, then
## @code{fftshift (fft (@var{x}))} corresponds to frequencies
##
## @example
## f = [ -(ceil((N-1)/2):-1:1)*df 0 (1:floor((N-1)/2))*df ]
## @end example
##
## @noindent
## where @nospell{@math{df} = 1 / @math{dt}}.
##
## If @var{x} is a matrix, the same holds for rows and columns.  If @var{x}
## is an array, then the same holds along each dimension.
##
## The optional @var{dim} argument can be used to limit the dimension along
## which the permutation occurs.
## @seealso{ifftshift}
## @end deftypefn
    
    ## Author: Vincent Cautaerts <vincent@comf5.comm.eng.osaka-u.ac.jp>
## Created: July 1997
## Adapted-By: jwe
    
    
@function
def fftshift(x=None,dim=None,*args,**kwargs):
    varargin = fftshift.varargin
    nargin = fftshift.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x) or ischar(x)))):
        error('fftshift: X must be a vector or matrix')
    
    if (nargin == 2):
        if (logical_not((isscalar(dim) and dim > 0 and dim == fix(dim)))):
            error('fftshift: dimension DIM must be a positive integer')
        nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:63
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:64
        sz2=ceil(sz[dim] / 2)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:65
        idx=cell()
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:66
        idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:67
        idx[dim]=cat(arange(sz2 + 1,sz[dim]),arange(1,sz2))
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:68
        retval=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:69
    else:
        if (isvector(x)):
            xl=length(x)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:72
            xx=ceil(xl / 2)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:73
            retval=x[cat(arange(xx + 1,xl),arange(1,xx))]
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:74
        else:
            nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:76
            sz=size(x)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:77
            sz2=ceil(sz / 2)
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:78
            idx=cell()
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:79
            for i in arange(1,nd).reshape(-1):
                idx[i]=cat(arange(sz2[i] + 1,sz[i]),arange(1,sz2[i]))
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:81
            retval=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/signal/fftshift.m:83
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test N-dimensional input (bug #45207)
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hanning (@var{m})
## @deftypefnx {Function File} {} hanning (@var{m}, "periodic")
## @deftypefnx {Function File} {} hanning (@var{m}, "symmetric")
## Return the filter coefficients of a Hanning window of length @var{m}.
##
## If the optional argument @qcode{"periodic"} is given, the periodic form
## of the window is returned.  This is equivalent to the window of length
## @var{m}+1 with the last coefficient removed.  The optional argument
## @qcode{"symmetric"} is equivalent to not specifying a second argument.
##
## For a definition of the Hanning window see, e.g.,
## @nospell{A.V. Oppenheim & R. W. Schafer},
## @cite{Discrete-Time Signal Processing}.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Coefficients of the Hanning window
    
    
@function
def hanning(m=None,opt=None,*args,**kwargs):
    varargin = hanning.varargin
    nargin = hanning.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isscalar(m) and (m == fix(m)) and (m > 0)))):
        error('hanning: M must be a positive integer')
    
    N=m - 1
# /home/lei/octave-4.0.2/scripts/signal/hanning.m:48
    if (nargin == 2):
        if 'periodic' == (opt):
            N=copy(m)
# /home/lei/octave-4.0.2/scripts/signal/hanning.m:52
        else:
            if 'symmetric' == (opt):
                ## Default option, same as no option specified.
                pass
            else:
                error('hanning: window type must be either "periodic" or "symmetric"')
    
    if (m == 1):
        c=1
# /home/lei/octave-4.0.2/scripts/signal/hanning.m:61
    else:
        m=m - 1
# /home/lei/octave-4.0.2/scripts/signal/hanning.m:63
        c=0.5 - dot(0.5,cos(dot(dot(2,pi),(arange(0,m)).T) / N))
# /home/lei/octave-4.0.2/scripts/signal/hanning.m:64
    
    return c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hurst (@var{x})
## Estimate the Hurst parameter of sample @var{x} via the rescaled range
## statistic.
##
## If @var{x} is a matrix, the parameter is estimated for every column.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Estimate the Hurst parameter
    
    
@function
def hurst(x=None,*args,**kwargs):
    varargin = hurst.varargin
    nargin = hurst.nargin

    if (nargin != 1):
        print_usage()
    
    if (isscalar(x)):
        error('hurst: X must not be a scalar')
    else:
        if (isvector(x)):
            x=reshape(x,length(x),1)
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:39
    
    xr,xc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:42
    s=std(x)
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:44
    w=cumsum(x - mean(x))
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:45
    RS=(max(w) - min(w)) / s
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:46
    H=log(RS) / log(xr)
# /home/lei/octave-4.0.2/scripts/signal/hurst.m:47
    return H
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} detrend (@var{x}, @var{p})
## If @var{x} is a vector, @code{detrend (@var{x}, @var{p})} removes the
## best fit of a polynomial of order @var{p} from the data @var{x}.
##
## If @var{x} is a matrix, @code{detrend (@var{x}, @var{p})} does the same
## for each column in @var{x}.
##
## The second argument @var{p} is optional.  If it is not specified, a value of
## 1 is assumed.  This corresponds to removing a linear trend.
##
## The order of the polynomial can also be given as a string, in which case
## @var{p} must be either @qcode{"constant"} (corresponds to @code{@var{p}=0})
## or @qcode{"linear"} (corresponds to @code{@var{p}=1}).
## @seealso{polyfit}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 11 October 1994
## Adapted-By: jwe
    
    
@function
def detrend(x=None,p=1,*args,**kwargs):
    varargin = detrend.varargin
    nargin = detrend.nargin

    ## Check input
    if (nargin > 0 and isreal(x) and ndims(x) <= 2):
        ## Check p
        if (ischar(p) and strcmpi(p,'constant')):
            p=0
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:45
        else:
            if (ischar(p) and strcmpi(p,'linear')):
                p=1
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:47
            else:
                if (logical_not(isscalar(p)) or p < 0 or p != fix(p)):
                    error('detrend: second input argument must be \'constant\', \'linear\' or a positive integer')
    else:
        error('detrend: first input argument must be a real vector or matrix')
    
    m,n=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:55
    if (m == 1):
        x=x.T
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:57
    
    r=rows(x)
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:60
    b=(dot((arange(1,r)).T,ones(1,p + 1))) ** (dot(ones(r,1),(arange(0,p))))
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:61
    y=x - dot(b,(numpy.linalg.solve(b,x)))
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:62
    if (m == 1):
        y=y.T
# /home/lei/octave-4.0.2/scripts/signal/detrend.m:65
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} sinewave (@var{m}, @var{n}, @var{d})
## Return an @var{m}-element vector with @var{i}-th element given by
## @code{sin (2 * pi * (@var{i}+@var{d}-1) / @var{n})}.
##
## The default value for @var{d} is 0 and the default value for @var{n} is
## @var{m}.
## @seealso{sinetone}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Compute a sine wave
    
    
@function
def sinewave(m=None,n=None,d=None,*args,**kwargs):
    varargin = sinewave.varargin
    nargin = sinewave.nargin

    if (nargin > 0 and nargin < 4):
        if (nargin < 3):
            d=0
# /home/lei/octave-4.0.2/scripts/signal/sinewave.m:36
        if (nargin < 2):
            n=copy(m)
# /home/lei/octave-4.0.2/scripts/signal/sinewave.m:39
        x=sin(dot(dot(((arange(1,m)) + d - 1),2),pi) / n)
# /home/lei/octave-4.0.2/scripts/signal/sinewave.m:41
    else:
        print_usage()
    
    return x
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} bartlett (@var{m})
## Return the filter coefficients of a Bartlett (triangular) window of length
## @var{m}.
##
## For a definition of the Bartlett window see, e.g.,
## @nospell{A.V. Oppenheim & R. W. Schafer},
## @cite{Discrete-Time Signal Processing}.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Coefficients of the Bartlett (triangular) window
    
    
@function
def bartlett(m=None,*args,**kwargs):
    varargin = bartlett.varargin
    nargin = bartlett.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isscalar(m) and (m == fix(m)) and (m > 0)))):
        error('bartlett: M must be a positive integer')
    
    if (m == 1):
        c=1
# /home/lei/octave-4.0.2/scripts/signal/bartlett.m:43
    else:
        m=m - 1
# /home/lei/octave-4.0.2/scripts/signal/bartlett.m:45
        n=fix(m / 2)
# /home/lei/octave-4.0.2/scripts/signal/bartlett.m:46
        c=cat(dot(2,(arange(0,n))) / m,2 - dot(2,(arange(n + 1,m))) / m).T
# /home/lei/octave-4.0.2/scripts/signal/bartlett.m:47
    
    return c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2002-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} freqz_plot (@var{w}, @var{h})
## @deftypefnx {Function File} {} freqz_plot (@var{w}, @var{h}, @var{freq_norm})
## Plot the magnitude and phase response of @var{h}.
##
## If the optional @var{freq_norm} argument is true, the frequency vector
## @var{w} is in units of normalized radians.  If @var{freq_norm} is false, or
## not given, then @var{w} is measured in Hertz.
## @seealso{freqz}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
    
    
@function
def freqz_plot(w=None,h=None,freq_norm=false,*args,**kwargs):
    varargin = freqz_plot.varargin
    nargin = freqz_plot.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    n=length(w)
# /home/lei/octave-4.0.2/scripts/signal/freqz_plot.m:38
    
    ## h = h (2 : length (h));
  ## w = w (2 : length (w));
  ## n = n-1;
    
    mag=dot(20,log10(abs(h)))
# /home/lei/octave-4.0.2/scripts/signal/freqz_plot.m:45
    phase=unwrap(arg(h))
# /home/lei/octave-4.0.2/scripts/signal/freqz_plot.m:46
    if (freq_norm):
        x_label='Normalized Frequency (\\times\\pi rad/sample)'
# /home/lei/octave-4.0.2/scripts/signal/freqz_plot.m:49
    else:
        x_label='Frequency (Hz)'
# /home/lei/octave-4.0.2/scripts/signal/freqz_plot.m:51
    
    subplot(2,1,1)
    plot(w,mag)
    grid('on')
    axis(cat(w[1],w[n]),'autoy')
    xlabel(x_label)
    ylabel('Magnitude (dB)')
    subplot(2,1,2)
    plot(w,dot(phase,360) / (dot(2,pi)))
    grid('on')
    axis(cat(w[1],w[n]),'autoy')
    xlabel(x_label)
    ylabel('Phase (degrees)')
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{x} =} synthesis (@var{y}, @var{c})
## Compute a signal from its short-time Fourier transform @var{y} and a
## 3-element vector @var{c} specifying window size, increment, and window type.
##
## The values @var{y} and @var{c} can be derived by
##
## @example
## [@var{y}, @var{c}] = stft (@var{x} , @dots{})
## @end example
## @seealso{stft}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Recover a signal from its short-term Fourier transform
    
    
@function
def synthesis(y=None,c=None,*args,**kwargs):
    varargin = synthesis.varargin
    nargin = synthesis.nargin

    if (nargin != 2):
        print_usage()
    
    if (numel(c) != 3):
        error('synthesis: C must contain exactly 3 elements')
    
    w_size=c[1]
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:45
    inc=c[2]
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:46
    w_type=c[3]
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:47
    if (w_type == 1):
        w_coeff=hanning(w_size)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:50
    else:
        if (w_type == 2):
            w_coeff=hamming(w_size)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:52
        else:
            if (w_type == 3):
                w_coeff=ones(w_size,1)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:54
            else:
                error('synthesis: window_type must be 1, 2, or 3')
    
    z=real(ifft(y))
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:59
    st=fix((w_size - inc) / 2)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:60
    z=z[st + 1:st + inc,:]
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:61
    w_coeff=w_coeff[st + 1:st + inc]
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:62
    nc=columns(z)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:64
    for i in arange(1,nc).reshape(-1):
        z[:,i] / w_coeff
    
    x=reshape(z,dot(inc,nc),1)
# /home/lei/octave-4.0.2/scripts/signal/synthesis.m:69
    return x
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{h}, @var{w}] =} freqz (@var{b}, @var{a}, @var{n}, "whole")
## @deftypefnx {Function File} {[@var{h}, @var{w}] =} freqz (@var{b})
## @deftypefnx {Function File} {[@var{h}, @var{w}] =} freqz (@var{b}, @var{a})
## @deftypefnx {Function File} {[@var{h}, @var{w}] =} freqz (@var{b}, @var{a}, @var{n})
## @deftypefnx {Function File} {@var{h} =} freqz (@var{b}, @var{a}, @var{w})
## @deftypefnx {Function File} {[@var{h}, @var{w}] =} freqz (@dots{}, @var{Fs})
## @deftypefnx {Function File} {} freqz (@dots{})
##
## Return the complex frequency response @var{h} of the rational IIR filter
## whose numerator and denominator coefficients are @var{b} and @var{a},
## respectively.
##
## The response is evaluated at @var{n} angular frequencies between 0 and
## @ifnottex
## 2*pi.
## @end ifnottex
## @tex
## $2\pi$.
## @end tex
##
## @noindent
## The output value @var{w} is a vector of the frequencies.
##
## If @var{a} is omitted, the denominator is assumed to be 1 (this
## corresponds to a simple FIR filter).
##
## If @var{n} is omitted, a value of 512 is assumed.  For fastest computation,
## @var{n} should factor into a small number of small primes.
##
## If the fourth argument, @qcode{"whole"}, is omitted the response is
## evaluated at frequencies between 0 and
## @ifnottex
## pi.
## @end ifnottex
## @tex
## $\pi$.
## @end tex
##
## @code{freqz (@var{b}, @var{a}, @var{w})}
##
## Evaluate the response at the specific frequencies in the vector @var{w}.
## The values for @var{w} are measured in radians.
##
## @code{[@dots{}] = freqz (@dots{}, @var{Fs})}
##
## Return frequencies in Hz instead of radians assuming a sampling rate
## @var{Fs}.  If you are evaluating the response at specific frequencies
## @var{w}, those frequencies should be requested in Hz rather than radians.
##
## @code{freqz (@dots{})}
##
## Plot the magnitude and phase response of @var{h} rather than returning them.
##
## @seealso{freqz_plot}
## @end deftypefn
    
    ## Author: jwe ???
    
    
@function
def freqz(b=None,a=None,n=None,region=None,Fs=None,*args,**kwargs):
    varargin = freqz.varargin
    nargin = freqz.nargin

    if (nargin < 1 or nargin > 5):
        print_usage()
    else:
        if (nargin == 1):
            ## Response of an FIR filter.
            a=n=region=Fs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:84
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:84
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:84
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:84
        else:
            if (nargin == 2):
                ## Response of an IIR filter
                n=region=Fs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:87
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:87
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:87
            else:
                if (nargin == 3):
                    region=Fs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:89
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:89
                else:
                    if (nargin == 4):
                        Fs=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:91
                        if (logical_not(ischar(region)) and logical_not(isempty(region))):
                            Fs=copy(region)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:93
                            region=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:94
    
    if (isempty(b)):
        b=1
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:99
    else:
        if (logical_not(isvector(b))):
            error('freqz: B must be a vector')
    
    if (isempty(a)):
        a=1
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:104
    else:
        if (logical_not(isvector(a))):
            error('freqz: A must be a vector')
    
    if (isempty(n)):
        n=512
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:109
    else:
        if (isscalar(n) and n < 1):
            error('freqz: N must be a positive integer')
    
    if (isempty(region)):
        if (isreal(b) and isreal(a)):
            region='half'
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:115
        else:
            region='whole'
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:117
    
    if (isempty(Fs)):
        freq_norm=copy(true)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:121
        if (nargout == 0):
            Fs=2
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:123
        else:
            Fs=dot(2,pi)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:125
    else:
        freq_norm=copy(false)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:128
    
    plot_output=(nargout == 0)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:130
    whole_region=strcmp(region,'whole')
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:131
    a=ravel(a)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:133
    b=ravel(b)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:134
    if (logical_not(isscalar(n))):
        ## Explicit frequency vector given
        w=f=copy(n)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:138
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:138
        if (nargin == 4):
            ## Sampling rate Fs was specified
            w=dot(dot(2,pi),f) / Fs
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:141
        k=max(length(b),length(a))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:143
        hb=polyval(postpad(b,k),exp(dot(j,w)))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:144
        ha=polyval(postpad(a,k),exp(dot(j,w)))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:145
    else:
        ## polyval(fliplr(P),exp(jw)) is O(p n) and fft(x) is O(n log(n)),
    ## where p is the order of the polynomial P.  For small p it
    ## would be faster to use polyval but in practice the overhead for
    ## polyval is much higher and the little bit of time saved isn't
    ## worth the extra code.
        k=max(length(b),length(a))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:152
        if (k > n / 2 and nargout == 0):
            ## Ensure a causal phase response.
            n=dot(n,2 ** ceil(log2(dot(2,k) / n)))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:155
        if (whole_region):
            N=copy(n)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:159
            if (plot_output):
                f=dot(Fs,(arange(0,n)).T) / N
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:161
            else:
                f=dot(Fs,(arange(0,n - 1)).T) / N
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:163
        else:
            N=dot(2,n)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:166
            if (plot_output):
                n
            f=dot(Fs,(arange(0,n - 1)).T) / N
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:170
        pad_sz=dot(N,ceil(k / N))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:173
        b=postpad(b,pad_sz)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:174
        a=postpad(a,pad_sz)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:175
        hb=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:177
        ha=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:178
        for i in arange(1,pad_sz,N).reshape(-1):
            hb=hb + fft(postpad(b[i:i + N - 1],N))(arange(1,n))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:181
            ha=ha + fft(postpad(a[i:i + N - 1],N))(arange(1,n))
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:182
    
    h=hb / ha
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:187
    if (plot_output):
        ## Plot and don't return values.
        if (whole_region):
            h[end() + 1]=h[1]
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:192
        freqz_plot(f,h,freq_norm)
    else:
        ## Return values and don't plot.
        h_r=copy(h)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:197
        f_r=copy(f)
# /home/lei/octave-4.0.2/scripts/signal/freqz.m:198
    
    return h_r,f_r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
## FIXME: Need to put tests here and simplify input validation in the main code.
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fftfilt (@var{b}, @var{x})
## @deftypefnx {Function File} {} fftfilt (@var{b}, @var{x}, @var{n})
## Filter @var{x} with the FIR filter @var{b} using the FFT.
##
## If @var{x} is a matrix, filter each column of the matrix.
##
## Given the optional third argument, @var{n}, @code{fftfilt} uses the
## overlap-add method to filter @var{x} with @var{b} using an N-point FFT@.
## The FFT size must be an even power of 2 and must be greater than or equal to
## the length of @var{b}.  If the specified @var{n} does not meet these
## criteria, it is automatically adjusted to the nearest value that does.
##
## @seealso{filter, filter2}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Created: 3 September 1994
## Adapted-By: jwe
    
    
@function
def fftfilt(b=None,x=None,n=None,*args,**kwargs):
    varargin = fftfilt.varargin
    nargin = fftfilt.nargin

    ## If N is not specified explicitly, we do not use the overlap-add
  ## method at all because loops are really slow.  Otherwise, we only
  ## ensure that the number of points in the FFT is the smallest power
  ## of two larger than N and length(b).  This could result in length
  ## one blocks, but if the user knows better ...
    
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    transpose=(rows(x) == 1)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:51
    if (transpose):
        x=x.T
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:54
    
    r_x,c_x=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:57
    r_b,c_b=size(b,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:58
    if (logical_not(isvector(b))):
        error('fftfilt: B must be a vector')
    
    if (ndims(x) != 2):
        error('fftfilt: X must be a 1-D or 2-D array')
    
    l_b=dot(r_b,c_b)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:68
    b=reshape(b,l_b,1)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:69
    if (nargin == 2):
        ## Use FFT with the smallest power of 2 which is >= length (x) +
    ## length (b) - 1 as number of points ...
        n=2 ** nextpow2(r_x + l_b - 1)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:74
        B=fft(b,n)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:75
        y=ifft(multiply(fft(x,n),B[:,ones(1,c_x)]))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:76
    else:
        ## Use overlap-add method ...
        if (logical_not((isscalar(n)))):
            error('fftfilt: N has to be a scalar')
        n=2 ** nextpow2(max(cat(n,l_b)))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:82
        L=n - l_b + 1
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:83
        B=fft(b,n)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:84
        B=B[:,ones(c_x,1)]
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:85
        R=ceil(r_x / L)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:86
        y=zeros(r_x,c_x)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:87
        for r in arange(1,R).reshape(-1):
            lo=dot((r - 1),L) + 1
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:89
            hi=min(dot(r,L),r_x)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:90
            tmp=zeros(n,c_x)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:91
            tmp[1:(hi - lo + 1),:]=x[lo:hi,:]
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:92
            tmp=ifft(multiply(fft(tmp),B))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:93
            hi=min(lo + n - 1,r_x)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:94
            y[lo:hi,:]=y[lo:hi,:] + tmp[1:(hi - lo + 1),:]
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:95
    
    y=y[1:r_x,:]
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:99
    
    ## - If both b and x are real, y should be real.
  ## - If b is real and x is imaginary, y should be imaginary.
  ## - If b is imaginary and x is real, y should be imaginary.
  ## - If both b and x are imaginary, y should be real.
    xisreal=all(imag(x) == 0)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:107
    xisimag=all(real(x) == 0)
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:108
    if (all(imag(b) == 0)):
        y[:,xisreal]=real(y[:,xisreal])
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:111
        y[:,xisimag]=complex(dot(real(y[:,xisimag]),0),imag(y[:,xisimag]))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:112
    else:
        if (all(real(b) == 0)):
            y[:,xisreal]=complex(dot(real(y[:,xisreal]),0),imag(y[:,xisreal]))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:114
            y[:,xisimag]=real(y[:,xisimag])
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:115
    
    ## - If both x and b are integer in both real and imaginary
  ##   components, y should be integer.
    if (logical_not(any(b - fix(b)))):
        idx=find(logical_not(any(x - fix(x))))
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:121
        y[:,idx]=round(y[:,idx])
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:122
    
    ## Transpose after cleanup, otherwise rounding fails.
    if (transpose):
        y=y.T
# /home/lei/octave-4.0.2/scripts/signal/fftfilt.m:127
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} arch_rnd (@var{a}, @var{b}, @var{t})
## Simulate an ARCH sequence of length @var{t} with AR coefficients @var{b} and
## CH coefficients @var{a}.
##
## The result @math{y(t)} follows the model
## @c Set example in small font to prevent overfull line
##
## @smallexample
## y(t) = b(1) + b(2) * y(t-1) + @dots{} + b(lb) * y(t-lb+1) + e(t),
## @end smallexample
##
## @noindent
## where @math{e(t)}, given @var{y} up to time @math{t-1}, is
## @math{N(0, h(t))}, with
## @c Set example in small font to prevent overfull line
##
## @smallexample
## h(t) = a(1) + a(2) * e(t-1)^2 + @dots{} + a(la) * e(t-la+1)^2
## @end smallexample
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Simulate an ARCH process
    
    
@function
def arch_rnd(a=None,b=None,t=None,*args,**kwargs):
    varargin = arch_rnd.varargin
    nargin = arch_rnd.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(((min(size(a)) == 1) and (min(size(b)) == 1)))):
        error('arch_rnd: A and B must both be scalars or vectors')
    
    if (logical_not((isscalar(t) and (t > 0) and (rem(t,1) == 0)))):
        error('arch_rnd: T must be a positive integer')
    
    if (logical_not((a[1] > 0))):
        error('arch_rnd: A(1) must be positive')
    
    ## perhaps add a test for the roots of a(z) here ...
    
    la=length(a)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:62
    a=reshape(a,1,la)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:63
    if (la == 1):
        a=matlabarray(cat(a,0))
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:65
        la=la + 1
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:66
    
    lb=length(b)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:69
    b=reshape(b,1,lb)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:70
    if (lb == 1):
        b=matlabarray(cat(b,0))
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:72
        lb=lb + 1
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:73
    
    m=max(cat(la,lb))
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:75
    e=zeros(t,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:77
    h=zeros(t,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:78
    y=zeros(t,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:79
    h[1]=a[1]
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:81
    e[1]=dot(sqrt(h[1]),randn)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:82
    y[1]=b[1] + e[1]
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:83
    for t in arange(2,m).reshape(-1):
        ta=min(cat(t,la))
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:86
        h[t]=a[1] + dot(a[2:ta],e[t - ta + 1:t - 1] ** 2)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:87
        e[t]=dot(sqrt(h[t]),randn)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:88
        tb=min(cat(t,lb))
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:89
        y[t]=b[1] + dot(b[2:tb],y[t - tb + 1:t - 1]) + e[t]
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:90
    
    if (t > m):
        for t in arange(m + 1,t).reshape(-1):
            h[t]=a[1] + dot(a[2:la],e[t - la + 1:t - 1] ** 2)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:95
            e[t]=dot(sqrt(h[t]),randn)
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:96
            y[t]=b[1] + dot(b[2:lb],y[t - tb + 1:t - 1]) + e[t]
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:97
    
    y=y[1:t]
# /home/lei/octave-4.0.2/scripts/signal/arch_rnd.m:101
    return y
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} spencer (@var{x})
## Return Spencer's 15 point moving average of each column of @var{x}.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Apply Spencer's 15-point MA filter
    
    
@function
def spencer(x=None,*args,**kwargs):
    varargin = spencer.varargin
    nargin = spencer.nargin

    if (nargin != 1):
        print_usage()
    
    xr,xc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:33
    n=copy(xr)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:35
    c=copy(xc)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:36
    if (isvector(x)):
        n=length(x)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:39
        c=1
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:40
        x=reshape(x,n,1)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:41
    
    w=cat(- 3,- 6,- 5,3,21,46,67,74,67,46,21,3,- 5,- 6,- 3) / 320
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:44
    retval=fftfilt(w,x)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:46
    retval=matlabarray(cat([zeros(7,c)],[retval[15:n,:]],[zeros(7,c)]))
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:47
    retval=reshape(retval,xr,xc)
# /home/lei/octave-4.0.2/scripts/signal/spencer.m:49
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{a}, @var{b}] =} arch_fit (@var{y}, @var{x}, @var{p}, @var{iter}, @var{gamma}, @var{a0}, @var{b0})
## Fit an ARCH regression model to the time series @var{y} using the scoring
## algorithm in @nospell{Engle's} original ARCH paper.
##
## The model is
##
## @example
## @group
## y(t) = b(1) * x(t,1) + @dots{} + b(k) * x(t,k) + e(t),
## h(t) = a(1) + a(2) * e(t-1)^2 + @dots{} + a(p+1) * e(t-p)^2
## @end group
## @end example
##
## @noindent
## in which @math{e(t)} is @math{N(0, h(t))}, given a time-series vector
## @var{y} up to time @math{t-1} and a matrix of (ordinary) regressors @var{x}
## up to @math{t}.  The order of the regression of the residual variance is
## specified by @var{p}.
##
## If invoked as @code{arch_fit (@var{y}, @var{k}, @var{p})} with a positive
## integer @var{k}, fit an ARCH(@var{k}, @var{p}) process, i.e., do the above
## with the @math{t}-th row of @var{x} given by
##
## @example
## [1, y(t-1), @dots{}, y(t-k)]
## @end example
##
## Optionally, one can specify the number of iterations @var{iter}, the
## updating factor @var{gamma}, and initial values @math{a0} and @math{b0}
## for the scoring algorithm.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Fit an ARCH regression model
    
    
@function
def arch_fit(y=None,x=None,p=None,iter=None,gamma=None,a0=None,b0=None,*args,**kwargs):
    varargin = arch_fit.varargin
    nargin = arch_fit.nargin

    if (nargin < 3 or nargin == 6 or nargin > 7):
        print_usage()
    
    if (logical_not((isvector(y)))):
        error('arch_fit: Y must be a vector')
    
    T=length(y)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:65
    y=reshape(y,T,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:66
    rx,cx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:67
    if ((rx == 1) and (cx == 1)):
        x=autoreg_matrix(y,x)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:69
    else:
        if (logical_not((rx == T))):
            error('arch_fit: either rows (X) == length (Y), or X is a scalar')
    
    T,k=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:74
    if (nargin == 7):
        a=copy(a0)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:77
        b=copy(b0)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:78
        e=y - dot(x,b)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:79
    else:
        b,v_b,e=ols(y,x,nargout=3)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:81
        a=cat(v_b,(zeros(1,p))).T
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:82
        if (nargin < 5):
            gamma=0.1
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:84
            if (nargin < 4):
                iter=50
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:86
    
    esq=e ** 2
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:91
    Z=autoreg_matrix(esq,p)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:92
    for i in arange(1,iter).reshape(-1):
        h=dot(Z,a)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:95
        tmp=esq / h ** 2 - 1 / h
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:96
        s=1 / h[1:T - p]
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:97
        for j in arange(1,p).reshape(-1):
            s=s - dot(a[j + 1],tmp[j + 1:T - p + j])
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:99
        r=1 / h[1:T - p]
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:101
        for j in arange(1,p).reshape(-1):
            r=r + multiply(dot(2,h[j + 1:T - p + j] ** 2),esq[1:T - p])
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:103
        r=sqrt(r)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:105
        X_tilde=multiply(x[1:T - p,:],(dot(r,ones(1,k))))
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:106
        e_tilde=multiply(e[1:T - p],s) / r
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:107
        delta_b=dot(dot(inv(dot(X_tilde.T,X_tilde)),X_tilde.T),e_tilde)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:108
        b=b + dot(gamma,delta_b)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:109
        e=y - dot(x,b)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:110
        esq=e ** 2
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:111
        Z=autoreg_matrix(esq,p)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:112
        h=dot(Z,a)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:113
        f=esq / h - ones(T,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:114
        Z_tilde=Z / (dot(h,ones(1,p + 1)))
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:115
        delta_a=dot(dot(inv(dot(Z_tilde.T,Z_tilde)),Z_tilde.T),f)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:116
        a=a + dot(gamma,delta_a)
# /home/lei/octave-4.0.2/scripts/signal/arch_fit.m:117
    
    return a,b
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1997-2015 Vincent Cautaerts
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ifftshift (@var{x})
## @deftypefnx {Function File} {} ifftshift (@var{x}, @var{dim})
## Undo the action of the @code{fftshift} function.
##
## For even length @var{x}, @code{fftshift} is its own inverse, but odd lengths
## differ slightly.
## @seealso{fftshift}
## @end deftypefn
    
    ## Author: Vincent Cautaerts <vincent@comf5.comm.eng.osaka-u.ac.jp>
## Created: July 1997
## Adapted-By: jwe
## Modified-By: Paul Kienzle, converted from fftshift
## Modified-By: David Bateman, add NDArray capability and option dim arg
    
    
@function
def ifftshift(x=None,dim=None,*args,**kwargs):
    varargin = ifftshift.varargin
    nargin = ifftshift.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x) or ischar(x)))):
        error('ifftshift: X must be a vector or matrix')
    
    if (nargin == 2):
        if (logical_not((isscalar(dim) and dim > 0 and dim == fix(dim)))):
            error('ifftshift: dimension DIM must be a positive integer')
        nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:49
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:50
        sz2=floor(sz[dim] / 2)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:51
        idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:52
        idx[dim]=cat(arange(sz2 + 1,sz[dim]),arange(1,sz2))
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:53
        retval=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:54
    else:
        if (isvector(x)):
            xl=length(x)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:57
            xx=floor(xl / 2)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:58
            retval=x[cat(arange(xx + 1,xl),arange(1,xx))]
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:59
        else:
            nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:61
            sz=size(x)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:62
            sz2=floor(sz / 2)
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:63
            idx=cell()
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:64
            for i in arange(1,nd).reshape(-1):
                idx[i]=cat(arange(sz2[i] + 1,sz[i]),arange(1,sz2[i]))
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:66
            retval=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/signal/ifftshift.m:68
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test N-dimensional input (bug #45207)
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{lm}] =} arch_test (@var{y}, @var{x}, @var{p})
## For a linear regression model
##
## @example
## y = x * b + e
## @end example
##
## @noindent
## perform a Lagrange Multiplier (LM) test of the null hypothesis of no
## conditional heteroscedascity against the alternative of CH(@var{p}).
##
## I.e., the model is
##
## @example
## y(t) = b(1) * x(t,1) + @dots{} + b(k) * x(t,k) + e(t),
## @end example
##
## @noindent
## given @var{y} up to @math{t-1} and @var{x} up to @math{t},
## @math{e}(t) is @math{N(0, h(t))} with
##
## @example
## h(t) = v + a(1) * e(t-1)^2 + @dots{} + a(p) * e(t-p)^2,
## @end example
##
## @noindent
## and the null is @math{a(1)} == @dots{} == @math{a(p)} == 0.
##
## If the second argument is a scalar integer, @math{k}, perform the same
## test in a linear autoregression model of order @math{k}, i.e., with
##
## @example
## [1, y(t-1), @dots{}, y(t-@var{k})]
## @end example
##
## @noindent
## as the @math{t}-th row of @var{x}.
##
## Under the null, LM approximately has a chisquare distribution with
## @var{p} degrees of freedom and @var{pval} is the @math{p}-value (1
## minus the CDF of this distribution at LM) of the test.
##
## If no output argument is given, the @math{p}-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test for conditional heteroscedascity
    
    
@function
def arch_test(y=None,x=None,p=None,*args,**kwargs):
    varargin = arch_test.varargin
    nargin = arch_test.nargin

    if (nargin != 3):
        error('arch_test: 3 input arguments required')
    
    if (logical_not((isvector(y)))):
        error('arch_test: Y must be a vector')
    
    T=length(y)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:77
    y=reshape(y,T,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:78
    rx,cx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:79
    if ((rx == 1) and (cx == 1)):
        x=autoreg_matrix(y,x)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:81
    else:
        if (logical_not((rx == T))):
            error('arch_test: either rows (X) == length (Y), or X is a scalar')
    
    if (logical_not((isscalar(p) and (rem(p,1) == 0) and (p > 0)))):
        error('arch_test: P must be a positive integer')
    
    b,v_b,e=ols(y,x,nargout=3)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:89
    Z=autoreg_matrix(e ** 2,p)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:90
    f=e ** 2 / v_b - ones(T,1)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:91
    f=dot(Z.T,f)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:92
    lm=dot(dot(f.T,inv(dot(Z.T,Z))),f) / 2
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:93
    pval=1 - chi2cdf(lm,p)
# /home/lei/octave-4.0.2/scripts/signal/arch_test.m:94
    return pval,lm
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{y} =} filter2 (@var{b}, @var{x})
## @deftypefnx {Function File} {@var{y} =} filter2 (@var{b}, @var{x}, @var{shape})
## Apply the 2-D FIR filter @var{b} to @var{x}.
##
## If the argument @var{shape} is specified, return an array of the desired
## shape.  Possible values are:
##
## @table @asis
## @item @qcode{"full"}
## pad @var{x} with zeros on all sides before filtering.
##
## @item @qcode{"same"}
## unpadded @var{x} (default)
##
## @item @qcode{"valid"}
## trim @var{x} after filtering so edge effects are no included.
## @end table
##
## Note this is just a variation on convolution, with the parameters reversed
## and @var{b} rotated 180 degrees.
## @seealso{conv2}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
## 2001-02-08
##    * initial release
    
    
@function
def filter2(b=None,x=None,shape=None,*args,**kwargs):
    varargin = filter2.varargin
    nargin = filter2.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (nargin < 3):
        shape='same'
# /home/lei/octave-4.0.2/scripts/signal/filter2.m:53
    
    nr,nc=size(b,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/filter2.m:56
    y=conv2(x,b[nr:- 1:1,nc:- 1:1],shape)
# /home/lei/octave-4.0.2/scripts/signal/filter2.m:57
    return y
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rectangle_sw (@var{n}, @var{b})
## Rectangular spectral window.  Subfunction used for spectral density
## estimation.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Rectangular spectral window
    
    
@function
def rectangle_sw(n=None,b=None,*args,**kwargs):
    varargin = rectangle_sw.varargin
    nargin = rectangle_sw.nargin

    retval=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_sw.m:30
    retval[1]=2 / b + 1
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_sw.m:31
    l=(arange(2,n)).T - 1
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_sw.m:33
    l=dot(dot(2,pi),l) / n
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_sw.m:34
    retval[2:n]=sin(dot((2 / b + 1),l) / 2) / sin(l / 2)
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_sw.m:36
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} triangle_sw (@var{n}, @var{b})
## Triangular spectral window.  Subfunction used for spectral density
## estimation.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Triangular spectral window
    
    
@function
def triangle_sw(n=None,b=None,*args,**kwargs):
    varargin = triangle_sw.varargin
    nargin = triangle_sw.nargin

    retval=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_sw.m:30
    retval[1]=1 / b
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_sw.m:31
    l=(arange(2,n)).T - 1
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_sw.m:33
    l=dot(dot(2,pi),l) / n
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_sw.m:34
    retval[2:n]=dot(b,(sin(l / (dot(2,b))) / sin(l / 2)) ** 2)
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_sw.m:36
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} triangle_lw (@var{n}, @var{b})
## Triangular lag window.  Subfunction used for spectral density
## estimation.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Triangular lag window
    
    
@function
def triangle_lw(n=None,b=None,*args,**kwargs):
    varargin = triangle_lw.varargin
    nargin = triangle_lw.nargin

    retval=1 - dot((arange(0,n - 1)).T,b)
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_lw.m:30
    retval=max(cat([retval.T],[(zeros(1,n))])).T
# /home/lei/octave-4.0.2/scripts/signal/private/triangle_lw.m:31
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} rectangle_lw (@var{n}, @var{b})
## Rectangular lag window.  Subfunction used for spectral density
## estimation.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Rectangular lag window
    
    
@function
def rectangle_lw(n=None,b=None,*args,**kwargs):
    varargin = rectangle_lw.varargin
    nargin = rectangle_lw.nargin

    retval=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_lw.m:30
    t=floor(1 / b)
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_lw.m:31
    retval[1:t,1]=ones(t,1)
# /home/lei/octave-4.0.2/scripts/signal/private/rectangle_lw.m:33
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} sinetone (@var{freq}, @var{rate}, @var{sec}, @var{ampl})
## Return a sinetone of frequency @var{freq} with a length of @var{sec}
## seconds at sampling rate @var{rate} and with amplitude @var{ampl}.
##
## The arguments @var{freq} and @var{ampl} may be vectors of common size.
##
## The defaults are @var{rate} = 8000, @var{sec} = 1, and @var{ampl} = 64.
## @seealso{sinewave}
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Compute a sine tone
    
    
@function
def sinetone(freq=None,rate=8000,sec=1,ampl=64,*args,**kwargs):
    varargin = sinetone.varargin
    nargin = sinetone.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    err,freq,ampl=common_size(freq,ampl,nargout=3)
# /home/lei/octave-4.0.2/scripts/signal/sinetone.m:39
    if (err or logical_not(isvector(freq))):
        error('sinetone: FREQ and AMPL must be vectors of common size')
    
    if (logical_not((isscalar(rate) and isscalar(sec)))):
        error('sinetone: RATE and SEC must be scalars')
    
    n=length(freq)
# /home/lei/octave-4.0.2/scripts/signal/sinetone.m:48
    ns=round(dot(rate,sec))
# /home/lei/octave-4.0.2/scripts/signal/sinetone.m:49
    retval=zeros(ns,n)
# /home/lei/octave-4.0.2/scripts/signal/sinetone.m:51
    for k in arange(1,n).reshape(-1):
        retval[:,k]=dot(ampl[k],sin(dot(dot(dot(2,pi),(arange(1,ns))) / rate,freq[k])).T)
# /home/lei/octave-4.0.2/scripts/signal/sinetone.m:54
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
## Copyright (C) 2010 Alois Schloegl
## Copyright (C) 2014-2015 Drew Abbot
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{Pxx}, @var{w}] =} periodogram (@var{x})
## @deftypefnx {Function File} {[@var{Pxx}, @var{w}] =} periodogram (@var{x}, @var{win})
## @deftypefnx {Function File} {[@var{Pxx}, @var{w}] =} periodogram (@var{x}, @var{win}, @var{nfft})
## @deftypefnx {Function File} {[@var{Pxx}, @var{f}] =} periodogram (@var{x}, @var{win}, @var{nfft}, @var{Fs})
## @deftypefnx {Function File} {[@var{Pxx}, @var{f}] =} periodogram (@dots{}, "@var{range}")
## @deftypefnx {Function File} {} periodogram (@dots{})
## Return the periodogram (Power Spectral Density) of @var{x}.
##
## The possible inputs are:
##
## @table @var
## @item x
##
## data vector.  If @var{x} is real-valued a one-sided spectrum is estimated.
## If @var{x} is complex-valued, or @qcode{"@var{range}"} specifies
## @qcode{"@nospell{twosided}"}, the full spectrum is estimated.
##
## @item win
## window weight data.  If window is empty or unspecified a default rectangular
## window is used.  Otherwise, the window is applied to the signal
## (@code{@var{x} .* @var{win}}) before computing the periodogram.  The window
## data must be a vector of the same length as @var{x}.
##
## @item nfft
## number of frequency bins.  The default is 256 or the next higher power of
## 2 greater than the length of @var{x}
## (@code{max (256, 2.^nextpow2 (length (x)))}).  If @var{nfft} is greater
## than the length of the input then @var{x} will be zero-padded to the length
## of @var{nfft}.
##
## @item Fs
## sampling rate.  The default is 1.
##
## @item range
## range of spectrum.  @qcode{"@nospell{onesided}"} computes spectrum from
## [0..nfft/2+1].  @qcode{"@nospell{twosided}"} computes spectrum from
## [0..nfft-1].
## @end table
##
## The optional second output @var{w} are the normalized angular frequencies.
## For a one-sided calculation @var{w} is in the range [0, pi] if @var{nfft}
## is even and [0, pi) if @var{nfft} is odd.  Similarly, for a two-sided
## calculation @var{w} is in the range [0, 2*pi] or [0, 2*pi) depending on
## @var{nfft}.
##
## If a sampling frequency is specified, @var{Fs}, then the output frequencies
## @var{f} will be in the range [0, @var{Fs}/2] or [0, @var{Fs}/2) for
## one-sided calculations.  For two-sided calculations the range will be
## [0, @var{Fs}).
##
## When called with no outputs the periodogram is immediately plotted in the
## current figure window.
## @seealso{fft}
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Compute the periodogram
    
    
@function
def periodogram(x=None,varargin=None,*args,**kwargs):
    varargin = periodogram.varargin
    nargin = periodogram.nargin

    ## check input arguments
    if (nargin < 1 or nargin > 5):
        print_usage()
    
    nfft=fs=range_=window=matlabarray([])
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:87
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:87
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:87
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:87
    j=2
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:88
    for k in arange(1,length(varargin)).reshape(-1):
        if (ischar(varargin[k])):
            range_=varargin[k]
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:91
        else:
            if 2 == (j):
                window=varargin[k]
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:95
            else:
                if 3 == (j):
                    nfft=varargin[k]
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:97
                else:
                    if 4 == (j):
                        fs=varargin[k]
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:99
            j
    
    if (logical_not(isvector(x))):
        error('periodogram: X must be a real or complex vector')
    
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:108
    
    n=rows(x)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:110
    if (logical_not(isempty(window))):
        if (logical_not(isvector(window)) or length(window) != n):
            error('periodogram: WIN must be a vector of the same length as X')
        window=ravel(window)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:116
        x * window
    
    if (isempty(nfft)):
        nfft=max(256,2.0 ** nextpow2(n))
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:121
    else:
        if (logical_not(isscalar(nfft))):
            error('periodogram: NFFT must be a scalar')
    
    use_w_freq=isempty(fs)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:126
    if (logical_not(use_w_freq) and logical_not(isscalar(fs))):
        error('periodogram: FS must be a scalar')
    
    if (strcmpi(range_,'onesided')):
        range_=1
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:132
    else:
        if (strcmpi(range_,'twosided')):
            range_=2
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:134
        else:
            if (strcmpi(range_,'centered')):
                error('periodogram: "centered" range type is not implemented')
            else:
                range_=2 - isreal(x)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:138
    
    ## compute periodogram
    
    if (n > nfft):
        Pxx=0
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:144
        rr=rem(length(x),nfft)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:145
        if (rr):
            x=matlabarray(cat([ravel(x)],[zeros(nfft - rr,1)]))
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:147
        x=sum(reshape(x,nfft,[]),2)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:149
    
    if (logical_not(isempty(window))):
        n=sumsq(window)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:153
    
    Pxx=(abs(fft(x,nfft))) ** 2 / n
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:155
    if (use_w_freq):
        Pxx /= dot(2,pi)
    else:
        Pxx /= fs
    
    ## generate output arguments
    
    if (range_ == 1):
        if (logical_not(rem(nfft,2))):
            psd_len=nfft / 2 + 1
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:167
            Pxx=Pxx[1:psd_len] + cat([0],[Pxx[nfft:- 1:psd_len + 1]],[0])
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:168
        else:
            psd_len=(nfft + 1) / 2
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:170
            Pxx=Pxx[1:psd_len] + cat([0],[Pxx[nfft:- 1:psd_len + 1]])
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:171
    
    if (nargout != 1):
        if (range_ == 1):
            f=(arange(0,nfft / 2)).T / nfft
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:177
        else:
            if (range_ == 2):
                f=(arange(0,nfft - 1)).T / nfft
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:179
        if (use_w_freq):
            f *= dot(2,pi)
        else:
            f *= fs
    
    if (nargout == 0):
        if (use_w_freq):
            plot(f / (dot(2,pi)),dot(10,log10(Pxx)))
            xlabel('normalized frequency [x pi rad]')
            ylabel('Power density [dB/rad/sample]')
        else:
            plot(f,dot(10,log10(Pxx)))
            xlabel('frequency [Hz]')
            ylabel('Power density [dB/Hz]')
        grid('on')
        title('Periodogram Power Spectral Density Estimate')
    else:
        pxx=copy(Pxx)
# /home/lei/octave-4.0.2/scripts/signal/periodogram.m:201
    
    return pxx,f
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Need some functional tests
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{d}, @var{dd}] =} diffpara (@var{x}, @var{a}, @var{b})
## Return the estimator @var{d} for the differencing parameter of an
## integrated time series.
##
## The frequencies from @math{[2*pi*a/t, 2*pi*b/T]} are used for the
## estimation.  If @var{b} is omitted, the interval
## @math{[2*pi/T, 2*pi*a/T]} is used.  If both @var{b} and @var{a} are omitted
## then @math{a = 0.5 * sqrt (T)} and @math{b = 1.5 * sqrt (T)} is used, where
## @math{T} is the sample size.  If @var{x} is a matrix, the differencing
## parameter of each column is estimated.
##
## The estimators for all frequencies in the intervals described above is
## returned in @var{dd}.
##
## The value of @var{d} is simply the mean of @var{dd}.
##
## Reference: @nospell{P.J. Brockwell & R.A. Davis}. @cite{Time Series:
## Theory and Methods}. Springer 1987.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Estimate the fractional differencing parameter
    
    
@function
def diffpara(x=None,a=None,b=None,*args,**kwargs):
    varargin = diffpara.varargin
    nargin = diffpara.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (isvector(x)):
        n=length(x)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:50
        k=1
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:51
        x=reshape(x,n,1)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:52
    else:
        n,k=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:54
    
    if (nargin == 1):
        a=dot(0.5,sqrt(n))
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:57
        b=dot(1.5,sqrt(n))
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:58
    else:
        if (nargin == 2):
            b=copy(a)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:60
            a=1
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:61
    
    if (logical_not((isscalar(a) and isscalar(b)))):
        error('diffpara: A and B must be scalars')
    
    dd=zeros(b - a + 1,k)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:68
    for l in arange(1,k).reshape(-1):
        w=dot(dot(2,pi),(arange(1,n - 1))) / n
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:72
        x=dot(2,log(abs(1 - exp(dot(- i,w)))))
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:74
        y=log(periodogram(x[2:n,l]))
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:75
        x=center(x)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:77
        y=center(y)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:78
        for m in arange(a,b).reshape(-1):
            dd[m - a + 1]=dot(- x[1:m],y[1:m]) / sumsq(x[1:m])
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:81
    
    d=mean(dd)
# /home/lei/octave-4.0.2/scripts/signal/diffpara.m:86
    return d,dd
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} durbinlevinson (@var{c}, @var{oldphi}, @var{oldv})
## Perform one step of the @nospell{Durbin-Levinson} algorithm.
##
## The vector @var{c} specifies the autocovariances
## @code{[gamma_0, @dots{}, gamma_t]} from lag 0 to @var{t}, @var{oldphi}
## specifies the coefficients based on @var{c}(@var{t}-1) and @var{oldv}
## specifies the corresponding error.
##
## If @var{oldphi} and @var{oldv} are omitted, all steps from 1 to @var{t} of
## the algorithm are performed.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Perform one step of the Durbin-Levinson algorithm
    
    
@function
def durbinlevinson(c=None,oldphi=None,oldv=None,*args,**kwargs):
    varargin = durbinlevinson.varargin
    nargin = durbinlevinson.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (columns(c) > 1):
        c=c.T
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:42
    
    newphi=0
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:45
    newv=0
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:46
    if (nargin == 3):
        t=length(oldphi) + 1
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:50
        if (length(c) < t + 1):
            error('durbinlevinson: C too small')
        if (oldv == 0):
            error('durbinlevinson: OLDV = 0')
        if (rows(oldphi) > 1):
            oldphi=oldphi.T
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:61
        newphi=zeros(1,t)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:64
        newphi[1]=(c[t + 1] - dot(oldphi,c[2:t])) / oldv
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:65
        for i in arange(2,t).reshape(-1):
            newphi[i]=oldphi[i - 1] - dot(newphi[1],oldphi[t - i + 1])
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:67
        newv=dot((1 - newphi[1] ** 2),oldv)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:69
    else:
        if (nargin == 1):
            tt=length(c) - 1
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:73
            oldphi=c[2] / c[1]
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:74
            oldv=dot((1 - oldphi ** 2),c[1])
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:75
            for t in arange(2,tt).reshape(-1):
                newphi=zeros(1,t)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:79
                newphi[1]=(c[t + 1] - dot(oldphi,c[2:t])) / oldv
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:80
                for i in arange(2,t).reshape(-1):
                    newphi[i]=oldphi[i - 1] - dot(newphi[1],oldphi[t - i + 1])
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:82
                newv=dot((1 - newphi[1] ** 2),oldv)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:84
                oldv=copy(newv)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:86
                oldphi=copy(newphi)
# /home/lei/octave-4.0.2/scripts/signal/durbinlevinson.m:87
    
    return newphi,newv
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} blackman (@var{m})
## @deftypefnx {Function File} {} blackman (@var{m}, "periodic")
## @deftypefnx {Function File} {} blackman (@var{m}, "symmetric")
## Return the filter coefficients of a Blackman window of length @var{m}.
##
## If the optional argument @qcode{"periodic"} is given, the periodic form
## of the window is returned.  This is equivalent to the window of length
## @var{m}+1 with the last coefficient removed.  The optional argument
## @qcode{"symmetric"} is equivalent to not specifying a second argument.
##
## For a definition of the Blackman window, see, e.g.,
## @nospell{A.V. Oppenheim & R. W. Schafer},
## @cite{Discrete-Time Signal Processing}.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Coefficients of the Blackman window
    
    
@function
def blackman(m=None,opt=None,*args,**kwargs):
    varargin = blackman.varargin
    nargin = blackman.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isscalar(m) and (m == fix(m)) and (m > 0)))):
        error('blackman: M must be a positive integer')
    
    N=m - 1
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:48
    if (nargin == 2):
        if 'periodic' == (opt):
            N=copy(m)
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:52
        else:
            if 'symmetric' == (opt):
                ## Default option, same as no option specified.
                pass
            else:
                error('blackman: window type must be either "periodic" or "symmetric"')
    
    if (m == 1):
        c=1
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:61
    else:
        m=m - 1
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:63
        k=(arange(0,m)).T / N
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:64
        c=0.42 - dot(0.5,cos(dot(dot(2,pi),k))) + dot(0.08,cos(dot(dot(4,pi),k)))
# /home/lei/octave-4.0.2/scripts/signal/blackman.m:65
    
    return c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fftconv (@var{x}, @var{y})
## @deftypefnx {Function File} {} fftconv (@var{x}, @var{y}, @var{n})
## Convolve two vectors using the FFT for computation.
##
## @code{c = fftconv (@var{x}, @var{y})} returns a vector of length equal to
## @code{length (@var{x}) + length (@var{y}) - 1}.  If @var{x} and @var{y}
## are the coefficient vectors of two polynomials, the returned value is the
## coefficient vector of the product polynomial.
##
## The computation uses the FFT by calling the function @code{fftfilt}.  If
## the optional argument @var{n} is specified, an N-point FFT is used.
## @seealso{deconv, conv, conv2}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 3 September 1994
## Adapted-By: jwe
    
    
@function
def fftconv(x=None,y=None,n=None,*args,**kwargs):
    varargin = fftconv.varargin
    nargin = fftconv.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('fftconv: both A and B must be vectors')
    
    la=length(x)
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:47
    lb=length(y)
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:48
    if ((la == 1) or (lb == 1)):
        c=dot(x,y)
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:50
    else:
        lc=la + lb - 1
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:52
        x[lc]=0
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:53
        y[lc]=0
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:54
        if (nargin == 2):
            c=fftfilt(x,y)
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:56
        else:
            if (logical_not(isscalar(n))):
                error('fftconv: N must be a scalar')
            c=fftfilt(x,y,n)
# /home/lei/octave-4.0.2/scripts/signal/fftconv.m:61
    
    return c
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Borrow tests from conv.m.  May need tolerance on the assert stmt.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} spectral_xdf (@var{x})
## @deftypefnx {Function File} {} spectral_xdf (@var{x}, @var{win})
## @deftypefnx {Function File} {} spectral_xdf (@var{x}, @var{win}, @var{b})
## Return the spectral density estimator given a data vector @var{x}, window
## name @var{win}, and bandwidth, @var{b}.
##
## The window name, e.g., @qcode{"triangle"} or @qcode{"rectangle"} is used to
## search for a function called @code{@var{win}_sw}.
##
## If @var{win} is omitted, the triangle window is used.
##
## If @var{b} is omitted, @code{1 / sqrt (length (@var{x}))} is used.
## @seealso{spectral_adf}
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Spectral density estimation
    
    
@function
def spectral_xdf(x=None,win=None,b=None,*args,**kwargs):
    varargin = spectral_xdf.varargin
    nargin = spectral_xdf.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    xr=length(x)
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:44
    if (columns(x) > 1):
        x=x.T
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:47
    
    if (nargin < 3):
        b=1 / ceil(sqrt(xr))
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:51
    
    if (nargin == 1):
        w=triangle_sw(xr,b)
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:55
    else:
        if (logical_not(ischar(win))):
            error('spectral_xdf: WIN must be a string')
        else:
            win=str2func(cat(win,'_sw'))
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:59
            w=feval(win,xr,b)
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:60
    
    x=x - sum(x) / xr
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:63
    retval=(abs(fft(x)) / xr) ** 2
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:65
    retval=real(ifft(multiply(fft(retval),fft(w))))
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:66
    retval=matlabarray(cat((zeros(xr,1)),retval))
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:68
    retval[:,1]=(arange(0,xr - 1)).T / xr
# /home/lei/octave-4.0.2/scripts/signal/spectral_xdf.m:69
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} fractdiff (@var{x}, @var{d})
## Compute the fractional differences @math{(1-L)^d x} where @math{L}
## denotes the lag-operator and @math{d} is greater than -1.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Compute fractional differences
    
    
@function
def fractdiff(x=None,d=None,*args,**kwargs):
    varargin = fractdiff.varargin
    nargin = fractdiff.nargin

    if (nargin != 2):
        print_usage()
    
    N=100
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:34
    if (logical_not(isvector(x))):
        error('fractdiff: X must be a vector')
    
    if (logical_not(isscalar(d))):
        error('fractdiff: D must be a scalar')
    
    if (d >= 1):
        for k in arange(1,d).reshape(-1):
            x=x[2:length(x)] - x[1:length(x) - 1]
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:47
    
    if (d > - 1):
        d=rem(d,1)
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:53
        if (d != 0):
            n=(arange(0,N)).T
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:56
            w=real(gamma(- d + n) / gamma(- d) / gamma(n + 1))
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:57
            retval=fftfilt(w,x)
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:58
            retval=retval[1:length(x)]
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:59
        else:
            retval=copy(x)
# /home/lei/octave-4.0.2/scripts/signal/fractdiff.m:61
    else:
        error('fractdiff: D must be > -1')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} autoreg_matrix (@var{y}, @var{k})
## Given a time series (vector) @var{y}, return a matrix with ones in the first
## column and the first @var{k} lagged values of @var{y} in the other columns.
##
## In other words, for @var{t} > @var{k},
## @code{[1, @var{y}(@var{t}-1), @dots{}, @var{y}(@var{t}-@var{k})]} is the
## t-th row of the result.
##
## The resulting matrix may be used as a regressor matrix in autoregressions.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Design matrix for autoregressions
    
    
@function
def autoreg_matrix(y=None,k=None,*args,**kwargs):
    varargin = autoreg_matrix.varargin
    nargin = autoreg_matrix.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isvector(y)))):
        error('autoreg_matrix: Y must be a vector')
    
    T=length(y)
# /home/lei/octave-4.0.2/scripts/signal/autoreg_matrix.m:44
    y=reshape(y,T,1)
# /home/lei/octave-4.0.2/scripts/signal/autoreg_matrix.m:45
    X=ones(T,k + 1)
# /home/lei/octave-4.0.2/scripts/signal/autoreg_matrix.m:46
    for j in arange(1,k).reshape(-1):
        X[:,j + 1]=cat([(zeros(j,1))],[y[1:T - j]])
# /home/lei/octave-4.0.2/scripts/signal/autoreg_matrix.m:48
    
    return X
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{a}, @var{v}] =} yulewalker (@var{c})
## Fit an AR (p)-model with Yule-Walker estimates given a vector @var{c} of
## autocovariances @code{[gamma_0, @dots{}, gamma_p]}.
##
## Returns the AR coefficients, @var{a}, and the variance of white noise,
## @var{v}.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Fit AR model by Yule-Walker method
    
    
@function
def yulewalker(c=None,*args,**kwargs):
    varargin = yulewalker.varargin
    nargin = yulewalker.nargin

    if (nargin != 1):
        print_usage()
    
    p=length(c) - 1
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:37
    if (columns(c) > 1):
        c=c.T
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:40
    
    cp=c[2:p + 1]
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:43
    CP=zeros(p,p)
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:44
    for i in arange(1,p).reshape(-1):
        for j in arange(1,p).reshape(-1):
            CP[i,j]=c[abs(i - j) + 1]
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:48
    
    a=dot(inv(CP),cp)
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:52
    v=c[1] - dot(a.T,cp)
# /home/lei/octave-4.0.2/scripts/signal/yulewalker.m:53
    return a,v
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Andreas Weingessel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hamming (@var{m})
## @deftypefnx {Function File} {} hamming (@var{m}, "periodic")
## @deftypefnx {Function File} {} hamming (@var{m}, "symmetric")
## Return the filter coefficients of a Hamming window of length @var{m}.
##
## If the optional argument @qcode{"periodic"} is given, the periodic form
## of the window is returned.  This is equivalent to the window of length
## @var{m}+1 with the last coefficient removed.  The optional argument
## @qcode{"symmetric"} is equivalent to not specifying a second argument.
##
## For a definition of the Hamming window see, e.g.,
## @nospell{A.V. Oppenheim & R. W. Schafer},
## @cite{Discrete-Time Signal Processing}.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Description: Coefficients of the Hamming window
    
    
@function
def hamming(m=None,opt=None,*args,**kwargs):
    varargin = hamming.varargin
    nargin = hamming.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isscalar(m) and (m == fix(m)) and (m > 0)))):
        error('hamming: M must be a positive integer')
    
    N=m - 1
# /home/lei/octave-4.0.2/scripts/signal/hamming.m:48
    if (nargin == 2):
        if 'periodic' == (opt):
            N=copy(m)
# /home/lei/octave-4.0.2/scripts/signal/hamming.m:52
        else:
            if 'symmetric' == (opt):
                ## Default option, same as no option specified.
                pass
            else:
                error('hamming: window type must be either "periodic" or "symmetric"')
    
    if (m == 1):
        c=1
# /home/lei/octave-4.0.2/scripts/signal/hamming.m:61
    else:
        m=m - 1
# /home/lei/octave-4.0.2/scripts/signal/hamming.m:63
        c=0.54 - dot(0.46,cos(dot(dot(2,pi),(arange(0,m)).T) / N))
# /home/lei/octave-4.0.2/scripts/signal/hamming.m:64
    
    return c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} savepath ()
## @deftypefnx {Function File} {} savepath (@var{file})
## @deftypefnx {Function File} {@var{status} =} savepath (@dots{})
## Save the unique portion of the current function search path that is
## not set during Octave's initialization process to @var{file}.
##
## If @var{file} is omitted, Octave looks in the current directory for a
## project-specific @file{.octaverc} file in which to save the path
## information.  If no such file is present then the user's configuration file
## @file{~/.octaverc} is used.
##
## If successful, @code{savepath} returns 0.
##
## The @code{savepath} function makes it simple to customize a user's
## configuration file to restore the working paths necessary for a particular
## instance of Octave.  Assuming no filename is specified, Octave will
## automatically restore the saved directory paths from the appropriate
## @file{.octaverc} file when starting up.  If a filename has been specified
## then the paths may be restored manually by calling @code{source @var{file}}.
## @seealso{path, addpath, rmpath, genpath, pathdef}
## @end deftypefn
    
    ## Author: Bill Denney <bill@givebillmoney.com>
    
    
@function
def savepath(file=None,*args,**kwargs):
    varargin = savepath.varargin
    nargin = savepath.nargin

    beginstring='## Begin savepath auto-created section, do not edit'
# /home/lei/octave-4.0.2/scripts/path/savepath.m:46
    endstring='## End savepath auto-created section'
# /home/lei/octave-4.0.2/scripts/path/savepath.m:47
    
    if (nargin == 0):
        file=fullfile(pwd,'.octaverc')
# /home/lei/octave-4.0.2/scripts/path/savepath.m:51
        if (logical_not(exist(file,'file'))):
            file=fullfile('~','.octaverc')
# /home/lei/octave-4.0.2/scripts/path/savepath.m:53
    
    ## Read in the file
    filelines,startline,endline=getsavepath(file,nargout=3)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:58
    
    if (isempty(filelines) or (startline == 1 and endline == length(filelines))):
        ## savepath is the entire file.
        pre=post=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:64
# /home/lei/octave-4.0.2/scripts/path/savepath.m:64
    else:
        if (endline == 0):
            ## Drop the savepath statements at the end of the file.
            pre=copy(filelines)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:67
            post=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:68
        else:
            if (startline == 1):
                pre=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:70
                post=filelines[endline + 1:end()]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:71
            else:
                if (endline == length(filelines)):
                    pre=filelines[1:startline - 1]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:73
                    post=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:74
                else:
                    ## Insert in the middle.
                    pre=filelines[1:startline - 1]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:77
                    post=filelines[endline + 1:end()]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:78
    
    ## Write the results.
    fid,msg=fopen(file,'wt',nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:82
    if (fid < 0):
        error('savepath: unable to open file for writing, %s, %s',file,msg)
    
    try:
        fprintf(fid,'%s\n',pre[:])
        ## and/or the environment.
        workingpath=parsepath(path)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:91
        cmd_line_path=parsepath(command_line_path())
# /home/lei/octave-4.0.2/scripts/path/savepath.m:92
        octave_path=parsepath(getenv('OCTAVE_PATH'))
# /home/lei/octave-4.0.2/scripts/path/savepath.m:93
        default_path=pathdef()
# /home/lei/octave-4.0.2/scripts/path/savepath.m:94
        if (isempty(default_path)):
            ## This occurs when running octave via run-octave.  In this instance
      ## the entire path is specified via the command line and pathdef()
      ## is empty.
            __,n=setdiff(workingpath,octave_path,nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:99
            default_path=copy(cmd_line_path)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:100
        else:
            __,n=setdiff(workingpath,union(cmd_line_path,octave_path),nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:102
            default_path=parsepath(default_path)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:103
        ## This is the path we'd like to preserve when octave is run.
        path_to_preserve=workingpath[sort(n)]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:106
        pkg_user,pkg_system=pkg('list',nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:109
        pkg_path=unique(cellfun(lambda elt=None: elt.archprefix,cat(pkg_user,pkg_system),'uniformoutput',false))
# /home/lei/octave-4.0.2/scripts/path/savepath.m:112
        if (logical_not(isempty(pkg_path))):
            __,n=setdiff(path_to_preserve,strcat(pkg_path,':'),nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:118
            path_to_preserve=path_to_preserve[sort(n)]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:119
        ## Split the path to be saved into two groups.  Those path elements that
    ## belong at the beginning and those at the end.
        if (logical_not(isempty(default_path))):
            n1=find(strcmp(default_path[1],path_to_preserve))
# /home/lei/octave-4.0.2/scripts/path/savepath.m:125
            n2=find(strcmp(default_path[end()],path_to_preserve))
# /home/lei/octave-4.0.2/scripts/path/savepath.m:126
            n_middle=round((n1 + n2) / 2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:127
            __,n=setdiff(path_to_preserve,default_path,nargout=2)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:128
            path_to_save=path_to_preserve[sort(n)]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:129
            path_to_save[strcmp(path_to_save,cat('.',pathsep))]=[]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:131
            if (logical_not(isempty(path_to_save))):
                n=ones(numel(path_to_save),1)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:133
                for m in arange(1,numel(path_to_save)).reshape(-1):
                    n[m]=find(strcmp(path_to_save[m],path_to_preserve))
# /home/lei/octave-4.0.2/scripts/path/savepath.m:135
                path_to_save_begin=path_to_save[n <= n_middle]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:137
                path_to_save_end=path_to_save[n > n_middle]
# /home/lei/octave-4.0.2/scripts/path/savepath.m:138
            else:
                path_to_save_begin=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:140
                path_to_save_end=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:141
        else:
            path_to_save_begin=copy(path_to_preserve)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:144
            path_to_save_end=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/savepath.m:145
        path_to_save_begin=cell2mat(path_to_save_begin)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:147
        path_to_save_end=cell2mat(path_to_save_end)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:148
        ## processing.  Since we are using single quotes around the arg,
    ## double any single quote characters found in the string.
        fprintf(fid,'%s\n',beginstring)
        if (logical_not(isempty(path_to_save_begin))):
            n=find(path_to_save_begin != pathsep,1,'last')
# /home/lei/octave-4.0.2/scripts/path/savepath.m:155
            fprintf(fid,'  addpath (\'%s\', \'-begin\');\n',strrep(path_to_save_begin[1:n],'\'','\'\''))
        if (logical_not(isempty(path_to_save_end))):
            n=find(path_to_save_end != pathsep,1,'last')
# /home/lei/octave-4.0.2/scripts/path/savepath.m:160
            fprintf(fid,'  addpath (\'%s\', \'-end\');\n',strrep(path_to_save_end[1:n],'\'','\'\''))
        fprintf(fid,'%s\n',endstring)
        fprintf(fid,'%s\n',post[:])
    finally:
        status=fclose(fid)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:168
        if (status < 0):
            error('savepath: could not close savefile after writing, %s',file)
        else:
            if (nargin == 0):
                warning('off','backtrace','local')
                warning('Octave:savepath-local','savepath: current path saved to %s',file)
    
    if (nargout > 0):
        retval=0
# /home/lei/octave-4.0.2/scripts/path/savepath.m:179
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Convert single string of paths to cell array of paths
    
@function
def parsepath(p=None,*args,**kwargs):
    varargin = parsepath.varargin
    nargin = parsepath.nargin

    path_elements=strcat(ostrsplit(p,pathsep),pathsep)
# /home/lei/octave-4.0.2/scripts/path/savepath.m:186
    return path_elements
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} matlabroot ()
## Return the name of the top-level Octave installation directory.
##
## This is an alias for the function @w{@code{OCTAVE_HOME}} provided for
## compatibility.
## @seealso{OCTAVE_HOME}
## @end deftypefn
    
    
@function
def matlabroot(*args,**kwargs):
    varargin = matlabroot.varargin
    nargin = matlabroot.nargin

    retval=copy(OCTAVE_HOME)
# /home/lei/octave-4.0.2/scripts/path/matlabroot.m:30
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2014-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    
@function
def getsavepath(file=None,*args,**kwargs):
    varargin = getsavepath.varargin
    nargin = getsavepath.nargin

    beginstring='## Begin savepath auto-created section, do not edit'
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:21
    endstring='## End savepath auto-created section'
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:22
    
    startline=endline=0
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:25
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:25
    filelines=cellarray([])
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:26
    if (exist(file) == 2):
        fid,msg=fopen(file,'rt',nargout=2)
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:28
        if (fid < 0):
            error('getsavepath: could not open file, %s: %s',file,msg)
        linenum=0
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:32
        while (ischar(line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:33)):

            filelines[++ linenum]=line
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:34
            if (strcmp(line,beginstring)):
                startline=copy(linenum)
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:37
            else:
                if (strcmp(line,endstring)):
                    endline=copy(linenum)
# /home/lei/octave-4.0.2/scripts/path/private/getsavepath.m:39

        if (fclose(fid) < 0):
            error('getsavepath: could not close file after reading, %s',file)
    
    ## Verify the file was correctly formatted.
    if (startline > endline or (startline > 0 and endline == 0)):
        error('getsavepath: unable to parse file, %s',file)
    
    return filelines,startline,endline
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2015 Mike Miller
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} soundsc (@var{y})
## @deftypefnx {Function File} {} soundsc (@var{y}, @var{fs})
## @deftypefnx {Function File} {} soundsc (@var{y}, @var{fs}, @var{nbits})
## @deftypefnx {Function File} {} soundsc (@dots{}, [@var{ymin}, @var{ymax}])
## Scale the audio data @var{y} and play it at sample rate @var{fs} to the
## default audio device.
##
## The audio signal @var{y} can be a vector or a two-column array, representing
## mono or stereo audio, respectively.
##
## If @var{fs} is not given, a default sample rate of 8000 samples per second
## is used.
##
## The optional argument @var{nbits} specifies the bit depth to play to the
## audio device and defaults to 8 bits.
##
## By default, @var{y} is automatically normalized to the range [-1, 1].  If the
## range [@var{ymin}, @var{ymax}] is given, then elements of @var{y} that fall
## within the range @var{ymin} @leq{} @var{y} @leq{} @var{ymax} are scaled to
## the range [-1, 1] instead.
##
## For more control over audio playback, use the @code{audioplayer} class.
## @seealso{sound, record}
## @end deftypefn
    
    
@function
def soundsc(y=None,fs=None,nbits=None,yrange=None,*args,**kwargs):
    varargin = soundsc.varargin
    nargin = soundsc.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (nargin < 4):
        yrange=matlabarray([])
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:52
    
    if (nargin < 2 or isempty(fs)):
        fs=8000
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:56
    else:
        if (nargin == 2 and numel(fs) > 1):
            yrange=copy(fs)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:58
            fs=8000
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:59
        else:
            if (logical_not((isscalar(fs) and (fs > 0)))):
                error('soundsc: sample rate FS must be a positive number')
    
    if (nargin < 3 or isempty(nbits)):
        nbits=8
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:65
    else:
        if (nargin == 3 and numel(nbits) > 1):
            yrange=copy(nbits)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:67
            nbits=8
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:68
        else:
            if (logical_not((isscalar(nbits) and (nbits == 8 or nbits == 16 or nbits == 24)))):
                error('soundsc: bit depth NBITS must be 8, 16, or 24')
    
    if (isreal(yrange) and (numel(yrange) == 2) and (yrange[1] <= yrange[2])):
        ymin=yrange[1]
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:74
        ymax=yrange[2]
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:75
    else:
        if (isempty(yrange)):
            ymin=min(ravel(y))
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:77
            ymax=max(ravel(y))
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:78
        else:
            error('soundsc: audio range must be a 2-element [YMIN, YMAX] vector')
    
    ymin=double(ymin)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:83
    ymax=double(ymax)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:84
    ymedian=(ymax + ymin) / 2
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:85
    yscale=2 / (ymax - ymin)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:86
    y=multiply((double(y) - ymedian),yscale)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:88
    play=audioplayer(y,fs,nbits)
# /home/lei/octave-4.0.2/scripts/audio/soundsc.m:90
    playblocking(play)
    return
    
if __name__ == '__main__':
    pass
    
    ## Tests of soundsc must not actually play anything.
    
    ## Test input validation
    
    ## Copyright (C) 2015 Mike Miller
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} sound (@var{y})
## @deftypefnx {Function File} {} sound (@var{y}, @var{fs})
## @deftypefnx {Function File} {} sound (@var{y}, @var{fs}, @var{nbits})
## Play audio data @var{y} at sample rate @var{fs} to the default audio
## device.
##
## The audio signal @var{y} can be a vector or a two-column array, representing
## mono or stereo audio, respectively.
##
## If @var{fs} is not given, a default sample rate of 8000 samples per second
## is used.
##
## The optional argument @var{nbits} specifies the bit depth to play to the
## audio device and defaults to 8 bits.
##
## For more control over audio playback, use the @code{audioplayer} class.
## @seealso{soundsc, record}
## @end deftypefn
    
    
@function
def sound(y=None,fs=None,nbits=None,*args,**kwargs):
    varargin = sound.varargin
    nargin = sound.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin < 2 or isempty(fs)):
        fs=8000
# /home/lei/octave-4.0.2/scripts/audio/sound.m:46
    else:
        if (logical_not((isscalar(fs) and (fs > 0)))):
            error('sound: sample rate FS must be a positive number')
    
    if (nargin < 3 or isempty(nbits)):
        nbits=8
# /home/lei/octave-4.0.2/scripts/audio/sound.m:52
    else:
        if (logical_not((isscalar(nbits) and (nbits == 8 or nbits == 16 or nbits == 24)))):
            error('sound: bit depth NBITS must be 8, 16, or 24')
    
    play=audioplayer(y,fs,nbits)
# /home/lei/octave-4.0.2/scripts/audio/sound.m:57
    playblocking(play)
    return
    
if __name__ == '__main__':
    pass
    
    ## Tests of sound must not actually play anything.
    
    ## Test input validation
    
    ## Copyright (C) 2015 Mike Miller
## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} record (@var{sec})
## @deftypefnx {Function File} {} record (@var{sec}, @var{fs})
## Record @var{sec} seconds of audio from the system's default audio input at
## a sampling rate of 8000 samples per second.
##
## If the optional argument @var{fs} is given, it specifies the sampling rate
## for recording.
##
## For more control over audio recording, use the @code{audiorecorder} class.
## @seealso{sound, soundsc}
## @end deftypefn
    
    
@function
def record(sec=None,fs=None,*args,**kwargs):
    varargin = record.varargin
    nargin = record.nargin

    if (nargin == 1):
        fs=8000
# /home/lei/octave-4.0.2/scripts/audio/record.m:36
    else:
        if (nargin != 2):
            print_usage()
    
    if (logical_not((isscalar(sec) and (sec >= 0)))):
        error('record: recording duration SEC must be a non-negative number')
    
    if (logical_not((isscalar(fs) and (fs > 0)))):
        error('record: sample rate FS must be a positive number')
    
    x=matlabarray([])
# /home/lei/octave-4.0.2/scripts/audio/record.m:49
    if (sec > 0):
        rec=audiorecorder(fs,16,1)
# /home/lei/octave-4.0.2/scripts/audio/record.m:53
        recordblocking(rec,sec)
        x=getaudiodata(rec)
# /home/lei/octave-4.0.2/scripts/audio/record.m:57
    
    return x
    
if __name__ == '__main__':
    pass
    
    ## Tests of record must not actually record anything.
    
    
    ## Test input validation
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} pause (@var{player})
## Pause the audioplayer @var{player}.
## @end deftypefn
    
    
@function
def pause(player=None,*args,**kwargs):
    varargin = pause.varargin
    nargin = pause.nargin

    if (nargin != 1):
        print_usage()
    
    __player_pause__(struct(player).player)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{value} =} subsasgn (@var{player}, @var{idx}, @var{rhs})
## Perform subscripted assignment on the audio player object @var{player}.
##
## Assign the value of @var{rhs} to the player property named by @var{idx}.
## @end deftypefn
    
    
@function
def subsasgn(player=None,idx=None,rhs=None,*args,**kwargs):
    varargin = subsasgn.varargin
    nargin = subsasgn.nargin

    if (isempty(idx)):
        error('audioplayer: missing index')
    
    if (strcmp(idx[1].type,'.')):
        field=idx.subs
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/subsasgn.m:33
        set(player,field,rhs)
        value=copy(player)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/subsasgn.m:35
    else:
        error('@audioplayer/subsasgn: invalid subscript type')
    
    return value
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} play (@var{player})
## @deftypefnx {Function File} {} play (@var{player}, @var{start})
## @deftypefnx {Function File} {} play (@var{player}, @var{limits})
## Play audio stored in the audioplayer object @var{player} without blocking.
##
## Given optional argument start, begin playing at @var{start} seconds in the
## recording.  Given a two-element vector @var{limits}, begin and end playing
## at the number of seconds specified by the elements of the vector.
## @end deftypefn
    
    
@function
def play(varargin=None,*args,**kwargs):
    varargin = play.varargin
    nargin = play.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    __player_play__(struct(varargin[1]).player,varargin[2:end()])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} display (@var{player})
## Display the properties of the audioplayer object @var{player}.
## @end deftypefn
    
    
@function
def display(player=None,*args,**kwargs):
    varargin = display.varargin
    nargin = display.nargin

    if (nargin != 1):
        print_usage()
    
    disp(__get_properties__(player))
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{player} =} audioplayer (@var{y}, @var{fs})
## @deftypefnx {Function File} {@var{player} =} audioplayer (@var{y}, @var{fs}, @var{nbits})
## @deftypefnx {Function File} {@var{player} =} audioplayer (@var{y}, @var{fs}, @var{nbits}, @var{id})
## @deftypefnx {Function File} {@var{player} =} audioplayer (@var{recorder})
## @deftypefnx {Function File} {@var{player} =} audioplayer (@var{recorder}, @var{id})
## Create an audioplayer object that will play back data @var{y} at sample
## rate @var{fs}.
##
## The optional arguments @var{nbits}, and @var{id} specify the bit depth and
## player device id, respectively.  Device IDs may be found using the
## audiodevinfo function.  Given an audioplayer object, use the data from the
## object to initialize the player.
##
## The signal @var{y} can be a vector or a two-dimensional array.
##
## The following example will create an audioplayer object that will play
## back one second of white noise at 44100 sample rate using 8 bits per
## sample.
##
## @example
## @group
## y = randn (2, 44100) - 0.5;
## player = audioplayer (y, 44100, 8);
## play (player);
## @end group
## @end example
## @end deftypefn
    
    ## FIXME: callbacks don't work properly, apparently because portaudio
## will execute the callbacks in a separate thread, and calling Octave
## functions in a separate thread which is likely to cause trouble with
## all of Octave's global data...
##
## @deftypefnx {Function File} {@var{player} =} audioplayer (@var{function}, @dots{})
##
## Given a function handle, use that function to process the audio.
    
    ## The following example will create and register a callback that generates
## a sine wave on both channels.
##
## @example
## @group
## function [ sound, status ] = callback_sine (frames)
##   global lphase = 0.0;
##   global rphase = 0.0;
##   incl = 440.0 / 44100.0;
##   incr = 443.0 / 44100.0;
##   nl = incl * frames;
##   nr = incr * frames;
##   left = sin (2.0 * pi * [lphase:incl:lphase+nl]);
##   right = sin (2.0 * pi * [rphase:incr:rphase+nr]);
##   sound = [left', right'];
##   status = 0;
##   lphase = lphase + nl;
##   rphase = rphase + nr;
## endfunction
## player = audioplayer (@@callback_sine, 44100);
## play (player);
## # play for as long as you want
## stop (player);
## @end group
    
    
@function
def audioplayer(varargin=None,*args,**kwargs):
    varargin = audioplayer.varargin
    nargin = audioplayer.nargin

    if (nargin < 1 or nargin > 4 or (nargin < 2 and (isa(varargin[1],'function_handle') or ischar(varargin[1])))):
        print_usage()
    
    if (isa(varargin[1],'audiorecorder')):
        if (nargin == 1):
            player=getplayer(varargin[1])
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:92
        else:
            if (nargin == 2):
                recorder=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:94
                data=getaudiodata(recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:95
                player=audioplayer(data,get(recorder,'SampleRate'),get(recorder,'BitsPerSample'),varargin[2])
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:96
            else:
                print_usage()
    else:
        if (ischar(varargin[1])):
            varargin[1]=str2func(varargin[1])
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:103
        player.player = copy(__player_audioplayer__(varargin[:]))
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:105
        player=class_(player,'audioplayer')
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/audioplayer.m:106
    
    return player
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests of audioplayer must not actually play anything.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##!function [sound, status] = callback (samples)
##!  sound = rand (samples, 2) - 0.5;
##!  status = 0;
##!endfunction
    
    ##!testif HAVE_PORTAUDIO
##! player = audioplayer (@callback, 44100);
##! play (player);
##! sleep (2);
##! stop (player);
##! assert (1);
    
    ##!testif HAVE_PORTAUDIO
##! player = audioplayer ("callback", 44100, 16);
##! play (player);
##! sleep (2);
##! stop (player);
##! assert (1);
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{properties} =} __get_properties__ (@var{player})
## Return a struct containing all named properties of the audioplayer object
## @var{player}.
## @end deftypefn
    
    
@function
def __get_properties__(player=None,*args,**kwargs):
    varargin = __get_properties__.varargin
    nargin = __get_properties__.nargin

    if (nargin != 1):
        print_usage()
    
    if (__player_isplaying__(struct(player).player)):
        running='on'
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/__get_properties__.m:32
    else:
        running='off'
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/__get_properties__.m:34
    
    props=struct('BitsPerSample',__player_get_nbits__(struct(player).player),'CurrentSample',__player_get_sample_number__(struct(player).player),'DeviceID',__player_get_id__(struct(player).player),'NumberOfChannels',__player_get_channels__(struct(player).player),'Running',running,'SampleRate',__player_get_fs__(struct(player).player),'TotalSamples',__player_get_total_samples__(struct(player).player),'Tag',__player_get_tag__(struct(player).player),'Type','audioplayer','UserData',__player_get_userdata__(struct(player).player))
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/__get_properties__.m:37
    return props
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{value} =} subsref (@var{player}, @var{idx})
## Perform subscripted selection on the audio player object @var{player}.
##
## Return the player property value named by @var{idx}.
## @end deftypefn
    
    
@function
def subsref(player=None,idx=None,*args,**kwargs):
    varargin = subsref.varargin
    nargin = subsref.nargin

    if (nargin != 2):
        print_usage()
    
    if (isempty(idx)):
        error('@audioplayer/subsref: missing index')
    
    if (strcmp(idx[1].type,'.')):
        field=idx.subs
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/subsref.m:36
        value=get(player,field)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/subsref.m:37
    else:
        error('@audioplayer/subsref: invalid subscript type')
    
    return value
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} stop (@var{player})
## Stop the playback for the audioplayer @var{player} and reset the
## relevant variables to their starting values.
## @end deftypefn
    
    
@function
def stop(player=None,*args,**kwargs):
    varargin = stop.varargin
    nargin = stop.nargin

    if (nargin != 1):
        print_usage()
    
    __player_stop__(struct(player).player)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isplaying (@var{player})
## Return true if the audioplayer object @var{player} is currently playing back
## audio and false otherwise.
## @end deftypefn
    
    
@function
def isplaying(player=None,*args,**kwargs):
    varargin = isplaying.varargin
    nargin = isplaying.nargin

    if (nargin != 1):
        print_usage()
    
    result=__player_isplaying__(struct(player).player)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/isplaying.m:31
    return result
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} playblocking (@var{player})
## @deftypefnx {Function File} {} playblocking (@var{player}, @var{start})
## @deftypefnx {Function File} {} playblocking (@var{player}, @var{limits})
## Play audio stored in the audioplayer object @var{player} with blocking.
##
## Given optional argument start, begin playing at @var{start} seconds in the
## recording.  Given a two-element vector @var{limits}, begin and end playing
## at the number of seconds specified by the elements of the vector.
## @end deftypefn
    
    
@function
def playblocking(varargin=None,*args,**kwargs):
    varargin = playblocking.varargin
    nargin = playblocking.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    __player_playblocking__(struct(varargin[1]).player,varargin[2:end()])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{value} =} get (@var{player}, @var{name})
## @deftypefnx {Function File} {@var{values} =} get (@var{player})
## Return the @var{value} of the property identified by @var{name}.
##
## If @var{name} is a cell array return the values of the properties
## identified by the elements of the cell array.  Given only the player
## object, return a scalar structure with values of all properties of
## @var{player}.  The field names of the structure correspond to property
## names.
## @end deftypefn
    
    
@function
def get(varargin=None,*args,**kwargs):
    varargin = get.varargin
    nargin = get.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    properties=__get_properties__(varargin[1])
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:37
    if (nargin == 1):
        retval=copy(properties)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:40
    else:
        if (nargin == 2):
            pnames=varargin[2]
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:42
            if (ischar(pnames)):
                retval=getfield(properties,pnames)
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:44
            else:
                if (iscellstr(pnames)):
                    retval=cell(size(pnames))
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:46
                    for i in arange(1,numel(pnames)).reshape(-1):
                        retval[i]=getfield(properties,pnames[i])
# /home/lei/octave-4.0.2/scripts/audio/@audioplayer/get.m:48
                else:
                    error('@audioplayer/get: invalid name argument')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} resume (@var{player})
## Resume playback for the paused audioplayer object @var{player}.
## @end deftypefn
    
    
@function
def resume(player=None,*args,**kwargs):
    varargin = resume.varargin
    nargin = resume.nargin

    if (nargin != 1):
        print_usage()
    
    __player_resume__(struct(player).player)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2015 Mike Miller
## Copyright (C) 2005-2015 Michael Zeising
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} wavwrite (@var{y}, @var{filename})
## @deftypefnx {Function File} {} wavwrite (@var{y}, @var{fs}, @var{filename})
## @deftypefnx {Function File} {} wavwrite (@var{y}, @var{fs}, @var{nbits}, @var{filename})
## Write the audio signal @var{y} to the RIFF/WAVE sound file @var{filename}.
##
## If @var{y} is a matrix, the columns represent multiple audio channels.
##
## The optional argument @var{fs} specifies the sample rate of the audio signal
## in Hz.
##
## The optional argument @var{nbits} specifies the number of bits per sample
## to write to @var{filename}.
##
## The default sample rate is 8000 Hz and the default bit depth is 16 bits
## per sample.
##
## @seealso{audiowrite, audioread, wavread}
## @end deftypefn
    
    
@function
def wavwrite(y=None,varargin=None,*args,**kwargs):
    varargin = wavwrite.varargin
    nargin = wavwrite.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    ## Defaults.
    fs=8000
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:47
    nbits=16
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:48
    filename=varargin[end()]
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:50
    if (nargin > 2):
        fs=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:52
        if (nargin > 3):
            nbits=varargin[2]
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:54
    
    ## calculate filesize
    n,channels=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:59
    
    if (n == 1):
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:63
        n=copy(channels)
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:64
        channels=1
# /home/lei/octave-4.0.2/scripts/audio/wavwrite.m:65
    
    ## test arguments
    if (channels < 1):
        error('wavwrite: Y must have at least one column')
    
    if (channels > 32767):
        error('wavwrite: Y must have no more than 32767 columns')
    
    if (logical_not((isscalar(fs) and (fs > 0)))):
        error('wavwrite: sample rate FS must be a positive number')
    
    if (logical_not(isscalar(nbits)) or isempty(find(nbits == cat(8,16,24,32)))):
        error('wavwrite: bit depth NBITS must be 8, 16, 24, or 32')
    
    audiowrite(filename,y,fs,'BitsPerSample',nbits)
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} lin2mu (@var{x}, @var{n})
## Convert audio data from linear to mu-law.
##
## Mu-law values use 8-bit unsigned integers.  Linear values use @var{n}-bit
## signed integers or floating point values in the range -1 @leq{} @var{x}
## @leq{} 1 if @var{n} is 0.
##
## If @var{n} is not specified it defaults to 0, 8, or 16 depending on
## the range of values in @var{x}.
## @seealso{mu2lin}
## @end deftypefn
    
    ## Author: Andreas Weingessel <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 17 October 1994
## Adapted-By: jwe
    
    
@function
def lin2mu(x=None,n=None,*args,**kwargs):
    varargin = lin2mu.varargin
    nargin = lin2mu.nargin

    if (nargin == 1):
        range_=max(abs(ravel(x)))
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:40
        if (range_ <= 1):
            n=0
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:42
        else:
            if (range_ <= 128):
                n=8
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:44
                warning('lin2mu: no precision specified, so using %d',n)
            else:
                n=16
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:47
    else:
        if (nargin == 2):
            if (n != 0 and n != 8 and n != 16):
                error('lin2mu: N must be either 0, 8 or 16')
        else:
            print_usage()
    
    ## Transform real and n-bit format to 16-bit.
    if (n == 0):
        ## [-1,1] -> [-32768, 32768]
        x=dot(32768,x)
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:60
    else:
        if (n != 16):
            x=multiply(2 ** (16 - n),x)
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:62
    
    ## Determine sign of x, set sign(0) = 1.
    sig=sign(x) + (x == 0)
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:66
    
    ## add bias.
    x=min(abs(x),32635) + 132
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:70
    
    f,e=log2(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:73
    y=dot(64,sig) - dot(16,e) - fix(dot(32,f)) + 335
# /home/lei/octave-4.0.2/scripts/audio/lin2mu.m:75
    return y
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} mu2lin (@var{x}, @var{n})
## Convert audio data from mu-law to linear.
##
## Mu-law values are 8-bit unsigned integers.  Linear values use @var{n}-bit
## signed integers or floating point values in the range -1@leq{}y@leq{}1 if
## @var{n} is 0.
##
## If @var{n} is not specified it defaults to 0.
## @seealso{lin2mu}
## @end deftypefn
    
    ## Author:  Andreas Weingessel <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 18 October 1994
## Adapted-By: jwe
    
    
@function
def mu2lin(x=None,n=0,*args,**kwargs):
    varargin = mu2lin.varargin
    nargin = mu2lin.nargin

    if (nargin == 2):
        if (n != 0 and n != 8 and n != 16):
            error('mu2lin: N must be either 0, 8, or 16')
    else:
        if (nargin != 1):
            print_usage()
    
    ulaw=matlabarray(cat(32124,31100,30076,29052,28028,27004,25980,24956,23932,22908,21884,20860,19836,18812,17788,16764,15996,15484,14972,14460,13948,13436,12924,12412,11900,11388,10876,10364,9852,9340,8828,8316,7932,7676,7420,7164,6908,6652,6396,6140,5884,5628,5372,5116,4860,4604,4348,4092,3900,3772,3644,3516,3388,3260,3132,3004,2876,2748,2620,2492,2364,2236,2108,1980,1884,1820,1756,1692,1628,1564,1500,1436,1372,1308,1244,1180,1116,1052,988,924,876,844,812,780,748,716,684,652,620,588,556,524,492,460,428,396,372,356,340,324,308,292,276,260,244,228,212,196,180,164,148,132,120,112,104,96,88,80,72,64,56,48,40,32,24,16,8,0))
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:45
    ulaw=matlabarray(cat(- ulaw,ulaw))
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:62
    
    ## ulaw of x.
    y=copy(x)
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:66
    ravel[y]=ulaw[x + 1]
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:67
    
    if (n == 0):
        ## [ -32768, 32767 ] -> [ -1, 1)
        y=y / 32768
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:72
    else:
        if (n == 8):
            ld=max(abs(ravel(y)))
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:74
            if (ld < 16384 and ld > 0):
                sc=64 / ld
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:76
            else:
                sc=1 / 256
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:78
            y=fix(dot(y,sc))
# /home/lei/octave-4.0.2/scripts/audio/mu2lin.m:80
    
    return y
    
if __name__ == '__main__':
    pass
    
    (nargin == 3)
    if (iscell(varargin[2])):
        index=1
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/set.m:50
        for property in varargin[2].reshape(-1):
            setproperty(recorder,char(property),varargin[3][index])
            index=index + 1
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/set.m:53
    else:
        setproperty(recorder,varargin[2],varargin[3])
    
    
    return settable
    
if __name__ == '__main__':
    pass
    
    
@function
def setproperty(recorder=None,property=None,value=None,*args,**kwargs):
    varargin = setproperty.varargin
    nargin = setproperty.nargin

    if 'SampleRate' == (property):
        __recorder_set_fs__(recorder,value)
    else:
        if 'Tag' == (property):
            __recorder_set_tag__(recorder,value)
        else:
            if 'UserData' == (property):
                __recorder_set_userdata__(recorder,value)
            else:
                error('@audiorecorder/set: no such property or the property specified is read-only')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} pause (@var{recorder})
## Pause recording with audiorecorder object @var{recorder}.
## @end deftypefn
    
    
@function
def pause(recorder=None,*args,**kwargs):
    varargin = pause.varargin
    nargin = pause.nargin

    if (nargin != 1):
        print_usage()
    
    __recorder_pause__(struct(recorder).recorder)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{value} =} subsasgn (@var{recorder}, @var{idx}, @var{rhs})
## Perform subscripted assignment on the audio recorder object @var{recorder}.
##
## Assign the value of @var{rhs} to the recorder property named by @var{idx}.
## @end deftypefn
    
    
@function
def subsasgn(recorder=None,idx=None,rhs=None,*args,**kwargs):
    varargin = subsasgn.varargin
    nargin = subsasgn.nargin

    if (nargin != 3):
        print_usage()
    
    if (isempty(idx)):
        error('@audiorecorder/subsasgn: missing index')
    
    if (strcmp(idx[1].type,'.')):
        field=idx.subs
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/subsasgn.m:36
        set(recorder,field,rhs)
        value=copy(recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/subsasgn.m:38
    else:
        error('@audiorecorder/subsasgn: invalid subscript type')
    
    return value
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{player} =} play (@var{recorder})
## @deftypefnx {Function File} {@var{player} =} play (@var{recorder}, @var{start})
## @deftypefnx {Function File} {@var{player} =} play (@var{recorder}, [@var{start}, @var{end}])
## Play the audio recorded in @var{recorder} and return a corresponding
## audioplayer object.
##
## If the optional argument @var{start} is provided, begin playing
## @var{start} seconds in to the recording.
##
## If the optional argument @var{end} is provided, stop playing at
## @var{end} seconds in the recording.
## @end deftypefn
    
    
@function
def play(varargin=None,*args,**kwargs):
    varargin = play.varargin
    nargin = play.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    recorder=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/play.m:39
    data=getaudiodata(recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/play.m:40
    player=audioplayer(data,get(recorder,'SampleRate'),get(recorder,'BitsPerSample'))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/play.m:41
    if (nargin == 1):
        play(player)
    else:
        play(player,varargin[2])
    
    return player
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} recordblocking (@var{recorder}, @var{length})
## Record audio with blocking (synchronous I/O).
##
## The length of the recording in seconds (@var{length}) must be specified.
## @end deftypefn
    
    
@function
def recordblocking(varargin=None,*args,**kwargs):
    varargin = recordblocking.varargin
    nargin = recordblocking.nargin

    if (nargin != 2):
        print_usage()
    
    __recorder_recordblocking__(struct(varargin[1]).recorder,varargin[2])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{recorder} =} audiorecorder ()
## @deftypefnx {Function File} {@var{recorder} =} audiorecorder (@var{fs}, @var{nbits}, @var{channels})
## @deftypefnx {Function File} {@var{recorder} =} audiorecorder (@var{fs}, @var{nbits}, @var{channels}, @var{id})
## Create an audiorecorder object recording 8 bit mono audio at 8000 Hz
## sample rate.
##
## The optional arguments @var{fs}, @var{nbits}, @var{channels}, and @var{id}
## specify the sample rate, bit depth, number of channels and recording
## device id, respectively.  Device IDs may be found using the audiodevinfo
## function.
## @end deftypefn
    
    ## FIXME: callbacks don't work properly, apparently because portaudio
## will execute the callbacks in a separate thread, and calling Octave
## functions in a separate thread which is likely to cause trouble with
## all of Octave's global data...
##
## @deftypefnx {Function File} {@var{recorder} =} audiorecorder (@var{function}, @dots{})
##
## Given a function handle, use that function to process the audio.
    
    
@function
def audiorecorder(varargin=None,*args,**kwargs):
    varargin = audiorecorder.varargin
    nargin = audiorecorder.nargin

    if (nargin > 5):
        print_usage()
    
    if (nargin > 0 and ischar(varargin[1])):
        varargin[1]=str2func(varargin[1])
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/audiorecorder.m:48
    
    recorder.recorder = copy(__recorder_audiorecorder__(varargin[:]))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/audiorecorder.m:51
    recorder=class_(recorder,'audiorecorder')
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/audiorecorder.m:52
    return recorder
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Tests of audiorecorder must not actually record anything.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##!function status = callback_record (sound)
##!  fid = fopen ("record.txt", "at");
##!  for index = 1:rows(sound)
##!    fprintf (fid, "#.4f, #.4f\n", sound(index, 1), sound(index, 2));
##!  endfor
##!  fclose (fid);
##!  status = 0;
##!endfunction
    
    ##!testif HAVE_PORTAUDIO
##! recorder = audiorecorder (@callback_record, 44100);
##! unlink ("record.txt")
##! record (recorder);
##! sleep (2);
##! stop (recorder);
##! s = stat ("record.txt");
##! assert (s.size > 0);
    
    ##!testif HAVE_PORTAUDIO
##! recorder = audiorecorder (@callback_record, 44100);
##! unlink ("record.txt")
##! record (recorder);
##! sleep (2);
##! stop (recorder);
##! s = stat ("record.txt");
##! assert (s.size > 0);
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} display (@var{recorder})
## Display the properties of the audiorecorder object @var{recorder}.
## @end deftypefn
    
    
@function
def display(recorder=None,*args,**kwargs):
    varargin = display.varargin
    nargin = display.nargin

    if (nargin != 1):
        print_usage()
    
    disp(__get_properties__(recorder))
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} record (@var{recorder})
## @deftypefnx {Function File} {} record (@var{recorder}, @var{length})
## Record audio without blocking using the audiorecorder object
## @var{recorder} until stopped or paused by the @var{stop} or @var{pause}
## method.
##
## Given the optional argument @var{length}, record for @var{length} seconds.
## @end deftypefn
    
    
@function
def record(varargin=None,*args,**kwargs):
    varargin = record.varargin
    nargin = record.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    __recorder_record__(struct(varargin[1]).recorder,varargin[2:end()])
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{player} =} getplayer (@var{recorder})
## Return an audioplayer object with data recorded by the audiorecorder object
## @var{recorder}.
## @end deftypefn
    
    
@function
def getplayer(varargin=None,*args,**kwargs):
    varargin = getplayer.varargin
    nargin = getplayer.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    recorder=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getplayer.m:31
    data=getaudiodata(recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getplayer.m:32
    player=audioplayer(data,get(recorder,'SampleRate'),get(recorder,'BitsPerSample'))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getplayer.m:33
    return player
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{properties} =} __get_properties__ (@var{recorder})
## Return a struct containing all named properties of the recorder object
## @var{recorder}.
## @end deftypefn
    
    
@function
def __get_properties__(recorder=None,*args,**kwargs):
    varargin = __get_properties__.varargin
    nargin = __get_properties__.nargin

    if (nargin != 1):
        print_usage()
    
    if (__recorder_isrecording__(struct(recorder).recorder)):
        running='on'
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/__get_properties__.m:32
    else:
        running='off'
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/__get_properties__.m:34
    
    props=struct('BitsPerSample',__recorder_get_nbits__(struct(recorder).recorder),'CurrentSample',__recorder_get_sample_number__(struct(recorder).recorder),'DeviceID',__recorder_get_id__(struct(recorder).recorder),'NumberOfChannels',__recorder_get_channels__(struct(recorder).recorder),'Running',running,'SampleRate',__recorder_get_fs__(struct(recorder).recorder),'TotalSamples',__recorder_get_total_samples__(struct(recorder).recorder),'Tag',__recorder_get_tag__(struct(recorder).recorder),'Type','audiorecorder','UserData',__recorder_get_userdata__(struct(recorder).recorder))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/__get_properties__.m:37
    return props
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{value} =} subsref (@var{recorder}, @var{idx})
## Perform subscripted selection on the audio recorder object @var{recorder}.
##
## Return the recorder property value named by @var{idx}.
## @end deftypefn
    
    
@function
def subsref(recorder=None,idx=None,*args,**kwargs):
    varargin = subsref.varargin
    nargin = subsref.nargin

    if (nargin != 2):
        print_usage()
    
    if (isempty(idx)):
        error('@audiorecorder/subsref: missing index')
    
    if (strcmp(idx[1].type,'.')):
        field=idx.subs
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/subsref.m:37
        value=get(recorder,field)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/subsref.m:38
    else:
        error('@audiorecorder/subsref: invalid subscript type')
    
    return value
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} stop (@var{recorder})
## Stop the audiorecorder object @var{recorder} and clean up any audio streams.
## @end deftypefn
    
    
@function
def stop(recorder=None,*args,**kwargs):
    varargin = stop.varargin
    nargin = stop.nargin

    if (nargin != 1):
        print_usage()
    
    __recorder_stop__(struct(recorder).recorder)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{data} =} getaudiodata (@var{recorder})
## @deftypefnx {Function File} {@var{data} =} getaudiodata (@var{recorder}, @var{datatype})
## Return recorder audio data as a matrix with values between -1.0 and 1.0
## and with as many columns as there are channels in the recorder.
##
## Given the optional argument @var{datatype}, convert the recorded data
## to the specified type, which may be one of @qcode{"double"},
## @qcode{"single"}, @qcode{"int16"}, @qcode{"int8"} or @qcode{"uint8"}.
## @end deftypefn
    
    
@function
def getaudiodata(varargin=None,*args,**kwargs):
    varargin = getaudiodata.varargin
    nargin = getaudiodata.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    recorder=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:36
    if (nargin == 1):
        data=__recorder_getaudiodata__(struct(recorder).recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:39
    else:
        data=__recorder_getaudiodata__(struct(recorder).recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:41
        type_=varargin[2]
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:42
        if 'int16' == (type_):
            data=int16(dot(data,(2.0 ** 15)))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:45
        else:
            if 'int8' == (type_):
                data=int8(dot(data,(2.0 ** 7)))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:47
            else:
                if 'uint8' == (type_):
                    data=uint8(dot(dot((data + 1.0),0.5),(2.0 ** 8 - 1)))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:49
    
    if (get(recorder,'NumberOfChannels') == 2):
        data=data.T
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:54
    else:
        data=data[1,:].T
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/getaudiodata.m:56
    
    return data
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isrecording (@var{recorder})
## Return true if the audiorecorder object @var{recorder} is currently recording
## audio and false otherwise.
## @end deftypefn
    
    
@function
def isrecording(recorder=None,*args,**kwargs):
    varargin = isrecording.varargin
    nargin = isrecording.nargin

    if (nargin != 1):
        print_usage()
    
    result=__recorder_isrecording__(struct(recorder).recorder)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/isrecording.m:31
    return result
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{value} =} get (@var{recorder}, @var{name})
## @deftypefnx {Function File} {@var{values} =} get (@var{recorder})
## Return the @var{value} of the property identified by @var{name}.
##
## If @var{name} is a cell array, return the values of the properties
## corresponding to the elements of the cell array.  Given only the recorder
## object, return a scalar structure with values of all properties of
## @var{recorder}.  The field names of the structure correspond to property
## names.
## @end deftypefn
    
    
@function
def get(varargin=None,*args,**kwargs):
    varargin = get.varargin
    nargin = get.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    properties=__get_properties__(varargin[1])
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:37
    if (nargin == 1):
        retval=copy(properties)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:40
    else:
        if (nargin == 2):
            pnames=varargin[2]
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:42
            if (ischar(pnames)):
                retval=getfield(properties,pnames)
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:44
            else:
                if (iscellstr(pnames)):
                    retval=cell(size(pnames))
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:46
                    for i in arange(1,numel(pnames)).reshape(-1):
                        retval[i]=getfield(properties,pnames[i])
# /home/lei/octave-4.0.2/scripts/audio/@audiorecorder/get.m:48
                else:
                    error('@audiorecorder/get: invalid name argument')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2013-2015 Vytautas Janauskas
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} resume (@var{recorder})
## Resume recording with the paused audiorecorder object @var{recorder}.
## @end deftypefn
    
    
@function
def resume(recorder=None,*args,**kwargs):
    varargin = resume.varargin
    nargin = resume.nargin

    if (nargin != 1):
        print_usage()
    
    __recorder_resume__(struct(recorder).recorder)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2015 Mike Miller
## Copyright (C) 2005-2015 Michael Zeising
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{y} =} wavread (@var{filename})
## @deftypefnx {Function File} {[@var{y}, @var{fs}, @var{nbits}] =} wavread (@var{filename})
## @deftypefnx {Function File} {[@dots{}] =} wavread (@var{filename}, @var{n})
## @deftypefnx {Function File} {[@dots{}] =} wavread (@var{filename}, [@var{n1} @var{n2}])
## @deftypefnx {Function File} {[@dots{}] =} wavread (@dots{}, @var{datatype})
## @deftypefnx {Function File} {@var{sz} =} wavread (@var{filename}, "size")
## @deftypefnx {Function File} {[@var{n_samp}, @var{n_chan}] =} wavread (@var{filename}, "size")
## Read the audio signal @var{y} from the RIFF/WAVE sound file @var{filename}.
##
## If the file contains multichannel data, then @var{y} is a matrix with the
## channels represented as columns.
##
## If @var{n} is specified, only the first @var{n} samples of the file are
## returned.  If [@var{n1} @var{n2}] is specified, only the range of samples
## from @var{n1} to @var{n2} is returned.  A value of @code{Inf} can be used
## to represent the total number of samples in the file.
##
## If the option @qcode{"size"} is given, then the size of the audio signal
## is returned instead of the data.  The size is returned in a row vector of
## the form [@var{samples} @var{channels}].  If there are two output arguments,
## the number of samples is assigned to the first and the number of channels
## is assigned to the second.
##
## The optional return value @var{fs} is the sample rate of the audio file in
## Hz.  The optional return value @var{nbits} is the number of bits per sample
## as encoded in the file.
##
## @seealso{audioread, audiowrite, wavwrite}
## @end deftypefn
    
    
@function
def wavread(filename=None,varargin=None,*args,**kwargs):
    varargin = wavread.varargin
    nargin = wavread.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(filename))):
        error('wavread: FILENAME must be a character string')
    
    datatype='double'
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:61
    samples=matlabarray(cat(1,Inf))
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:62
    do_file_size=copy(false)
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:63
    if (nargin == 3):
        samples=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:66
        datatype=varargin[2]
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:67
    else:
        if (nargin == 2):
            if (strcmp(varargin[1],'size')):
                do_file_size=copy(true)
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:70
            else:
                if (ischar(varargin[1])):
                    datatype=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:72
                else:
                    samples=varargin[1]
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:74
    
    if (isscalar(samples)):
        samples=matlabarray(cat(1,samples))
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:79
    
    if (logical_not((isrow(samples) and numel(samples) == 2 and all(samples > 0) and all(fix(samples) == samples)))):
        error('wavread: SAMPLES must be a 1- or 2-element integer row vector')
    
    if (logical_not((ischar(datatype) and any(strcmp(datatype,cellarray(['double','native'])))))):
        error('wavread: DATATYPE must be either "double" or "native"')
    
    info=audioinfo(filename)
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:91
    if (do_file_size):
        if (nargout > 1):
            y,fs=deal(info.TotalSamples,info.NumChannels,nargout=2)
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:95
        else:
            y=matlabarray(cat(info.TotalSamples,info.NumChannels))
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:97
    else:
        y,fs=audioread(filename,samples,datatype,nargout=2)
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:100
        nbits=info.BitsPerSample
# /home/lei/octave-4.0.2/scripts/audio/wavread.m:101
    
    return y,fs,nbits
    
if __name__ == '__main__':
    pass
    
    ## Functional tests for wavread/wavwrite pair are in wavwrite.m.
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} istriu (@var{A})
## Return true if @var{A} is an upper triangular matrix.
##
## An upper triangular matrix has nonzero entries only on the main diagonal and
## above.
## @seealso{isdiag, isbanded, istril, triu, bandwidth}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def istriu(A=None,*args,**kwargs):
    varargin = istriu.varargin
    nargin = istriu.nargin

    if (nargin != 1):
        print_usage()
    
    retval=(isnumeric(A) or islogical(A)) and ndims(A) == 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/istriu.m:36
    if (retval):
        i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/istriu.m:38
        retval=all(i <= j)
# /home/lei/octave-4.0.2/scripts/linear-algebra/istriu.m:39
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 Regents of the University of California
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{est}, @var{v}, @var{w}, @var{iter}] =} onenormest (@var{A}, @var{t})
## @deftypefnx {Function File} {[@var{est}, @var{v}, @var{w}, @var{iter}] =} onenormest (@var{apply}, @var{apply_t}, @var{n}, @var{t})
##
## Apply @nospell{Higham and Tisseur's} randomized block 1-norm estimator to
## matrix @var{A} using @var{t} test vectors.
##
## If @var{t} exceeds 5, then only 5 test vectors are used.
##
## If the matrix is not explicit, e.g., when estimating the norm of
## @code{inv (@var{A})} given an LU@tie{}factorization, @code{onenormest}
## applies @var{A} and its conjugate transpose through a pair of functions
## @var{apply} and @var{apply_t}, respectively, to a dense matrix of size
## @var{n} by @var{t}.  The implicit version requires an explicit dimension
## @var{n}.
##
## Returns the norm estimate @var{est}, two vectors @var{v} and @var{w} related
## by norm @code{(@var{w}, 1) = @var{est} * norm (@var{v}, 1)}, and the number
## of iterations @var{iter}.  The number of iterations is limited to 10 and is
## at least 2.
##
## References:
##
## @itemize
## @item
## @nospell{N.J. Higham and F. Tisseur}, @cite{A Block Algorithm
## for Matrix 1-Norm Estimation, with an Application to 1-Norm
## Pseudospectra}. SIMAX vol 21, no 4, pp 1185-1201.
## @url{http://dx.doi.org/10.1137/S0895479899356080}
##
## @item
## @nospell{N.J. Higham and F. Tisseur}, @cite{A Block Algorithm
## for Matrix 1-Norm Estimation, with an Application to 1-Norm
## Pseudospectra}. @url{http://citeseer.ist.psu.edu/223007.html}
## @end itemize
##
## @seealso{condest, norm, cond}
## @end deftypefn
    
    ## Code originally licensed under:
##
## Copyright (c) 2007, Regents of the University of California
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##    * Redistributions of source code must retain the above copyright
##      notice, this list of conditions and the following disclaimer.
##
##    * Redistributions in binary form must reproduce the above
##      copyright notice, this list of conditions and the following
##      disclaimer in the documentation and/or other materials provided
##      with the distribution.
##
##    * Neither the name of the University of California, Berkeley nor
##      the names of its contributors may be used to endorse or promote
##      products derived from this software without specific prior
##      written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
## AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
## PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND
## CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
## USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
## ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
## OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
## OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
## SUCH DAMAGE.
    
    ## Author: Jason Riedy <ejr@cs.berkeley.edu>
## Keywords: linear-algebra norm estimation
## Version: 0.2
    
    
@function
def onenormest(varargin=None,*args,**kwargs):
    varargin = onenormest.varargin
    nargin = onenormest.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    default_t=5
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:103
    itmax=10
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:104
    if (isnumeric(varargin[1])):
        n,nc=size(varargin[1],nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:107
        if (n != nc):
            error('onenormest: matrix must be square')
        apply=lambda x=None: dot(varargin[1],x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:111
        apply_t=lambda x=None: dot(varargin[1].T,x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:112
        if (nargin > 1):
            t=varargin[2]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:114
        else:
            t=min(n,default_t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:116
        issing=isa(varargin[1],'single')
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:118
    else:
        if (nargin < 3):
            print_usage()
        apply=varargin[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:123
        apply_t=varargin[2]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:124
        n=varargin[3]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:125
        if (nargin > 3):
            t=varargin[4]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:127
        else:
            t=copy(default_t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:129
        issing=isa(n,'single')
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:131
    
    ## Initial test vectors X.
    X=rand(n,t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:135
    X=X / (dot(ones(n,1),sum(abs(X),1)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:136
    
    been_there=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:139
    
    est_old=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:142
    
    S=zeros(n,t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:145
    if (issing):
        myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:148
        X=single(X)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:149
    else:
        myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:151
    
    for iter in arange(1,itmax + 1).reshape(-1):
        Y=feval(apply,X)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:155
        est,ind_best=max(sum(abs(Y),1),nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:158
        if (est > est_old or iter == 2):
            w=Y[:,ind_best]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:160
        if (iter >= 2 and est < est_old):
            ## No improvement, so stop.
            est=copy(est_old)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:164
            break
        est_old=copy(est)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:168
        S_old=copy(S)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:169
        if (iter > itmax):
            break
        S=sign(Y)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:175
        ## vectors or current S vectors.  If everything is parallel,
    ## stop.  Otherwise, replace any parallel vectors with
    ## rand{-1,+1}.
        partest=any(abs(dot(S_old.T,S) - n) < dot(dot(4,eps),n))
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:181
        if (all(partest)):
            ## All the current vectors are parallel to old vectors.
      ## We've hit a cycle, so stop.
            break
        if (any(partest)):
            ## Some vectors are parallel to old ones and are cycling,
      ## but not all of them.  Replace the parallel vectors with
      ## rand{-1,+1}.
            numpar=sum(partest)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:191
            replacements=dot(2,(rand(n,numpar) < 0.5)) - 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:192
            S[:,partest]=replacements
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:193
        ## Now test for parallel vectors within S.
        partest=any((dot(S.T,S) - eye(t)) == n)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:196
        if (any(partest)):
            numpar=sum(partest)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:198
            replacements=dot(2,(rand(n,numpar) < 0.5)) - 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:199
            S[:,partest]=replacements
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:200
        Z=feval(apply_t,S)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:203
        h=max(abs(Z),2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:206
        mh,mhi=max(h,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:207
        if (iter >= 2 and mhi == ind_best):
            ## Hit a cycle, stop.
            break
        h,ind=sort(h,'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:212
        if (t > 1):
            firstind=ind[1:t]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:214
            if (all(been_there[firstind])):
                ## Visited all these before, so stop.
                break
            ind=ind[logical_not(been_there[ind])]
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:219
            if (length(ind) < t):
                ## There aren't enough new vectors, so we're practically
        ## in a cycle.  Stop.
                break
        ## Visit the new indices.
        X=zeros(n,t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:228
        for zz in arange(1,t).reshape(-1):
            X[ind[zz],zz]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:230
        been_there[ind[1:t]]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:232
    
    ## The estimate est and vector w are set in the loop above.
  ## The vector v selects the ind_best column of A.
    v=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:237
    v[ind_best]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/onenormest.m:238
    return est,v,w,iter
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Only likely to be within a factor of 10.
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rref (@var{A})
## @deftypefnx {Function File} {} rref (@var{A}, @var{tol})
## @deftypefnx {Function File} {[@var{r}, @var{k}] =} rref (@dots{})
## Return the reduced row echelon form of @var{A}.
##
## @var{tol} defaults to
## @code{eps * max (size (@var{A})) * norm (@var{A}, inf)}.
##
## The optional return argument @var{k} contains the vector of
## "bound variables", which are those columns on which elimination has been
## performed.
##
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@users.sf.net>
##         (based on an anonymous source from the public domain)
    
    
@function
def rref(A=None,tol=None,*args,**kwargs):
    varargin = rref.varargin
    nargin = rref.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (ndims(A) > 2):
        error('rref: expecting matrix argument')
    
    rows,cols=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:47
    if (nargin < 2):
        if (isa(A,'single')):
            tol=dot(dot(eps('single'),max(rows,cols)),norm(A,inf('single')))
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:51
        else:
            tol=dot(dot(eps,max(rows,cols)),norm(A,inf))
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:53
    
    used=zeros(1,cols)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:57
    r=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:58
    for c in arange(1,cols).reshape(-1):
        ## Find the pivot row
        m,pivot=max(abs(A[r:rows,c]),nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:61
        pivot=r + pivot - 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:62
        if (m <= tol):
            ## Skip column c, making sure the approximately zero terms are
      ## actually zero.
            A[r:rows,c]=zeros(rows - r + 1,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:67
        else:
            ## keep track of bound variables
            used[1,c]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:70
            A[cat(pivot,r),c:cols]=A[cat(r,pivot),c:cols]
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:73
            A[r,c:cols]=A[r,c:cols] / A[r,c]
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:76
            ridx=matlabarray(cat(arange(1,r - 1),arange(r + 1,rows)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:79
            A[ridx,c:cols]=A[ridx,c:cols] - dot(A[ridx,c],A[r,c:cols])
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:80
            if (r == rows):
                break
    
    k=find(used)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rref.m:88
    return A,k
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} vech (@var{x})
## Return the vector obtained by eliminating all superdiagonal elements of
## the square matrix @var{x} and stacking the result one column above the
## other.
##
## This has uses in matrix calculus where the underlying matrix is symmetric
## and it would be pointless to keep values above the main diagonal.
## @seealso{vec}
## @end deftypefn
    
    ## See Magnus and Neudecker (1988), Matrix differential calculus with
## applications in statistics and econometrics.
    
    ## Author KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 8 May 1995
## Adapted-By: jwe
    
    
@function
def vech(x=None,*args,**kwargs):
    varargin = vech.varargin
    nargin = vech.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(issquare(x))):
        error('vech: X must be square')
    
    n=rows(x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/vech.m:48
    slices=cellslices(ravel(x),(arange(1,n)) + dot(n,(arange(0,n - 1))),dot(n,(arange(1,n))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/vech.m:49
    v=vertcat(slices[:])
# /home/lei/octave-4.0.2/scripts/linear-algebra/vech.m:50
    return v
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} trace (@var{A})
## Compute the trace of @var{A}, the sum of the elements along the main
## diagonal.
##
## The implementation is straightforward: @code{sum (diag (@var{A}))}.
## @seealso{eig}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def trace(A=None,*args,**kwargs):
    varargin = trace.varargin
    nargin = trace.nargin

    if (nargin != 1):
        print_usage()
    
    if (ndims(A) > 2):
        error('trace: only valid on 2-D objects')
    else:
        if (isempty(A)):
            y=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/trace.m:39
        else:
            if (isvector(A)):
                y=A[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/trace.m:41
            else:
                y=sum(diag(A))
# /home/lei/octave-4.0.2/scripts/linear-algebra/trace.m:43
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{bw} =} bandwidth (@var{A}, @var{type})
## @deftypefnx {Function File} {[@var{lower}, @var{upper}] =} bandwidth (@var{A})
## Compute the bandwidth of @var{A}.
##
## The @var{type} argument is the string @qcode{"lower"} for the lower
## bandwidth and @qcode{"upper"} for the upper bandwidth.  If no @var{type} is
## specified return both the lower and upper bandwidth of @var{A}.
##
## The lower/upper bandwidth of a matrix is the number of
## subdiagonals/superdiagonals with nonzero entries.
##
## @seealso{isbanded, isdiag, istril, istriu}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def bandwidth(A=None,type_=None,*args,**kwargs):
    varargin = bandwidth.varargin
    nargin = bandwidth.nargin

    if (logical_not(((nargin == 1 and nargout == 2) or (nargin == 2 and nargout <= 1)))):
        print_usage()
    
    if (logical_not(isnumeric(A)) and logical_not(islogical(A)) or ndims(A) != 2):
        error('bandwidth: A must be a 2-D numeric or logical matrix')
    else:
        if (nargin == 2 and logical_not((strcmp(type_,'lower') or strcmp(type_,'upper')))):
            error('bandwidth: TYPE must be "lower" or "upper"')
    
    if (nargin == 1):
        i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:49
        if (isempty(i)):
            lower=upper=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:51
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:51
        else:
            lower=max(i - j)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:53
            upper=max(j - i)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:54
    else:
        i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:57
        if (isempty(i)):
            lower=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:59
        else:
            if (strcmp(type_,'lower')):
                lower=max(i - j)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:61
            else:
                lower=max(j - i)
# /home/lei/octave-4.0.2/scripts/linear-algebra/bandwidth.m:63
    
    return lower,upper
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} duplication_matrix (@var{n})
## Return the duplication matrix
## @tex
##  $D_n$
## @end tex
## @ifnottex
## @nospell{@math{Dn}}
## @end ifnottex
## which is the unique
## @tex
##  $n^2 \times n(n+1)/2$
## @end tex
## @ifnottex
## @math{n^2} by @math{n*(n+1)/2}
## @end ifnottex
## matrix such that
## @tex
##  $D_n * {\rm vech} (A) = {\rm vec} (A)$
## @end tex
## @ifnottex
## @nospell{@math{Dn vech (A) = vec (A)}}
## @end ifnottex
## for all symmetric
## @tex
##  $n \times n$
## @end tex
## @ifnottex
## @math{n} by @math{n}
## @end ifnottex
## matrices
## @tex
##  $A$.
## @end tex
## @ifnottex
## @math{A}.
## @end ifnottex
##
## See @nospell{Magnus and Neudecker} (1988), @cite{Matrix Differential
## Calculus with Applications in Statistics and Econometrics.}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 8 May 1995
## Adapged-By: jwe
    
    
@function
def duplication_matrix(n=None,*args,**kwargs):
    varargin = duplication_matrix.varargin
    nargin = duplication_matrix.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isscalar(n) and n > 0 and n == fix(n)))):
        error('duplication_matrix: N must be a positive integer')
    
    d=zeros(dot(n,n),dot(n,(n + 1)) / 2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:75
    
    count=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:78
    for j in arange(1,n).reshape(-1):
        d[dot((j - 1),n) + j,count + j]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:80
        for i in arange((j + 1),n).reshape(-1):
            d[dot((j - 1),n) + i,count + i]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:82
            d[dot((i - 1),n) + j,count + i]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:83
        count=count + n - j
# /home/lei/octave-4.0.2/scripts/linear-algebra/duplication_matrix.m:85
    
    return d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} issymmetric (@var{A})
## @deftypefnx {Function File} {} issymmetric (@var{A}, @var{tol})
## Return true if @var{A} is a symmetric matrix within the tolerance specified
## by @var{tol}.
##
## The default tolerance is zero (uses faster code).
##
## Matrix @var{A} is considered symmetric if
## @code{norm (@var{A} - @var{A}.', Inf) / norm (@var{A}, Inf) < @var{tol}}.
## @seealso{ishermitian, isdefinite}
## @end deftypefn
    
    ## Author: A. S. Hodel <scotte@eng.auburn.edu>
## Created: August 1993
## Adapted-By: jwe
    
    
@function
def issymmetric(A=None,tol=0,*args,**kwargs):
    varargin = issymmetric.varargin
    nargin = issymmetric.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    retval=(isnumeric(A) or islogical(A)) and issquare(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/issymmetric.m:43
    if (retval):
        if (tol == 0):
            ## Handle large sparse matrices as well as full ones
            retval=nnz(A != A.T) == 0
# /home/lei/octave-4.0.2/scripts/linear-algebra/issymmetric.m:47
        else:
            norm_x=norm(A,inf)
# /home/lei/octave-4.0.2/scripts/linear-algebra/issymmetric.m:49
            retval=norm_x == 0 or norm(A - A.T,inf) / norm_x <= tol
# /home/lei/octave-4.0.2/scripts/linear-algebra/issymmetric.m:50
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{aa}, @var{bb}, @var{q}, @var{z}] =} qzhess (@var{A}, @var{B})
## Compute the Hessenberg-triangular decomposition of the matrix pencil
## @code{(@var{A}, @var{B})}, returning
## @code{@var{aa} = @var{q} * @var{A} * @var{z}},
## @code{@var{bb} = @var{q} * @var{B} * @var{z}}, with @var{q} and @var{z}
## orthogonal.
##
## For example:
##
## @example
## @group
## [aa, bb, q, z] = qzhess ([1, 2; 3, 4], [5, 6; 7, 8])
##      @result{} aa = [ -3.02244, -4.41741;  0.92998,  0.69749 ]
##      @result{} bb = [ -8.60233, -9.99730;  0.00000, -0.23250 ]
##      @result{}  q = [ -0.58124, -0.81373; -0.81373,  0.58124 ]
##      @result{}  z = [ 1, 0; 0, 1 ]
## @end group
## @end example
##
## The Hessenberg-triangular decomposition is the first step in
## @nospell{Moler and Stewart's} QZ@tie{}decomposition algorithm.
##
## Algorithm taken from @nospell{Golub and Van Loan},
## @cite{Matrix Computations, 2nd edition}.
##
## @seealso{lu, chol, hess, qr, qz, schur, svd}
## @end deftypefn
    
    ## Author: A. S. Hodel <scotte@eng.auburn.edu>
## Created: August 1993
## Adapted-By: jwe
    
    
@function
def qzhess(A=None,B=None,*args,**kwargs):
    varargin = qzhess.varargin
    nargin = qzhess.nargin

    if (nargin != 2):
        print_usage()
    
    na,ma=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:58
    nb,mb=size(B,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:59
    if (na != ma or na != nb or nb != mb):
        error('qzhess: incompatible dimensions')
    
    ## Reduce to hessenberg-triangular form.
    
    q,bb=qr(B,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:66
    aa=dot(q.T,A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:67
    q=q.T
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:68
    z=eye(na)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:69
    for j in arange(1,(na - 2)).reshape(-1):
        for i in arange(na,(j + 2),- 1).reshape(-1):
            ## disp (["zero out aa(", num2str(i), ",", num2str(j), ")"])
            rot=givens(aa[i - 1,j],aa[i,j])
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:75
            aa[(i - 1):i,:]=dot(rot,aa[(i - 1):i,:])
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:76
            bb[(i - 1):i,:]=dot(rot,bb[(i - 1):i,:])
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:77
            q[(i - 1):i,:]=dot(rot,q[(i - 1):i,:])
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:78
            rot=givens(bb[i,i],bb[i,i - 1]).T
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:82
            bb[:,(i - 1):i]=dot(bb[:,(i - 1):i],rot.T)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:83
            aa[:,(i - 1):i]=dot(aa[:,(i - 1):i],rot.T)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:84
            z[:,(i - 1):i]=dot(z[:,(i - 1):i],rot.T)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:85
    
    bb[2,1]=0.0
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:90
    for i in arange(3,na).reshape(-1):
        bb[i,1:(i - 1)]=zeros(1,i - 1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:92
        aa[i,1:(i - 2)]=zeros(1,i - 2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/qzhess.m:93
    
    return aa,bb,q,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 Auburn University.  All rights reserved.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{u}, @var{h}, @var{nu}] =} krylov (@var{A}, @var{V}, @var{k}, @var{eps1}, @var{pflg})
## Construct an orthogonal basis @var{u} of block Krylov subspace
##
## @example
## [v a*v a^2*v @dots{} a^(k+1)*v]
## @end example
##
## @noindent
## using Householder reflections to guard against loss of orthogonality.
##
## If @var{V} is a vector, then @var{h} contains the Hessenberg matrix
## such that @nospell{@tcode{a*u == u*h+rk*ek'}}, in which
## @code{rk = a*u(:,k)-u*h(:,k)}, and @nospell{@tcode{ek'}} is the vector
## @code{[0, 0, @dots{}, 1]} of length @code{k}.  Otherwise, @var{h} is
## meaningless.
##
## If @var{V} is a vector and @var{k} is greater than @code{length (A) - 1},
## then @var{h} contains the Hessenberg matrix such that @code{a*u == u*h}.
##
## The value of @var{nu} is the dimension of the span of the Krylov subspace
## (based on @var{eps1}).
##
## If @var{b} is a vector and @var{k} is greater than @var{m-1}, then @var{h}
## contains the Hessenberg decomposition of @var{A}.
##
## The optional parameter @var{eps1} is the threshold for zero.  The default
## value is 1e-12.
##
## If the optional parameter @var{pflg} is nonzero, row pivoting is used to
## improve numerical behavior.  The default value is 0.
##
## Reference: @nospell{A. Hodel, P. Misra}, @cite{Partial Pivoting in the
## Computation of Krylov Subspaces of Large Sparse Systems}, Proceedings of
## the 42nd IEEE Conference on Decision and Control, December 2003.
## @end deftypefn
    
    ## Author: A. Scottedward Hodel <a.s.hodel@eng.auburn.edu>
    
    
@function
def krylov(A=None,V=None,k=None,eps1=None,pflg=None,*args,**kwargs):
    varargin = krylov.varargin
    nargin = krylov.nargin

    if (isa(A,'single') or isa(V,'single')):
        defeps=1e-06
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:61
    else:
        defeps=1e-12
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:63
    
    if (nargin < 3 or nargin > 5):
        print_usage()
    else:
        if (nargin < 5):
            ## Default permutation flag.
            pflg=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:70
    
    if (nargin < 4):
        ## Default tolerance parameter.
        eps1=copy(defeps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:75
    
    if (isempty(eps1)):
        eps1=copy(defeps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:79
    
    if (logical_not(issquare(A)) or isempty(A)):
        error('krylov: A(%d x %d) must be a non-empty square matrix',rows(A),columns(A))
    
    na=rows(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:85
    m,kb=size(V,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:87
    if (m != na):
        error('krylov: A(%d x %d), V(%d x %d): argument dimensions do not match',na,na,m,kb)
    
    if (logical_not(isscalar(k))):
        error('krylov: K must be a scalar integer')
    
    Vnrm=norm(V,Inf)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:97
    
    if (Vnrm == 0):
        Uret=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:101
        H=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:102
        nu=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:103
        return Uret,H,nu
    
    ## Identify trivial null space.
    abm=max(abs(cat(A,V).T))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:108
    zidx=find(abm == 0)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:109
    
    pivot_vec=arange(1,na)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:112
    iter=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:114
    alpha=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:115
    nh=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:116
    while (length(alpha) < na) and (columns(V) > 0) and (iter < k):

        iter
        jj=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:121
        while (jj <= columns(V) and length(alpha) < na):

            ## Index of next Householder reflection.
            nu=length(alpha) + 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:124
            short_pv=pivot_vec[nu:na]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:126
            q=V[:,jj]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:127
            short_q=q[short_pv]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:128
            if (norm(short_q) < eps1):
                ## Insignificant column; delete.
                nv=columns(V)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:132
                if (jj != nv):
                    V[:,jj],V[:,nv]=swap(V[:,jj],V[:,nv],nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:134
                    ##        Not done since Block Hessenberg structure is lost anyway.
                V=V[:,1:(nv - 1)]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:138
                nu
            else:
                ## New householder reflection.
                if (pflg):
                    ## Locate max magnitude element in short_q.
                    asq=abs(short_q)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:145
                    maxv=max(asq)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:146
                    maxidx=find(asq == maxv,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:147
                    pivot_idx=short_pv[maxidx]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:148
                    if (pivot_idx != pivot_vec[nu]):
                        swapidx=maxidx + (nu - 1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:152
                        pivot_vec[nu],pivot_vec[swapidx]=swap(pivot_vec[nu],pivot_vec[swapidx],nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:153
                ## Isolate portion of vector for reflection.
                idx=pivot_vec[nu:na]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:159
                jdx=pivot_vec[1:nu]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:160
                hv,av,z=housh(q[idx],1,0,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:162
                alpha[nu]=av
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:163
                U[idx,nu]=hv
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:164
                V[idx,:]=V[idx,:] - dot(dot(av,hv),(dot(hv.T,V[idx,:])))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:167
                if (iter > 1):
                    ## FIXME: not done correctly for block case.
                    H[nu,nu - 1]=V[pivot_vec[nu],jj]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:170
                ## Advance to next column of V.
                jj

        ## Check for oversize V (due to full rank).
        if ((columns(V) > na) and (length(alpha) == na)):
            ## Trim to size.
            V=V[:,1:na]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:181
        else:
            if (columns(V) > na):
                krylov_V=copy(V)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:183
                krylov_na=copy(na)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:184
                krylov_length_alpha=length(alpha)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:185
                error('krylov: this case should never happen; submit a bug report')
        if (columns(V) > 0):
            ## Construct next Q and multiply.
            Q=zeros(size(V))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:191
            for kk in arange(1,columns(Q)).reshape(-1):
                Q[pivot_vec[nu - columns(Q) + kk],kk]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:193
            ## Apply Householder reflections.
            for ii in arange(nu,1,- 1).reshape(-1):
                idx=pivot_vec[ii:na]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:198
                hv=U[idx,ii]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:199
                av=alpha[ii]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:200
                Q[idx,:]=Q[idx,:] - dot(dot(av,hv),(dot(hv.T,Q[idx,:])))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:201
        ## Multiply to get new vector.
        V=dot(A,Q)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:206
        nu=length(alpha)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:208
        for i in arange(1,nu).reshape(-1):
            hv=U[:,i]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:210
            av=alpha[i]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:211
            V=V - dot(dot(av,hv),(dot(hv.T,V)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:212
            H[i,nu - columns(V) + (arange(1,columns(V)))]=V[pivot_vec[i],:]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:213

    
    ## Back out complete U matrix.
  ## back out U matrix.
    j1=columns(U)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:220
    for i in arange(j1,1,- 1).reshape(-1):
        idx=pivot_vec[i:na]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:222
        hv=U[idx,i]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:223
        av=alpha[i]
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:224
        U[:,i]=zeros(na,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:225
        U[idx[1],i]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:226
        U[idx,i:j1]=U[idx,i:j1] - dot(dot(av,hv),(dot(hv.T,U[idx,i:j1])))
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:227
    
    nu=length(alpha)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:230
    Uret=copy(U)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:231
    if (max(max(abs(Uret[zidx,:]))) > 0):
        warning('krylov: trivial null space corrupted; set pflg = 1 or eps1 > %e',eps1)
    
    return Uret,H,nu
    
if __name__ == '__main__':
    pass
    
    
@function
def swap(a=None,b=None,*args,**kwargs):
    varargin = swap.varargin
    nargin = swap.nargin

    a1=copy(b)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:242
    b1=copy(a)
# /home/lei/octave-4.0.2/scripts/linear-algebra/krylov.m:243
    return a1,b1
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2003-2015 Gabriele Pannocchia
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} isdefinite (@var{A})
## @deftypefnx {Function File} {} isdefinite (@var{A}, @var{tol})
## Return 1 if @var{A} is symmetric positive definite within the
## tolerance specified by @var{tol} or 0 if @var{A} is symmetric
## positive semidefinite.  Otherwise, return -1.
##
## If @var{tol} is omitted, use a tolerance of
## @code{100 * eps * norm (@var{A}, "fro")}
## @seealso{issymmetric, ishermitian}
## @end deftypefn
    
    ## Author: Gabriele Pannocchia <g.pannocchia@ing.unipi.it>
## Created: November 2003
## Adapted-By: jwe
    
    
@function
def isdefinite(A=None,tol=None,*args,**kwargs):
    varargin = isdefinite.varargin
    nargin = isdefinite.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(isfloat(A))):
        A=double(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:42
    
    if (nargin == 1):
        tol=dot(dot(100,eps(class_(A))),norm(A,'fro'))
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:46
    
    if (logical_not(ishermitian(A,tol))):
        error('isdefinite: A must be a Hermitian matrix')
    
    e=dot(tol,eye(rows(A)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:53
    r,p=chol(A - e,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:54
    if (p == 0):
        retval=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:56
    else:
        r,p=chol(A + e,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:58
        if (p == 0):
            retval=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:60
        else:
            retval=- 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdefinite.m:62
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Nir Krakauer
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; If not, see <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} linsolve (@var{A}, @var{b})
## @deftypefnx {Function File} {@var{x} =} linsolve (@var{A}, @var{b}, @var{opts})
## @deftypefnx {Function File} {[@var{x}, @var{R}] =} linsolve (@dots{})
## Solve the linear system @code{A*x = b}.
##
## With no options, this function is equivalent to the left division operator
## @w{(@code{x = A \ b})} or the matrix-left-divide function
## @w{(@code{x = mldivide (A, b)})}.
##
## Octave ordinarily examines the properties of the matrix @var{A} and chooses
## a solver that best matches the matrix.  By passing a structure @var{opts}
## to @code{linsolve} you can inform Octave directly about the matrix @var{A}.
## In this case Octave will skip the matrix examination and proceed directly
## to solving the linear system.
##
## @strong{Warning:} If the matrix @var{A} does not have the properties
## listed in the @var{opts} structure then the result will not be accurate
## AND no warning will be given.  When in doubt, let Octave examine the matrix
## and choose the appropriate solver as this step takes little time and the
## result is cached so that it is only done once per linear system.
##
## Possible @var{opts} fields (set value to true/false):
##
## @table @asis
## @item LT
##   @var{A} is lower triangular
##
## @item UT
##   @var{A} is upper triangular
##
## @item UHESS
##   @var{A} is upper Hessenberg (currently makes no difference)
##
## @item SYM
##   @var{A} is symmetric or complex Hermitian (currently makes no difference)
##
## @item POSDEF
##   @var{A} is positive definite
##
## @item RECT
##   @var{A} is general rectangular (currently makes no difference)
##
## @item TRANSA
##   Solve @code{A'*x = b} by @code{transpose (A) \ b}
## @end table
##
## The optional second output @var{R} is the inverse condition number of
## @var{A} (zero if matrix is singular).
## @seealso{mldivide, matrix_type, rcond}
## @end deftypefn
    
    ## Author: Nir Krakauer <nkrakauer@ccny.cuny.edu>
    
    
@function
def linsolve(A=None,b=None,opts=None,*args,**kwargs):
    varargin = linsolve.varargin
    nargin = linsolve.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(A) and isnumeric(b)))):
        error('linsolve: A and B must be numeric')
    
    trans_A=copy(false)
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:82
    
    if (nargin > 2):
        if (logical_not(isstruct(opts))):
            error('linsolve: OPTS must be a structure')
        if (isfield(opts,'TRANSA') and opts.TRANSA):
            trans_A=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:90
        if (isfield(opts,'POSDEF') and opts.POSDEF):
            A=matrix_type(A,'positive definite')
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:93
        if (isfield(opts,'LT') and opts.LT):
            A=matrix_type(A,'lower')
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:96
        else:
            if (isfield(opts,'UT') and opts.UT):
                A=matrix_type(A,'upper')
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:98
    
    ## This way is faster as the transpose is not calculated in Octave,
  ## but forwarded as a flag option to BLAS.
    if (trans_A):
        x=numpy.linalg.solve(A.T,b)
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:105
    else:
        x=numpy.linalg.solve(A,b)
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:107
    
    if (nargout > 1):
        if (issquare(A)):
            R=rcond(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:112
        else:
            R=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/linsolve.m:114
    
    return x,R
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} commutation_matrix (@var{m}, @var{n})
## Return the commutation matrix
## @tex
##  $K_{m,n}$
## @end tex
## @ifnottex
## K(m,n)
## @end ifnottex
## which is the unique
## @tex
##  $m n \times m n$
## @end tex
## @ifnottex
## @var{m}*@var{n} by @var{m}*@var{n}
## @end ifnottex
## matrix such that
## @tex
##  $K_{m,n} \cdot {\rm vec} (A) = {\rm vec} (A^T)$
## @end tex
## @ifnottex
## @math{K(m,n) * vec(A) = vec(A')}
## @end ifnottex
## for all
## @tex
##  $m\times n$
## @end tex
## @ifnottex
## @math{m} by @math{n}
## @end ifnottex
## matrices
## @tex
##  $A$.
## @end tex
## @ifnottex
## @math{A}.
## @end ifnottex
##
## If only one argument @var{m} is given,
## @tex
##  $K_{m,m}$
## @end tex
## @ifnottex
## @math{K(m,m)}
## @end ifnottex
## is returned.
##
## See @nospell{Magnus and Neudecker} (1988), @cite{Matrix Differential
## Calculus with Applications in Statistics and Econometrics.}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 8 May 1995
## Adapted-By: jwe
    
    
@function
def commutation_matrix(m=None,n=None,*args,**kwargs):
    varargin = commutation_matrix.varargin
    nargin = commutation_matrix.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (logical_not((isscalar(m) and m == fix(m) and m > 0))):
            error('commutation_matrix: M must be a positive integer')
        if (nargin == 1):
            n=copy(m)
# /home/lei/octave-4.0.2/scripts/linear-algebra/commutation_matrix.m:83
        else:
            if (logical_not((isscalar(n) and n == fix(n) and n > 0))):
                error('commutation_matrix: N must be a positive integer')
    
    ## It is clearly possible to make this a LOT faster!
    k=zeros(dot(m,n),dot(m,n))
# /home/lei/octave-4.0.2/scripts/linear-algebra/commutation_matrix.m:90
    for i in arange(1,m).reshape(-1):
        for j in arange(1,n).reshape(-1):
            k[dot((i - 1),n) + j,dot((j - 1),m) + i]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/commutation_matrix.m:93
    
    return k
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 A. Scottedward Hodel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{housv}, @var{beta}, @var{zer}] =} housh (@var{x}, @var{j}, @var{z})
## Compute Householder reflection vector @var{housv} to reflect @var{x} to be
## the j-th column of identity, i.e.,
##
## @example
## @group
## (I - beta*housv*housv')x =  norm (x)*e(j) if x(j) < 0,
## (I - beta*housv*housv')x = -norm (x)*e(j) if x(j) >= 0
## @end group
## @end example
##
## @noindent
## Inputs
##
## @table @var
## @item x
## vector
##
## @item j
## index into vector
##
## @item z
## threshold for zero  (usually should be the number 0)
## @end table
##
## @noindent
## Outputs (see @nospell{Golub and Van Loan}):
##
## @table @var
## @item beta
## If beta = 0, then no reflection need be applied (@nospell{zer} set to 0)
##
## @item housv
## householder vector
## @end table
## @end deftypefn
    
    ## Author: A. S. Hodel
## Created: August 1995
    
    
@function
def housh(x=None,j=None,z=None,*args,**kwargs):
    varargin = housh.varargin
    nargin = housh.nargin

    if (nargin != 3):
        print_usage()
    
    ## Check for valid inputs.
    if (logical_not(isvector(x)) and logical_not(isscalar(x))):
        error('housh: first input must be a vector')
    else:
        if (logical_not(isscalar(j))):
            error('housh: second argment must be an integer scalar')
        else:
            housv=copy(x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:72
            m=max(abs(housv))
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:73
            if (m != 0.0):
                housv=housv / m
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:75
                alpha=norm(housv)
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:76
                if (alpha > z):
                    beta=1.0 / (dot(alpha,(alpha + abs(housv[j]))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:78
                    sg=sign(housv[j])
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:79
                    if (sg == 0):
                        sg=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:81
                    housv[j]=housv[j] + dot(alpha,sg)
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:83
                else:
                    beta=0.0
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:85
            else:
                beta=0.0
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:88
            zer=(beta == 0)
# /home/lei/octave-4.0.2/scripts/linear-algebra/housh.m:90
    
    return housv,beta,zer
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cond (@var{A})
## @deftypefnx {Function File} {} cond (@var{A}, @var{p})
## Compute the @var{p}-norm condition number of a matrix.
##
## @code{cond (@var{A})} is defined as
## @tex
## $ {\parallel A \parallel_p * \parallel A^{-1} \parallel_p .} $
## @end tex
## @ifnottex
## @code{norm (@var{A}, @var{p}) * norm (inv (@var{A}), @var{p})}.
## @end ifnottex
##
## By default, @code{@var{p} = 2} is used which implies a (relatively slow)
## singular value decomposition.  Other possible selections are
## @code{@var{p} = 1, Inf, "fro"} which are generally faster.  See @code{norm}
## for a full discussion of possible @var{p} values.
##
## The condition number of a matrix quantifies the sensitivity of the matrix
## inversion operation when small changes are made to matrix elements.  Ideally
## the condition number will be close to 1.  When the number is large this
## indicates small changes (such as underflow or round-off error) will produce
## large changes in the resulting output.  In such cases the solution results
## from numerical computing are not likely to be accurate.
## @seealso{condest, rcond, norm, svd}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def cond(A=None,p=2,*args,**kwargs):
    varargin = cond.varargin
    nargin = cond.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (ndims(A) > 2):
        error('cond: A must be a 2-D matrix')
    
    if (p == 2):
        if (isempty(A)):
            retval=0.0
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:60
        else:
            if (any(logical_not(isfinite(ravel(A))))):
                error('cond: A must not contain Inf or NaN values')
            else:
                sigma=svd(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:64
                sigma_1=sigma[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:65
                sigma_n=sigma[end()]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:66
                if (sigma_1 == 0 or sigma_n == 0):
                    retval=copy(Inf)
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:68
                else:
                    retval=sigma_1 / sigma_n
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:70
    else:
        retval=dot(norm(A,p),norm(inv(A),p))
# /home/lei/octave-4.0.2/scripts/linear-algebra/cond.m:74
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 N. J. Higham
## Copyright (C) 2010 Richard T. Guy
## Copyright (C) 2010 Marco Caliari
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{s} =} logm (@var{A})
## @deftypefnx {Function File} {@var{s} =} logm (@var{A}, @var{opt_iters})
## @deftypefnx {Function File} {[@var{s}, @var{iters}] =} logm (@dots{})
## Compute the matrix logarithm of the square matrix @var{A}.
##
## The implementation utilizes a Pad@'e approximant and the identity
##
## @example
## logm (@var{A}) = 2^k * logm (@var{A}^(1 / 2^k))
## @end example
##
## The optional input @var{opt_iters} is the maximum number of square roots
## to compute and defaults to 100.
##
## The optional output @var{iters} is the number of square roots actually
## computed.
## @seealso{expm, sqrtm}
## @end deftypefn
    
    ## Reference: N. J. Higham, Functions of Matrices: Theory and Computation
##            (SIAM, 2008.)
##
    
    ## Author: N. J. Higham
## Author: Richard T. Guy <guyrt7@wfu.edu>
## Author: Marco Caliari <marco.caliari@univr.it>
    
    
@function
def logm(A=None,opt_iters=100,*args,**kwargs):
    varargin = logm.varargin
    nargin = logm.nargin

    if (nargin == 0 or nargin > 2):
        print_usage()
    
    if (logical_not(issquare(A))):
        error('logm: A must be a square matrix')
    
    if (isscalar(A)):
        s=log(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:60
        return s,iters
    else:
        if (strfind(typeinfo(A),'diagonal matrix')):
            s=diag(log(diag(A)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:63
            return s,iters
    
    u,s=schur(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:67
    if (isreal(A)):
        u,s=rsf2csf(u,s,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:70
    
    eigv=diag(s)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:73
    if (any(eigv < 0)):
        warning('Octave:logm:non-principal','logm: principal matrix logarithm is not defined for matrices with negative eigenvalues; computing non-principal logarithm')
    
    real_eig=all(eigv >= 0)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:79
    k=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:81
    
    theta=matlabarray(cat(0,0,0.0161,0.0538,0.113,0.186,0.264296083111))
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:83
    p=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:84
    m=7
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:85
    while (k < opt_iters):

        tau=norm(s - eye(size(s)),1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:87
        if (tau <= theta[7]):
            p=p + 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:89
            j[1]=find(tau <= theta,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:90
            j[2]=find(tau / 2 <= theta,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:91
            if (j[1] - j[2] <= 1 or p == 2):
                m=j[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:93
                break
        k=k + 1
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:97
        s=sqrtm(s)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:98

    
    if (k >= opt_iters):
        warning('logm: maximum number of square roots exceeded; results may still be accurate')
    
    s=s - eye(size(s))
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:105
    if (m > 1):
        s=logm_pade_pf(s,m)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:108
    
    s=dot(dot(dot(2 ** k,u),s),u.T)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:111
    
    if (real_eig and isreal(A)):
        s=real(s)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:115
    
    if (nargout == 2):
        iters=copy(k)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:119
    
    return s,iters
    
if __name__ == '__main__':
    pass
    
    ################## ANCILLARY FUNCTIONS ################################
######  Taken from the mfttoolbox (GPL 3) by D. Higham.
######  Reference:
######      D. Higham, Functions of Matrices: Theory and Computation
######      (SIAM, 2008.).
#######################################################################
    
    ##LOGM_PADE_PF   Evaluate Pade approximant to matrix log by partial fractions.
##   Y = LOGM_PADE_PF(A,M) evaluates the [M/M] Pade approximation to
##   LOG(EYE(SIZE(A))+A) using a partial fraction expansion.
    
    
@function
def logm_pade_pf(A=None,m=None,*args,**kwargs):
    varargin = logm_pade_pf.varargin
    nargin = logm_pade_pf.nargin

    nodes,wts=gauss_legendre(m,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:136
    
    nodes=(nodes + 1) / 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:138
    wts=wts / 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:139
    n=length(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:141
    s=zeros(n)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:142
    for j in arange(1,m).reshape(-1):
        s += dot(wts[j],(A / (eye(n) + dot(nodes[j],A))))
    
    return s
    
if __name__ == '__main__':
    pass
    
    ######################################################################
## GAUSS_LEGENDRE  Nodes and weights for Gauss-Legendre quadrature.
##   [X,W] = GAUSS_LEGENDRE(N) computes the nodes X and weights W
##   for N-point Gauss-Legendre quadrature.
    
    ## Reference:
## G. H. Golub and J. H. Welsch, Calculation of Gauss quadrature
## rules, Math. Comp., 23(106):221-230, 1969.
    
    
@function
def gauss_legendre(n=None,*args,**kwargs):
    varargin = gauss_legendre.varargin
    nargin = gauss_legendre.nargin

    i=arange(1,n - 1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:158
    v=i / sqrt((dot(2,i)) ** 2 - 1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:159
    V,D=eig(diag(v,- 1) + diag(v,1),nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:160
    x=diag(D)
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:161
    w=dot(2,(V[1,:].T ** 2))
# /home/lei/octave-4.0.2/scripts/linear-algebra/logm.m:162
    return x,w
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isbanded (@var{A}, @var{lower}, @var{upper})
## Return true if @var{A} is a matrix with entries confined between
## @var{lower} diagonals below the main diagonal and @var{upper} diagonals
## above the main diagonal.
##
## @var{lower} and @var{upper} must be non-negative integers.
## @seealso{isdiag, istril, istriu, bandwidth}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def isbanded(A=None,lower=None,upper=None,*args,**kwargs):
    varargin = isbanded.varargin
    nargin = isbanded.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isreal(lower)) or logical_not(isreal(upper)) or lower < 0 or upper < 0):
        error('isbanded: LOWER and UPPER must be non-negative integers')
    
    if (isempty(A)):
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:42
    else:
        retval=(isnumeric(A) or islogical(A)) and ndims(A) == 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:44
        if (retval):
            i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:46
            pupp=j >= i
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:47
            retval=all(j[pupp] - i[pupp] <= upper)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:48
            if (retval):
                plow=i >= j
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:50
                retval=all(i[plow] - j[plow] <= lower)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isbanded.m:51
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{G}, @var{y}] =} planerot (@var{x})
## Given a two-element column vector, return the
## @tex
## $2 \times 2$ orthogonal matrix
## @end tex
## @ifnottex
## 2 by 2 orthogonal matrix
## @end ifnottex
## @var{G} such that
## @code{@var{y} = @var{g} * @var{x}} and @code{@var{y}(2) = 0}.
## @seealso{givens}
## @end deftypefn
    
    
@function
def planerot(x=None,*args,**kwargs):
    varargin = planerot.varargin
    nargin = planerot.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not((isvector(x) and numel(x) == 2))):
            error('planerot: X must be a 2-element vector')
    
    G=givens(x[1],x[2])
# /home/lei/octave-4.0.2/scripts/linear-algebra/planerot.m:41
    y=dot(G,ravel(x))
# /home/lei/octave-4.0.2/scripts/linear-algebra/planerot.m:42
    return G,y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} orth (@var{A})
## @deftypefnx {Function File} {} orth (@var{A}, @var{tol})
## Return an orthonormal basis of the range space of @var{A}.
##
## The dimension of the range space is taken as the number of singular values
## of @var{A} greater than @var{tol}.  If the argument @var{tol} is missing, it
## is computed as
##
## @example
## max (size (@var{A})) * max (svd (@var{A})) * eps
## @end example
## @seealso{null}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 24 December 1993.
## Adapted-By: jwe
    
    
@function
def orth(A=None,tol=None,*args,**kwargs):
    varargin = orth.varargin
    nargin = orth.nargin

    if (nargin == 1 or nargin == 2):
        if (isempty(A)):
            retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:43
            return retval
        U,S,V=svd(A,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:47
        rows,cols=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:49
        S_nr,S_nc=size(S,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:51
        if (S_nr == 1 or S_nc == 1):
            s=S[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:54
        else:
            s=diag(S)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:56
        if (nargin == 1):
            if (isa(A,'single')):
                tol=dot(dot(max(size(A)),s[1]),eps('single'))
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:61
            else:
                tol=dot(dot(max(size(A)),s[1]),eps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:63
        rank=sum(s > tol)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:67
        if (rank > 0):
            retval=- U[:,1:rank]
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:70
        else:
            retval=zeros(rows,0)
# /home/lei/octave-4.0.2/scripts/linear-algebra/orth.m:72
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rank (@var{A})
## @deftypefnx {Function File} {} rank (@var{A}, @var{tol})
## Compute the rank of matrix @var{A}, using the singular value decomposition.
##
## The rank is taken to be the number of singular values of @var{A} that are
## greater than the specified tolerance @var{tol}.  If the second argument is
## omitted, it is taken to be
##
## @example
## tol = max (size (@var{A})) * sigma(1) * eps;
## @end example
##
## @noindent
## where @code{eps} is machine precision and @code{sigma(1)} is the largest
## singular value of @var{A}.
##
## The rank of a matrix is the number of linearly independent rows or columns
## and determines how many particular solutions exist to a system of equations.
## Use @code{null} for finding the remaining homogenous solutions.
##
## Example:
##
## @example
## @group
## x = [1 2 3
##      4 5 6
##      7 8 9];
## rank (x)
##   @result{} 2
## @end group
## @end example
##
## @noindent
## The number of linearly independent rows is only 2 because the final row is a
## linear combination of -1*row1 + 2*row2.
##
## @seealso{null, sprank, svd}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def rank(A=None,tol=None,*args,**kwargs):
    varargin = rank.varargin
    nargin = rank.nargin

    if (nargin == 1):
        sigma=svd(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:64
        if (isempty(sigma)):
            tolerance=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:66
        else:
            if (isa(A,'single')):
                tolerance=dot(dot(max(size(A)),sigma[1]),eps('single'))
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:69
            else:
                tolerance=dot(dot(max(size(A)),sigma[1]),eps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:71
    else:
        if (nargin == 2):
            sigma=svd(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:75
            tolerance=copy(tol)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:76
        else:
            print_usage()
    
    retval=sum(sigma > tolerance)
# /home/lei/octave-4.0.2/scripts/linear-algebra/rank.m:81
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} ishermitian (@var{A})
## @deftypefnx {Function File} {} ishermitian (@var{A}, @var{tol})
## Return true if @var{A} is Hermitian within the tolerance specified by
## @var{tol}.
##
## The default tolerance is zero (uses faster code).
##
## Matrix @var{A} is considered symmetric if
## @code{norm (@var{A} - @var{A}', Inf) / norm (@var{A}, Inf) < @var{tol}}.
## @seealso{issymmetric, isdefinite}
## @end deftypefn
    
    ## Author: A. S. Hodel <scotte@eng.auburn.edu>
## Created: August 1993
## Adapted-By: jwe
    
    
@function
def ishermitian(A=None,tol=0,*args,**kwargs):
    varargin = ishermitian.varargin
    nargin = ishermitian.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    retval=isnumeric(A) and issquare(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/ishermitian.m:43
    if (retval):
        if (tol == 0):
            retval=all(ravel((A == A.T)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/ishermitian.m:46
        else:
            norm_x=norm(A,inf)
# /home/lei/octave-4.0.2/scripts/linear-algebra/ishermitian.m:48
            retval=norm_x == 0 or norm(A - A.T,inf) / norm_x <= tol
# /home/lei/octave-4.0.2/scripts/linear-algebra/ishermitian.m:49
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Regents of the University of California
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} condest (@var{A})
## @deftypefnx {Function File} {} condest (@var{A}, @var{t})
## @deftypefnx {Function File} {[@var{est}, @var{v}] =} condest (@dots{})
## @deftypefnx {Function File} {[@var{est}, @var{v}] =} condest (@var{A}, @var{solve}, @var{solve_t}, @var{t})
## @deftypefnx {Function File} {[@var{est}, @var{v}] =} condest (@var{apply}, @var{apply_t}, @var{solve}, @var{solve_t}, @var{n}, @var{t})
##
## Estimate the 1-norm condition number of a matrix @var{A} using @var{t} test
## vectors using a randomized 1-norm estimator.
##
## If @var{t} exceeds 5, then only 5 test vectors are used.
##
## If the matrix is not explicit, e.g., when estimating the condition
## number of @var{A} given an LU@tie{}factorization, @code{condest} uses the
## following functions:
##
## @table @var
## @item apply
## @code{A*x} for a matrix @code{x} of size @var{n} by @var{t}.
##
## @item apply_t
## @code{A'*x} for a matrix @code{x} of size @var{n} by @var{t}.
##
## @item solve
## @code{A \ b} for a matrix @code{b} of size @var{n} by @var{t}.
##
## @item solve_t
## @code{A' \ b} for a matrix @code{b} of size @var{n} by @var{t}.
## @end table
##
## The implicit version requires an explicit dimension @var{n}.
##
## @code{condest} uses a randomized algorithm to approximate the 1-norms.
##
## @code{condest} returns the 1-norm condition estimate @var{est} and a vector
## @var{v} satisfying @code{norm (A*v, 1) == norm (A, 1) * norm
## (@var{v}, 1) / @var{est}}.  When @var{est} is large, @var{v} is an
## approximate null vector.
##
## References:
##
## @itemize
## @item
## @nospell{N.J. Higham and F. Tisseur}, @cite{A Block Algorithm
## for Matrix 1-Norm Estimation, with an Application to 1-Norm
## Pseudospectra}. SIMAX vol 21, no 4, pp 1185-1201.
## @url{http://dx.doi.org/10.1137/S0895479899356080}
##
## @item
## @nospell{N.J. Higham and F. Tisseur}, @cite{A Block Algorithm
## for Matrix 1-Norm Estimation, with an Application to 1-Norm
## Pseudospectra}. @url{http://citeseer.ist.psu.edu/223007.html}
## @end itemize
##
## @seealso{cond, norm, onenormest}
## @end deftypefn
    
    ## Code originally licensed under:
##
## Copyright (c) 2007, Regents of the University of California
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##    * Redistributions of source code must retain the above copyright
##      notice, this list of conditions and the following disclaimer.
##
##    * Redistributions in binary form must reproduce the above
##      copyright notice, this list of conditions and the following
##      disclaimer in the documentation and/or other materials provided
##      with the distribution.
##
##    * Neither the name of the University of California, Berkeley nor
##      the names of its contributors may be used to endorse or promote
##      products derived from this software without specific prior
##      written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
## AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
## PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND
## CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
## USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
## ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
## OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
## OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
## SUCH DAMAGE.
    
    ## Author: Jason Riedy <ejr@cs.berkeley.edu>
## Keywords: linear-algebra norm estimation
## Version: 0.2
    
    
@function
def condest(varargin=None,*args,**kwargs):
    varargin = condest.varargin
    nargin = condest.nargin

    if (nargin < 1 or nargin > 6):
        print_usage()
    
    default_t=5
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:121
    have_A=copy(false)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:123
    have_t=copy(false)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:124
    have_solve=copy(false)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:125
    if (isnumeric(varargin[1])):
        A=varargin[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:128
        if (logical_not(issquare(A))):
            error('condest: matrix must be square')
        n=rows(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:132
        have_A=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:133
        if (nargin > 1):
            if (logical_not(is_function_handle(varargin[2]))):
                t=varargin[2]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:137
                have_t=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:138
            else:
                if (nargin > 2):
                    solve=varargin[2]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:140
                    solve_t=varargin[3]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:141
                    have_solve=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:142
                    if (nargin > 3):
                        t=varargin[4]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:144
                        have_t=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:145
                else:
                    error('condest: must supply both SOLVE and SOLVE_T')
    else:
        if (nargin > 4):
            apply=varargin[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:152
            apply_t=varargin[2]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:153
            solve=varargin[3]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:154
            solve_t=varargin[4]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:155
            have_solve=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:156
            n=varargin[5]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:157
            if (logical_not(isscalar(n))):
                error('condest: dimension argument of implicit form must be scalar')
            if (nargin > 5):
                t=varargin[6]
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:162
                have_t=copy(true)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:163
        else:
            error('condest: implicit form of condest requires at least 5 arguments')
    
    if (logical_not(have_t)):
        t=min(n,default_t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:170
    
    if (logical_not(have_solve)):
        if (issparse(A)):
            L,U,P,Pc=lu(A,nargout=4)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:175
            solve=lambda x=None: dot(Pc.T,(numpy.linalg.solve(U,(numpy.linalg.solve(L,(dot(P,x)))))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:176
            solve_t=lambda x=None: dot(P.T,(numpy.linalg.solve(L.T,(numpy.linalg.solve(U.T,(dot(Pc,x)))))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:177
        else:
            L,U,P=lu(A,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:179
            solve=lambda x=None: numpy.linalg.solve(U,(numpy.linalg.solve(L,(dot(P,x)))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:180
            solve_t=lambda x=None: dot(P.T,(numpy.linalg.solve(L.T,(numpy.linalg.solve(U.T,x)))))
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:181
    
    if (have_A):
        Anorm=norm(A,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:186
    else:
        Anorm=onenormest(apply,apply_t,n,t)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:188
    
    Ainv_norm,v,w=onenormest(solve,solve_t,n,t,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:191
    est=dot(Anorm,Ainv_norm)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:193
    v=w / norm(w,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/condest.m:194
    return est,v
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Yes, these test bounds are really loose.  There's
## enough randomization to trigger odd cases with hilb().
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} null (@var{A})
## @deftypefnx {Function File} {} null (@var{A}, @var{tol})
## Return an orthonormal basis of the null space of @var{A}.
##
## The dimension of the null space is taken as the number of singular values of
## @var{A} not greater than @var{tol}.  If the argument @var{tol} is missing,
## it is computed as
##
## @example
## max (size (@var{A})) * max (svd (@var{A})) * eps
## @end example
## @seealso{orth}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 24 December 1993.
## Adapted-By: jwe
    
    
@function
def null(A=None,tol=None,*args,**kwargs):
    varargin = null.varargin
    nargin = null.nargin

    if (isempty(A)):
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:41
    else:
        U,S,V=svd(A,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:43
        rows,cols=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:45
        S_nr,S_nc=size(S,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:47
        if (S_nr == 1 or S_nc == 1):
            s=S[1]
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:50
        else:
            s=diag(S)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:52
        if (nargin == 1):
            if (isa(A,'single')):
                tol=dot(dot(max(size(A)),s[1]),eps('single'))
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:57
            else:
                tol=dot(dot(max(size(A)),s[1]),eps)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:59
        else:
            if (nargin != 2):
                print_usage()
        rank=sum(s > tol)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:65
        if (rank < cols):
            retval=V[:,rank + 1:cols]
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:68
            if (isa(A,'single')):
                retval[abs(retval) < eps('single')]=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:70
            else:
                retval[abs(retval) < eps]=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:72
        else:
            retval=zeros(cols,0)
# /home/lei/octave-4.0.2/scripts/linear-algebra/null.m:75
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Need some tests for 'single' variables as well
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} istril (@var{A})
## Return true if @var{A} is a lower triangular matrix.
##
## A lower triangular matrix has nonzero entries only on the main diagonal and
## below.
## @seealso{istriu, isbanded, isdiag, tril, bandwidth}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def istril(A=None,*args,**kwargs):
    varargin = istril.varargin
    nargin = istril.nargin

    if (nargin != 1):
        print_usage()
    
    retval=(isnumeric(A) or islogical(A)) and ndims(A) == 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/istril.m:36
    if (retval):
        i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/istril.m:38
        retval=all(i >= j)
# /home/lei/octave-4.0.2/scripts/linear-algebra/istril.m:39
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2006-2015 David Bateman and Marco Caliari
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{n} =} normest (@var{A})
## @deftypefnx {Function File} {@var{n} =} normest (@var{A}, @var{tol})
## @deftypefnx {Function File} {[@var{n}, @var{c}] =} normest (@dots{})
## Estimate the 2-norm of the matrix @var{A} using a power series analysis.
##
## This is typically used for large matrices, where the cost of calculating
## @code{norm (@var{A})} is prohibitive and an approximation to the 2-norm is
## acceptable.
##
## @var{tol} is the tolerance to which the 2-norm is calculated.  By default
## @var{tol} is 1e-6.
##
## The optional output @var{c} returns the number of iterations needed for
## @code{normest} to converge.
## @end deftypefn
    
    
@function
def normest(A=None,tol=1e-06,*args,**kwargs):
    varargin = normest.varargin
    nargin = normest.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(A) and ndims(A) == 2))):
        error('normest: A must be a numeric 2-D matrix')
    
    if (logical_not((isscalar(tol) and isreal(tol)))):
        error('normest: TOL must be a real scalar')
    
    if (logical_not(isfloat(A))):
        A=double(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:52
    
    tol=max(tol,eps(class_(A)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:55
    
    v=rand('state')
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:57
    rand('state',full(trace(A)))
    ncols=columns(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:59
    
    y=rand(ncols,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:61
    c=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:62
    n=0
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:63
    do
    n0=copy(n)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:65
    x=dot(A,y)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:66
    normx=norm(x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:67
    if (normx == 0):
        x=rand(ncols,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:69
    else:
        x=x / normx
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:71
    
    y=dot(A.T,x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:73
    n=norm(y)
# /home/lei/octave-4.0.2/scripts/linear-algebra/normest.m:74
    c += 1
    until(abs(n - n0) <= dot(tol,n))
    rand('state',v)
    
    return n,c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cross (@var{x}, @var{y})
## @deftypefnx {Function File} {} cross (@var{x}, @var{y}, @var{dim})
## Compute the vector cross product of two 3-dimensional vectors @var{x} and
## @var{y}.
##
## If @var{x} and @var{y} are matrices, the cross product is applied along the
## first dimension with three elements.
##
## The optional argument  @var{dim} forces the cross product to be calculated
## along the specified dimension.
##
## Example Code:
##
## @example
## @group
## cross ([1,1,0], [0,1,1])
##      @result{} [ 1; -1; 1 ]
## @end group
## @end example
##
## @seealso{dot, curl, divergence}
## @end deftypefn
    
    ## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
## Created: 15 October 1994
## Adapted-By: jwe
    
    
@function
def cross(x=None,y=None,dim=None,*args,**kwargs):
    varargin = cross.varargin
    nargin = cross.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    if (ndims(x) < 3 and ndims(y) < 3 and nargin < 3):
        ## COMPATIBILITY -- opposite behaviour for cross(row,col)
    ## Swap x and y in the assignments below to get the matlab behaviour.
    ## Better yet, fix the calling code so that it uses conformant vectors.
        if (columns(x) == 1 and rows(y) == 1):
            warning('cross: taking cross product of column by row')
            y=y.T
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:59
        else:
            if (rows(x) == 1 and columns(y) == 1):
                warning('cross: taking cross product of row by column')
                x=x.T
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:62
    
    if (nargin == 2):
        dim=find(size(x) == 3,1)
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:67
        if (isempty(dim)):
            error('cross: must have at least one dimension with 3 elements')
    else:
        if (size(x,dim) != 3):
            error('cross: dimension DIM must have 3 elements')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:77
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:78
    idx2=idx3=idx1=cellarray([':'])(ones(1,nd))
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:79
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:79
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:79
    idx1[dim]=1
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:80
    idx2[dim]=2
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:81
    idx3[dim]=3
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:82
    if (size_equal(x,y)):
        x1=x[idx1[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:85
        x2=x[idx2[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:86
        x3=x[idx3[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:87
        y1=y[idx1[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:88
        y2=y[idx2[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:89
        y3=y[idx3[:]]
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:90
        z=cat(dim,(multiply(x2,y3) - multiply(x3,y2)),(multiply(x3,y1) - multiply(x1,y3)),(multiply(x1,y2) - multiply(x2,y1)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/cross.m:91
    else:
        error('cross: X and Y must have the same dimensions')
    
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s., Czech Republic
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{angle} =} subspace (@var{A}, @var{B})
## Determine the largest principal angle between two subspaces
## spanned by the columns of matrices @var{A} and @var{B}.
## @end deftypefn
    
    ## Author: Jaroslav Hajek <highegg@gmail.com>
    
    ## reference:
## [1]  Andrew V. Knyazev, Merico E. Argentati:
## Principal Angles between Subspaces in an A-Based Scalar Product:
## Algorithms and Perturbation Estimates.
## SIAM Journal on Scientific Computing, Vol. 23 no. 6, pp. 2008-2040
##
## other texts are also around...
    
    
@function
def subspace(A=None,B=None,*args,**kwargs):
    varargin = subspace.varargin
    nargin = subspace.nargin

    if (nargin != 2):
        print_usage()
    else:
        if (ndims(A) != 2 or ndims(B) != 2):
            error('subspace: expecting A and B to be 2-dimensional arrays')
        else:
            if (rows(A) != rows(B)):
                error('subspace: column dimensions of A and B must match')
    
    A=orth(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:45
    B=orth(B)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:46
    c=dot(A.T,B)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:47
    scos=min(svd(c))
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:48
    if (scos ** 2 > 1 / 2):
        if (columns(A) >= columns(B)):
            c=B - dot(A,c)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:51
        else:
            c=A - dot(B,c.T)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:53
        ssin=max(svd(c))
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:55
        ang=asin(min(ssin,1))
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:56
    else:
        ang=acos(scos)
# /home/lei/octave-4.0.2/scripts/linear-algebra/subspace.m:58
    
    return ang
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Jaroslav Hajek, Marco Caliari
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} expm (@var{A})
## Return the exponential of a matrix.
##
## The matrix exponential is defined as the infinite Taylor series
## @tex
## $$
##  \exp (A) = I + A + {A^2 \over 2!} + {A^3 \over 3!} + \cdots
## $$
## @end tex
## @ifnottex
##
## @example
## expm (A) = I + A + A^2/2! + A^3/3! + @dots{}
## @end example
##
## @end ifnottex
## However, the Taylor series is @emph{not} the way to compute the matrix
## exponential; see @nospell{Moler and Van Loan}, @cite{Nineteen Dubious Ways
## to Compute the Exponential of a Matrix}, SIAM Review, 1978.  This routine
## uses Ward's diagonal Pad@'e approximation method with three step
## preconditioning (SIAM Journal on Numerical Analysis, 1977).  Diagonal
## Pad@'e approximations are rational polynomials of matrices
## @tex
## $D_q(A)^{-1}N_q(A)$
## @end tex
## @ifnottex
##
## @example
## @group
##      -1
## D (A)   N (A)
## @end group
## @end example
##
## @end ifnottex
## whose Taylor series matches the first
## @tex
## $2 q + 1 $
## @end tex
## @ifnottex
## @code{2q+1}
## @end ifnottex
## terms of the Taylor series above; direct evaluation of the Taylor series
## (with the same preconditioning steps) may be desirable in lieu of the
## Pad@'e approximation when
## @tex
## $D_q(A)$
## @end tex
## @ifnottex
## @code{Dq(A)}
## @end ifnottex
## is ill-conditioned.
## @seealso{logm, sqrtm}
## @end deftypefn
    
    
@function
def expm(A=None,*args,**kwargs):
    varargin = expm.varargin
    nargin = expm.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isnumeric(A)) or logical_not(issquare(A))):
        error('expm: A must be a square matrix')
    
    if (isscalar(A)):
        r=exp(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:86
        return r
    else:
        if (strfind(typeinfo(A),'diagonal matrix')):
            r=diag(exp(diag(A)))
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:89
            return r
    
    n=rows(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:93
    
    A[A == - Inf]=- realmax
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:95
    trshift=trace(A) / length(A)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:96
    if (trshift > 0):
        A -= dot(trshift,eye(n))
    
    ## Balancing.
    d,p,aa=balance(A,nargout=3)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:101
    
    ## this:
  ##
  ##   [d, xx, aa] = balance (A, "noperm");
  ##   [xx, p, aa] = balance (aa, "noscal");
    f,e=log2(norm(aa,'inf'),nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:107
    s=max(0,e)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:108
    s=min(s,1023)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:109
    aa *= 2 ** (- s)
    
    c=matlabarray(cat(0.5,0.116666666667,0.0166666666667,0.00160256410256,0.000106837606838,4.85625485625e-06,1.3875013875e-07,1.92708526042e-09))
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:113
    a2=aa ** 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:122
    id=eye(n)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:123
    x=dot((dot((dot((dot(c[8],a2) + dot(c[6],id)),a2) + dot(c[4],id)),a2) + dot(c[2],id)),a2) + id
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:124
    y=dot((dot((dot((dot(c[7],a2) + dot(c[5],id)),a2) + dot(c[3],id)),a2) + dot(c[1],id)),aa)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:125
    r=numpy.linalg.solve((x - y),(x + y))
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:127
    
    for k in arange(1,s).reshape(-1):
        r ^= 2
    
    ## inverse balancing.
    d=diag(d)
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:135
    r=dot(d,r) / d
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:136
    r[p,p]=r
# /home/lei/octave-4.0.2/scripts/linear-algebra/expm.m:137
    
    if (trshift > 0):
        r *= exp(trshift)
    
    return r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 Massimiliano Fasi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isdiag (@var{A})
## Return true if @var{A} is a diagonal matrix.
## @seealso{isbanded, istril, istriu, diag, bandwidth}
## @end deftypefn
    
    ## Author: Massimiliano Fasi
    
    
@function
def isdiag(A=None,*args,**kwargs):
    varargin = isdiag.varargin
    nargin = isdiag.nargin

    if (nargin != 1):
        print_usage()
    
    retval=(isnumeric(A) or islogical(A)) and ndims(A) == 2
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdiag.m:33
    if (retval):
        i,j=find(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdiag.m:35
        retval=all(i == j)
# /home/lei/octave-4.0.2/scripts/linear-algebra/isdiag.m:36
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{yi} =} ppval (@var{pp}, @var{xi})
## Evaluate the piecewise polynomial structure @var{pp} at the points @var{xi}.
##
## If @var{pp} describes a scalar polynomial function, the result is an array
## of the same shape as @var{xi}.  Otherwise, the size of the result is
## @code{[pp.dim, length(@var{xi})]} if @var{xi} is a vector, or
## @code{[pp.dim, size(@var{xi})]} if it is a multi-dimensional array.
## @seealso{mkpp, unmkpp, spline, pchip}
## @end deftypefn
    
    
@function
def ppval(pp=None,xi=None,*args,**kwargs):
    varargin = ppval.varargin
    nargin = ppval.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isstruct(pp) and isfield(pp,'form') and strcmp(pp.form,'pp')))):
        error('ppval: first argument must be a pp-form structure')
    
    ## Extract info.
    x,P,n,k,d=unmkpp(pp,nargout=5)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:40
    
    sxi=size(xi)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:43
    if (isvector(xi)):
        xi=ravel(xi).T
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:45
    
    nd=length(d)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:48
    
    xn=numel(xi)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:51
    idx=lookup(x,xi,'lr')
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:52
    P=reshape(P,cat(d,dot(n,k)))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:54
    P=shiftdim(P,nd)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:55
    P=reshape(P,cat(n,k,d))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:56
    Pidx=P[ravel(idx),:]
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:57
    
    if (isvector(xi)):
        Pidx=reshape(Pidx,cat(xn,k,d))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:60
        Pidx=shiftdim(Pidx,1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:61
        dimvec=matlabarray(cat(d,xn))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:62
    else:
        Pidx=reshape(Pidx,cat(sxi,k,d))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:64
        Pidx=shiftdim(Pidx,length(sxi))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:65
        dimvec=matlabarray(cat(d,sxi))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:66
    
    ndv=length(dimvec)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:68
    
    dx=ravel((xi - x[idx])).T
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:71
    dx=repmat(dx,cat(prod(d),1))
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:72
    dx=reshape(dx,dimvec)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:73
    dx=shiftdim(dx,ndv - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:74
    
    if (k > 1):
        yi=shiftdim(reshape(Pidx[1,:],dimvec),ndv - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:78
    else:
        yi=shiftdim(reshape(Pidx,dimvec),ndv - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:80
    
    for i in arange(2,k).reshape(-1):
        yi * dx
        yi += shiftdim(reshape(Pidx[i,:],dimvec),ndv - 1)
    
    ## Adjust shape.
    if ((numel(xi) > 1) or (length(d) == 1)):
        yi=reshape(shiftdim(yi,1),dimvec)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:90
    
    if (isvector(xi) and (d == 1)):
        yi=reshape(yi,sxi)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:94
    else:
        if (isfield(pp,'orient') and strcmp(pp.orient,'first')):
            yi=shiftdim(yi,nd)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:96
    
    if (d == 1):
        yi=reshape(yi,sxi)
# /home/lei/octave-4.0.2/scripts/polynomial/ppval.m:100
    
    return yi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{pp} =} mkpp (@var{breaks}, @var{coefs})
## @deftypefnx {Function File} {@var{pp} =} mkpp (@var{breaks}, @var{coefs}, @var{d})
##
## Construct a piecewise polynomial (pp) structure from sample points
## @var{breaks} and coefficients @var{coefs}.
##
## @var{breaks} must be a vector of strictly increasing values.  The number of
## intervals is given by @code{@var{ni} = length (@var{breaks}) - 1}.
##
## When @var{m} is the polynomial order @var{coefs} must be of size:
## @var{ni} x @var{m} + 1.
##
## The i-th row of @var{coefs}, @code{@var{coefs} (@var{i},:)}, contains the
## coefficients for the polynomial over the @var{i}-th interval, ordered from
## highest (@var{m}) to lowest (@var{0}).
##
## @var{coefs} may also be a multi-dimensional array, specifying a vector-valued
## or array-valued polynomial.  In that case the polynomial order is defined
## by the length of the last dimension of @var{coefs}.  The size of first
## dimension(s) are given by the scalar or vector @var{d}.  If @var{d} is not
## given it is set to @code{1}.  In any case @var{coefs} is reshaped to a 2-D
## matrix of size @code{[@var{ni}*prod(@var{d} @var{m})] }
##
## @seealso{unmkpp, ppval, spline, pchip, ppder, ppint, ppjumps}
## @end deftypefn
    
    
@function
def mkpp(x=None,P=None,d=None,*args,**kwargs):
    varargin = mkpp.varargin
    nargin = mkpp.nargin

    ## check number of arguments
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    ## check x
    if (length(x) < 2):
        error('mkpp: at least one interval is needed')
    
    if (logical_not(isvector(x))):
        error('mkpp: x must be a vector')
    
    len_=length(x) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:62
    dP=length(size(P))
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:63
    pp=struct('form','pp','breaks',ravel(x).T,'coefs',[],'pieces',len_,'order',prod(size(P)) / len_,'dim',1)
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:65
    if (nargin == 3):
        pp.dim = copy(d)
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:73
        pp.order /= prod(d)
    
    dim_vec=matlabarray(cat(dot(pp.pieces,prod(pp.dim)),pp.order))
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:77
    pp.coefs = copy(reshape(P,dim_vec))
# /home/lei/octave-4.0.2/scripts/polynomial/mkpp.m:78
    return pp
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2007-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{multp}, @var{idxp}] =} mpoles (@var{p})
## @deftypefnx {Function File} {[@var{multp}, @var{idxp}] =} mpoles (@var{p}, @var{tol})
## @deftypefnx {Function File} {[@var{multp}, @var{idxp}] =} mpoles (@var{p}, @var{tol}, @var{reorder})
## Identify unique poles in @var{p} and their associated multiplicity.
##
## The output is ordered from largest pole to smallest pole.
##
## If the relative difference of two poles is less than @var{tol} then they are
## considered to be multiples.  The default value for @var{tol} is 0.001.
##
## If the optional parameter @var{reorder} is zero, poles are not sorted.
##
## The output @var{multp} is a vector specifying the multiplicity of the poles.
## @code{@var{multp}(n)} refers to the multiplicity of the Nth pole
## @code{@var{p}(@var{idxp}(n))}.
##
## For example:
##
## @example
## @group
## p = [2 3 1 1 2];
## [m, n] = mpoles (p)
##    @result{} m = [1; 1; 2; 1; 2]
##    @result{} n = [2; 5; 1; 4; 3]
##    @result{} p(n) = [3, 2, 2, 1, 1]
## @end group
## @end example
##
## @seealso{residue, poly, roots, conv, deconv}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Created: Sept 30, 2007
    
    
@function
def mpoles(p=None,tol=None,reorder=None,*args,**kwargs):
    varargin = mpoles.varargin
    nargin = mpoles.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin < 2 or isempty(tol)):
        tol=0.001
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:61
    
    if (nargin < 3 or isempty(reorder)):
        reorder=copy(true)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:65
    
    Np=numel(p)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:68
    
    p=ravel(p)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:72
    
    if (reorder):
        ## Sort with smallest magnitude first.
        p,ordr=sort(p,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:78
        n=arange(Np,1,- 1)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:80
        p=p[n]
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:81
        ordr=ordr[n]
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:82
    else:
        ordr=arange(1,Np)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:84
    
    ## Find pole multiplicty by comparing the relative differnce in the
  ## poles.
    
    multp=zeros(Np,1)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:90
    indx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:91
    n=find(multp == 0,1)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:92
    while (n):

        dp=abs(p - p[n])
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:94
        if (p[n] == 0.0):
            if (any(abs(p) > logical_and(0,isfinite(p)))):
                p0=mean(abs(p[abs(p) > logical_and(0,isfinite(p))]))
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:97
            else:
                p0=1
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:99
        else:
            p0=abs(p[n])
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:102
        k=find(dp < dot(tol,p0))
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:104
        if (numel(indx)):
            k=k[logical_not(ismember(k,indx))]
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:107
        m=arange(1,numel(k))
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:109
        multp[k]=m
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:110
        indx=matlabarray(cat([indx],[k]))
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:111
        n=find(multp == 0,1)
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:112

    
    multp=multp[indx]
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:114
    indx=ordr[indx]
# /home/lei/octave-4.0.2/scripts/polynomial/mpoles.m:115
    return multp,indx
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} compan (@var{c})
## Compute the companion matrix corresponding to polynomial coefficient vector
## @var{c}.
##
## The companion matrix is
## @tex
## $$
## A = \left[\matrix{
##  -c_2/c_1 & -c_3/c_1 & \cdots & -c_N/c_1 & -c_{N+1}/c_1\cr
##      1    &     0    & \cdots &     0    &         0   \cr
##      0    &     1    & \cdots &     0    &         0   \cr
##   \vdots  &   \vdots & \ddots &  \vdots  &      \vdots \cr
##      0    &     0    & \cdots &     1    &         0}\right].
## $$
## @end tex
## @ifnottex
## @c Set example in small font to prevent overfull line
##
## @smallexample
## @group
##      _                                                        _
##     |  -c(2)/c(1)   -c(3)/c(1)  @dots{}  -c(N)/c(1)  -c(N+1)/c(1)  |
##     |       1            0      @dots{}       0             0      |
##     |       0            1      @dots{}       0             0      |
## A = |       .            .      .         .             .      |
##     |       .            .       .        .             .      |
##     |       .            .        .       .             .      |
##     |_      0            0      @dots{}       1             0     _|
## @end group
## @end smallexample
##
## @end ifnottex
## The eigenvalues of the companion matrix are equal to the roots of the
## polynomial.
## @seealso{roots, poly, eig}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def compan(c=None,*args,**kwargs):
    varargin = compan.varargin
    nargin = compan.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isvector(c))):
        error('compan: expecting a vector argument')
    
    n=length(c)
# /home/lei/octave-4.0.2/scripts/polynomial/compan.m:71
    if (n == 1):
        A=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/compan.m:74
    else:
        A=diag(ones(n - 2,1),- 1)
# /home/lei/octave-4.0.2/scripts/polynomial/compan.m:76
        A[1,:]=- c[2:n] / c[1]
# /home/lei/octave-4.0.2/scripts/polynomial/compan.m:77
    
    return A
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} polyder (@var{p})
## @deftypefnx {Function File} {[@var{k}] =} polyder (@var{a}, @var{b})
## @deftypefnx {Function File} {[@var{q}, @var{d}] =} polyder (@var{b}, @var{a})
## Return the coefficients of the derivative of the polynomial whose
## coefficients are given by the vector @var{p}.
##
## If a pair of polynomials is given, return the derivative of the product
## @math{@var{a}*@var{b}}.
##
## If two inputs and two outputs are given, return the derivative of the
## polynomial quotient @math{@var{b}/@var{a}}.  The quotient numerator is
## in @var{q} and the denominator in @var{d}.
## @seealso{polyint, polyval, polyreduce}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def polyder(p=None,a=None,*args,**kwargs):
    varargin = polyder.varargin
    nargin = polyder.nargin

    if (nargin == 1 or nargin == 2):
        if (logical_not(isvector(p))):
            error('polyder: argument must be a vector')
        if (nargin == 2):
            if (logical_not(isvector(a))):
                error('polyder: argument must be a vector')
            if (nargout == 1):
                ## derivative of p*a returns a single polynomial
                q=polyder(conv(p,a))
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:51
            else:
                ## derivative of p/a returns numerator and denominator
                d=conv(a,a)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:54
                if (numel(p) == 1):
                    q=dot(- p,polyder(a))
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:56
                else:
                    if (numel(a) == 1):
                        q=dot(a,polyder(p))
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:58
                    else:
                        q=conv(polyder(p),a) - conv(p,polyder(a))
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:60
                        q=polyreduce(q)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:61
                ## remove common factors from numerator and denominator
                x=polygcd(q,d)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:65
                if (length(x) != 1):
                    q=deconv(q,x)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:67
                    d=deconv(d,x)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:68
                ## move all the gain into the numerator
                q=q / d[1]
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:72
                d=d / d[1]
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:73
        else:
            lp=numel(p)
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:76
            if (lp == 1):
                q=0
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:78
                return q,d
            else:
                if (lp == 0):
                    q=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:81
                    return q,d
            ## Force P to be a row vector.
            p=ravel(p).T
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:86
            q=multiply(p[1:(lp - 1)],cat(arange((lp - 1),1,- 1)))
# /home/lei/octave-4.0.2/scripts/polynomial/polyder.m:88
    else:
        print_usage()
    
    return q,d
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} conv (@var{a}, @var{b})
## @deftypefnx {Function File} {} conv (@var{a}, @var{b}, @var{shape})
## Convolve two vectors @var{a} and @var{b}.
##
## The output convolution is a vector with length equal to
## @code{length (@var{a}) + length (@var{b}) - 1}.
## When @var{a} and @var{b} are the coefficient vectors of two polynomials, the
## convolution represents the coefficient vector of the product polynomial.
##
## The optional @var{shape} argument may be
##
## @table @asis
## @item @var{shape} = @qcode{"full"}
## Return the full convolution.  (default)
##
## @item @var{shape} = @qcode{"same"}
## Return the central part of the convolution with the same size as @var{a}.
## @end table
##
## @seealso{deconv, conv2, convn, fftconv}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def conv(a=None,b=None,shape='full',*args,**kwargs):
    varargin = conv.varargin
    nargin = conv.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(a) and isvector(b)))):
        error('conv: both arguments A and B must be vectors')
    else:
        if (nargin == 3 and logical_not(any(strcmpi(shape,cellarray(['full','same','valid']))))):
            error('conv: SHAPE argument must be "full", "same", or "valid"')
    
    la=la_orig=length(a)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:58
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:58
    lb=lb_orig=length(b)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:59
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:59
    ly=la + lb - 1
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:61
    if (ly == 0):
        y=zeros(1,0)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:64
        return y
    
    ## Use shortest vector as the coefficent vector to filter.
    if (la > lb):
        a,b=deal(b,a,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:70
        lb=copy(la)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:71
    
    x=copy(b)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:73
    
    if (ly > lb):
        x[end() + 1:end() + ly - lb]=0
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:77
    
    y=filter(a,1,x)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:80
    if (strcmpi(shape,'same')):
        idx=ceil((ly - la) / 2)
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:83
        y=y[idx + 1:idx + la]
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:84
    else:
        if (strcmpi(shape,'valid')):
            len_=la_orig - lb_orig
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:86
            y=y[lb_orig:lb_orig + len_]
# /home/lei/octave-4.0.2/scripts/polynomial/conv.m:87
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{x}, @var{p}, @var{n}, @var{k}, @var{d}] =} unmkpp (@var{pp})
##
## Extract the components of a piecewise polynomial structure @var{pp}.
##
## The components are:
##
## @table @asis
## @item @var{x}
## Sample points.
##
## @item @var{p}
## Polynomial coefficients for points in sample interval.
## @code{@var{p} (@var{i}, :)} contains the coefficients for the polynomial
## over interval @var{i} ordered from highest to lowest.  If
## @code{@var{d} > 1}, @code{@var{p} (@var{r}, @var{i}, :)} contains the
## coefficients for the r-th polynomial defined on interval @var{i}.
##
## @item @var{n}
## Number of polynomial pieces.
##
## @item @var{k}
## Order of the polynomial plus 1.
##
## @item @var{d}
## Number of polynomials defined for each interval.
## @end table
##
## @seealso{mkpp, ppval, spline, pchip}
## @end deftypefn
    
    
@function
def unmkpp(pp=None,*args,**kwargs):
    varargin = unmkpp.varargin
    nargin = unmkpp.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isstruct(pp) and isfield(pp,'form') and strcmp(pp.form,'pp')))):
        error('unmkpp: PP must be a piecewise polynomial structure')
    
    x=pp.breaks
# /home/lei/octave-4.0.2/scripts/polynomial/unmkpp.m:58
    P=pp.coefs
# /home/lei/octave-4.0.2/scripts/polynomial/unmkpp.m:59
    n=pp.pieces
# /home/lei/octave-4.0.2/scripts/polynomial/unmkpp.m:60
    k=pp.order
# /home/lei/octave-4.0.2/scripts/polynomial/unmkpp.m:61
    d=pp.dim
# /home/lei/octave-4.0.2/scripts/polynomial/unmkpp.m:62
    return x,P,n,k,d
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Kai Habel
## Copyright (C) 2006 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{pp} =} spline (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{yi} =} spline (@var{x}, @var{y}, @var{xi})
## Return the cubic spline interpolant of points @var{x} and @var{y}.
##
## When called with two arguments, return the piecewise polynomial @var{pp}
## that may be used with @code{ppval} to evaluate the polynomial at specific
## points.
##
## When called with a third input argument, @code{spline} evaluates the spline
## at the points @var{xi}.  The third calling form
## @code{spline (@var{x}, @var{y}, @var{xi})} is equivalent to
## @code{ppval (spline (@var{x}, @var{y}), @var{xi})}.
##
## The variable @var{x} must be a vector of length @var{n}.
##
## @var{y} can be either a vector or array.  If @var{y} is a vector it must
## have a length of either @var{n} or @code{@var{n} + 2}.  If the length of
## @var{y} is @var{n}, then the @qcode{"not-a-knot"} end condition is used.
## If the length of @var{y} is @code{@var{n} + 2}, then the first and last
## values of the vector @var{y} are the values of the first derivative of the
## cubic spline at the endpoints.
##
## If @var{y} is an array, then the size of @var{y} must have the form
## @tex
## $$[s_1, s_2, \cdots, s_k, n]$$
## @end tex
## @ifnottex
## @code{[@var{s1}, @var{s2}, @dots{}, @var{sk}, @var{n}]}
## @end ifnottex
## or
## @tex
## $$[s_1, s_2, \cdots, s_k, n + 2].$$
## @end tex
## @ifnottex
## @code{[@var{s1}, @var{s2}, @dots{}, @var{sk}, @var{n} + 2]}.
## @end ifnottex
## The array is reshaped internally to a matrix where the leading
## dimension is given by
## @tex
## $$s_1 s_2 \cdots s_k$$
## @end tex
## @ifnottex
## @code{@var{s1} * @var{s2} * @dots{} * @var{sk}}
## @end ifnottex
## and each row of this matrix is then treated separately.  Note that this is
## exactly the opposite of @code{interp1} but is done for @sc{matlab}
## compatibility.
##
## @seealso{pchip, ppval, mkpp, unmkpp}
## @end deftypefn
    
    ## This code is based on csape.m from octave-forge, but has been
## modified to use the sparse solver code in octave that itself allows
## special casing of tri-diagonal matrices, modified for NDArrays and
## for the treatment of vectors y 2 elements longer than x as complete
## splines.
    
    
@function
def spline(x=None,y=None,xi=None,*args,**kwargs):
    varargin = spline.varargin
    nargin = spline.nargin

    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:80
    n=length(x)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:81
    if (n < 2):
        error('spline: requires at least 2 points')
    
    ## Check the size and shape of y
    ndy=ndims(y)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:87
    szy=size(y)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:88
    if (ndy == 2 and (any(szy == n) or any(szy == n + 2))):
        if (szy[2] == n or szy[2] == n + 2):
            a=y.T
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:91
        else:
            a=copy(y)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:93
            szy=szy[cat(2,1)]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:94
    else:
        a=shiftdim(reshape(y,cat(prod(szy[1:end() - 1]),szy[end()])),1)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:97
    
    for k in (arange(1,columns(a)))(any(isnan(a))).reshape(-1):
        ok=logical_not(isnan(a[:,k]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:101
        a[logical_not(ok),k]=spline(x[ok],a[ok,k],x[logical_not(ok)])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:102
    
    complete=copy(false)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:105
    if (rows(a) == n + 2):
        complete=copy(true)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:107
        dfs=a[1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:108
        dfe=a[end(),:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:109
        a=a[2:end() - 1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:110
    
    if (logical_not(issorted(x))):
        x,idx=sort(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:114
        a=a[idx,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:115
    
    b=c=zeros(size(a))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:118
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:118
    h=diff(x)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:119
    idx=ones(columns(a),1)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:120
    if (complete):
        if (n == 2):
            d=(dfs + dfe) / (x[2] - x[1]) ** 2 + dot(2,(a[1,:] - a[2,:])) / (x[2] - x[1]) ** 3
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:125
            c=(dot(- 2,dfs) - dfe) / (x[2] - x[1]) - dot(3,(a[1,:] - a[2,:])) / (x[2] - x[1]) ** 2
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:127
            b=copy(dfs)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:129
            a=a[1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:130
        else:
            g[1,:]=(a[2,:] - a[1,:]) / h[1] - dfs
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:132
            g[2:n - 1,:]=(a[3:n,:] - a[2:n - 1,:]) / h[2:n - 1] - (a[2:n - 1,:] - a[1:n - 2,:]) / h[1:n - 2]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:133
            g[n,:]=dfe - (a[n,:] - a[n - 1,:]) / h[n - 1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:135
            c=numpy.linalg.solve(spdiags(cat(cat([h / 6],[0]),cat([h[1] / 3],[(h[1:n - 2] + h[2:n - 1]) / 3],[h[n - 1] / 3]),cat([0],[h / 6])),cat(- 1,0,1),n,n),(g / 2))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:136
            b=diff(a) / h[1:n - 1,idx] - multiply(h[1:n - 1,idx] / 3,(c[2:n,:] + dot(2,c[1:n - 1,:])))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:138
            d=diff(c) / (dot(3,h[1:n - 1,idx]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:140
            d=ravel(d.T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:142
            c=ravel(c[1:n - 1,:].T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:143
            b=ravel(b.T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:144
            a=ravel(a[1:n - 1,:].T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:145
    else:
        if (n == 2):
            b=(a[2,:] - a[1,:]) / (x[2] - x[1])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:150
            a=a[1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:151
            d=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:152
            c=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:153
        else:
            if (n == 3):
                n=2
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:156
                c=(a[1,:] - a[3,:]) / (dot((x[3] - x[1]),(x[2] - x[3]))) + (a[2,:] - a[1,:]) / (dot((x[2] - x[1]),(x[2] - x[3])))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:157
                b=dot((a[2,:] - a[1,:]),(x[3] - x[1])) / (dot((x[2] - x[1]),(x[3] - x[2]))) + dot((a[1,:] - a[3,:]),(x[2] - x[1])) / (dot((x[3] - x[1]),(x[3] - x[2])))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:159
                a=a[1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:163
                d=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:164
                x=matlabarray(cat(min(x),max(x)))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:165
            else:
                g=zeros(n - 2,columns(a))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:168
                g[1,:]=dot(3 / (h[1] + h[2]),(a[3,:] - a[2,:] - dot(h[2] / h[1],(a[2,:] - a[1,:]))))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:169
                g[n - 2,:]=dot(3 / (h[n - 1] + h[n - 2]),(dot(h[n - 2] / h[n - 1],(a[n,:] - a[n - 1,:])) - (a[n - 1,:] - a[n - 2,:])))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:171
                if (n > 4):
                    g[2:n - 3,:]=dot(3,diff(a[3:n - 1,:])) / h[3:n - 2,idx] - dot(3,diff(a[2:n - 2,:])) / h[2:n - 3,idx]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:176
                    dg=dot(2,(h[1:n - 2]+ h[2:n - 1]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:179
                    dg[1]=dg[1] - h[1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:180
                    dg[n - 2]=dg[n - 2] - h[n - 1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:181
                    ldg=udg=h[2:n - 2]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:183
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:183
                    udg[1]=udg[1] - h[1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:184
                    ldg[n - 3]=ldg[n - 3] - h[n - 1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:185
                    c[2:n - 1,:]=numpy.linalg.solve(spdiags(cat(cat([ravel(ldg)],[0]),dg,cat([0],[ravel(udg)])),cat(- 1,0,1),n - 2,n - 2),g)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:186
                else:
                    if (n == 4):
                        dg=matlabarray(cat([h[1] + dot(2,h[2])],[dot(2,h[2]) + h[3]]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:191
                        ldg=h[2] - h[3]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:192
                        udg=h[2] - h[1]
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:193
                        c[2:n - 1,:]=numpy.linalg.solve(spdiags(cat(cat([ravel(ldg)],[0]),dg,cat([0],[ravel(udg)])),cat(- 1,0,1),n - 2,n - 2),g)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:194
                c[1,:]=c[2,:] + dot(h[1] / h[2],(c[2,:] - c[3,:]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:199
                c[n,:]=c[n - 1,:] + dot(h[n - 1] / h[n - 2],(c[n - 1,:] - c[n - 2,:]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:200
                b=diff(a) / h[1:n - 1,idx] - multiply(h[1:n - 1,idx] / 3,(c[2:n,:] + dot(2,c[1:n - 1,:])))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:201
                d=diff(c) / (dot(3,h[1:n - 1,idx]))
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:203
                d=ravel(d.T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:205
                c=ravel(c[1:n - 1,:].T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:206
                b=ravel(b.T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:207
                a=ravel(a[1:n - 1,:].T)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:208
    
    ret=mkpp(x,cat(2,d,c,b,a),szy[1:end() - 1])
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:212
    if (nargin == 3):
        ret=ppval(ret,xi)
# /home/lei/octave-4.0.2/scripts/polynomial/spline.m:215
    
    return ret
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} deconv (@var{y}, @var{a})
## Deconvolve two vectors.
##
## @code{[b, r] = deconv (y, a)} solves for @var{b} and @var{r} such that
## @code{y = conv (a, b) + r}.
##
## If @var{y} and @var{a} are polynomial coefficient vectors, @var{b} will
## contain the coefficients of the polynomial quotient and @var{r} will be
## a remainder polynomial of lowest order.
## @seealso{conv, residue}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def deconv(y=None,a=None,*args,**kwargs):
    varargin = deconv.varargin
    nargin = deconv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isvector(y) and isvector(a)))):
        error('deconv: both arguments must be vectors')
    
    la=length(a)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:46
    ly=length(y)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:47
    lb=ly - la + 1
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:49
    
    if (dot(diff(size(y)(arange(1,2))),diff(size(a)(arange(1,2)))) < 0):
        a=permute(a,cat(2,1))
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:53
    
    if (ly > la):
        x=zeros(size(y) - size(a) + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:57
        x[1]=1
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:58
        b=filter(y,a,x)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:59
    else:
        if (ly == la):
            b=filter(y,a,1)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:61
        else:
            b=0
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:63
    
    lc=la + length(b) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:66
    if (ly == lc):
        r=y - conv(a,b)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:68
    else:
        ## Respect the orientation of Y"
        if (rows(y) <= columns(y)):
            r=cat((zeros(1,lc - ly)),y) - conv(a,b)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:72
        else:
            r=cat([(zeros(lc - ly,1))],[y]) - conv(a,b)
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:74
        if (ly < la):
            ## Trim the remainder is equal to the length of Y.
            r=r[end() - (length(y) - 1):end()]
# /home/lei/octave-4.0.2/scripts/polynomial/deconv.m:78
    
    return b,r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{p} =} polyfit (@var{x}, @var{y}, @var{n})
## @deftypefnx {Function File} {[@var{p}, @var{s}] =} polyfit (@var{x}, @var{y}, @var{n})
## @deftypefnx {Function File} {[@var{p}, @var{s}, @var{mu}] =} polyfit (@var{x}, @var{y}, @var{n})
## Return the coefficients of a polynomial @var{p}(@var{x}) of degree
## @var{n} that minimizes the least-squares-error of the fit to the points
## @code{[@var{x}, @var{y}]}.
##
## If @var{n} is a logical vector, it is used as a mask to selectively force
## the corresponding polynomial coefficients to be used or ignored.
##
## The polynomial coefficients are returned in a row vector.
##
## The optional output @var{s} is a structure containing the following fields:
##
## @table @samp
## @item R
## Triangular factor R from the QR@tie{}decomposition.
##
## @item X
## The Vandermonde matrix used to compute the polynomial coefficients.
##
## @item C
## The unscaled covariance matrix, formally equal to the inverse of
## @var{x'}*@var{x}, but computed in a way minimizing roundoff error
## propagation.
##
## @item df
## The degrees of freedom.
##
## @item normr
## The norm of the residuals.
##
## @item yf
## The values of the polynomial for each value of @var{x}.
## @end table
##
## The second output may be used by @code{polyval} to calculate the
## statistical error limits of the predicted values.  In particular, the
## standard deviation of @var{p} coefficients is given by
##
## @code{sqrt (diag (s.C)/s.df)*s.normr}.
##
## When the third output, @var{mu}, is present the coefficients, @var{p}, are
## associated with a polynomial in
##
## @code{@var{xhat} = (@var{x} - @var{mu}(1)) / @var{mu}(2)} @*
## where @var{mu}(1) = mean (@var{x}), and @var{mu}(2) = std (@var{x}).
##
## This linear transformation of @var{x} improves the numerical stability of
## the fit.
## @seealso{polyval, polyaffine, roots, vander, zscore}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 13 December 1994
## Adapted-By: jwe
## Modified on 20120204 by P. Dupuis; added the ability to specify a
## polynomial mask instead of a polynomial degree.
    
    
@function
def polyfit(x=None,y=None,n=None,*args,**kwargs):
    varargin = polyfit.varargin
    nargin = polyfit.nargin

    if (nargin < 3 or nargin > 4):
        print_usage()
    
    if (nargout > 2):
        ## Normalized the x values.
        mu=matlabarray(cat(mean(x),std(x)))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:87
        x=(x - mu[1]) / mu[2]
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:88
    
    if (logical_not(size_equal(x,y))):
        error('polyfit: X and Y must be vectors of the same size')
    
    if (islogical(n)):
        polymask=copy(n)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:96
        ## effective number of used coefficients.
        n=length(polymask) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:99
        m=sum(polymask) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:99
    else:
        if (logical_not((isscalar(n) and n >= 0 and logical_not(isinf(n)) and n == fix(n)))):
            error('polyfit: N must be a non-negative integer')
        polymask=logical(ones(1,n + 1))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:104
        m=copy(n)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:104
    
    y_is_row_vector=(rows(y) == 1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:107
    
    l=numel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:110
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:111
    y=ravel(y)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:112
    
    v=vander(x,n + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:115
    
    q,r,k=qr(v[:,polymask],0,nargout=3)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:118
    p=numpy.linalg.solve(r,(dot(q.T,y)))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:119
    p[k]=p
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:120
    if (n != m):
        q=copy(p)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:123
        p=zeros(n + 1,1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:123
        p[polymask]=q
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:124
    
    if (nargout > 1):
        yf=dot(v,p)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:128
        if (y_is_row_vector):
            s.yf = copy(yf.T)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:131
        else:
            s.yf = copy(yf)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:133
        s.X = copy(v)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:135
        ## Invert it by cholinv to avoid taking the square root of squared
    ## quantities. If cholinv fails, then X(:, polymask) is rank
    ## deficient and not invertible.
        try:
            C=cholinv(dot(r.T,r))(k,k)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:142
        finally:
            pass
        if (n != m):
            ## fill matrices if required
            s.X[:,logical_not(polymask)]=0
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:149
            s.R = copy(zeros(n + 1,n + 1))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:150
            s.R[polymask,polymask]=r
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:150
            s.C = copy(zeros(n + 1,n + 1))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:151
            s.C[polymask,polymask]=C
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:151
        else:
            s.R = copy(r)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:153
            s.C = copy(C)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:154
        s.df = copy(l - m - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:156
        s.normr = copy(norm(yf - y))
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:157
    
    ## Return a row vector.
    p=p.T
# /home/lei/octave-4.0.2/scripts/polynomial/polyfit.m:161
    return p,s,mu
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test difficult case where scaling is really needed. This example
## demonstrates the rather poor result which occurs when the dependent
## variable is not normalized properly.
## Also check the usage of 2nd & 3rd output arguments.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Fotios Kasolis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{z} =} polyeig (@var{C0}, @var{C1}, @dots{}, @var{Cl})
## @deftypefnx {Function File} {[@var{v}, @var{z}] =} polyeig (@var{C0}, @var{C1}, @dots{}, @var{Cl})
##
## Solve the polynomial eigenvalue problem of degree @var{l}.
##
## Given an @var{n*n} matrix polynomial
##
## @code{@var{C}(s) = @var{C0} + @var{C1} s + @dots{} + @var{Cl} s^l}
##
## @code{polyeig} solves the eigenvalue problem
##
## @code{(@var{C0} + @var{C1} + @dots{} + @var{Cl})v = 0}.
##
## Note that the eigenvalues @var{z} are the zeros of the matrix polynomial.
## @var{z} is a row vector with @var{n*l} elements.  @var{v} is a matrix
## (@var{n} x @var{n}*@var{l}) with columns that correspond to the
## eigenvectors.
##
## @seealso{eig, eigs, compan}
## @end deftypefn
    
    ## Author: Fotios Kasolis
    
    
@function
def polyeig(varargin=None,*args,**kwargs):
    varargin = polyeig.varargin
    nargin = polyeig.nargin

    if (nargin < 1 or nargout > 2):
        print_usage()
    
    nin=numel(varargin)
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:49
    n=rows(varargin[1])
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:50
    for i in arange(1,nin).reshape(-1):
        if (logical_not(issquare(varargin[i]))):
            error('polyeig: coefficients must be square matrices')
        if (rows(varargin[i]) != n):
            error('polyeig: coefficients must have the same dimensions')
    
    ## matrix polynomial degree
    l=nin - 1
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:62
    
    C=matlabarray(cat([zeros(dot(n,(l - 1)),n),eye(dot(n,(l - 1)))],[- cell2mat(varargin[1:end() - 1])]))
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:65
    D=matlabarray(cat([eye(dot(n,(l - 1))),zeros(dot(n,(l - 1)),n)],[zeros(n,dot(n,(l - 1))),varargin[end()]]))
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:68
    
    if (nargout == 2):
        z,v=eig(C,D,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:73
        v=diag(v)
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:74
        z=z[1:n,:]
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:76
        t=max(z)
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:78
        z /= diag(t)
    else:
        z=eig(C,D)
# /home/lei/octave-4.0.2/scripts/polynomial/polyeig.m:81
    
    return z,v
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 2008-2015 VZLU Prague, a.s., Czech Republic
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{jumps} =} ppjumps (@var{pp})
## Evaluate the boundary jumps of a piecewise polynomial.
##
## If there are @math{n} intervals, and the dimensionality of @var{pp} is
## @math{d}, the resulting array has dimensions @code{[d, n-1]}.
## @seealso{mkpp}
## @end deftypefn
    
    
@function
def ppjumps(pp=None,*args,**kwargs):
    varargin = ppjumps.varargin
    nargin = ppjumps.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isstruct(pp) and strcmp(pp.form,'pp')))):
        error('ppjumps: PP must be a structure')
    
    ## Extract info.
    x,P,n,k,d=unmkpp(pp,nargout=5)
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:38
    nd=length(d) + 1
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:39
    
    dx=diff(x[1:n])
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:42
    dx=repmat(dx,cat(prod(d),1))
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:43
    dx=reshape(dx,cat(d,n - 1))
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:44
    dx=shiftdim(dx,nd - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:45
    
    if (k > 1):
        llim=shiftdim(reshape(P[1:dot((n - 1),prod(d)),1],cat(d,n - 1)),nd - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:49
    
    for i in arange(2,k).reshape(-1):
        llim * dx
        llim += shiftdim(reshape(P[1:dot((n - 1),prod(d)),i],cat(d,n - 1)),nd - 1)
    
    rlim=shiftdim(ppval(pp,x[2:end() - 1]),nd - 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:57
    jumps=shiftdim(rlim - llim,1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppjumps.m:58
    return jumps
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Tony Richardson, Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} polyaffine (@var{f}, @var{mu})
## Return the coefficients of the polynomial vector @var{f} after an affine
## transformation.
##
## If @var{f} is the vector representing the polynomial f(x), then
## @code{@var{g} = polyaffine (@var{f}, @var{mu})} is the vector representing:
##
## @example
## g(x) = f( (x - @var{mu}(1)) / @var{mu}(2) )
## @end example
##
## @seealso{polyval, polyfit}
## @end deftypefn
    
    
@function
def polyaffine(f=None,mu=None,*args,**kwargs):
    varargin = polyaffine.varargin
    nargin = polyaffine.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isvector(f))):
        error('polyaffine: F must be a vector')
    
    if (logical_not(isvector(mu)) or length(mu) != 2):
        error('polyaffine: MU must be a two-element vector')
    
    lf=length(f)
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:48
    
    if (rows(f) > 1):
        f=f.T
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:52
    
    g=copy(f)
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:55
    
    if (mu[2] != 1):
        g=g / (mu[2] ** (arange(lf - 1,0,- 1)))
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:59
    
    ## Translate.
    if (mu[1] != 0):
        w=(- mu[1]) ** (arange(0,lf - 1))
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:64
        ii=arange(lf,1,- 1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:65
        g=dot(g[ii],(multiply(toeplitz(w),pascal(lf,- 1))))
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:66
        g=g[ii]
# /home/lei/octave-4.0.2/scripts/polynomial/polyaffine.m:67
    
    return g
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} polyvalm (@var{c}, @var{x})
## Evaluate a polynomial in the matrix sense.
##
## @code{polyvalm (@var{c}, @var{x})} will evaluate the polynomial in the
## matrix sense, i.e., matrix multiplication is used instead of element by
## element multiplication as used in @code{polyval}.
##
## The argument @var{x} must be a square matrix.
## @seealso{polyval, roots, poly}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def polyvalm(c=None,x=None,*args,**kwargs):
    varargin = polyvalm.varargin
    nargin = polyvalm.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isvector(c) or isempty(c)))):
        error('polyvalm: first argument must be a vector')
    
    if (logical_not(issquare(x))):
        error('polyvalm: second argument must be a square matrix')
    
    n=length(c)
# /home/lei/octave-4.0.2/scripts/polynomial/polyvalm.m:50
    if (n == 0):
        y=zeros(rows(x),class_(x))
# /home/lei/octave-4.0.2/scripts/polynomial/polyvalm.m:52
    else:
        id=eye(rows(x),class_(x))
# /home/lei/octave-4.0.2/scripts/polynomial/polyvalm.m:54
        y=dot(c[1],id)
# /home/lei/octave-4.0.2/scripts/polynomial/polyvalm.m:55
        for i in arange(2,n).reshape(-1):
            y=dot(y,x) + dot(c[i],id)
# /home/lei/octave-4.0.2/scripts/polynomial/polyvalm.m:57
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2001-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{pp} =} pchip (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{yi} =} pchip (@var{x}, @var{y}, @var{xi})
## Return the Piecewise Cubic Hermite Interpolating Polynomial (pchip) of
## points @var{x} and @var{y}.
##
## If called with two arguments, return the piecewise polynomial @var{pp}
## that may be used with @code{ppval} to evaluate the polynomial at specific
## points.
##
## When called with a third input argument, @code{pchip} evaluates the pchip
## polynomial at the points @var{xi}.  The third calling form is equivalent to
## @code{ppval (pchip (@var{x}, @var{y}), @var{xi})}.
##
## The variable @var{x} must be a strictly monotonic vector (either increasing
## or decreasing) of length @var{n}.
##
## @var{y} can be either a vector or array.  If @var{y} is a vector then it
## must be the same length @var{n} as @var{x}.  If @var{y} is an array then
## the size of @var{y} must have the form
## @tex
## $$[s_1, s_2, \cdots, s_k, n]$$
## @end tex
## @ifnottex
## @code{[@var{s1}, @var{s2}, @dots{}, @var{sk}, @var{n}]}
## @end ifnottex
## The array is reshaped internally to a matrix where the leading dimension is
## given by
## @tex
## $$s_1 s_2 \cdots s_k$$
## @end tex
## @ifnottex
## @code{@var{s1} * @var{s2} * @dots{} * @var{sk}}
## @end ifnottex
## and each row of this matrix is then treated separately.  Note that this is
## exactly opposite to @code{interp1} but is done for @sc{matlab} compatibility.
##
## @seealso{spline, ppval, mkpp, unmkpp}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
## Date: 9. mar 2001
##
## S_k = a_k + b_k*x + c_k*x^2 + d_k*x^3; (spline polynom)
##
## 4 conditions:
## S_k(x_k) = y_k;
## S_k(x_k+1) = y_k+1;
## S_k'(x_k) = y_k';
## S_k'(x_k+1) = y_k+1';
    
    
@function
def pchip(x=None,y=None,xi=None,*args,**kwargs):
    varargin = pchip.varargin
    nargin = pchip.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    ## make row vector
    x=ravel(x).T
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:77
    n=length(x)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:78
    
    if (isvector(y)):
        y=ravel(y).T
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:82
        szy=size(y)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:83
        if (logical_not(size_equal(x,y))):
            error('pchip: length of X and Y must match')
    else:
        szy=size(y)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:88
        if (n != szy[end()]):
            error('pchip: length of X and last dimension of Y must match')
        y=reshape(y,cat(prod(szy[1:end() - 1]),szy[end()]))
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:92
    
    h=diff(x)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:95
    if (all(h < 0)):
        x=fliplr(x)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:97
        h=diff(x)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:98
        y=fliplr(y)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:99
    else:
        if (any(h <= 0)):
            error('pchip: X must be strictly monotonic')
    
    f1=y[:,1:n - 1]
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:104
    
    d=__pchip_deriv__(x,y,2)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:107
    d1=d[:,1:n - 1]
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:108
    d2=d[:,2:n]
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:109
    
    h=diag(h)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:112
    delta=diff(y,1,2) / h
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:114
    del1=(d1 - delta) / h
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:115
    del2=(d2 - delta) / h
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:116
    c3=del1 + del2
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:117
    c2=- c3 - del1
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:118
    c3=c3 / h
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:119
    coeffs=cat(3,c3,c2,d1,f1)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:120
    ret=mkpp(x,coeffs,szy[1:end() - 1])
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:122
    if (nargin == 3):
        ret=ppval(ret,xi)
# /home/lei/octave-4.0.2/scripts/polynomial/pchip.m:125
    
    return ret
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} polygcd (@var{b}, @var{a})
## @deftypefnx {Function File} {@var{q} =} polygcd (@var{b}, @var{a}, @var{tol})
##
## Find the greatest common divisor of two polynomials.
##
## This is equivalent to the polynomial found by multiplying together all the
## common roots.  Together with deconv, you can reduce a ratio of two
## polynomials.
##
## The tolerance @var{tol} defaults to @code{sqrt (eps)}.
##
## @strong{Caution:} This is a numerically unstable algorithm and should not
## be used on large polynomials.
##
## Example code:
##
## @example
## @group
## polygcd (poly (1:8), poly (3:12)) - poly (3:8)
## @result{} [ 0, 0, 0, 0, 0, 0, 0 ]
## deconv (poly (1:8), polygcd (poly (1:8), poly (3:12))) - poly (1:2)
## @result{} [ 0, 0, 0 ]
## @end group
## @end example
## @seealso{poly, roots, conv, deconv, residue}
## @end deftypefn
    
    
@function
def polygcd(b=None,a=None,tol=None,*args,**kwargs):
    varargin = polygcd.varargin
    nargin = polygcd.nargin

    if (nargin == 2 or nargin == 3):
        if (nargin == 2):
            if (isa(a,'single') or isa(b,'single')):
                tol=sqrt(eps('single'))
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:52
            else:
                tol=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:54
        if (length(a) == 1 or length(b) == 1):
            if (a == 0):
                x=copy(b)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:59
            else:
                if (b == 0):
                    x=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:61
                else:
                    x=1
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:63
        else:
            a /= a[1]
            while (1):

                d,r=deconv(b,a,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:68
                nz=find(abs(r) > tol)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:69
                if (isempty(nz)):
                    x=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:71
                    break
                else:
                    r=r[nz[1]:length(r)]
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:74
                b=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:76
                a=r / r[1]
# /home/lei/octave-4.0.2/scripts/polynomial/polygcd.m:77

    else:
        print_usage()
    
    return x
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Auburn University.  All rights reserved.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} polyout (@var{c})
## @deftypefnx {Function File} {} polyout (@var{c}, @var{x})
## @deftypefnx {Function File} {@var{str} =} polyout (@dots{})
## Display a formatted version of the polynomial @var{c}.
##
## The formatted polynomial
## @tex
## $$ c(x) = c_1 x^n + \ldots + c_n x + c_{n+1} $$
## @end tex
## @ifnottex
##
## @example
## c(x) = c(1) * x^n + @dots{} + c(n) x + c(n+1)
## @end example
##
## @end ifnottex
## is returned as a string or written to the screen if @code{nargout} is zero.
##
## The second argument @var{x} specifies the variable name to use for each term
## and defaults to the string @qcode{"s"}.
## @seealso{polyreduce}
## @end deftypefn
    
    ## Author: A. S. Hodel <a.s.hodel@eng.auburn.edu>
## Created: May 1995
## Nov 1998: Correctly handles complex coefficients
    
    
@function
def polyout(c=None,x=None,*args,**kwargs):
    varargin = polyout.varargin
    nargin = polyout.nargin

    if (nargin < 1) or (nargin > 2) or (nargout < 0) or (nargout > 1):
        print_usage()
    
    if (logical_not(isvector(c))):
        error('polyout: first argument must be a vector')
    
    if (nargin == 1):
        x='s'
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:58
    else:
        if (logical_not(ischar(x))):
            error('polyout: second argument must be a string')
    
    n=length(c)
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:63
    if (n > 0):
        n1=n + 1
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:65
        tmp=coeff(c[1])
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:67
        for ii in arange(2,n).reshape(-1):
            if (real(c[ii]) < 0):
                ns=' - '
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:70
                c[ii]=- c[ii]
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:71
            else:
                ns=' + '
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:73
            tmp=sprintf('%s*%s^%d%s%s',tmp,x,n1 - ii,ns,coeff(c[ii]))
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:76
    else:
        tmp=' '
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:80
    
    if (nargout == 0):
        disp(tmp)
    else:
        y=copy(tmp)
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:86
    
    return y
    
if __name__ == '__main__':
    pass
    
    
@function
def coeff(c=None,*args,**kwargs):
    varargin = coeff.varargin
    nargin = coeff.nargin

    if (imag(c)):
        if (real(c)):
            str=sprintf('(%s)',num2str(c,5))
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:94
        else:
            str=num2str(c,5)
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:96
    else:
        str=num2str(c,5)
# /home/lei/octave-4.0.2/scripts/polynomial/polyout.m:99
    
    return str
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Ben Abbott, Jonas Lundgren
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{pp} =} splinefit (@var{x}, @var{y}, @var{breaks})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@var{x}, @var{y}, @var{p})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@dots{}, "periodic", @var{periodic})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@dots{}, "robust", @var{robust})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@dots{}, "beta", @var{beta})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@dots{}, "order", @var{order})
## @deftypefnx {Function File} {@var{pp} =} splinefit (@dots{}, "constraints", @var{constraints})
##
## Fit a piecewise cubic spline with breaks (knots) @var{breaks} to the
## noisy data, @var{x} and @var{y}.
##
## @var{x} is a vector, and @var{y} is a vector or N-D array.  If @var{y} is an
## N-D array, then @var{x}(j) is matched to @var{y}(:,@dots{},:,j).
##
## @var{p} is a positive integer defining the number of intervals along @var{x},
## and @var{p}+1 is the number of breaks.  The number of points in each interval
## differ by no more than 1.
##
## The optional property @var{periodic} is a logical value which specifies
## whether a periodic boundary condition is applied to the spline.  The
## length of the period is @code{max (@var{breaks}) - min (@var{breaks})}.
## The default value is @code{false}.
##
## The optional property @var{robust} is a logical value which specifies
## if robust fitting is to be applied to reduce the influence of outlying
## data points.  Three iterations of weighted least squares are performed.
## Weights are computed from previous residuals.  The sensitivity of outlier
## identification is controlled by the property @var{beta}.  The value of
## @var{beta} is restricted to the range, 0 < @var{beta} < 1.  The default
## value is @var{beta} = 1/2.  Values close to 0 give all data equal
## weighting.  Increasing values of @var{beta} reduce the influence of
## outlying data.  Values close to unity may cause instability or rank
## deficiency.
##
## The fitted spline is returned as a piecewise polynomial, @var{pp}, and
## may be evaluated using @code{ppval}.
##
## The splines are constructed of polynomials with degree @var{order}.
## The default is a cubic, @var{order}=3.  A spline with P pieces has
## P+@var{order} degrees of freedom.  With periodic boundary conditions
## the degrees of freedom are reduced to P.
##
## The optional property, @var{constaints}, is a structure specifying linear
## constraints on the fit.  The structure has three fields, @qcode{"xc"},
## @qcode{"yc"}, and @qcode{"cc"}.
##
## @table @asis
## @item @qcode{"xc"}
## Vector of the x-locations of the constraints.
##
## @item @qcode{"yc"}
## Constraining values at the locations @var{xc}.
## The default is an array of zeros.
##
## @item @qcode{"cc"}
## Coefficients (matrix).  The default is an array of ones.  The number of
## rows is limited to the order of the piecewise polynomials, @var{order}.
## @end table
##
## Constraints are linear combinations of derivatives of order 0 to
## @var{order}-1 according to
##
## @example
## @group
## @tex
## $cc(1,j) \cdot y(xc(j)) + cc(2,j) \cdot y\prime(xc(j)) + ... = yc(:,\dots,:,j)$.
## @end tex
## @ifnottex
## cc(1,j) * y(xc(j)) + cc(2,j) * y'(xc(j)) + ... = yc(:,...,:,j).
## @end ifnottex
## @end group
## @end example
##
## @seealso{interp1, unmkpp, ppval, spline, pchip, ppder, ppint, ppjumps}
## @end deftypefn
    
    
@function
def splinefit(x=None,y=None,breaks=None,varargin=None,*args,**kwargs):
    varargin = splinefit.varargin
    nargin = splinefit.nargin

    if (nargin > 3):
        n=cellfun('isclass',varargin,'char')
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:98
        varargin[n]=lower(varargin[n])
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:99
        try:
            props=struct(varargin[:])
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:101
        finally:
            pass
    else:
        props=struct()
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:106
    
    fields=fieldnames(props)
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:108
    for f in arange(1,numel(fields)).reshape(-1):
        if (logical_not(any(strcmp(fields[f],cellarray(['periodic','robust','beta','order','constraints']))))):
            error('splinefit:invalidproperty','unrecognized property \'%s\'',fields[f])
    
    args=cellarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:116
    if (isfield(props,'periodic') and props.periodic):
        args[end() + 1]='p'
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:118
    
    if (isfield(props,'robust') and props.robust):
        args[end() + 1]='r'
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:121
    
    if (isfield(props,'beta')):
        if (0 < props.beta and props.beta < 1):
            args[end() + 1]=props.beta
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:125
        else:
            error('splinefit:invalidbeta','invalid beta parameter (0 < beta < 1)')
    
    if (isfield(props,'order')):
        if (props.order >= 0):
            args[end() + 1]=props.order + 1
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:132
        else:
            error('splinefit:invalidorder','invalid order')
    
    if (isfield(props,'constraints')):
        args[end() + 1]=props.constraints
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:138
    
    if (nargin < 3):
        print_usage()
    else:
        if (logical_not(isnumeric(breaks)) or logical_not(isvector(breaks))):
            print_usage()
    
    pp=__splinefit__(x,y,breaks,args[:])
# /home/lei/octave-4.0.2/scripts/polynomial/splinefit.m:145
    return pp
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## This function is private because it is maintained by Jonas Lundgren
## separtely from Octave.  Please do not reformat to match Octave coding
## conventions as that would make it harder to integrate upstream
## changes.
    
    # Copyright (c) 2010, Jonas Lundgren
# All rights reserved.
    
    # Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
    
    #     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the distribution
    
    # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
    
@function
def __splinefit__(varargin=None,*args,**kwargs):
    varargin = __splinefit__.varargin
    nargin = __splinefit__.nargin

    #SPLINEFIT Fit a spline to noisy data.
#   PP = SPLINEFIT(X,Y,BREAKS) fits a piecewise cubic spline with breaks
#   (knots) BREAKS to the noisy data (X,Y). X is a vector and Y is a vector
#   or an ND array. If Y is an ND array, then X(j) and Y(:,...,:,j) are
#   matched. Use PPVAL to evaluate PP.
    
    #   PP = SPLINEFIT(X,Y,P) where P is a positive integer interpolates the
#   breaks linearly from the sorted locations of X. P is the number of
#   spline pieces and P+1 is the number of breaks.
    
    #   OPTIONAL INPUT
#   Argument places 4 to 8 are reserved for optional input.
#   These optional arguments can be given in any order:
    
    #   PP = SPLINEFIT(...,'p') applies periodic boundary conditions to
#   the spline. The period length is MAX(BREAKS)-MIN(BREAKS).
    
    #   PP = SPLINEFIT(...,'r') uses robust fitting to reduce the influence
#   from outlying data points. Three iterations of weighted least squares
#   are performed. Weights are computed from previous residuals.
    
    #   PP = SPLINEFIT(...,BETA), where 0 < BETA < 1, sets the robust fitting
#   parameter BETA and activates robust fitting ('r' can be omitted).
#   Default is BETA = 1/2. BETA close to 0 gives all data equal weighting.
#   Increase BETA to reduce the influence from outlying data. BETA close
#   to 1 may cause instability or rank deficiency.
    
    #   PP = SPLINEFIT(...,N) sets the spline order to N. Default is a cubic
#   spline with order N = 4. A spline with P pieces has P+N-1 degrees of
#   freedom. With periodic boundary conditions the degrees of freedom are
#   reduced to P.
    
    #   PP = SPLINEFIT(...,CON) applies linear constraints to the spline.
#   CON is a structure with fields 'xc', 'yc' and 'cc':
#       'xc', x-locations (vector)
#       'yc', y-values (vector or ND array)
#       'cc', coefficients (matrix).
    
    #   Constraints are linear combinations of derivatives of order 0 to N-2
#   according to
    
    #     cc(1,j)*y(x) + cc(2,j)*y'(x) + ... = yc(:,...,:,j),  x = xc(j).
    
    #   The maximum number of rows for 'cc' is N-1. If omitted or empty 'cc'
#   defaults to a single row of ones. Default for 'yc' is a zero array.
    
    #   EXAMPLES
    
    #       # Noisy data
#       x = linspace(0,2*pi,100);
#       y = sin(x) + 0.1*randn(size(x));
#       # Breaks
#       breaks = [0:5,2*pi];
    
    #       # Fit a spline of order 5
#       pp = splinefit(x,y,breaks,5);
    
    #       # Fit a spline of order 3 with periodic boundary conditions
#       pp = splinefit(x,y,breaks,3,'p');
    
    #       # Constraints: y(0) = 0, y'(0) = 1 and y(3) + y"(3) = 0
#       xc = [0 0 3];
#       yc = [0 1 0];
#       cc = [1 0 1; 0 1 0; 0 0 1];
#       con = struct('xc',xc,'yc',yc,'cc',cc);
    
    #       # Fit a cubic spline with 8 pieces and constraints
#       pp = splinefit(x,y,8,con);
    
    #       # Fit a spline of order 6 with constraints and periodicity
#       pp = splinefit(x,y,breaks,con,6,'p');
    
    #   See also SPLINE, PPVAL, PPDIFF, PPINT
    
    #   Author: Jonas Lundgren <splinefit@gmail.com> 2010
    
    #   2009-05-06  Original SPLINEFIT.
#   2010-06-23  New version of SPLINEFIT based on B-splines.
#   2010-09-01  Robust fitting scheme added.
#   2010-09-01  Support for data containing NaNs.
#   2011-07-01  Robust fitting parameter added.
    
    # Check number of arguments
    narginchk(3,7)
    # Check arguments
    x,y,dim,breaks,n,periodic,beta,constr=arguments(varargin[:],nargout=8)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:117
    # Evaluate B-splines
    base=splinebase(breaks,n)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:120
    pieces=base.pieces
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:121
    A=ppval(base,x)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:122
    # Bin data
    junk,ibin=histc(x,cat(- inf,breaks[2:end() - 1],inf),nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:125
    
    # Sparse system matrix
    mx=numel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:128
    ii=matlabarray(cat([ibin],[ones(n - 1,mx)]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:129
    ii=cumsum(ii,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:130
    jj=repmat(arange(1,mx),n,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:131
    if periodic:
        ii=mod(ii - 1,pieces) + 1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:133
        A=sparse(ii,jj,A,pieces,mx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:134
    else:
        A=sparse(ii,jj,A,pieces + n - 1,mx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:136
    
    # Don't use the sparse solver for small problems
    if pieces < dot(20,n) / log(dot(1.7,n)):
        A=full(A)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:141
    
    # Solve
    if isempty(constr):
        # Solve Min norm(u*A-y)
        u=lsqsolve(A,y,beta)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:147
    else:
        # Evaluate constraints
        B=evalcon(base,constr,periodic)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:150
        Z,u0=solvecon(B,constr,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:152
        y=y - dot(u0,A)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:154
        A=dot(Z,A)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:155
        v=lsqsolve(A,y,beta)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:156
        u=u0 + dot(v,Z)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:157
    
    # Periodic expansion of solution
    if periodic:
        jj=mod(arange(0,pieces + n - 2),pieces) + 1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:162
        u=u[:,jj]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:163
    
    # Compute polynomial coefficients
    ii=matlabarray(cat([repmat(arange(1,pieces),1,n)],[ones(n - 1,dot(n,pieces))]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:167
    ii=cumsum(ii,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:168
    jj=repmat(arange(1,dot(n,pieces)),n,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:169
    C=sparse(ii,jj,base.coefs,pieces + n - 1,dot(n,pieces))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:170
    coefs=dot(u,C)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:171
    coefs=reshape(coefs,[],n)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:172
    # Make piecewise polynomial
    pp=mkpp(breaks,coefs,dim)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:175
    #--------------------------------------------------------------------------
    
@function
def arguments(varargin=None,*args,**kwargs):
    varargin = arguments.varargin
    nargin = arguments.nargin

    #ARGUMENTS Lengthy input checking
#   x           Noisy data x-locations (1 x mx)
#   y           Noisy data y-values (prod(dim) x mx)
#   dim         Leading dimensions of y
#   breaks      Breaks (1 x (pieces+1))
#   n           Spline order
#   periodic    True if periodic boundary conditions
#   beta        Robust fitting parameter, no robust fitting if beta = 0
#   constr      Constraint structure
#   constr.xc   x-locations (1 x nx)
#   constr.yc   y-values (prod(dim) x nx)
#   constr.cc   Coefficients (?? x nx)
    
    # Reshape x-data
    x=varargin[1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:194
    mx=numel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:195
    x=reshape(x,1,mx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:196
    # Remove trailing singleton dimensions from y
    y=varargin[2]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:199
    dim=size(y)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:200
    while numel(dim) > 1 and dim[end()] == 1:

        dim[end()]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:202

    
    my=dim[end()]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:204
    # Leading dimensions of y
    if numel(dim) > 1:
        dim[end()]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:208
    else:
        dim=1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:210
    
    # Reshape y-data
    pdim=prod(dim)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:214
    y=reshape(y,pdim,my)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:215
    # Check data size
    if mx != my:
        mess='Last dimension of array y must equal length of vector x.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:219
        error('arguments:datasize',mess)
    
    # Treat NaNs in x-data
    inan=find(isnan(x))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:224
    if logical_not(isempty(inan)):
        x[inan]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:226
        y[:,inan]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:227
        mess='All data points with NaN as x-location will be ignored.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:228
        warning('arguments:nanx',mess)
    
    # Treat NaNs in y-data
    inan=find(any(isnan(y),1))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:233
    if logical_not(isempty(inan)):
        x[inan]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:235
        y[:,inan]=[]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:236
        mess='All data points with NaN in their y-value will be ignored.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:237
        warning('arguments:nany',mess)
    
    # Check number of data points
    mx=numel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:242
    if mx == 0:
        error('arguments:nodata','There must be at least one data point.')
    
    # Sort data
    if any(diff(x) < 0):
        x,isort=sort(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:249
        y=y[:,isort]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:250
    
    # Breaks
    if isscalar(varargin[3]):
        # Number of pieces
        p=varargin[3]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:256
        if logical_not(isreal(p)) or logical_not(isfinite(p)) or p < 1 or fix(p) < p:
            mess='Argument #3 must be a vector or a positive integer.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:258
            error('arguments:breaks1',mess)
        if x[1] < x[end()]:
            # Interpolate breaks linearly from x-data
            dx=diff(x)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:263
            ibreaks=linspace(1,mx,p + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:264
            junk,ibin=histc(ibreaks,cat(0,arange(2,mx - 1),mx + 1),nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:265
            breaks=x[ibin] + multiply(dx[ibin],(ibreaks - ibin))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:266
        else:
            breaks=x[1] + linspace(0,1,p + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:268
    else:
        # Vector of breaks
        breaks=reshape(varargin[3],1,[])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:272
        if isempty(breaks) or min(breaks) == max(breaks):
            mess='At least two unique breaks are required.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:274
            error('arguments:breaks2',mess)
    
    # Unique breaks
    if any(diff(breaks) <= 0):
        breaks=unique(breaks)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:281
    
    # Optional input defaults
    n=4
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:285
    
    periodic=copy(false)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:286
    
    robust=copy(false)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:287
    
    beta=0.5
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:288
    
    constr=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:289
    
    # Loop over optional arguments
    for k in arange(4,nargin).reshape(-1):
        a=varargin[k]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:293
        if ischar(a) and isscalar(a) and lower(a) == 'p':
            # Periodic conditions
            periodic=copy(true)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:296
        else:
            if ischar(a) and isscalar(a) and lower(a) == 'r':
                # Robust fitting scheme
                robust=copy(true)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:299
            else:
                if isreal(a) and isscalar(a) and isfinite(a) and a > 0 and a < 1:
                    # Robust fitting parameter
                    beta=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:302
                    robust=copy(true)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:303
                else:
                    if isreal(a) and isscalar(a) and isfinite(a) and a > 0 and fix(a) == a:
                        # Spline order
                        n=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:306
                    else:
                        if isstruct(a) and isscalar(a):
                            # Constraint structure
                            constr=copy(a)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:309
                        else:
                            error('arguments:nonsense','Failed to interpret argument #%d.',k)
    
    # No robust fitting
    if logical_not(robust):
        beta=0
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:317
    
    # Check exterior data
    h=diff(breaks)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:321
    xlim1=breaks[1] - dot(0.01,h[1])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:322
    xlim2=breaks[end()] + dot(0.01,h[end()])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:323
    if x[1] < xlim1 or x[end()] > xlim2:
        if periodic:
            # Move data inside domain
            P=breaks[end()] - breaks[1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:327
            x=mod(x - breaks[1],P) + breaks[1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:328
            x,isort=sort(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:330
            y=y[:,isort]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:331
        else:
            mess='Some data points are outside the spline domain.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:333
            warning('arguments:exteriordata',mess)
    
    # Return
    if isempty(constr):
        return x,y,dim,breaks,n,periodic,beta,constr
    
    # Unpack constraints
    xc=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:344
    yc=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:345
    cc=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:346
    names=fieldnames(constr)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:347
    for k in arange(1,numel(names)).reshape(-1):
        if cellarray(['xc']) == names[k]:
            xc=constr.xc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:351
        else:
            if cellarray(['yc']) == names[k]:
                yc=constr.yc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:353
            else:
                if cellarray(['cc']) == names[k]:
                    cc=constr.cc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:355
                else:
                    mess='Unknown field \'%s\' in constraint structure.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:357
                    warning('arguments:unknownfield',mess,names[k])
    
    # Check xc
    if isempty(xc):
        mess='Constraints contains no x-locations.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:364
        error('arguments:emptyxc',mess)
    else:
        nx=numel(xc)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:367
        xc=reshape(xc,1,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:368
    
    # Check yc
    if isempty(yc):
        # Zero array
        yc=zeros(pdim,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:374
    else:
        if numel(yc) == 1:
            # Constant array
            yc=zeros(pdim,nx) + yc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:377
        else:
            if numel(yc) != dot(pdim,nx):
                # Malformed array
                error('arguments:ycsize','Cannot reshape yc to size %dx%d.',pdim,nx)
            else:
                # Reshape array
                yc=reshape(yc,pdim,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:383
    
    # Check cc
    if isempty(cc):
        cc=ones(size(xc))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:388
    else:
        if numel(size(cc)) != 2:
            error('arguments:ccsize1','Constraint coefficients cc must be 2-D.')
        else:
            if size(cc,2) != nx:
                mess='Last dimension of cc must equal length of xc.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:392
                error('arguments:ccsize2',mess)
    
    # Check high order derivatives
    if size(cc,1) >= n:
        if any(any(cc[n:end(),:])):
            mess='Constraints involve derivatives of order %d or larger.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:399
            error('arguments:difforder',mess,n - 1)
        cc=cc[1:n - 1,:]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:402
    
    # Check exterior constraints
    if min(xc) < xlim1 or max(xc) > xlim2:
        if periodic:
            # Move constraints inside domain
            P=breaks[end()] - breaks[1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:409
            xc=mod(xc - breaks[1],P) + breaks[1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:410
        else:
            mess='Some constraints are outside the spline domain.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:412
            warning('arguments:exteriorconstr',mess)
    
    # Pack constraints
    constr=struct('xc',xc,'yc',yc,'cc',cc)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:418
    #--------------------------------------------------------------------------
    
@function
def splinebase(breaks=None,n=None,*args,**kwargs):
    varargin = splinebase.varargin
    nargin = splinebase.nargin

    #SPLINEBASE Generate B-spline base PP of order N for breaks BREAKS
    
    breaks=ravel(breaks)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:425
    
    breaks0=breaks.T
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:426
    
    h=diff(breaks)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:427
    
    pieces=numel(h)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:428
    
    deg=n - 1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:429
    
    # Extend breaks periodically
    if deg > 0:
        if deg <= pieces:
            hcopy=copy(h)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:434
        else:
            hcopy=repmat(h,ceil(deg / pieces),1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:436
        # to the left
        hl=hcopy[end():- 1:end() - deg + 1]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:439
        bl=breaks[1] - cumsum(hl)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:440
        hr=hcopy[1:deg]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:442
        br=breaks[end()] + cumsum(hr)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:443
        breaks=matlabarray(cat([bl[deg:- 1:1]],[breaks],[br]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:445
        h=diff(breaks)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:446
        pieces=numel(h)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:447
    
    # Initiate polynomial coefficients
    coefs=zeros(dot(n,pieces),n)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:451
    coefs[1:n:end(),1]=1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:452
    # Expand h
    ii=matlabarray(cat([arange(1,pieces)],[ones(deg,pieces)]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:455
    ii=cumsum(ii,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:456
    ii=min(ii,pieces)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:457
    H=h[ravel(ii)]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:458
    # Recursive generation of B-splines
    for k in arange(2,n).reshape(-1):
        # Antiderivatives of splines
        for j in arange(1,k - 1).reshape(-1):
            coefs[:,j]=multiply(coefs[:,j],H) / (k - j)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:464
        Q=sum(coefs,2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:466
        Q=reshape(Q,n,pieces)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:467
        Q=cumsum(Q,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:468
        c0=matlabarray(cat([zeros(1,pieces)],[Q[1:deg,:]]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:469
        coefs[:,k]=ravel(c0)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:470
        fmax=repmat(Q[n,:],n,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:472
        fmax=ravel(fmax)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:473
        for j in arange(1,k).reshape(-1):
            coefs[:,j]=coefs[:,j] / fmax
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:475
        # Diff of adjacent antiderivatives
        coefs[1:end() - deg,1:k]=coefs[1:end() - deg,1:k] - coefs[n:end(),1:k]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:478
        coefs[1:n:end(),k]=0
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:479
    
    # Scale coefficients
    scale=ones(size(H))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:483
    for k in arange(1,n - 1).reshape(-1):
        scale=scale / H
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:485
        coefs[:,n - k]=multiply(scale,coefs[:,n - k])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:486
    
    # Reduce number of pieces
    pieces=pieces - dot(2,deg)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:490
    # Sort coefficients by interval number
    ii=matlabarray(cat([dot(n,(arange(1,pieces)))],[dot(deg,ones(deg,pieces))]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:493
    ii=cumsum(ii,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:494
    coefs=coefs[ravel(ii),:]
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:495
    # Make piecewise polynomial
    pp=mkpp(breaks0,coefs,n)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:498
    #--------------------------------------------------------------------------
    
@function
def evalcon(base=None,constr=None,periodic=None,*args,**kwargs):
    varargin = evalcon.varargin
    nargin = evalcon.nargin

    #EVALCON Evaluate linear constraints
    
    # Unpack structures
    breaks=base.breaks
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:506
    pieces=base.pieces
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:507
    n=base.order
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:508
    xc=constr.xc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:509
    cc=constr.cc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:510
    # Bin data
    junk,ibin=histc(xc,cat(- inf,breaks[2:end() - 1],inf),nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:513
    
    # Evaluate constraints
    nx=numel(xc)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:516
    B0=zeros(n,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:517
    for k in arange(1,size(cc,1)).reshape(-1):
        if any(cc[k,:]):
            B0=B0 + multiply(repmat(cc[k,:],n,1),ppval(base,xc))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:520
        # Differentiate base
        coefs=base.coefs(arange(),arange(1,n - k))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:523
        for j in arange(1,n - k - 1).reshape(-1):
            coefs[:,j]=dot((n - k - j + 1),coefs[:,j])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:525
        base.coefs = copy(coefs)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:527
        base.order = copy(n - k)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:528
    
    # Sparse output
    ii=matlabarray(cat([ibin],[ones(n - 1,nx)]))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:532
    ii=cumsum(ii,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:533
    jj=repmat(arange(1,nx),n,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:534
    if periodic:
        ii=mod(ii - 1,pieces) + 1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:536
        B=sparse(ii,jj,B0,pieces,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:537
    else:
        B=sparse(ii,jj,B0,pieces + n - 1,nx)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:539
    
    #--------------------------------------------------------------------------
    
@function
def solvecon(B=None,constr=None,*args,**kwargs):
    varargin = solvecon.varargin
    nargin = solvecon.nargin

    #SOLVECON Find a particular solution u0 and null space Z (Z*B = 0)
#         for constraint equation u*B = yc.
    
    yc=constr.yc
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:548
    tol=dot(1000,eps)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:549
    # Remove blank rows
    ii=any(B,2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:552
    B2=full(B[ii,:])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:553
    # Null space of B2
    if isempty(B2):
        Z2=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:557
    else:
        # QR decomposition with column permutation
        Q,R,dummy=qr(B2,nargout=3)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:560
        R=abs(R)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:561
        jj=all(R < dot(R[1],tol),2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:562
        Z2=Q[:,jj].T
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:563
    
    # Sizes
    m,ncon=size(B,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:567
    m2=size(B2,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:568
    nz=size(Z2,1)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:569
    # Sparse null space of B
    Z=sparse(arange(nz + 1,nz + m - m2),find(logical_not(ii)),1,nz + m - m2,m)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:572
    Z[1:nz,ii]=Z2
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:573
    # Warning rank deficient
    if nz + ncon > m2:
        mess='Rank deficient constraints, rank = %d.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:577
        warning('solvecon:deficient',mess,m2 - nz)
    
    # Particular solution
    u0=zeros(size(yc,1),m)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:582
    if any(ravel(yc)):
        # Non-homogeneous case
        u0[:,ii]=yc / B2
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:585
        if norm(dot(u0,B) - yc,'fro') > dot(norm(yc,'fro'),tol):
            mess='Inconsistent constraints. No solution within tolerance.'
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:588
            error('solvecon:inconsistent',mess)
    
    #--------------------------------------------------------------------------
    
@function
def lsqsolve(A=None,y=None,beta=None,*args,**kwargs):
    varargin = lsqsolve.varargin
    nargin = lsqsolve.nargin

    #LSQSOLVE Solve Min norm(u*A-y)
    
    # Avoid sparse-complex limitations
    if issparse(A) and logical_not(isreal(y)):
        A=full(A)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:600
    
    # Solution
    u=y / A
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:604
    # Robust fitting
    if beta > 0:
        m,n=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:608
        alpha=dot(0.5,beta) / (1 - beta) / m
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:609
        for k in arange(1,3).reshape(-1):
            # Residual
            r=dot(u,A) - y
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:612
            rr=multiply(r,conj(r))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:613
            rrmean=sum(rr,2) / n
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:614
            rrmean[logical_not(rrmean)]=1
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:615
            rrhat=dot((alpha / rrmean).T,rr)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:616
            w=exp(- rrhat)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:618
            spw=spdiags(w.T,0,n,n)
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:619
            u=(dot(y,spw)) / (dot(A,spw))
# /home/lei/octave-4.0.2/scripts/polynomial/private/__splinefit__.m:621
    
    ## Copyright (C) 1994-2015 John W. Eaton
## Copyright (C) 2007 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{r}, @var{p}, @var{k}, @var{e}] =} residue (@var{b}, @var{a})
## @deftypefnx {Function File} {[@var{b}, @var{a}] =} residue (@var{r}, @var{p}, @var{k})
## @deftypefnx {Function File} {[@var{b}, @var{a}] =} residue (@var{r}, @var{p}, @var{k}, @var{e})
## The first calling form computes the partial fraction expansion for the
## quotient of the polynomials, @var{b} and @var{a}.
##
## The quotient is defined as
## @tex
## $$
## {B(s)\over A(s)} = \sum_{m=1}^M {r_m\over (s-p_m)^e_m}
##   + \sum_{i=1}^N k_i s^{N-i}.
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## B(s)    M       r(m)        N
## ---- = SUM ------------- + SUM k(i)*s^(N-i)
## A(s)   m=1 (s-p(m))^e(m)   i=1
## @end group
## @end example
##
## @end ifnottex
## @noindent
## where @math{M} is the number of poles (the length of the @var{r}, @var{p},
## and @var{e}), the @var{k} vector is a polynomial of order @math{N-1}
## representing the direct contribution, and the @var{e} vector specifies the
## multiplicity of the m-th residue's pole.
##
## For example,
##
## @example
## @group
## b = [1, 1, 1];
## a = [1, -5, 8, -4];
## [r, p, k, e] = residue (b, a)
##    @result{} r = [-2; 7; 3]
##    @result{} p = [2; 2; 1]
##    @result{} k = [](0x0)
##    @result{} e = [1; 2; 1]
## @end group
## @end example
##
## @noindent
## which represents the following partial fraction expansion
## @tex
## $$
## {s^2+s+1\over s^3-5s^2+8s-4} = {-2\over s-2} + {7\over (s-2)^2} + {3\over s-1}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##         s^2 + s + 1       -2        7        3
##    ------------------- = ----- + ------- + -----
##    s^3 - 5s^2 + 8s - 4   (s-2)   (s-2)^2   (s-1)
## @end group
## @end example
##
## @end ifnottex
##
## The second calling form performs the inverse operation and computes the
## reconstituted quotient of polynomials, @var{b}(s)/@var{a}(s), from the
## partial fraction expansion; represented by the residues, poles, and a direct
## polynomial specified by @var{r}, @var{p} and @var{k}, and the pole
## multiplicity @var{e}.
##
## If the multiplicity, @var{e}, is not explicitly specified the multiplicity is
## determined by the function @code{mpoles}.
##
## For example:
##
## @example
## @group
## r = [-2; 7; 3];
## p = [2; 2; 1];
## k = [1, 0];
## [b, a] = residue (r, p, k)
##    @result{} b = [1, -5, 9, -3, 1]
##    @result{} a = [1, -5, 8, -4]
##
## where mpoles is used to determine e = [1; 2; 1]
## @end group
## @end example
##
## Alternatively the multiplicity may be defined explicitly, for example,
##
## @example
## @group
## r = [7; 3; -2];
## p = [2; 1; 2];
## k = [1, 0];
## e = [2; 1; 1];
## [b, a] = residue (r, p, k, e)
##    @result{} b = [1, -5, 9, -3, 1]
##    @result{} a = [1, -5, 8, -4]
## @end group
## @end example
##
## @noindent
## which represents the following partial fraction expansion
## @tex
## $$
## {-2\over s-2} + {7\over (s-2)^2} + {3\over s-1} + s = {s^4-5s^3+9s^2-3s+1\over s^3-5s^2+8s-4}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##  -2        7        3         s^4 - 5s^3 + 9s^2 - 3s + 1
## ----- + ------- + ----- + s = --------------------------
## (s-2)   (s-2)^2   (s-1)          s^3 - 5s^2 + 8s - 4
## @end group
## @end example
##
## @end ifnottex
## @seealso{mpoles, poly, roots, conv, deconv}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Author: Ben Abbott <bpabbott@mac.com>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def residue(b=None,a=None,varargin=None,*args,**kwargs):
    varargin = residue.varargin
    nargin = residue.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    toler=0.001
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:154
    if (nargin >= 3):
        if (nargin >= 4):
            e=varargin[2]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:158
        else:
            e=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:160
        ## The inputs are the residue, pole, and direct part. Solve for the
    ## corresponding numerator and denominator polynomials
        r,p=rresidue(b,a,varargin[1],toler,e,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:164
        return r,p,k,e
    
    ## Make sure both polynomials are in reduced form.
    
    a=polyreduce(a)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:170
    b=polyreduce(b)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:171
    b=b / a[1]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:173
    a=a / a[1]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:174
    la=length(a)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:176
    lb=length(b)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:177
    
    if (la == 0 or lb == 0):
        k=r=p=e=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:182
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:182
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:182
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:182
        return r,p,k,e
    else:
        if (la == 1):
            k=b / a
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:185
            r=p=e=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:186
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:186
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:186
            return r,p,k,e
    
    ## Find the poles.
    
    p=roots(a)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:192
    lp=length(p)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:193
    
    e,indx=mpoles(p,toler,1,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:197
    p=p[indx]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:198
    
    ## pole to the average of the group. This reduces the error in
  ## the resulting poles.
    
    p_group=cumsum(e == 1)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:204
    for ng in arange(1,p_group[end()]).reshape(-1):
        m=find(p_group == ng)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:206
        p[m]=mean(p[m])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:207
    
    ## Find the direct term if there is one.
    
    if (lb >= la):
        ## Also return the reduced numerator.
        k,b=deconv(b,a,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:214
        lb=length(b)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:215
    else:
        k=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:217
    
    ## Determine if the poles are (effectively) zero.
    
    small=max(abs(p))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:222
    if (isa(a,'single') or isa(b,'single')):
        small=dot(dot(dot(max(cat(small,1)),eps('single')),10000.0),(1 + numel(p)) ** 2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:224
    else:
        small=dot(dot(dot(max(cat(small,1)),eps),10000.0),(1 + numel(p)) ** 2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:226
    
    p[abs(p) < small]=0
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:228
    
    index=(abs(imag(p)) < small)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:232
    p[index]=real(p[index])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:233
    index=(abs(real(p)) < small)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:234
    p[index]=dot(1j,imag(p[index]))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:235
    
    ## is trivial.
    
    if (lp == 1):
        r=polyval(b,p)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:241
        return r,p,k,e
    
    ## Determine the order of the denominator and remaining numerator.
  ## With the direct term removed the potential order of the numerator
  ## is one less than the order of the denominator.
    
    aorder=numel(a) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:249
    border=aorder - 1
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:250
    
    ## contributions from each residue to the complete numerator.
    
    A=zeros(border + 1,border + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:255
    B=prepad(reshape(b,cat(numel(b),1)),border + 1,0)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:256
    for ip in arange(1,numel(p)).reshape(-1):
        ri=zeros(size(p))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:258
        ri[ip]=1
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:259
        A[:,ip]=prepad(rresidue(ri,p,[],toler),border + 1,0).T
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:260
    
    ## Solve for the residues.
    
    r=numpy.linalg.solve(A,B)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:265
    return r,p,k,e
    
if __name__ == '__main__':
    pass
    
    
@function
def rresidue(r=None,p=None,k=None,toler=None,e=None,*args,**kwargs):
    varargin = rresidue.varargin
    nargin = rresidue.nargin

    ## Reconstitute the numerator and denominator polynomials from the
  ## residues, poles, and direct term.
    
    if (nargin < 2 or nargin > 5):
        print_usage()
    
    if (nargin < 5):
        e=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:279
    
    if (nargin < 4):
        toler=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:283
    
    if (nargin < 3):
        k=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:287
    
    if (numel(e)):
        indx=arange(1,numel(p))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:291
    else:
        e,indx=mpoles(p,toler,0,nargout=2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:293
        p=p[indx]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:294
        r=r[indx]
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:295
    
    indx=arange(1,numel(p))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:298
    for n in indx.reshape(-1):
        pn=matlabarray(cat(1,- p[n]))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:301
        if (n == 1):
            pden=copy(pn)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:303
        else:
            pden=conv(pden,pn)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:305
    
    ## D is the order of the denominator
  ## K is the order of the direct polynomial
  ## N is the order of the resulting numerator
  ## pnum(1:(N+1)) is the numerator's polynomial
  ## pden(1:(D+1)) is the denominator's polynomial
  ## pm is the multible pole for the nth residue
  ## pn is the numerator contribution for the nth residue
    
    D=numel(pden) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:317
    K=numel(k) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:318
    N=K + D
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:319
    pnum=zeros(1,N + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:320
    for n in indx[abs(r) > 0].reshape(-1):
        p1=matlabarray(cat(1,- p[n]))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:322
        for m in arange(1,e[n]).reshape(-1):
            if (m == 1):
                pm=copy(p1)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:325
            else:
                pm=conv(pm,p1)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:327
        pn=deconv(pden,pm)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:330
        pn=dot(r[n],pn)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:331
        pnum=pnum + prepad(pn,N + 1,0,2)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:332
    
    ## Add the direct term.
    
    if (numel(k)):
        pnum=pnum + conv(pden,k)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:338
    
    ## Check for leading zeros and trim the polynomial coefficients.
    if (isa(r,'single') or isa(p,'single') or isa(k,'single')):
        small=dot(max(cat(max(abs(pden)),max(abs(pnum)),1)),eps('single'))
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:343
    else:
        small=dot(max(cat(max(abs(pden)),max(abs(pnum)),1)),eps)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:345
    
    pnum[abs(pnum) < small]=0
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:348
    pden[abs(pden) < small]=0
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:349
    pnum=polyreduce(pnum)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:351
    pden=polyreduce(pden)
# /home/lei/octave-4.0.2/scripts/polynomial/residue.m:352
    return pnum,pden,e
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## The following test is due to Bernard Grung (bug #34266)
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} roots (@var{c})
##
## Compute the roots of the polynomial @var{c}.
##
## For a vector @var{c} with @math{N} components, return the roots of the
## polynomial
## @tex
## $$
## c_1 x^{N-1} + \cdots + c_{N-1} x + c_N.
## $$
## @end tex
## @ifnottex
##
## @example
## c(1) * x^(N-1) + @dots{} + c(N-1) * x + c(N)
## @end example
##
## @end ifnottex
##
## As an example, the following code finds the roots of the quadratic
## polynomial
## @tex
## $$ p(x) = x^2 - 5. $$
## @end tex
## @ifnottex
##
## @example
## p(x) = x^2 - 5.
## @end example
##
## @end ifnottex
##
## @example
## @group
## c = [1, 0, -5];
## roots (c)
## @result{}  2.2361
## @result{} -2.2361
## @end group
## @end example
##
## Note that the true result is
## @tex
## $\pm \sqrt{5}$
## @end tex
## @ifnottex
## @math{+/- sqrt(5)}
## @end ifnottex
## which is roughly
## @tex
## $\pm 2.2361$.
## @end tex
## @ifnottex
## @math{+/- 2.2361}.
## @end ifnottex
## @seealso{poly, compan, fzero}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 24 December 1993
## Adapted-By: jwe
    
    
@function
def roots(v=None,*args,**kwargs):
    varargin = roots.varargin
    nargin = roots.nargin

    if (nargin != 1 or (logical_not(isvector(v)) and logical_not(isempty(v)))):
        print_usage()
    else:
        if (any(logical_not(isfinite(v)))):
            error('roots: inputs must not contain Inf or NaN')
    
    v=ravel(v)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:90
    n=numel(v)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:91
    
    ## we can remove the leading k zeros,
  ## and n - k - l roots of the polynomial are zero.
    
    v_max=max(abs(v))
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:97
    if (isempty(v) or v_max == 0):
        r=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:99
        return r
    
    f=find(v / v_max)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:103
    m=numel(f)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:104
    v=v[f[1]:f[m]]
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:106
    l=numel(v)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:107
    if (l > 1):
        A=diag(ones(1,l - 2),- 1)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:109
        A[1,:]=- v[2:l] / v[1]
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:110
        r=eig(A)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:111
        if (f[m] < n):
            r=matlabarray(cat([r],[zeros(n - f[m],1)]))
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:113
    else:
        r=zeros(n - f[m],1)
# /home/lei/octave-4.0.2/scripts/polynomial/roots.m:116
    
    return r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} polyint (@var{p})
## @deftypefnx {Function File} {} polyint (@var{p}, @var{k})
## Return the coefficients of the integral of the polynomial whose
## coefficients are represented by the vector @var{p}.
##
## The variable @var{k} is the constant of integration, which by default is
## set to zero.
## @seealso{polyder, polyval}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def polyint(p=None,k=None,*args,**kwargs):
    varargin = polyint.varargin
    nargin = polyint.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        k=0
# /home/lei/octave-4.0.2/scripts/polynomial/polyint.m:41
    else:
        if (logical_not(isscalar(k))):
            error('polyint: the constant of integration must be a scalar')
    
    if (logical_not((isvector(p) or isempty(p)))):
        error('polyint: argument must be a vector')
    
    lp=length(p)
# /home/lei/octave-4.0.2/scripts/polynomial/polyint.m:50
    if (lp == 0):
        retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/polyint.m:53
        return retval
    
    if (rows(p) > 1):
        ## Convert to column vector
        p=p.T
# /home/lei/octave-4.0.2/scripts/polynomial/polyint.m:59
    
    retval=matlabarray(cat((p / cat(arange(lp,1,- 1))),k))
# /home/lei/octave-4.0.2/scripts/polynomial/polyint.m:62
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s., Czech Republic
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{ppi} =} ppint (@var{pp})
## @deftypefnx {Function File} {@var{ppi} =} ppint (@var{pp}, @var{c})
## Compute the integral of the piecewise polynomial struct @var{pp}.
##
## @var{c}, if given, is the constant of integration.
## @seealso{mkpp, ppval, ppder}
## @end deftypefn
    
    
@function
def ppint(pp=None,c=None,*args,**kwargs):
    varargin = ppint.varargin
    nargin = ppint.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isstruct(pp) and strcmp(pp.form,'pp')))):
        error('ppint: PP must be a structure')
    
    x,p,n,k,d=unmkpp(pp,nargout=5)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:36
    p=reshape(p,[],k)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:37
    
    pi=p / diag(arange(k,1,- 1))
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:40
    k += 1
    if (nargin == 1):
        pi[:,k]=0
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:43
    else:
        pi[:,k]=repmat(ravel(c),n,1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:45
    
    ppi=mkpp(x,pi,d)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:48
    tmp=- cumsum(ppjumps(ppi),length(d) + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:50
    ppi.coefs[prod(d) + 1:end(),k]=ravel(tmp)
# /home/lei/octave-4.0.2/scripts/polynomial/ppint.m:51
    return ppi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{y} =} polyval (@var{p}, @var{x})
## @deftypefnx {Function File} {@var{y} =} polyval (@var{p}, @var{x}, [], @var{mu})
## @deftypefnx {Function File} {[@var{y}, @var{dy}] =} polyval (@var{p}, @var{x}, @var{s})
## @deftypefnx {Function File} {[@var{y}, @var{dy}] =} polyval (@var{p}, @var{x}, @var{s}, @var{mu})
##
## Evaluate the polynomial @var{p} at the specified values of @var{x}.
##
## If @var{x} is a vector or matrix, the polynomial is evaluated for each of
## the elements of @var{x}.
##
## When @var{mu} is present, evaluate the polynomial for
## (@var{x}-@var{mu}(1))/@var{mu}(2).
##
## In addition to evaluating the polynomial, the second output represents the
## prediction interval, @var{y} +/- @var{dy}, which contains at least 50# of
## the future predictions.  To calculate the prediction interval, the
## structured variable @var{s}, originating from @code{polyfit}, must be
## supplied.
##
## @seealso{polyvalm, polyaffine, polyfit, roots, poly}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def polyval(p=None,x=None,s=[],mu=None,*args,**kwargs):
    varargin = polyval.varargin
    nargin = polyval.nargin

    if (nargin < 2 or nargin > 4 or (nargout == 2 and nargin < 3)):
        print_usage()
    
    if (isempty(x)):
        y=matlabarray([])
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:53
        return y,dy
    else:
        if (isempty(p)):
            y=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:56
            return y,dy
        else:
            if (logical_not(isvector(p))):
                error('polyval: first argument must be a vector')
    
    if (nargin > 3):
        x=(x - mu[1]) / mu[2]
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:63
    
    n=length(p) - 1
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:66
    y=dot(p[1],ones(size(x)))
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:67
    for i in arange(2,n + 1).reshape(-1):
        y=multiply(y,x) + p[i]
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:69
    
    if (nargout == 2):
        ## Note: the F-Distribution is generally considered to be single-sided.
    ## http://www.itl.nist.gov/div898/handbook/eda/section3/eda3673.htm
    ##   t = finv (1-alpha, s.df, s.df);
    ##   dy = t * sqrt (1 + sumsq (A/s.R, 2)) * s.normr / sqrt (s.df)
    ## If my inference is correct, then t must equal 1 for polyval.
    ## This is because finv (0.5, n, n) = 1.0 for any n.
        try:
            k=numel(x)
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:80
            A=(dot(ravel(x),ones(1,n + 1))) ** (dot(ones(k,1),(arange(n,0,- 1))))
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:81
            dy=dot(sqrt(1 + sumsq(A / s.R,2)),s.normr) / sqrt(s.df)
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:82
            dy=reshape(dy,size(x))
# /home/lei/octave-4.0.2/scripts/polynomial/polyval.m:83
        finally:
            pass
    
    return y,dy
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s., Czech Republic
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {ppd =} ppder (pp)
## @deftypefnx {Function File} {ppd =} ppder (pp, m)
## Compute the piecewise @var{m}-th derivative of a piecewise polynomial
## struct @var{pp}.
##
## If @var{m} is omitted the first derivative is calculated.
## @seealso{mkpp, ppval, ppint}
## @end deftypefn
    
    
@function
def ppder(pp=None,m=1,*args,**kwargs):
    varargin = ppder.varargin
    nargin = ppder.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isstruct(pp) and strcmp(pp.form,'pp')))):
        error('ppder: PP must be a structure')
    
    x,p,n,k,d=unmkpp(pp,nargout=5)
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:39
    if (k - m <= 0):
        x=matlabarray(cat(x[1],x[end()]))
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:42
        pd=zeros(prod(d),1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:43
    else:
        f=arange(k,1,- 1)
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:45
        ff=multiply(bincoeff(f,m + 1),factorial(m + 1)) / f
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:46
        k -= m
        pd=dot(p[:,1:k],diag(ff[1:k]))
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:48
    
    ppd=mkpp(x,pd,d)
# /home/lei/octave-4.0.2/scripts/polynomial/ppder.m:51
    return ppd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} polyreduce (@var{c})
## Reduce a polynomial coefficient vector to a minimum number of terms by
## stripping off any leading zeros.
## @seealso{polyout}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
## Adapted-By: jwe
    
    
@function
def polyreduce(c=None,*args,**kwargs):
    varargin = polyreduce.varargin
    nargin = polyreduce.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(isvector(c)) or isempty(c)):
            error('polyreduce: C must be a non-empty vector')
    
    idx=find(c != 0,1)
# /home/lei/octave-4.0.2/scripts/polynomial/polyreduce.m:38
    if (isempty(idx)):
        p=0
# /home/lei/octave-4.0.2/scripts/polynomial/polyreduce.m:41
    else:
        p=c[idx:end()]
# /home/lei/octave-4.0.2/scripts/polynomial/polyreduce.m:43
    
    return p
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} poly (@var{A})
## @deftypefnx {Function File} {} poly (@var{x})
## If @var{A} is a square @math{N}-by-@math{N} matrix, @code{poly (@var{A})}
## is the row vector of the coefficients of @code{det (z * eye (N) - A)},
## the characteristic polynomial of @var{A}.
##
## For example, the following code finds the eigenvalues of @var{A} which are
## the roots of @code{poly (@var{A})}.
##
## @example
## @group
## roots (poly (eye (3)))
##     @result{} 1.00001 + 0.00001i
##        1.00001 - 0.00001i
##        0.99999 + 0.00000i
## @end group
## @end example
##
## In fact, all three eigenvalues are exactly 1 which emphasizes that for
## numerical performance the @code{eig} function should be used to compute
## eigenvalues.
##
## If @var{x} is a vector, @code{poly (@var{x})} is a vector of the
## coefficients of the polynomial whose roots are the elements of @var{x}.
## That is, if @var{c} is a polynomial, then the elements of
## @code{@var{d} = roots (poly (@var{c}))} are contained in @var{c}.  The
## vectors @var{c} and @var{d} are not identical, however, due to sorting and
## numerical errors.
## @seealso{roots, eig}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 24 December 1993
## Adapted-By: jwe
    
    
@function
def poly(x=None,*args,**kwargs):
    varargin = poly.varargin
    nargin = poly.nargin

    if (nargin != 1):
        print_usage()
    
    m=min(size(x))
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:61
    n=max(size(x))
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:62
    if (m == 0):
        y=1
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:64
        return y
    else:
        if (m == 1):
            v=copy(x)
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:67
        else:
            if (m == n):
                v=eig(x)
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:69
            else:
                print_usage()
    
    y=zeros(1,n + 1)
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:74
    y[1]=1
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:75
    for j in arange(1,n).reshape(-1):
        y[2:(j + 1)]=y[2:(j + 1)] - multiply(v[j],y[1:j])
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:77
    
    if (all(all(imag(x) == 0))):
        y=real(y)
# /home/lei/octave-4.0.2/scripts/polynomial/poly.m:81
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} structfun (@var{func}, @var{S})
## @deftypefnx {Function File} {[@var{A}, @dots{}] =} structfun (@dots{})
## @deftypefnx {Function File} {} structfun (@dots{}, "ErrorHandler", @var{errfunc})
## @deftypefnx {Function File} {} structfun (@dots{}, "UniformOutput", @var{val})
##
## Evaluate the function named @var{name} on the fields of the structure
## @var{S}.  The fields of @var{S} are passed to the function @var{func}
## individually.
##
## @code{structfun} accepts an arbitrary function @var{func} in the form of an
## inline function, function handle, or the name of a function (in a character
## string).  In the case of a character string argument, the function must
## accept a single argument named @var{x}, and it must return a string value.
## If the function returns more than one argument, they are returned as
## separate output variables.
##
## If the parameter @qcode{"UniformOutput"} is set to true (the default), then
## the function must return a single element which will be concatenated into
## the return value.  If @qcode{"UniformOutput"} is false, the outputs are
## placed into a structure with the same fieldnames as the input structure.
##
## @example
## @group
## s.name1 = "John Smith";
## s.name2 = "Jill Jones";
## structfun (@@(x) regexp (x, '(\w+)$', "matches")@{1@}, s,
##            "UniformOutput", false)
## @result{}
##    @{
##      name1 = Smith
##      name2 = Jones
##    @}
## @end group
## @end example
##
## Given the parameter @qcode{"ErrorHandler"}, @var{errfunc} defines a function
## to call in case @var{func} generates an error.  The form of the function is
##
## @example
## function [@dots{}] = errfunc (@var{se}, @dots{})
## @end example
##
## @noindent
## where there is an additional input argument to @var{errfunc} relative to
## @var{func}, given by @nospell{@var{se}}.  This is a structure with the
## elements @qcode{"identifier"}, @qcode{"message"} and @qcode{"index"},
## giving respectively the error identifier, the error message, and the index
## into the input arguments of the element that caused the error.  For an
## example on how to use an error handler, @pxref{XREFcellfun,,cellfun}.
##
## @seealso{cellfun, arrayfun, spfun}
## @end deftypefn
    
    
@function
def structfun(func=None,S=None,varargin=None,*args,**kwargs):
    varargin = structfun.varargin
    nargin = structfun.nargin

    if (nargin < 2):
        print_usage()
    
    nargs=length(varargin)
# /home/lei/octave-4.0.2/scripts/general/structfun.m:80
    recognized_opts=cellarray(['UniformOutput','ErrorHandler'])
# /home/lei/octave-4.0.2/scripts/general/structfun.m:82
    uo_str=recognized_opts[1]
# /home/lei/octave-4.0.2/scripts/general/structfun.m:83
    uniform_output=copy(true)
# /home/lei/octave-4.0.2/scripts/general/structfun.m:85
    while (nargs >= 2):

        opt_match=strcmpi(varargin[nargs - 1],recognized_opts)
# /home/lei/octave-4.0.2/scripts/general/structfun.m:88
        if (opt_match[1]):
            uniform_output=varargin[nargs]
# /home/lei/octave-4.0.2/scripts/general/structfun.m:90
        if (any(opt_match)):
            nargs -= 2
        else:
            break

    
    if (nargs > 0):
        error('structfun: invalid options')
    
    varargout=cell(max(cat(nargout,1)),1)
# /home/lei/octave-4.0.2/scripts/general/structfun.m:103
    varargout[:]=cellfun(func,struct2cell(S),varargin[:])
# /home/lei/octave-4.0.2/scripts/general/structfun.m:104
    if (logical_not(uniform_output)):
        varargout=cellfun('cell2struct',varargout,cellarray([fieldnames(S)]),cellarray([1]),uo_str,false)
# /home/lei/octave-4.0.2/scripts/general/structfun.m:107
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2013-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} validateattributes (@var{A}, @var{classes}, @var{attributes})
## @deftypefnx {Function File} {} validateattributes (@var{A}, @var{classes}, @var{attributes}, @var{arg_idx})
## @deftypefnx {Function File} {} validateattributes (@var{A}, @var{classes}, @var{attributes}, @var{func_name})
## @deftypefnx {Function File} {} validateattributes (@var{A}, @var{classes}, @var{attributes}, @var{func_name}, @var{arg_name})
## @deftypefnx {Function File} {} validateattributes (@var{A}, @var{classes}, @var{attributes}, @var{func_name}, @var{arg_name}, @var{arg_idx})
## Check validity of input argument.
##
## Confirms that the argument @var{A} is valid by belonging to one of
## @var{classes}, and holding all of the @var{attributes}.  If it does not,
## an error is thrown, with a message formatted accordingly.  The error
## message can be made further complete by the function name @var{fun_name},
## the argument name @var{arg_name}, and its position in the input
## @var{arg_idx}.
##
## @var{classes} must be a cell array of strings (an empty cell array is
## allowed) with the name of classes (remember that a class name is case
## sensitive).  In addition to the class name, the following categories
## names are also valid:
##
## @table @asis
## @item @qcode{"float"}
## Floating point value comprising classes @qcode{"double"} and
## @qcode{"single"}.
##
## @item @qcode{"integer"}
## Integer value comprising classes (u)int8, (u)int16, (u)int32, (u)int64.
##
## @item @qcode{"numeric"}
## Numeric value comprising either a floating point or integer value.
##
## @end table
##
## @var{attributes} must be a cell array with names of checks for @var{A}.
## Some of them require an additional value to be supplied right after the
## name (see details for each below).
##
## @table @asis
## @item @qcode{"<="}
## All values are less than or equal to the following value in @var{attributes}.
##
## @item @qcode{"<"}
## All values are less than the following value in @var{attributes}.
##
## @item @qcode{">="}
## All values are greater than or equal to the following value in
## @var{attributes}.
##
## @item @qcode{">"}
## All values are greater than the following value in @var{attributes}.
##
## @item @qcode{"2d"}
## A 2-dimensional matrix.  Note that vectors and empty matrices have
## 2 dimensions, one of them being of length 1, or both length 0.
##
## @item @qcode{"3d"}
## Has no more than 3 dimensions.  A 2-dimensional matrix is a 3-D matrix
## whose 3rd dimension is of length 1.
##
## @item @qcode{"binary"}
## All values are either 1 or 0.
##
## @item @qcode{"column"}
## Values are arranged in a single column.
##
## @item @qcode{"decreasing"}
## No value is @var{NaN}, and each is less than the preceding one.
##
## @item @qcode{"even"}
## All values are even numbers.
##
## @item @qcode{"finite"}
## All values are finite.
##
## @item @qcode{"increasing"}
## No value is @var{NaN}, and each is greater than the preceding one.
##
## @item @qcode{"integer"}
## All values are integer.  This is different than using @code{isinteger}
## which only checks its an integer type.  This checks that each value in
## @var{A} is an integer value, i.e., it has no decimal part.
##
## @item @qcode{"ncols"}
## Has exactly as many columns as the next value in @var{attributes}.
##
## @item @qcode{"ndims"}
## Has exactly as many dimensions as the next value in @var{attributes}.
##
## @item @qcode{"nondecreasing"}
## No value is @var{NaN}, and each is greater than or equal to the preceding
## one.
##
## @item @qcode{"nonempty"}
## It is not empty.
##
## @item @qcode{"nonincreasing"}
## No value is @var{NaN}, and each is less than or equal to the preceding one.
##
## @item @qcode{"nonnan"}
## No value is a @code{NaN}.
##
## @item @qcode{"nonnegative"}
## All values are non negative.
##
## @item @qcode{"nonsparse"}
## It is not a sparse matrix.
##
## @item @qcode{"nonzero"}
## No value is zero.
##
## @item @qcode{"nrows"}
## Has exactly as many rows as the next value in @var{attributes}.
##
## @item @qcode{"numel"}
## Has exactly as many elements as the next value in @var{attributes}.
##
## @item @qcode{"odd"}
## All values are odd numbers.
##
## @item @qcode{"positive"}
## All values are positive.
##
## @item @qcode{"real"}
## It is a non-complex matrix.
##
## @item @qcode{"row"}
## Values are arranged in a single row.
##
## @item @qcode{"scalar"}
## It is a scalar.
##
## @item @qcode{"size"}
## Its size has length equal to the values of the next in @var{attributes}.
## The next value must is an array with the length for each dimension.  To
## ignore the check for a certain dimension, the value of @code{NaN} can be
## used.
##
## @item @qcode{"square"}
## Is a square matrix.
##
## @item @qcode{"vector"}
## Values are arranged in a single vector (column or vector).
##
## @end table
##
## @seealso{isa, validatestring, inputParser}
## @end deftypefn
    
    
@function
def validateattributes(A=None,cls=None,attr=None,varargin=None,*args,**kwargs):
    varargin = validateattributes.varargin
    nargin = validateattributes.nargin

    if (nargin < 3 or nargin > 6):
        print_usage()
    else:
        if (logical_not(iscellstr(cls))):
            error('validateattributes: CLASSES must be a cell array of strings')
        else:
            if (logical_not(iscell(attr))):
                error('validateattributes: ATTRIBUTES must be a cell array')
    
    ## Built start of error message from the extra optional arguments
    func_name=''
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:177
    var_name='input'
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:178
    if (nargin > 3):
        fourth=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:180
        if (ischar(fourth)):
            func_name=matlabarray(cat(fourth,': '))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:182
        else:
            if (nargin == 4 and valid_arg_idx(fourth)):
                var_name=sprintf('input %d',fourth)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:184
            else:
                error('validateattributes: 4th input argument must be ARG_IDX or FUNC_NAME')
        if (nargin > 4):
            var_name=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:190
            if (logical_not(ischar(var_name))):
                error('validateattributes: VAR_NAME must be a string')
            if (nargin > 5):
                arg_idx=varargin[3]
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:196
                if (logical_not(valid_arg_idx(arg_idx))):
                    error('validateattributes: ARG_IDX must be a positive integer')
                var_name=sprintf('%s (argument #%i)',var_name,arg_idx)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:200
    
    err_ini=matlabarray(cat(func_name,var_name))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:204
    check_cl=isa(A,cls)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:206
    if (logical_not(isempty(check_cl)) and logical_not(any(check_cl))):
        ## Allowing for an empty list of classes is Matlab incompatible but
    ## that should count as a just a Matlab bug, not an incompatibility.
        ## Replace the category names with the classes that belong to it.
        integer=cellarray(['int8','int16','int32','int64','uint8','uint16','uint32','uint64'])
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:212
        float_=cellarray(['single','double'])
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:214
        numeric=cellarray([integer[:],float_[:]])
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:215
        cls=replace_cl_group(cls,'integer',integer)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:216
        cls=replace_cl_group(cls,'float',float_)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:217
        cls=replace_cl_group(cls,'numeric',numeric)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:218
        cls=unique(cls)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:219
        classes=sprintf(' %s',cls[:])
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:221
        error('%s must be of class:\n\n %s\n\nbut was of class %s',err_ini,classes,class_(A))
    
    ## We use a while loop because some attributes require the following value
  ## in the cell array. Also, we can't just get the boolean value for the
  ## test and check at the end the error message since some of the tests
  ## require some more complex error message.
    
    ## It may look like that we don't perform enough input check in this
  ## function (e.g., we don't check if there's a value after the size
  ## attribute). The reasoning is that this will be a function mostly used
  ## by developers with fairly static input so any problem would be caught
  ## immediately during that functino development, it's no dependent on the
  ## final user input. In addition, it can be called so many times at the
  ## start of every function, we want it to run specially fast.
    idx=1
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:238
    problem=copy(false)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:239
    
    while (idx <= numel(attr)):

        ## TODO: once we use this in Octave core, it might be worthy to find
    ## which attributes are checked more often, and place them in that
    ## order inside the switch block.
        if '2d' == (tolower(attr[idx])):
            problem=ndims(A) != 2
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:245
        else:
            if '3d' == (tolower(attr[idx])):
                problem=ndims(A) > 3
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:246
            else:
                if 'column' == (tolower(attr[idx])):
                    problem=logical_not(iscolumn(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:247
                else:
                    if 'row' == (tolower(attr[idx])):
                        problem=logical_not(isrow(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:248
                    else:
                        if 'scalar' == (tolower(attr[idx])):
                            problem=logical_not(isscalar(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:249
                        else:
                            if 'vector' == (tolower(attr[idx])):
                                problem=logical_not(isvector(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:250
                            else:
                                if 'square' == (tolower(attr[idx])):
                                    problem=logical_not(issquare(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:251
                                else:
                                    if 'nonempty' == (tolower(attr[idx])):
                                        problem=isempty(A)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:252
                                    else:
                                        if 'nonsparse' == (tolower(attr[idx])):
                                            problem=issparse(A)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:253
                                        else:
                                            if 'binary' == (tolower(attr[idx])):
                                                problem=logical_not(islogical(A)) and any(logical_and((ravel(A) != 1),(ravel(A) != 0)))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:254
                                            else:
                                                if 'even' == (tolower(attr[idx])):
                                                    problem=any(rem(ravel(A),2) != 0)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:256
                                                else:
                                                    if 'odd' == (tolower(attr[idx])):
                                                        problem=any(mod(ravel(A),2) != 1)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:257
                                                    else:
                                                        if 'integer' == (tolower(attr[idx])):
                                                            problem=logical_not(isinteger(A)) and any(ceil(ravel(A)) != ravel(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:258
                                                        else:
                                                            if 'real' == (tolower(attr[idx])):
                                                                problem=logical_not(isreal(A))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:260
                                                            else:
                                                                if 'finite' == (tolower(attr[idx])):
                                                                    problem=logical_not(isinteger(A)) and logical_not(all(isfinite(ravel(A))))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:261
                                                                else:
                                                                    if 'nonnan' == (tolower(attr[idx])):
                                                                        problem=logical_not(isinteger(A)) and any(isnan(ravel(A)))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:263
                                                                    else:
                                                                        if 'nonnegative' == (tolower(attr[idx])):
                                                                            problem=any(ravel(A) < 0)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:265
                                                                        else:
                                                                            if 'nonzero' == (tolower(attr[idx])):
                                                                                problem=any(ravel(A) == 0)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:266
                                                                            else:
                                                                                if 'positive' == (tolower(attr[idx])):
                                                                                    problem=any(ravel(A) <= 0)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:267
                                                                                else:
                                                                                    if 'decreasing' == (tolower(attr[idx])):
                                                                                        problem=(any(isnan(ravel(A))) or any(diff(ravel(A)) >= 0))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:268
                                                                                    else:
                                                                                        if 'increasing' == (tolower(attr[idx])):
                                                                                            problem=(any(isnan(ravel(A))) or any(diff(ravel(A)) <= 0))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:270
                                                                                        else:
                                                                                            if 'nondecreasing' == (tolower(attr[idx])):
                                                                                                problem=(any(isnan(ravel(A))) or any(diff(ravel(A)) < 0))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:272
                                                                                            else:
                                                                                                if 'nonincreasing' == (tolower(attr[idx])):
                                                                                                    problem=(any(isnan(ravel(A))) or any(diff(ravel(A)) > 0))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:274
                                                                                                else:
                                                                                                    if 'size' == (tolower(attr[idx])):
                                                                                                        A_size=size(A)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:277
                                                                                                        w_size=attr[idx]
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:278
                                                                                                        A_size[isnan(w_size)]=NaN
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:279
                                                                                                        if (logical_not(isequaln(A_size,w_size))):
                                                                                                            A_size_str=sprintf('%dx',size(A))(arange(1,end() - 1))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:281
                                                                                                            w_size_str=sprintf('%ix',w_size)(arange(1,end() - 1))
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:282
                                                                                                            w_size_str=strrep(w_size_str,'NaN','N')
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:283
                                                                                                            error('%s must be of size %s but was %s',err_ini,w_size_str,A_size_str)
                                                                                                    else:
                                                                                                        if 'numel' == (tolower(attr[idx])):
                                                                                                            if (numel(A) != attr[idx]):
                                                                                                                error('%s must have %d elements',err_ini,attr[idx - 1])
                                                                                                        else:
                                                                                                            if 'ncols' == (tolower(attr[idx])):
                                                                                                                if (columns(A) != attr[idx]):
                                                                                                                    error('%s must have %d columns',err_ini,attr[idx - 1])
                                                                                                            else:
                                                                                                                if 'nrows' == (tolower(attr[idx])):
                                                                                                                    if (rows(A) != attr[idx]):
                                                                                                                        error('%s must have %d rows',err_ini,attr[idx - 1])
                                                                                                                else:
                                                                                                                    if 'ndims' == (tolower(attr[idx])):
                                                                                                                        ## but is ok for "3d". This is not a bug.
                                                                                                                        if (ndims(A) != attr[idx]):
                                                                                                                            error('%s must have %d dimensions',err_ini,attr[idx - 1])
                                                                                                                    else:
                                                                                                                        if '>' == (tolower(attr[idx])):
                                                                                                                            if (logical_not(all(ravel(A) > attr[idx]))):
                                                                                                                                error('%s must be greater than %f',err_ini,attr[idx - 1])
                                                                                                                        else:
                                                                                                                            if '>=' == (tolower(attr[idx])):
                                                                                                                                if (logical_not(all(ravel(A) >= attr[idx]))):
                                                                                                                                    error('%s must be greater than or equal to %f',err_ini,attr[idx - 1])
                                                                                                                            else:
                                                                                                                                if '<' == (tolower(attr[idx])):
                                                                                                                                    if (logical_not(all(ravel(A) < attr[idx]))):
                                                                                                                                        error('%s must be less than %f',err_ini,attr[idx - 1])
                                                                                                                                else:
                                                                                                                                    if '<=' == (tolower(attr[idx])):
                                                                                                                                        if (logical_not(all(ravel(A) <= attr[idx]))):
                                                                                                                                            error('%s must be less than or equal to %f',err_ini,attr[idx - 1])
                                                                                                                                    else:
                                                                                                                                        error('validateattributes: unknown ATTRIBUTE %s',attr[idx - 1])
        if (problem):
            error('%s must be %s',err_ini,attr[idx - 1])

    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def valid_arg_idx(arg=None,*args,**kwargs):
    varargin = valid_arg_idx.varargin
    nargin = valid_arg_idx.nargin

    retval=isnumeric(arg) and isscalar(arg) and arg > 0 and arg == fix(arg)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:330
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def replace_cl_group(cls=None,name=None,group=None,*args,**kwargs):
    varargin = replace_cl_group.varargin
    nargin = replace_cl_group.nargin

    num_pos=strcmpi(cls,name)
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:334
    if (any(num_pos)):
        cls[num_pos]=[]
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:336
        cls[end() + 1:end() + numel(group)]=group
# /home/lei/octave-4.0.2/scripts/general/validateattributes.m:337
    
    return cls
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} narginchk (@var{minargs}, @var{maxargs})
## Check for correct number of input arguments.
##
## Generate an error message if the number of arguments in the calling function
## is outside the range @var{minargs} and @var{maxargs}.  Otherwise, do nothing.
##
## Both @var{minargs} and @var{maxargs} must be scalar numeric values.  Zero,
## Inf, and negative values are all allowed, and @var{minargs} and @var{maxargs}
## may be equal.
##
## Note that this function evaluates @code{nargin} on the caller.
##
## @seealso{nargoutchk, error, nargout, nargin}
## @end deftypefn
    
    ## Author: Carn Draug <carandraug+dev@gmail.com>
    
    
@function
def narginchk(minargs=None,maxargs=None,*args,**kwargs):
    varargin = narginchk.varargin
    nargin = narginchk.nargin

    if (nargin != 2):
        print_usage
    else:
        if (logical_not(isnumeric(minargs)) or logical_not(isscalar(minargs))):
            error('minargs must be a numeric scalar')
        else:
            if (logical_not(isnumeric(maxargs)) or logical_not(isscalar(maxargs))):
                error('maxargs must be a numeric scalar')
            else:
                if (minargs > maxargs):
                    error('minargs cannot be larger than maxargs')
    
    args=evalin('caller','nargin;')
# /home/lei/octave-4.0.2/scripts/general/narginchk.m:49
    if (args < minargs):
        error('not enough input arguments')
    else:
        if (args > maxargs):
            error('too many input arguments')
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} bincoeff (@var{n}, @var{k})
## Return the binomial coefficient of @var{n} and @var{k}, defined as
## @tex
## $$
##  {n \choose k} = {n (n-1) (n-2) \cdots (n-k+1) \over k!}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##  /   \
##  | n |    n (n-1) (n-2) @dots{} (n-k+1)
##  |   |  = -------------------------
##  | k |               k!
##  \   /
## @end group
## @end example
##
## @end ifnottex
## For example:
##
## @example
## @group
## bincoeff (5, 2)
##    @result{} 10
## @end group
## @end example
##
## In most cases, the @code{nchoosek} function is faster for small
## scalar integer arguments.  It also warns about loss of precision for
## big arguments.
##
## @seealso{nchoosek}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 8 October 1994
## Adapted-By: jwe
    
    
@function
def bincoeff(n=None,k=None,*args,**kwargs):
    varargin = bincoeff.varargin
    nargin = bincoeff.nargin

    if (nargin != 2):
        print_usage()
    
    retval,n,k=common_size(n,k,nargout=3)
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:66
    if (retval > 0):
        error('bincoeff: N and K must be of common size or scalars')
    
    if (iscomplex(n) or iscomplex(k)):
        error('bincoeff: N and K must not be complex')
    
    b=zeros(size(n))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:75
    ok=logical_and(logical_and((k >= 0),(k == fix(k))),(logical_not(isnan(n))))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:77
    b[logical_not(ok)]=NaN
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:78
    n_int=(n == fix(n))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:80
    idx=logical_and(logical_and(n_int,(n < 0)),ok)
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:81
    b[idx]=multiply((- 1) ** k[idx],exp(gammaln(abs(n[idx]) + k[idx]) - gammaln(k[idx] + 1) - gammaln(abs(n[idx]))))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:82
    idx=logical_and((n >= k),ok)
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:86
    b[idx]=exp(gammaln(n[idx] + 1) - gammaln(k[idx] + 1) - gammaln(n[idx] - k[idx] + 1))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:87
    idx=logical_and(logical_and((logical_not(n_int)),(n < k)),ok)
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:91
    b[idx]=dot((1 / pi),exp(gammaln(n[idx] + 1) - gammaln(k[idx] + 1) + gammaln(k[idx] - n[idx]) + log(sin(dot(pi,(n[idx] - k[idx] + 1))))))
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:92
    
    b[n_int]=round(b[n_int])
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:98
    idx=logical_not(n_int)
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:100
    b[idx]=real(b[idx])
# /home/lei/octave-4.0.2/scripts/general/bincoeff.m:101
    return b
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{b} =} loadobj (@var{a})
## Method of a class to manipulate an object after loading it from a file.
##
## The function @code{loadobj} is called when the object @var{a} is loaded
## using the @code{load} function.  An example of the use of @code{saveobj}
## might be to add fields to an object that don't make sense to be saved.
## For example:
##
## @example
## @group
## function b = loadobj (a)
##   b = a;
##   b.addmissingfield = addfield (b);
## endfunction
## @end group
## @end example
##
## @seealso{saveobj, class}
## @end deftypefn
    
    
@function
def loadobj(a=None,*args,**kwargs):
    varargin = loadobj.varargin
    nargin = loadobj.nargin

    error('loadobj: not defined for class "%s"',class_(a))
    return b
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Daniel Kraft
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} profile on
## @deftypefnx {Command} {} profile off
## @deftypefnx {Command} {} profile resume
## @deftypefnx {Command} {} profile clear
## @deftypefnx {Function File} {@var{S} =} profile ("status")
## @deftypefnx {Function File} {@var{T} =} profile ("info")
## Control the built-in profiler.
##
## @table @code
## @item profile on
## Start the profiler, clearing all previously collected data if there is any.
##
## @item profile off
## Stop profiling.  The collected data can later be retrieved and examined
## with @code{T = profile ("info")}.
##
## @item profile clear
## Clear all collected profiler data.
##
## @item profile resume
## Restart profiling without clearing the old data.  All newly collected
## statistics are added to the existing ones.
##
## @item @var{S} = profile ("status")
## Return a structure with information about the current status of the profiler.
## At the moment, the only field is @code{ProfilerStatus} which is either
## @qcode{"on"} or @qcode{"off"}.
##
## @item @var{T} = profile ("info")
## Return the collected profiling statistics in the structure @var{T}.  The
## flat profile is returned in the field @code{FunctionTable} which is an
## array of structures, each entry corresponding to a function which was called
## and for which profiling statistics are present.  In addition, the field
## @code{Hierarchical} contains the hierarchical call tree.  Each node has an
## index into the @code{FunctionTable} identifying the function it corresponds
## to as well as data fields for number of calls and time spent at this level
## in the call tree.
## @seealso{profshow, profexplore}
## @end table
## @end deftypefn
    
    ## Built-in profiler.
## Author: Daniel Kraft <d@domob.eu>
    
    
@function
def profile(option=None,*args,**kwargs):
    varargin = profile.varargin
    nargin = profile.nargin

    if (nargin != 1):
        print_usage()
    
    if 'on' == (option):
        __profiler_reset__()
        __profiler_enable__(true)
    else:
        if 'off' == (option):
            __profiler_enable__(false)
        else:
            if 'clear' == (option):
                __profiler_reset__()
            else:
                if 'resume' == (option):
                    __profiler_enable__(true)
                else:
                    if 'status' == (option):
                        enabled=__profiler_enable__()
# /home/lei/octave-4.0.2/scripts/general/profile.m:85
                        if (enabled):
                            enabled='on'
# /home/lei/octave-4.0.2/scripts/general/profile.m:87
                        else:
                            enabled='off'
# /home/lei/octave-4.0.2/scripts/general/profile.m:89
                        retval=struct('ProfilerStatus',enabled)
# /home/lei/octave-4.0.2/scripts/general/profile.m:91
                    else:
                        if 'info' == (option):
                            flat,tree=__profiler_data__(nargout=2)
# /home/lei/octave-4.0.2/scripts/general/profile.m:94
                            retval=struct('FunctionTable',flat,'Hierarchical',tree)
# /home/lei/octave-4.0.2/scripts/general/profile.m:95
                        else:
                            warning('profile: Unrecognized option \'%s\'',option)
                            print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2010-2015 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} accumdim (@var{subs}, @var{vals}, @var{dim}, @var{n}, @var{func}, @var{fillval})
## Create an array by accumulating the slices of an array into the
## positions defined by their subscripts along a specified dimension.
##
## The subscripts are defined by the index vector @var{subs}.
## The dimension is specified by @var{dim}.  If not given, it defaults
## to the first non-singleton dimension.  The length of @var{subs} must
## be equal to @code{size (@var{vals}, @var{dim})}.
##
## The extent of the result matrix in the working dimension will be
## determined by the subscripts themselves.  However, if @var{n} is
## defined it determines this extent.
##
## The default action of @code{accumdim} is to sum the subarrays with the
## same subscripts.  This behavior can be modified by defining the
## @var{func} function.  This should be a function or function handle
## that accepts an array and a dimension, and reduces the array along
## this dimension.  As a special exception, the built-in @code{min} and
## @code{max} functions can be used directly, and @code{accumdim}
## accounts for the middle empty argument that is used in their calling.
##
## The slices of the returned array that have no subscripts associated
## with them are set to zero.  Defining @var{fillval} to some other
## value allows these values to be defined.
##
## An example of the use of @code{accumdim} is:
##
## @example
## @group
## accumdim ([1, 2, 1, 2, 1], [ 7, -10,   4;
##                             -5, -12,   8;
##                            -12,   2,   8;
##                            -10,   9,  -3;
##                             -5,  -3, -13])
## @result{} [-10,-11,-1;-15,-3,5]
## @end group
## @end example
##
## @seealso{accumarray}
## @end deftypefn
    
    
@function
def accumdim(subs=None,vals=None,dim=None,n=0,func=[],fillval=0,*args,**kwargs):
    varargin = accumdim.varargin
    nargin = accumdim.nargin

    if (nargin < 2 or nargin > 6):
        print_usage()
    
    if (isempty(fillval)):
        fillval=0
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:68
    
    if (logical_not(isvector(subs))):
        error('accumdim: SUBS must be a subscript vector')
    else:
        if (logical_not(isindex(subs))):
            error('accumdim: indices must be positive integers')
        else:
            m=max(subs)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:76
            if (n == 0 or isempty(n)):
                n=copy(m)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:78
            else:
                if (n < m):
                    error('accumdim: N index out of range')
    
    sz=size(vals)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:84
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:None
    else:
        if (logical_not(isindex(dim))):
            error('accumdim: DIM must be a valid dimension')
        else:
            if (dim > length(sz)):
                sz[end() + 1:dim]=1
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:92
    
    sz[dim]=n
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:94
    if (length(subs) != size(vals,dim)):
        error('accumdim: dimension mismatch')
    
    if (isempty(func) or func == sum):
        ## Fast summation case.
        A=__accumdim_sum__(subs,vals,dim,n)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:102
        if (fillval != 0):
            mask=true(n,1)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:106
            mask[subs]=false
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:107
            subsc=cellarray([':'])(ones(1,length(sz)))
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:108
            subsc[dim]=mask
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:109
            A[subsc[:]]=fillval
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:110
        return A
    
    ## The general case.
    ns=length(subs)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:116
    
    subs,idx=sort(ravel(subs),nargout=2)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:118
    
    jdx=find(subs[1:ns - 1] != subs[2:ns])
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:120
    jdx=matlabarray(cat([jdx],[ns]))
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:121
    
    szc=num2cell(sz)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:123
    szc[dim]=diff(cat([0],[jdx]))
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:124
    subsc=cellarray([':'])(ones(1,length(sz)))
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:125
    subsc[dim]=idx
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:126
    vals=mat2cell(vals[subsc[:]],szc[:])
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:127
    
    if (func == min or func == max):
        vals=cellfun(func,vals,cellarray([[]]),cellarray([dim]),'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:130
    else:
        vals=cellfun(func,vals,cellarray([dim]),'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:132
    
    subs=subs[jdx]
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:134
    
    vals=cat(dim,vals[:])
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:137
    
    if (fillval == 0):
        A=zeros(sz,class_(vals))
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:141
    else:
        A=repmat(fillval,sz)
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:143
    
    ## Set the reduced values.
    subsc[dim]=subs
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:147
    A[subsc[:]]=vals
# /home/lei/octave-4.0.2/scripts/general/accumdim.m:148
    return A
    
if __name__ == '__main__':
    pass
    
    ## Test accumdim vs. accumarray
    
    
    
    
    
    
    ## Test fillval
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 David Bateman
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} flipdim (@var{x})
## @deftypefnx {Function File} {} flipdim (@var{x}, @var{dim})
## Flip array across dimension @var{dim}.
##
## This function is an alias for @code{flip} and exists for backwards and
## @sc{matlab} compatibility.  See @code{flip} for complete usage information.
##
## @seealso{flip, fliplr, flipud, rot90, rotdim}
## @end deftypefn
    
    ## Author: David Bateman, Jaroslav Hajek
    
    
@function
def flipdim(varargin=None,*args,**kwargs):
    varargin = flipdim.varargin
    nargin = flipdim.nargin

    y=flip(varargin[:])
# /home/lei/octave-4.0.2/scripts/general/flipdim.m:34
    return y
    
if __name__ == '__main__':
    pass
    
    ## No tests needed for alias.  All tests for functionality are in flip.m
    
    ## Copyright (C) 2014-2015 Markus Bergholz
## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2008 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} repmat (@var{A}, @var{m})
## @deftypefnx {Function File} {} repmat (@var{A}, @var{m}, @var{n})
## @deftypefnx {Function File} {} repmat (@var{A}, @var{m}, @var{n}, @var{p} @dots{})
## @deftypefnx {Function File} {} repmat (@var{A}, [@var{m} @var{n}])
## @deftypefnx {Function File} {} repmat (@var{A}, [@var{m} @var{n} @var{p} @dots{}])
## Form a block matrix of size @var{m} by @var{n}, with a copy of matrix
## @var{A} as each element.
##
## If @var{n} is not specified, form an @var{m} by @var{m} block matrix.  For
## copying along more than two dimensions, specify the number of times to copy
## across each dimension @var{m}, @var{n}, @var{p}, @dots{}, in a vector in the
## second argument.
## @seealso{repelems}
## @end deftypefn
    
    ## Author: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
## Created: July 2000
    
    
@function
def repmat(A=None,m=None,varargin=None,*args,**kwargs):
    varargin = repmat.varargin
    nargin = repmat.nargin

    if (nargin < 2):
        print_usage()
    
    if (nargin == 3):
        n=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:47
        if (logical_not(isempty(m)) and isempty(n)):
            m=ravel(m).T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:49
            n=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:50
        else:
            if (isempty(m) and logical_not(isempty(n))):
                m=ravel(n).T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:52
                n=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:53
            else:
                if (isempty(m) and isempty(n)):
                    m=n=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:55
# /home/lei/octave-4.0.2/scripts/general/repmat.m:55
                else:
                    if (all(size(m) > 1)):
                        m=m[:,1]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:58
                        if (numel(m) < 3):
                            n=n[end()]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:60
                        else:
                            n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/repmat.m:62
                    if (all(size(n) > 1)):
                        n=n[:,1]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:66
                    m=ravel(m).T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:68
                    n=ravel(n).T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:69
    else:
        if (nargin > 3):
            ## input check for m and varargin
            if (isscalar(m) and all(cellfun('numel',varargin) == 1)):
                m=matlabarray(cat(m,varargin[:]))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:75
                n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/repmat.m:76
            else:
                error('repmat: all input arguments must be scalar')
        else:
            if (isempty(m)):
                m=n=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:81
# /home/lei/octave-4.0.2/scripts/general/repmat.m:81
            else:
                if (isscalar(m)):
                    n=copy(m)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:83
                else:
                    if (ndims(m) > 2):
                        error('repmat: M has more than 2 dimensions')
                    else:
                        if (all(size(m) > 1)):
                            m=m[:,1].T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:87
                            n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/repmat.m:88
                        else:
                            m=ravel(m).T
# /home/lei/octave-4.0.2/scripts/general/repmat.m:90
                            n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/repmat.m:91
    
    idx=matlabarray(cat(m,n))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:94
    if (all(idx < 0)):
        error('repmat: invalid dimensions')
    else:
        idx=max(idx,0)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:99
    
    if (numel(A) == 1):
        ## optimize the scalar fill case.
        if (any(idx == 0)):
            x=resize(A,idx)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:105
        else:
            x[1:prod(idx)]=A
# /home/lei/octave-4.0.2/scripts/general/repmat.m:107
            x=reshape(x,idx)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:108
    else:
        if (ndims(A) == 2 and length(idx) < 3):
            if (issparse(A)):
                x=kron(ones(idx),A)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:112
            else:
                ## indexing is now faster, so we use it rather than kron.
                m=rows(A)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:115
                n=columns(A)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:115
                p=idx[1]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:116
                q=idx[2]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:116
                x=reshape(A,m,1,n,1)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:117
                x=x[:,ones(1,p),:,ones(1,q)]
# /home/lei/octave-4.0.2/scripts/general/repmat.m:118
                x=reshape(x,dot(m,p),dot(n,q))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:119
        else:
            aidx=size(A)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:122
            idx[end() + 1:length(aidx)]=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:124
            aidx[end() + 1:length(idx)]=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:125
            cidx=cell(2,length(aidx))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:127
            for i in arange(1,length(aidx)).reshape(-1):
                cidx[1,i]=':'
# /home/lei/octave-4.0.2/scripts/general/repmat.m:129
                cidx[2,i]=ones(1,idx[i])
# /home/lei/octave-4.0.2/scripts/general/repmat.m:130
            aaidx=copy(aidx)
# /home/lei/octave-4.0.2/scripts/general/repmat.m:132
            aaidx[2,:]=1
# /home/lei/octave-4.0.2/scripts/general/repmat.m:134
            A=reshape(A,ravel(aaidx))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:135
            x=reshape(A[cidx[:]],multiply(idx,aidx))
# /home/lei/octave-4.0.2/scripts/general/repmat.m:136
    
    return x
    
if __name__ == '__main__':
    pass
    
    ## Tests for ML compatibility
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test various methods of providing size parameters
    
    
    
    
    
    
    
    
    
    ## Tests for numel==1 case:
    
    
    
    
    
    
    ## Tests for ndims==2 case:
    
    
    
    
    
    
    ## Tests for dim>2 case:
    
    
    
    
    
    
    
    ## Test that sparsity is kept
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2016 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{y}] =} pol2cart (@var{theta}, @var{r})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{theta}, @var{r}, @var{z})
## @deftypefnx {Function File} {[@var{x}, @var{y}] =} pol2cart (@var{P})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{P})
## @deftypefnx {Function File} {@var{C} =} pol2cart (@dots{})
## Transform polar or cylindrical coordinates to Cartesian coordinates.
##
## The inputs @var{theta}, @var{r}, (and @var{z}) must be the same shape, or
## scalar.  If called with a single matrix argument then each row of @var{P}
## represents the polar/(cylindrical) coordinate (@var{theta}, @var{r}
## (, @var{z})).
##
## @var{theta} describes the angle relative to the positive x-axis.
##
## @var{r} is the distance to the z-axis (0, 0, z).
##
## If only a single return argument is requested then return a matrix @var{C}
## where each row represents one Cartesian coordinate
## (@var{x}, @var{y} (, @var{z})).
## @seealso{cart2pol, sph2cart, cart2sph}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def pol2cart(theta=None,r=None,z=[],*args,**kwargs):
    varargin = pol2cart.varargin
    nargin = pol2cart.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin == 1):
        if (logical_not((isnumeric(theta) and ismatrix(theta) and (columns(theta) == 2 or columns(theta) == 3)))):
            error('pol2cart: matrix input must have 2 or 3 columns [THETA, R (, Z)]')
        if (columns(theta) == 3):
            z=theta[:,3]
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:57
        r=theta[:,2]
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:59
        theta=theta[:,1]
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:60
    else:
        if (nargin == 2):
            if (logical_not(((isnumeric(theta) and isnumeric(r)) and (size_equal(theta,r) or isscalar(theta) or isscalar(r))))):
                error('pol2cart: THETA, R must be numeric arrays of the same size, or scalar')
        else:
            if (nargin == 3):
                if (logical_not(((isnumeric(theta) and isnumeric(r) and isnumeric(z)) and (size_equal(theta,r) or isscalar(theta) or isscalar(r)) and (size_equal(theta,z) or isscalar(theta) or isscalar(z)) and (size_equal(r,z) or isscalar(r) or isscalar(z))))):
                    error('pol2cart: THETA, R, Z must be numeric arrays of the same size, or scalar')
    
    x=multiply(r,cos(theta))
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:75
    y=multiply(r,sin(theta))
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:76
    if (nargout <= 1):
        x=matlabarray(cat(ravel(x),ravel(y),ravel(z)))
# /home/lei/octave-4.0.2/scripts/general/pol2cart.m:79
    
    return x,y,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} prepad (@var{x}, @var{l})
## @deftypefnx {Function File} {} prepad (@var{x}, @var{l}, @var{c})
## @deftypefnx {Function File} {} prepad (@var{x}, @var{l}, @var{c}, @var{dim})
## Prepend the scalar value @var{c} to the vector @var{x} until it is of length
## @var{l}.  If @var{c} is not given, a value of 0 is used.
##
## If @code{length (@var{x}) > @var{l}}, elements from the beginning of @var{x}
## are removed until a vector of length @var{l} is obtained.
##
## If @var{x} is a matrix, elements are prepended or removed from each row.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## If @var{dim} is larger than the dimensions of @var{x}, the result will have
## @var{dim} dimensions.
## @seealso{postpad, cat, resize}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
    
    
@function
def prepad(x=None,l=None,c=None,dim=None,*args,**kwargs):
    varargin = prepad.varargin
    nargin = prepad.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (nargin < 3 or isempty(c)):
        c=0
# /home/lei/octave-4.0.2/scripts/general/prepad.m:48
    else:
        if (logical_not(isscalar(c))):
            error('prepad: pad value C must be empty or a scalar')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/prepad.m:55
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/prepad.m:56
    if (nargin < 4):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/prepad.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim) and dim >= 1))):
            error('prepad: DIM must be an integer and a valid dimension')
    
    if (logical_not(isscalar(l)) or l < 0):
        error('prepad: length L must be a positive scalar')
    
    if (dim > nd):
        sz[nd + 1:dim]=1
# /home/lei/octave-4.0.2/scripts/general/prepad.m:71
    
    d=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/prepad.m:74
    if (d >= l):
        idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/prepad.m:77
        idx[dim]=arange(d - l + 1,d)
# /home/lei/octave-4.0.2/scripts/general/prepad.m:78
        y=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/prepad.m:79
    else:
        sz[dim]=l - d
# /home/lei/octave-4.0.2/scripts/general/prepad.m:81
        y=cat(dim,c[ones(sz)],x)
# /home/lei/octave-4.0.2/scripts/general/prepad.m:82
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: We need tests for multidimensional arrays.
    
    
    ## Copyright (C) 2008-2015 Bill Denney
## Copyright (C) 2012 Carn Draug
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} nargoutchk (@var{minargs}, @var{maxargs})
## @deftypefnx {Function File} {@var{msgstr} =} nargoutchk (@var{minargs}, @var{maxargs}, @var{nargs})
## @deftypefnx {Function File} {@var{msgstr} =} nargoutchk (@var{minargs}, @var{maxargs}, @var{nargs}, "string")
## @deftypefnx {Function File} {@var{msgstruct} =} nargoutchk (@var{minargs}, @var{maxargs}, @var{nargs}, "struct")
## Check for correct number of output arguments.
##
## In the first form, return an error if the number of arguments is not between
## @var{minargs} and @var{maxargs}.  Otherwise, do nothing.  Note that this
## function evaluates the value of @code{nargout} on the caller so its value
## must have not been tampered with.
##
## Both @var{minargs} and @var{maxargs} must be numeric scalars.  Zero, Inf,
## and negative are all valid, and they can have the same value.
##
## For backwards compatibility, the other forms return an appropriate error
## message string (or structure) if the number of outputs requested is
## invalid.
##
## This is useful for checking to that the number of output arguments supplied
## to a function is within an acceptable range.
## @seealso{narginchk, error, nargout, nargin}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
## Author: Carn Draug <carandraug+dev@gmail.com>
    
    
@function
def nargoutchk(minargs=None,maxargs=None,nargs=None,outtype=None,*args,**kwargs):
    varargin = nargoutchk.varargin
    nargin = nargoutchk.nargin

    ## before matlab's 2011b, nargoutchk would return an error message (just the
  ## message in a string). With 2011b, it no longer returns anything, it simply
  ## gives an error if the args number is incorrect.
  ## To try to keep compatibility with both versions, check nargout and nargin
  ## to guess if the caller is expecting a value (old syntax)
  ## or none (new syntax).
    
    if (nargout == 1 and (nargin == 3 or nargin == 4)):
        if (minargs > maxargs):
            error('nargoutchk: MINARGS must be <= MAXARGS')
        else:
            if (nargin == 3):
                outtype='string'
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:61
            else:
                if (logical_not(any(strcmpi(outtype,cellarray(['string','struct']))))):
                    error('nargoutchk: output type must be either string or struct')
                else:
                    if (logical_not((isscalar(minargs) and isscalar(maxargs) and isscalar(nargs)))):
                        error('nargoutchk: MINARGS, MAXARGS, and NARGS must be scalars')
        msg=struct('message','','identifier','')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:68
        if (nargs < minargs):
            msg.message = copy('not enough output arguments')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:70
            msg.identifier = copy('Octave:nargoutchk:not-enough-outputs')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:71
        else:
            if (nargs > maxargs):
                msg.message = copy('too many output arguments')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:73
                msg.identifier = copy('Octave:nargoutchk:too-many-outputs')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:74
        if (strcmpi(outtype,'string')):
            msg=msg.message
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:78
        else:
            if (isempty(msg.message)):
                ## Compatibility: Matlab returns a 0x1 empty struct when nargoutchk passes
                msg=resize(msg,0,1)
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:81
    else:
        if (nargout == 0 and nargin == 2):
            if (logical_not(isnumeric(minargs)) or logical_not(isscalar(minargs))):
                error('minargs must be a numeric scalar')
            else:
                if (logical_not(isnumeric(maxargs)) or logical_not(isscalar(maxargs))):
                    error('maxargs must be a numeric scalar')
                else:
                    if (minargs > maxargs):
                        error('minargs cannot be larger than maxargs')
            args=evalin('caller','nargout;')
# /home/lei/octave-4.0.2/scripts/general/nargoutchk.m:94
            if (args < minargs):
                error('Not enough output arguments.')
            else:
                if (args > maxargs):
                    error('Too many output arguments.')
        else:
            print_usage
    
    return msg
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Struct outputs
    
    
    
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} cumtrapz (@var{y})
## @deftypefnx {Function File} {@var{q} =} cumtrapz (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{q} =} cumtrapz (@dots{}, @var{dim})
## Cumulative numerical integration of points @var{y} using the trapezoidal
## method.
##
## @w{@code{cumtrapz (@var{y})}} computes the cumulative integral of @var{y}
## along the first non-singleton dimension.  Where @code{trapz} reports only
## the overall integral sum, @code{cumtrapz} reports the current partial sum
## value at each point of @var{y}.
##
## When the argument @var{x} is omitted an equally spaced @var{x} vector with
## unit spacing (1) is assumed.  @code{cumtrapz (@var{x}, @var{y})} evaluates
## the integral with respect to the spacing in @var{x} and the values in
## @var{y}.  This is useful if the points in @var{y} have been sampled unevenly.
##
## If the optional @var{dim} argument is given, operate along this dimension.
##
## Application Note: If @var{x} is not specified then unit spacing will be
## used.  To scale the integral to the correct value you must multiply by the
## actual spacing value (deltaX).
## @seealso{trapz, cumsum}
## @end deftypefn
    
    ## Author:      Kai Habel <kai.habel@gmx.de>
##
## also: June 2000 Paul Kienzle (fixes,suggestions)
## 2006-05-12 David Bateman - Modified for NDArrays
    
    
@function
def cumtrapz(x=None,y=None,dim=None,*args,**kwargs):
    varargin = cumtrapz.varargin
    nargin = cumtrapz.nargin

    if (nargin < 1) or (nargin > 3):
        print_usage()
    
    have_xy=have_dim=copy(false)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:55
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:55
    if (nargin == 3):
        have_xy=copy(true)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:58
        have_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:59
    else:
        if (nargin == 2):
            if (logical_not(size_equal(x,y)) and isscalar(y)):
                dim=copy(y)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:62
                have_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:63
            else:
                have_xy=copy(true)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:65
    
    if (have_xy):
        nd=ndims(y)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:70
        sz=size(y)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:71
    else:
        nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:73
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:74
    
    if (logical_not(have_dim)):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('trapz: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:87
    idx1=idx2=repmat(cellarray([':']),cat(nd,1))
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:88
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:88
    idx1[dim]=arange(2,n)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:89
    idx2[dim]=arange(1,(n - 1))
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:90
    if (logical_not(have_xy)):
        z=dot(0.5,cumsum(x[idx1[:]] + x[idx2[:]],dim))
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:93
    else:
        if (isvector(x) and logical_not(isvector(y))):
            if (length(x) != sz[dim]):
                error('cumtrapz: length of X and length of Y along DIM must match')
            ## Reshape vector to point along dimension DIM
            shape=ones(nd,1)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:100
            shape[dim]=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:101
            x=reshape(x,shape)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:102
            z=dot(0.5,cumsum(bsxfun(times,diff(x),y[idx1[:]] + y[idx2[:]]),dim))
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:103
        else:
            if (logical_not(size_equal(x,y))):
                error('cumtrapz: X and Y must have same shape')
            z=dot(0.5,cumsum(multiply(diff(x,1,dim),(y[idx1[:]] + y[idx2[:]])),dim))
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:108
    
    sz[dim]=1
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:112
    z=cat(dim,zeros(sz),z)
# /home/lei/octave-4.0.2/scripts/general/cumtrapz.m:113
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test ND-array implementation
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} trapz (@var{y})
## @deftypefnx {Function File} {@var{q} =} trapz (@var{x}, @var{y})
## @deftypefnx {Function File} {@var{q} =} trapz (@dots{}, @var{dim})
##
## Numerically evaluate the integral of points @var{y} using the trapezoidal
## method.
##
## @w{@code{trapz (@var{y})}} computes the integral of @var{y} along the first
## non-singleton dimension.  When the argument @var{x} is omitted an equally
## spaced @var{x} vector with unit spacing (1) is assumed.
## @code{trapz (@var{x}, @var{y})} evaluates the integral with respect to the
## spacing in @var{x} and the values in @var{y}.  This is useful if the points
## in @var{y} have been sampled unevenly.
##
## If the optional @var{dim} argument is given, operate along this dimension.
##
## Application Note: If @var{x} is not specified then unit spacing will be
## used.  To scale the integral to the correct value you must multiply by the
## actual spacing value (deltaX).  As an example, the integral of @math{x^3}
## over the range [0, 1] is @math{x^4/4} or 0.25.  The following code uses
## @code{trapz} to calculate the integral in three different ways.
##
## @example
## @group
## x = 0:0.1:1;
## y = x.^3;
## q = trapz (y)
##   @result{} q = 2.525   # No scaling
## q * 0.1
##   @result{} q = 0.2525  # Approximation to integral by scaling
## trapz (x, y)
##   @result{} q = 0.2525  # Same result by specifying @var{x}
## @end group
## @end example
##
## @seealso{cumtrapz}
## @end deftypefn
    
    ## Author:      Kai Habel <kai.habel@gmx.de>
##
## also: June 2000 - Paul Kienzle (fixes,suggestions)
## 2006-05-12 David Bateman - Modified for NDArrays
    
    
@function
def trapz(x=None,y=None,dim=None,*args,**kwargs):
    varargin = trapz.varargin
    nargin = trapz.nargin

    if (nargin < 1) or (nargin > 3):
        print_usage()
    
    have_xy=have_dim=copy(false)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:69
# /home/lei/octave-4.0.2/scripts/general/trapz.m:69
    if (nargin == 3):
        have_xy=copy(true)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:72
        have_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:73
    else:
        if (nargin == 2):
            if (logical_not(size_equal(x,y)) and isscalar(y)):
                dim=copy(y)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:76
                have_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:77
            else:
                have_xy=copy(true)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:79
    
    if (have_xy):
        nd=ndims(y)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:84
        sz=size(y)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:85
    else:
        nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:87
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:88
    
    if (logical_not(have_dim)):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/trapz.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('trapz: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/trapz.m:101
    idx1=idx2=repmat(cellarray([':']),cat(nd,1))
# /home/lei/octave-4.0.2/scripts/general/trapz.m:102
# /home/lei/octave-4.0.2/scripts/general/trapz.m:102
    idx1[dim]=arange(2,n)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:103
    idx2[dim]=arange(1,(n - 1))
# /home/lei/octave-4.0.2/scripts/general/trapz.m:104
    if (logical_not(have_xy)):
        z=dot(0.5,sum(x[idx1[:]] + x[idx2[:]],dim))
# /home/lei/octave-4.0.2/scripts/general/trapz.m:107
    else:
        if (isvector(x) and logical_not(isvector(y))):
            if (length(x) != sz[dim]):
                error('trapz: length of X and length of Y along DIM must match')
            ## Reshape vector to point along dimension DIM
            shape=ones(nd,1)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:114
            shape[dim]=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/trapz.m:115
            x=reshape(x,shape)
# /home/lei/octave-4.0.2/scripts/general/trapz.m:116
            z=dot(0.5,sum(bsxfun(times,diff(x),y[idx1[:]] + y[idx2[:]]),dim))
# /home/lei/octave-4.0.2/scripts/general/trapz.m:117
        else:
            if (logical_not(size_equal(x,y))):
                error('trapz: X and Y must have same shape')
            z=dot(0.5,sum(multiply(diff(x,1,dim),(y[idx1[:]] + y[idx2[:]])),dim))
# /home/lei/octave-4.0.2/scripts/general/trapz.m:122
    
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} interpft (@var{x}, @var{n})
## @deftypefnx {Function File} {} interpft (@var{x}, @var{n}, @var{dim})
##
## Fourier interpolation.
##
## If @var{x} is a vector then @var{x} is resampled with @var{n} points.  The
## data in @var{x} is assumed to be equispaced.  If @var{x} is a matrix or an
## N-dimensional array, the interpolation is performed on each column of
## @var{x}.
##
## If @var{dim} is specified, then interpolate along the dimension @var{dim}.
##
## @code{interpft} assumes that the interpolated function is periodic, and so
## assumptions are made about the endpoints of the interpolation.
## @seealso{interp1}
## @end deftypefn
    
    ## Author: Paul Kienzle
## 2001-02-11
##    * initial version
## 2002-03-17 aadler
##    * added code to work on matrices as well
## 2006-05-25 dbateman
##    * Make it matlab compatiable, cutting out the 2-D interpolation
    
    
@function
def interpft(x=None,n=None,dim=None,*args,**kwargs):
    varargin = interpft.varargin
    nargin = interpft.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isscalar(n) and n == fix(n)))):
        error('interpft: N must be a scalar integer')
    
    if (nargin == 2):
        if (isrow(x)):
            dim=2
# /home/lei/octave-4.0.2/scripts/general/interpft.m:57
        else:
            dim=1
# /home/lei/octave-4.0.2/scripts/general/interpft.m:59
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:63
    if (dim < 1 or dim > nd):
        error('interpft: invalid dimension DIM')
    
    perm=matlabarray(cat(arange(dim,nd),arange(1,(dim - 1))))
# /home/lei/octave-4.0.2/scripts/general/interpft.m:69
    x=permute(x,perm)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:70
    m=rows(x)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:71
    inc=ceil(m / n)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:73
    y=fft(x) / m
# /home/lei/octave-4.0.2/scripts/general/interpft.m:74
    k=ceil(m / 2)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:75
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:76
    sz[1]=dot(n,inc) - m
# /home/lei/octave-4.0.2/scripts/general/interpft.m:77
    idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:79
    idx[1]=arange(1,k)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:80
    z=cat(1,y[idx[:]],zeros(sz))
# /home/lei/octave-4.0.2/scripts/general/interpft.m:81
    idx[1]=arange(k + 1,m)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:82
    z=cat(1,z,y[idx[:]])
# /home/lei/octave-4.0.2/scripts/general/interpft.m:83
    
    ## If zero-padded above, distribute the value of the Nyquist bin evenly
  ## between the new corresponding positive and negative frequency bins.
    if (sz[1] > 0 and k == m / 2):
        idx[1]=dot(n,inc) - k + 1
# /home/lei/octave-4.0.2/scripts/general/interpft.m:89
        tmp=z[idx[:]] / 2
# /home/lei/octave-4.0.2/scripts/general/interpft.m:90
        z[idx[:]]=tmp
# /home/lei/octave-4.0.2/scripts/general/interpft.m:91
        idx[1]=k + 1
# /home/lei/octave-4.0.2/scripts/general/interpft.m:92
        z[idx[:]]=tmp
# /home/lei/octave-4.0.2/scripts/general/interpft.m:93
    
    z=dot(n,ifft(z))
# /home/lei/octave-4.0.2/scripts/general/interpft.m:96
    if (inc != 1):
        sz[1]=n
# /home/lei/octave-4.0.2/scripts/general/interpft.m:99
        z=dot(inc,reshape(z[1:inc:end()],sz))
# /home/lei/octave-4.0.2/scripts/general/interpft.m:100
    
    z=ipermute(z,perm)
# /home/lei/octave-4.0.2/scripts/general/interpft.m:103
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test case with complex input from bug #39566
    
    
    
    ## Test for correct spectral symmetry with even/odd lengths
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nextpow2 (@var{x})
## Compute the exponent for the smallest power of two larger than the input.
##
## For each element in the input array @var{x}, return the first integer
## @var{n} such that
## @tex
## $2^n \ge |x|$.
## @end tex
## @ifnottex
## 2^n @geq{} abs (x).
## @end ifnottex
##
## @seealso{pow2, log2}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 7 October 1994
## Adapted-By: jwe
    
    
@function
def nextpow2(x=None,*args,**kwargs):
    varargin = nextpow2.varargin
    nargin = nextpow2.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isnumeric(x))):
        error('nextpow2: X must be numeric')
    
    f,n=log2(abs(x),nargout=2)
# /home/lei/octave-4.0.2/scripts/general/nextpow2.m:49
    n[f == 0.5]
    return n
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} logspace (@var{a}, @var{b})
## @deftypefnx {Function File} {} logspace (@var{a}, @var{b}, @var{n})
## @deftypefnx {Function File} {} logspace (@var{a}, pi, @var{n})
## Return a row vector with @var{n} elements logarithmically spaced from
## @tex
## $10^{a}$ to $10^{b}$.
## @end tex
## @ifnottex
## 10^@var{a} to 10^@var{b}.
## @end ifnottex
##
## If @var{n} is unspecified it defaults to 50.
##
## If @var{b} is equal to
## @tex
## $\pi$,
## @end tex
## @ifnottex
## pi,
## @end ifnottex
## the points are between
## @tex
## $10^{a}$ and $\pi$,
## @end tex
## @ifnottex
## 10^@var{a} and pi,
## @end ifnottex
## @emph{not}
## @tex
## $10^{a}$ and $10^{\pi}$,
## @end tex
## @ifnottex
## 10^@var{a} and 10^pi,
## @end ifnottex
## in order to be compatible with the corresponding @sc{matlab} function.
##
## Also for compatibility with @sc{matlab}, return the second argument @var{b}
## if fewer than two values are requested.
## @seealso{linspace}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def logspace(base=None,limit=None,n=50,*args,**kwargs):
    varargin = logspace.varargin
    nargin = logspace.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    if (logical_not((isscalar(base) and isscalar(limit) and isscalar(n)))):
        error('logspace: arguments BASE, LIMIT, and N must be scalars')
    
    npoints=fix(n)
# /home/lei/octave-4.0.2/scripts/general/logspace.m:73
    if (limit == pi):
        limit=log10(pi)
# /home/lei/octave-4.0.2/scripts/general/logspace.m:76
    
    retval=10 ** (linspace(base,limit,npoints))
# /home/lei/octave-4.0.2/scripts/general/logspace.m:79
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{names} =} fieldnames (@var{struct})
## @deftypefnx {Function File} {@var{names} =} fieldnames (@var{obj})
## @deftypefnx {Function File} {@var{names} =} fieldnames (@var{javaobj})
## @deftypefnx {Function File} {@var{names} =} fieldnames ("@var{jclassname}")
## Return a cell array of strings with the names of the fields in the
## specified input.
##
## When the input is a structure @var{struct}, the names are the elements of
## the structure.
##
## When the input is an Octave object @var{obj}, the names are the public
## properties of the object.
##
## When the input is a Java object @var{javaobj} or Java classname
## @var{jclassname} the name are the public data elements of the object or
## class.
## @seealso{numfields, isfield, orderfields, struct, methods}
## @end deftypefn
    
    
@function
def fieldnames(obj=None,*args,**kwargs):
    varargin = fieldnames.varargin
    nargin = fieldnames.nargin

    if (nargin != 1):
        print_usage()
    
    if (isstruct(obj) or isobject(obj)):
        ## Call internal C++ function for structs or Octave objects
        names=__fieldnames__(obj)
# /home/lei/octave-4.0.2/scripts/general/fieldnames.m:47
    else:
        if (isjava(obj) or ischar(obj)):
            ## FIXME: Function prototype that excepts java obj exists, but doesn't
    ##        work if obj is java.lang.String.  Convert obj to classname.
    ## FIXME this is now working for objects whose class is in the dynamic
    ##        classpath but will continue to fail if such classnames are used
    ##        instead (see bug #42710)
            if (isa(obj,'java.lang.String')):
                obj=class_(obj)
# /home/lei/octave-4.0.2/scripts/general/fieldnames.m:55
            names_str=javaMethod('getFields','org.octave.ClassHelper',obj)
# /home/lei/octave-4.0.2/scripts/general/fieldnames.m:57
            names=ostrsplit(names_str,';')
# /home/lei/octave-4.0.2/scripts/general/fieldnames.m:58
        else:
            error('fieldnames: Invalid input argument')
    
    return names
    
if __name__ == '__main__':
    pass
    
    ## test preservation of fieldname order
    
    
    ## test empty structure
    
    
    ## test Java classname by passing classname
    
    
    ## test Java classname by passing java object
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Kai Habel
## Copyright (C) 2007  David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{d} =} del2 (@var{M})
## @deftypefnx {Function File} {@var{d} =} del2 (@var{M}, @var{h})
## @deftypefnx {Function File} {@var{d} =} del2 (@var{M}, @var{dx}, @var{dy}, @dots{})
##
## Calculate the discrete Laplace
## @tex
## operator $( \nabla^2 )$.
## @end tex
## @ifnottex
## operator.
## @end ifnottex
##
## For a 2-dimensional matrix @var{M} this is defined as
## @tex
## $$d = {1 \over 4} \left( {d^2 \over dx^2} M(x,y) + {d^2 \over dy^2} M(x,y) \right)$$
## @end tex
## @ifnottex
##
## @example
## @group
##       1    / d^2            d^2         \
## D  = --- * | ---  M(x,y) +  ---  M(x,y) |
##       4    \ dx^2           dy^2        /
## @end group
## @end example
##
## @end ifnottex
## For N-dimensional arrays the sum in parentheses is expanded to include second
## derivatives over the additional higher dimensions.
##
## The spacing between evaluation points may be defined by @var{h}, which is a
## scalar defining the equidistant spacing in all dimensions.  Alternatively,
## the spacing in each dimension may be defined separately by @var{dx},
## @var{dy}, etc.  A scalar spacing argument defines equidistant spacing,
## whereas a vector argument can be used to specify variable spacing.  The
## length of the spacing vectors must match the respective dimension of
## @var{M}.  The default spacing value is 1.
##
## At least 3 data points are needed for each dimension.  Boundary points are
## calculated from the linear extrapolation of interior points.
##
## @seealso{gradient, diff}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
    
    
@function
def del2(M=None,varargin=None,*args,**kwargs):
    varargin = del2.varargin
    nargin = del2.nargin

    if (nargin < 1):
        print_usage()
    
    nd=ndims(M)
# /home/lei/octave-4.0.2/scripts/general/del2.m:73
    sz=size(M)
# /home/lei/octave-4.0.2/scripts/general/del2.m:74
    dx=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/del2.m:75
    if (nargin == 2 or nargin == 1):
        if (nargin == 1):
            h=1
# /home/lei/octave-4.0.2/scripts/general/del2.m:78
        else:
            h=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/del2.m:80
        for i in arange(1,nd).reshape(-1):
            if (isscalar(h)):
                dx[i]=dot(h,ones(sz[i],1))
# /home/lei/octave-4.0.2/scripts/general/del2.m:84
            else:
                if (length(h) == sz[i]):
                    dx[i]=ravel(diff(h))
# /home/lei/octave-4.0.2/scripts/general/del2.m:87
                else:
                    error('del2: dimensionality mismatch in %d-th spacing vector',i)
    else:
        if (nargin - 1 == nd):
            ## Reverse dx{1} and dx{2} as the X-dim is the 2nd dim of the ND array
            tmp=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/del2.m:95
            varargin[1]=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/del2.m:96
            varargin[2]=tmp
# /home/lei/octave-4.0.2/scripts/general/del2.m:97
            for i in arange(1,nd).reshape(-1):
                if (isscalar(varargin[i])):
                    dx[i]=dot(varargin[i],ones(sz[i],1))
# /home/lei/octave-4.0.2/scripts/general/del2.m:101
                else:
                    if (length(varargin[i]) == sz[i]):
                        dx[i]=ravel(diff(varargin[i]))
# /home/lei/octave-4.0.2/scripts/general/del2.m:104
                    else:
                        error('del2: dimensionality mismatch in %d-th spacing vector',i)
        else:
            print_usage()
    
    idx=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/del2.m:114
    for i in arange(1,nd).reshape(-1):
        idx[i]=':'
# /home/lei/octave-4.0.2/scripts/general/del2.m:116
    
    D=zeros(sz)
# /home/lei/octave-4.0.2/scripts/general/del2.m:119
    for i in arange(1,nd).reshape(-1):
        if (sz[i] >= 3):
            DD=zeros(sz)
# /home/lei/octave-4.0.2/scripts/general/del2.m:122
            idx1=idx2=idx3=copy(idx)
# /home/lei/octave-4.0.2/scripts/general/del2.m:123
# /home/lei/octave-4.0.2/scripts/general/del2.m:123
# /home/lei/octave-4.0.2/scripts/general/del2.m:123
            idx1[i]=arange(1,sz[i] - 2)
# /home/lei/octave-4.0.2/scripts/general/del2.m:126
            idx2[i]=arange(2,sz[i] - 1)
# /home/lei/octave-4.0.2/scripts/general/del2.m:127
            idx3[i]=arange(3,sz[i])
# /home/lei/octave-4.0.2/scripts/general/del2.m:128
            szi=copy(sz)
# /home/lei/octave-4.0.2/scripts/general/del2.m:129
            szi[i]=1
# /home/lei/octave-4.0.2/scripts/general/del2.m:130
            h1=repmat(shiftdim(dx[i](arange(1,sz[i] - 2)),1 - i),szi)
# /home/lei/octave-4.0.2/scripts/general/del2.m:132
            h2=repmat(shiftdim(dx[i](arange(2,sz[i] - 1)),1 - i),szi)
# /home/lei/octave-4.0.2/scripts/general/del2.m:133
            DD[idx2[:]]=((M[idx1[:]] - M[idx2[:]]) / h1 + (M[idx3[:]] - M[idx2[:]]) / h2) / (h1 + h2)
# /home/lei/octave-4.0.2/scripts/general/del2.m:134
            if (sz[i] == 3):
                DD[idx1[:]]=DD[idx3[:]]=DD[idx2[:]]
# /home/lei/octave-4.0.2/scripts/general/del2.m:139
# /home/lei/octave-4.0.2/scripts/general/del2.m:139
            else:
                idx1[i]=1
# /home/lei/octave-4.0.2/scripts/general/del2.m:141
                idx2[i]=2
# /home/lei/octave-4.0.2/scripts/general/del2.m:142
                idx3[i]=3
# /home/lei/octave-4.0.2/scripts/general/del2.m:143
                DD[idx1[:]]=dot((dx[i](1) + dx[i](2)) / dx[i](2),DD[idx2[:]]) - dot(dx[i](1) / dx[i](2),DD[idx3[:]])
# /home/lei/octave-4.0.2/scripts/general/del2.m:144
                idx1[i]=sz[i]
# /home/lei/octave-4.0.2/scripts/general/del2.m:147
                idx2[i]=sz[i] - 1
# /home/lei/octave-4.0.2/scripts/general/del2.m:148
                idx3[i]=sz[i] - 2
# /home/lei/octave-4.0.2/scripts/general/del2.m:149
                DD[idx1[:]]=dot((dx[i](sz[i] - 1) + dx[i](sz[i] - 2)) / dx[i](sz[i] - 2),DD[idx2[:]]) - dot(dx[i](sz[i] - 1) / dx[i](sz[i] - 2),DD[idx3[:]])
# /home/lei/octave-4.0.2/scripts/general/del2.m:150
            D += DD
    
    D=D / nd
# /home/lei/octave-4.0.2/scripts/general/del2.m:159
    return D
    
if __name__ == '__main__':
    pass
    
    ## 3x3 constant test
    
    
    
    
    
    ## 3x3 planar test
    
    
    
    
    
    ## 3x3 corner test
    
    
    
    
    
    
    
    
    
    ## 3x3 boundary test
    
    
    
    
    
    
    
    
    
    ## 3x3 center test
    
    
    
    
    
    
    ## 4x4 constant test
    
    
    
    
    
    
    ## 4x4 planar test
    
    
    
    
    
    
    ## 4x4 corner test
    
    
    
    
    
    
    
    
    
    
    ## 9x9 center test
    
    
    
    
    
    
    
    
    
    
    
    
    ## 9x9 boundary test
    
    
    
    
    
    
    
    
    
    
    
    
    ## 9x9 dh center test
    
    
    
    
    
    
    
    
    ## 9x9 dx test
    
    
    
    
    
    
    
    
    ## 9x9 dy test
    
    
    
    
    
    
    
    
    ## 3D test
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} display (@var{a})
## Display the contents of an object.
##
## If @var{a} is an object of the class @qcode{"myclass"}, then @code{display}
## is called in a case like
##
## @example
## myclass (@dots{})
## @end example
##
## @noindent
## where Octave is required to display the contents of a variable of the
## type @qcode{"myclass"}.
##
## @seealso{class, subsref, subsasgn}
## @end deftypefn
    
    
@function
def display(a=None,*args,**kwargs):
    varargin = display.varargin
    nargin = display.nargin

    if (nargin != 1):
        print_usage()
    
    ## Only reason we got here is that there was no overloaded display()
  ## function for object a.  This may mean it is a built-in.
    str=disp(a)
# /home/lei/octave-4.0.2/scripts/general/display.m:45
    if (isempty(strfind(str,'<class '))):
        disp(str)
    else:
        error('display: not defined for class "%s"',class_(a))
    
    return idx
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2004-2015 John Eaton and David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{y} =} shiftdim (@var{x}, @var{n})
## @deftypefnx {Function File} {[@var{y}, @var{ns}] =} shiftdim (@var{x})
## Shift the dimensions of @var{x} by @var{n}, where @var{n} must be
## an integer scalar.
##
## When @var{n} is positive, the dimensions of @var{x} are shifted to the left,
## with the leading dimensions circulated to the end.  If @var{n} is negative,
## then the dimensions of @var{x} are shifted to the right, with @var{n}
## leading singleton dimensions added.
##
## Called with a single argument, @code{shiftdim}, removes the leading
## singleton dimensions, returning the number of dimensions removed in the
## second output argument @var{ns}.
##
## For example:
##
## @example
## @group
## x = ones (1, 2, 3);
## size (shiftdim (x, -1))
##    @result{} [1, 1, 2, 3]
## size (shiftdim (x, 1))
##    @result{} [2, 3]
## [b, ns] = shiftdim (x)
##    @result{} b = [1, 1, 1; 1, 1, 1]
##    @result{} ns = 1
## @end group
## @end example
## @seealso{reshape, permute, ipermute, circshift, squeeze}
## @end deftypefn
    
    
@function
def shiftdim(x=None,n=None,*args,**kwargs):
    varargin = shiftdim.varargin
    nargin = shiftdim.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:57
    orig_dims=size(x)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:58
    if (nargin == 1):
        ## Find the first non-singleton dimension.
        n=find(orig_dims != 1,1) - 1 or nd
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:None
    else:
        if (logical_not((isscalar(n) and n == fix(n)))):
            error('shiftdim: N must be a scalar integer')
    
    if (n >= nd):
        n=rem(n,nd)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:68
    
    if (n < 0):
        singleton_dims=ones(1,- n)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:72
        y=reshape(x,cat(singleton_dims,orig_dims))
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:73
    else:
        if (n > 0):
            ## We need permute here instead of reshape to shift values in a
    ## compatible way.
            y=permute(x,cat(arange(n + 1,nd),arange(1,n)))
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:77
        else:
            y=copy(x)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:79
    
    ns=copy(n)
# /home/lei/octave-4.0.2/scripts/general/shiftdim.m:82
    return y,ns
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} int2str (@var{n})
## Convert an integer (or array of integers) to a string (or a character
## array).
##
## @example
## @group
## int2str (123)
##      @result{} "123"
##
## s = int2str ([1, 2, 3; 4, 5, 6])
##      @result{} s =
##         1  2  3
##         4  5  6
##
## whos s
##      @result{}
##       Attr Name        Size                     Bytes  Class
##       ==== ====        ====                     =====  =====
##            s           2x7                         14  char
## @end group
## @end example
##
## This function is not very flexible.  For better control over the
## results, use @code{sprintf} (@pxref{Formatted Output}).
## @seealso{sprintf, num2str, mat2str}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def int2str(n=None,*args,**kwargs):
    varargin = int2str.varargin
    nargin = int2str.nargin

    if (nargin != 1):
        print_usage()
    
    if (isempty(n)):
        retval=''
# /home/lei/octave-4.0.2/scripts/general/int2str.m:56
        return retval
    
    n=round(real(n))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:60
    sz=size(n)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:61
    nd=ndims(n)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:62
    nc=columns(n)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:63
    if (nc > 1):
        idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:65
        idx[2]=1
# /home/lei/octave-4.0.2/scripts/general/int2str.m:66
        ifmt=get_fmt(n[idx[:]],0)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:67
        idx[2]=arange(2,sz[2])
# /home/lei/octave-4.0.2/scripts/general/int2str.m:68
        rfmt=get_fmt(n[idx[:]],2)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:69
        fmt=matlabarray(cat(ifmt,repmat(rfmt,1,nc - 1),'\n'))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:70
    else:
        fmt=matlabarray(cat(get_fmt(n,0),'\n'))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:72
    
    tmp=sprintf(fmt,permute(n,cat(2,1,arange(3,nd))))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:74
    tmp[end()]=''
# /home/lei/octave-4.0.2/scripts/general/int2str.m:75
    retval=char(ostrsplit(tmp,'\n'))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:76
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def get_fmt(x=None,sep=None,*args,**kwargs):
    varargin = get_fmt.varargin
    nargin = get_fmt.nargin

    t=ravel(x)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:82
    t=t[t != 0]
# /home/lei/octave-4.0.2/scripts/general/int2str.m:83
    if (isempty(t)):
        ## All zeros.
        fmt=sprintf('%%%dd',1 + sep)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:86
    else:
        ## Maybe have some zeros.
        nan_inf=logical_not(isfinite(t))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:89
        if (any(nan_inf)):
            if (any(t[nan_inf] < 0)):
                min_fw=4 + sep
# /home/lei/octave-4.0.2/scripts/general/int2str.m:92
            else:
                min_fw=3 + sep
# /home/lei/octave-4.0.2/scripts/general/int2str.m:94
        else:
            min_fw=1 + sep
# /home/lei/octave-4.0.2/scripts/general/int2str.m:97
        t=t[logical_not(nan_inf)]
# /home/lei/octave-4.0.2/scripts/general/int2str.m:99
        if (isempty(t)):
            ## Only zeros, Inf, and NaN.
            fmt=sprintf('%%%dd',min_fw)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:102
        else:
            ## Could have anything.
            tfw=floor(log10(double(abs(t)))) + 1 + sep
# /home/lei/octave-4.0.2/scripts/general/int2str.m:105
            fw=max(tfw)
# /home/lei/octave-4.0.2/scripts/general/int2str.m:106
            if (any(t[tfw == fw] < 0)):
                fw
            fmt=sprintf('%%%dd',max(fw,min_fw))
# /home/lei/octave-4.0.2/scripts/general/int2str.m:110
    
    return fmt
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 Alois Schloegl
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isdir (@var{f})
## Return true if @var{f} is a directory.
## @seealso{exist, stat, is_absolute_filename, is_rooted_relative_filename}
## @end deftypefn
    
    
@function
def isdir(f=None,*args,**kwargs):
    varargin = isdir.varargin
    nargin = isdir.nargin

    if (nargin != 1):
        print_usage('isdir')
    
    ## Exist returns an integer but isdir should return a logical.
    retval=(exist(f,'dir') == 7)
# /home/lei/octave-4.0.2/scripts/general/isdir.m:31
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{vi} =} interp3 (@var{x}, @var{y}, @var{z}, @var{v}, @var{xi}, @var{yi}, @var{zi})
## @deftypefnx {Function File} {@var{vi} =} interp3 (@var{v}, @var{xi}, @var{yi}, @var{zi})
## @deftypefnx {Function File} {@var{vi} =} interp3 (@var{v}, @var{n})
## @deftypefnx {Function File} {@var{vi} =} interp3 (@var{v})
## @deftypefnx {Function File} {@var{vi} =} interp3 (@dots{}, @var{method})
## @deftypefnx {Function File} {@var{vi} =} interp3 (@dots{}, @var{method}, @var{extrapval})
##
## Three-dimensional interpolation.
##
## Interpolate reference data @var{x}, @var{y}, @var{z}, @var{v} to determine
## @var{vi} at the coordinates @var{xi}, @var{yi}, @var{zi}.  The reference
## data @var{x}, @var{y}, @var{z} can be matrices, as returned by
## @code{meshgrid}, in which case the sizes of @var{x}, @var{y}, @var{z}, and
## @var{v} must be equal.  If @var{x}, @var{y}, @var{z} are vectors describing
## a cubic grid then @code{length (@var{x}) == columns (@var{v})},
## @code{length (@var{y}) == rows (@var{v})}, and
## @code{length (@var{z}) == size (@var{v}, 3)}.  In either case the input
## data must be strictly monotonic.
##
## If called without @var{x}, @var{y}, @var{z}, and just a single reference
## data matrix @var{v}, the 3-D region
## @code{@var{x} = 1:columns (@var{v}), @var{y} = 1:rows (@var{v}),
## @var{z} = 1:size (@var{v}, 3)} is assumed.
## This saves memory if the grid is regular and the distance between points is
## not important.
##
## If called with a single reference data matrix @var{v} and a refinement
## value @var{n}, then perform interpolation over a 3-D grid where each original
## interval has been recursively subdivided @var{n} times.  This results in
## @code{2^@var{n}-1} additional points for every interval in the original
## grid.  If @var{n} is omitted a value of 1 is used.  As an example, the
## interval [0,1] with @code{@var{n}==2} results in a refined interval with
## points at [0, 1/4, 1/2, 3/4, 1].
##
## The interpolation @var{method} is one of:
##
## @table @asis
## @item @qcode{"nearest"}
## Return the nearest neighbor.
##
## @item @qcode{"linear"} (default)
## Linear interpolation from nearest neighbors.
##
## @item @qcode{"cubic"}
## Piecewise cubic Hermite interpolating polynomial---shape-preserving
## interpolation with smooth first derivative (not implemented yet).
##
## @item @qcode{"spline"}
## Cubic spline interpolation---smooth first and second derivatives
## throughout the curve.
## @end table
##
## @var{extrapval} is a scalar number.  It replaces values beyond the endpoints
## with @var{extrapval}.  Note that if @var{extrapval} is used, @var{method}
## must be specified as well.  If @var{extrapval} is omitted and the
## @var{method} is @qcode{"spline"}, then the extrapolated values of the
## @qcode{"spline"} are used.  Otherwise the default @var{extrapval} value for
## any other @var{method} is @qcode{"NA"}.
## @seealso{interp1, interp2, interpn, meshgrid}
## @end deftypefn
    
    ## FIXME: Need to add support for 'cubic' method (maybe change interpn).
    
    
@function
def interp3(varargin=None,*args,**kwargs):
    varargin = interp3.varargin
    nargin = interp3.nargin

    narginchk(1,9)
    method='linear'
# /home/lei/octave-4.0.2/scripts/general/interp3.m:87
    extrapval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/interp3.m:88
    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:89
    if (nargin < 1 or logical_not(isnumeric(varargin[1]))):
        print_usage()
    
    if (nargs > 1 and ischar(varargin[end() - 1])):
        if (logical_not(isnumeric(varargin[end()])) or logical_not(isscalar(varargin[end()]))):
            error('interp3: EXTRAPVAL must be a numeric scalar')
        extrapval=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:99
        method=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:100
        nargs -= 2
    else:
        if (ischar(varargin[end()])):
            method=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:103
            nargs
    
    if (method[1] == '*'):
        warning('interp3: ignoring unsupported \'*\' flag to METHOD')
        method[1]=[]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:109
    
    method=validatestring(method,cellarray(['nearest','linear','cubic','spline']))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:111
    if (nargs < 3):
        ## Calling form interp3 (v) OR interp3 (v, n)
        v=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:116
        if (ndims(v) != 3):
            error('interp3: V must be a 3-D array of values')
        n=varargin[2:nargs]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:120
        v=permute(v,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:121
        if (isempty(extrapval)):
            vi=interpn(v,n[:],method)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:123
        else:
            vi=interpn(v,n[:],method,extrapval)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:125
        vi=ipermute(vi,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:127
    else:
        if (nargs == 4 and logical_not(isvector(varargin[1]))):
            ## Calling form interp3 (v, xi, yi, zi)
            v=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:131
            if (ndims(v) != 3):
                error('interp3: V must be a 3-D array of values')
            xi=varargin[2:4]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:135
            if (any(logical_not(cellfun(isvector,xi)))):
                ## Meshgridded values rather than vectors
                if (logical_not(size_equal(xi[:]))):
                    error('interp3: XI, YI, and ZI dimensions must be equal')
                for i in arange(1,3).reshape(-1):
                    xi[i]=permute(xi[i],cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:142
            v=permute(v,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:145
            if (isempty(extrapval)):
                vi=interpn(v,xi[:],method)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:147
            else:
                vi=interpn(v,xi[:],method,extrapval)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:149
            vi=ipermute(vi,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:151
        else:
            if (nargs == 7):
                ## Calling form interp3 (x, y, z, v, xi, yi, zi)
                v=varargin[4]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:155
                if (ndims(v) != 3):
                    error('interp3: V must be a 3-D array of values')
                x=varargin[1:3]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:159
                if (any(logical_not(cellfun(isvector,x)))):
                    ## Meshgridded values rather than vectors
                    if (logical_not(size_equal(x[:],v))):
                        error('interp3: X, Y, Z, and V dimensions must be equal')
                    for i in arange(1,3).reshape(-1):
                        x[i]=permute(x[i],cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:166
                xi=varargin[5:7]
# /home/lei/octave-4.0.2/scripts/general/interp3.m:169
                if (any(logical_not(cellfun(isvector,xi)))):
                    ## Meshgridded values rather than vectors
                    if (logical_not(size_equal(xi[:]))):
                        error('interp3: XI, YI, and ZI dimensions must be equal')
                    for i in arange(1,3).reshape(-1):
                        xi[i]=permute(xi[i],cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:176
                v=permute(v,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:179
                if (isempty(extrapval)):
                    vi=interpn(x[:],v,xi[:],method)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:181
                else:
                    vi=interpn(x[:],v,xi[:],method,extrapval)
# /home/lei/octave-4.0.2/scripts/general/interp3.m:183
                vi=ipermute(vi,cat(2,1,3))
# /home/lei/octave-4.0.2/scripts/general/interp3.m:185
            else:
                error('interp3: wrong number or incorrectly formatted input arguments')
    
    return vi
    
if __name__ == '__main__':
    pass
    
    ## FIXME: Need some demo blocks here to show off the function like interp2.m.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} dblquad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb})
## @deftypefnx {Function File} {} dblquad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{tol})
## @deftypefnx {Function File} {} dblquad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{tol}, @var{quadf})
## @deftypefnx {Function File} {} dblquad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{tol}, @var{quadf}, @dots{})
## Numerically evaluate the double integral of @var{f}.
##
## @var{f} is a function handle, inline function, or string containing the name
## of the function to evaluate.  The function @var{f} must have the form
## @math{z = f(x,y)} where @var{x} is a vector and @var{y} is a scalar.  It
## should return a vector of the same length and orientation as @var{x}.
##
## @var{xa}, @var{ya} and @var{xb}, @var{yb} are the lower and upper limits of
## integration for x and y respectively.  The underlying integrator determines
## whether infinite bounds are accepted.
##
## The optional argument @var{tol} defines the absolute tolerance used to
## integrate each sub-integral.  The default value is @math{1e^{-6}}.
##
## The optional argument @var{quadf} specifies which underlying integrator
## function to use.  Any choice but @code{quad} is available and the default
## is @code{quadcc}.
##
## Additional arguments, are passed directly to @var{f}.  To use the default
## value for @var{tol} or @var{quadf} one may pass @qcode{':'} or an empty
## matrix ([]).
## @seealso{triplequad, quad, quadv, quadl, quadgk, quadcc, trapz}
## @end deftypefn
    
    
@function
def dblquad(f=None,xa=None,xb=None,ya=None,yb=None,tol=1e-06,quadf=quadcc,varargin=None,*args,**kwargs):
    varargin = dblquad.varargin
    nargin = dblquad.nargin

    if (nargin < 5):
        print_usage()
    
    if (isempty(tol)):
        tol=1e-06
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:54
    
    if (isempty(quadf)):
        quadf=quadcc
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:57
    
    inner=__dblquad_inner__
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:60
    if (ischar(f)):
        f=lambda x=None,y=None: feval(f,x,y,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:62
        varargin=cellarray([])
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:63
    
    q=feval(quadf,lambda y=None: inner[y,f,xa,xb,tol,quadf,varargin[:]],ya,yb,tol)
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:66
    return q
    
if __name__ == '__main__':
    pass
    
    
@function
def __dblquad_inner__(y=None,f=None,xa=None,xb=None,tol=None,quadf=None,varargin=None,*args,**kwargs):
    varargin = __dblquad_inner__.varargin
    nargin = __dblquad_inner__.nargin

    q=zeros(size(y))
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:71
    for i in arange(1,length(y)).reshape(-1):
        q[i]=feval(quadf,lambda x=None: f[x,y[i],varargin[:]],xa,xb,tol)
# /home/lei/octave-4.0.2/scripts/general/dblquad.m:73
    
    return q
    
if __name__ == '__main__':
    pass
    
    ## Nasty integrand to show quadcc off
    
    
    
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} methods (@var{obj})
## @deftypefnx {Function File} {} methods ("@var{classname}")
## @deftypefnx {Function File} {@var{mtds} =} methods (@dots{})
##
## Return a cell array containing the names of the methods for the
## object @var{obj} or the named class @var{classname}.
##
## @var{obj} may be an Octave class object or a Java object.
##
## @seealso{fieldnames}
## @end deftypefn
    
    
@function
def methods(obj=None,*args,**kwargs):
    varargin = methods.varargin
    nargin = methods.nargin

    if (nargin != 1):
        print_usage()
    
    if (isobject(obj)):
        ## Call internal C++ function for Octave objects
        mtds_list=__methods__(obj)
# /home/lei/octave-4.0.2/scripts/general/methods.m:40
    else:
        if (ischar(obj)):
            ## Could be a classname for an Octave class or Java class.
    ## Try Octave class first.
            mtds_list=__methods__(obj)
# /home/lei/octave-4.0.2/scripts/general/methods.m:44
            if (isempty(mtds_list)):
                mtds_str=javaMethod('getMethods','org.octave.ClassHelper',obj)
# /home/lei/octave-4.0.2/scripts/general/methods.m:46
                mtds_list=ostrsplit(mtds_str,';')
# /home/lei/octave-4.0.2/scripts/general/methods.m:47
        else:
            if (isjava(obj)):
                ## FIXME: Function prototype accepts java obj, but doesn't work if obj
    ##        is e.g., java.lang.String.  Convert obj to classname then.
                try:
                    mtds_str=javaMethod('getMethods','org.octave.ClassHelper',obj)
# /home/lei/octave-4.0.2/scripts/general/methods.m:53
                finally:
                    pass
                mtds_list=strsplit(mtds_str,';')
# /home/lei/octave-4.0.2/scripts/general/methods.m:58
            else:
                error('methods: Invalid input argument')
    
    if (nargout == 0):
        classname=ifelse(ischar(obj),obj,class_(obj))
# /home/lei/octave-4.0.2/scripts/general/methods.m:64
        printf('Methods for class %s:\n',classname)
        disp(list_in_columns(mtds_list))
    else:
        mtds=copy(mtds_list)
# /home/lei/octave-4.0.2/scripts/general/methods.m:68
    
    return mtds
    
if __name__ == '__main__':
    pass
    
    ## test Octave classname
    
    
    ## test Java classname
    
    
    
    ## Copyright (C) 2014-2015 Nir Krakauer
## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{yi} =} interp1 (@var{x}, @var{y}, @var{xi})
## @deftypefnx {Function File} {@var{yi} =} interp1 (@var{y}, @var{xi})
## @deftypefnx {Function File} {@var{yi} =} interp1 (@dots{}, @var{method})
## @deftypefnx {Function File} {@var{yi} =} interp1 (@dots{}, @var{extrap})
## @deftypefnx {Function File} {@var{yi} =} interp1 (@dots{}, "left")
## @deftypefnx {Function File} {@var{yi} =} interp1 (@dots{}, "right")
## @deftypefnx {Function File} {@var{pp} =} interp1 (@dots{}, "pp")
##
## One-dimensional interpolation.
##
## Interpolate input data to determine the value of @var{yi} at the points
## @var{xi}.  If not specified, @var{x} is taken to be the indices of @var{y}
## (@code{1:length (@var{y})}).  If @var{y} is a matrix or an N-dimensional
## array, the interpolation is performed on each column of @var{y}.
##
## The interpolation @var{method} is one of:
##
## @table @asis
## @item @qcode{"nearest"}
## Return the nearest neighbor.
##
## @item @qcode{"previous"}
## Return the previous neighbor.
##
## @item @qcode{"next"}
## Return the next neighbor.
##
## @item @qcode{"linear"} (default)
## Linear interpolation from nearest neighbors.
##
## @item @qcode{"pchip"}
## Piecewise cubic Hermite interpolating polynomial---shape-preserving
## interpolation with smooth first derivative.
##
## @item @qcode{"cubic"}
## Cubic interpolation (same as @qcode{"pchip"}).
##
## @item @qcode{"spline"}
## Cubic spline interpolation---smooth first and second derivatives
## throughout the curve.
## @end table
##
## Adding '*' to the start of any method above forces @code{interp1}
## to assume that @var{x} is uniformly spaced, and only @code{@var{x}(1)}
## and @code{@var{x}(2)} are referenced.  This is usually faster,
## and is never slower.  The default method is @qcode{"linear"}.
##
## If @var{extrap} is the string @qcode{"extrap"}, then extrapolate values
## beyond the endpoints using the current @var{method}.  If @var{extrap} is a
## number, then replace values beyond the endpoints with that number.  When
## unspecified, @var{extrap} defaults to @code{NA}.
##
## If the string argument @qcode{"pp"} is specified, then @var{xi} should not
## be supplied and @code{interp1} returns a piecewise polynomial object.  This
## object can later be used with @code{ppval} to evaluate the interpolation.
## There is an equivalence, such that @code{ppval (interp1 (@var{x},
## @var{y}, @var{method}, @qcode{"pp"}), @var{xi}) == interp1 (@var{x}, @var{y},
## @var{xi}, @var{method}, @qcode{"extrap"})}.
##
## Duplicate points in @var{x} specify a discontinuous interpolant.  There
## may be at most 2 consecutive points with the same value.
## If @var{x} is increasing, the default discontinuous interpolant is
## right-continuous.  If @var{x} is decreasing, the default discontinuous
## interpolant is left-continuous.
## The continuity condition of the interpolant may be specified by using
## the options @qcode{"left"} or @qcode{"right"} to select a left-continuous
## or right-continuous interpolant, respectively.
## Discontinuous interpolation is only allowed for @qcode{"nearest"} and
## @qcode{"linear"} methods; in all other cases, the @var{x}-values must be
## unique.
##
## An example of the use of @code{interp1} is
##
## @example
## @group
## xf = [0:0.05:10];
## yf = sin (2*pi*xf/5);
## xp = [0:10];
## yp = sin (2*pi*xp/5);
## lin = interp1 (xp, yp, xf);
## near = interp1 (xp, yp, xf, "nearest");
## pch = interp1 (xp, yp, xf, "pchip");
## spl = interp1 (xp, yp, xf, "spline");
## plot (xf,yf,"r", xf,near,"g", xf,lin,"b", xf,pch,"c", xf,spl,"m",
##       xp,yp,"r*");
## legend ("original", "nearest", "linear", "pchip", "spline");
## @end group
## @end example
##
## @seealso{pchip, spline, interpft, interp2, interp3, interpn}
## @end deftypefn
    
    ## Author: Paul Kienzle
## Date: 2000-03-25
##    added 'nearest' as suggested by Kai Habel
## 2000-07-17 Paul Kienzle
##    added '*' methods and matrix y
##    check for proper table lengths
## 2002-01-23 Paul Kienzle
##    fixed extrapolation
    
    
@function
def interp1(x=None,y=None,varargin=None,*args,**kwargs):
    varargin = interp1.varargin
    nargin = interp1.nargin

    if (nargin < 2 or nargin > 6):
        print_usage()
    
    method='linear'
# /home/lei/octave-4.0.2/scripts/general/interp1.m:129
    extrap=copy(NA)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:130
    xi=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:131
    ispp=copy(false)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:132
    firstnumeric=copy(true)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:133
    rightcontinuous=copy(NaN)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:134
    if (nargin > 2):
        for i in arange(1,length(varargin)).reshape(-1):
            arg=varargin[i]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:138
            if (ischar(arg)):
                arg=tolower(arg)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:140
                if 'extrap' == (arg):
                    extrap='extrap'
# /home/lei/octave-4.0.2/scripts/general/interp1.m:143
                else:
                    if 'pp' == (arg):
                        ispp=copy(true)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:145
                    else:
                        if cellarray(['right','-right']) == (arg):
                            rightcontinuous=copy(true)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:147
                        else:
                            if cellarray(['left','-left']) == (arg):
                                rightcontinuous=copy(false)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:149
                            else:
                                method=copy(arg)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:151
            else:
                if (firstnumeric):
                    xi=copy(arg)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:155
                    firstnumeric=copy(false)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:156
                else:
                    extrap=copy(arg)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:158
    
    if (isempty(xi) and firstnumeric and logical_not(ispp)):
        xi=copy(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:165
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:166
        if (isvector(y)):
            x=arange(1,numel(y))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:168
        else:
            x=arange(1,rows(y))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:170
    
    ## reshape matrices for convenience
    x=ravel(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:175
    nx=rows(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:176
    szx=size(xi)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:177
    if (isvector(y)):
        y=ravel(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:179
    
    szy=size(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:182
    y=y[:,:]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:183
    ny,nc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:184
    xi=ravel(xi)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:185
    
    if (nx < 2 or ny < 2):
        error('interp1: minimum of 2 points required in each dimension')
    
    ## check whether x is sorted; sort if not.
    if (logical_not(issorted(x,'either'))):
        x,p=sort(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:194
        y=y[p,:]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:195
    
    if (any(strcmp(method,cellarray(['previous','*previous','next','*next'])))):
        rightcontinuous=copy(NaN)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:199
    
    if (isnan(rightcontinuous)):
        ## If not specified, set the continuity condition
        if (x[end()] < x[1]):
            rightcontinuous=copy(false)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:205
        else:
            rightcontinuous=copy(true)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:207
    else:
        if ((rightcontinuous and (x[end()] < x[1])) or (logical_not(rightcontinuous) and (x[end()] > x[1]))):
            ## Switch between left-continuous and right-continuous
            x=flipud(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:212
            y=flipud(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:213
    
    ## Because of the way mkpp works, it's easiest to implement "next"
  ## by running "previous" with vectors flipped.
    if (strcmp(method,'next')):
        x=flipud(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:219
        y=flipud(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:220
        method='previous'
# /home/lei/octave-4.0.2/scripts/general/interp1.m:221
    else:
        if (strcmp(method,'*next')):
            x=flipud(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:223
            y=flipud(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:224
            method='*previous'
# /home/lei/octave-4.0.2/scripts/general/interp1.m:225
    
    starmethod=method[1] == '*'
# /home/lei/octave-4.0.2/scripts/general/interp1.m:228
    if (starmethod):
        dx=x[2] - x[1]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:231
    else:
        jumps=x[1:end() - 1] == x[2:end()]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:233
        have_jumps=any(jumps)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:234
        if (have_jumps):
            if (strcmp(method,'linear') or strcmp(method,('nearest'))):
                if (any(logical_and(jumps[1:nx - 2],jumps[2:nx - 1]))):
                    warning('interp1: multiple discontinuities at the same X value')
            else:
                error('interp1: discontinuities not supported for method \'%s\'',method)
    
    ## Proceed with interpolating by all methods.
    if 'nearest' == (method):
        pp=mkpp(cat([x[1]],[(x[1:nx - 1] + x[2:nx]) / 2],[x[nx]]),shiftdim(y,1),szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:251
        pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:253
        if (ispp):
            yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:256
        else:
            yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:258
    else:
        if '*nearest' == (method):
            pp=mkpp(cat(x[1],x[1] + dot(cat(arange(0.5,(nx - 1))),dx),x[nx]),shiftdim(y,1),szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:262
            pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:264
            if (ispp):
                yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:267
            else:
                yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:269
        else:
            if 'previous' == (method):
                pp=mkpp(cat([x[1:nx]],[dot(2,x[nx]) - x[nx - 1]]),shiftdim(y,1),szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:273
                pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:275
                if (ispp):
                    yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:278
                else:
                    yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:280
            else:
                if '*previous' == (method):
                    pp=mkpp(x[1] + dot(cat(arange(0,nx)),dx),shiftdim(y,1),szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:284
                    pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:286
                    if (ispp):
                        yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:289
                    else:
                        yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:291
                else:
                    if 'linear' == (method):
                        xx=copy(x)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:296
                        nxx=copy(nx)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:297
                        yy=copy(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:298
                        dy=diff(yy)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:299
                        if (have_jumps):
                            ## Omit zero-size intervals.
                            xx[jumps]=[]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:302
                            nxx=rows(xx)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:303
                            yy[jumps,:]=[]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:304
                            dy[jumps,:]=[]
# /home/lei/octave-4.0.2/scripts/general/interp1.m:305
                        dx=diff(xx)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:308
                        dx=repmat(dx,cat(1,size(dy)(arange(2,end()))))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:309
                        coefs=matlabarray(cat((dy / dx).T,yy[1:nxx - 1,:].T))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:311
                        pp=mkpp(xx,coefs,szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:313
                        pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:314
                        if (ispp):
                            yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:317
                        else:
                            yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:319
                    else:
                        if '*linear' == (method):
                            dy=diff(y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:323
                            coefs=matlabarray(cat(ravel((dy / dx).T),ravel(y[1:nx - 1,:].T)))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:324
                            pp=mkpp(x,coefs,szy[2:end()])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:325
                            pp.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:326
                            if (ispp):
                                yi=copy(pp)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:329
                            else:
                                yi=ppval(pp,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:331
                        else:
                            if cellarray(['pchip','*pchip','cubic','*cubic']) == (method):
                                if (nx == 2 or starmethod):
                                    x=linspace(x[1],x[nx],ny)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:336
                                if (ispp):
                                    y=shiftdim(reshape(y,szy),1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:340
                                    yi=pchip(x,y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:341
                                    yi.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:342
                                else:
                                    y=shiftdim(y,1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:344
                                    yi=pchip(x,y,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:345
                                    if (logical_not(isvector(y))):
                                        yi=shiftdim(yi,1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:347
                            else:
                                if cellarray(['spline','*spline']) == (method):
                                    if (nx == 2 or starmethod):
                                        x=linspace(x[1],x[nx],ny)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:353
                                    if (ispp):
                                        y=shiftdim(reshape(y,szy),1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:357
                                        yi=spline(x,y)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:358
                                        yi.orient = copy('first')
# /home/lei/octave-4.0.2/scripts/general/interp1.m:359
                                    else:
                                        y=shiftdim(y,1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:361
                                        yi=spline(x,y,reshape(xi,szx))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:362
                                        if (logical_not(isvector(y))):
                                            yi=shiftdim(yi,1)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:364
                                else:
                                    error('interp1: invalid method \'%s\'',method)
    
    if (logical_not(ispp) and isnumeric(extrap)):
        ## determine which values are out of range and set them to extrap,
    ## unless extrap == "extrap".
        minx=min(x[1],x[nx])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:376
        maxx=max(x[1],x[nx])
# /home/lei/octave-4.0.2/scripts/general/interp1.m:377
        xi=reshape(xi,szx)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:379
        outliers=xi < logical_or(minx,logical_not((xi <= maxx)))
# /home/lei/octave-4.0.2/scripts/general/interp1.m:380
        if (size_equal(outliers,yi)):
            yi[outliers]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp1.m:382
            yi=reshape(yi,szx)
# /home/lei/octave-4.0.2/scripts/general/interp1.m:383
        else:
            if (logical_not(isvector(yi))):
                yi[outliers,:]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp1.m:385
            else:
                yi[outliers.T]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp1.m:387
    
    return yi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##FIXME: add test for N-d arguments here
    
    ## For each type of interpolated test, confirm that the interpolated
## value at the knots match the values at the knots.  Points away
## from the knots are requested, but only "nearest" and "linear"
## confirm they are the correct values.
    
    
    
    
    
    ## The following BLOCK/ENDBLOCK section is repeated for each style
##    nearest, previous, next, linear, cubic, spline, pchip
## The test for ppval of cubic has looser tolerance, but otherwise
## the tests are identical.
## Note that the block checks style and *style; if you add more tests
## be sure to add them to both sections of each block.  One test,
## style vs. *style, occurs only in the first section.
## There is an ENDBLOCKTEST after the final block
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    ## This test is expected to fail, so commented out.
## "previous" and "next" options are not symmetric w.r.t to flipping xp,yp
##!assert (interp1 (xp,yp,xi,style),...
##!        interp1 (fliplr (xp),fliplr (yp),xi,style),100*eps)
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##!assert (interp1 (xp,yp,xi,style),...
##!        interp1 (fliplr (xp),fliplr (yp),xi,style),100*eps)
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    ##!assert (interp1 (xp,yp,xi,style),...
##!        interp1 (fliplr (xp),fliplr (yp),xi,style),100*eps)
    
    
    
    
    
    
    
    
    
    
    
    
    
    ##!assert (interp1 (xp,yp,xi,style),...
##!        interp1 (fliplr (xp),fliplr (yp),xi,style),100*eps)
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ENDBLOCK
    
    ## BLOCK
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## ENDBLOCK
## ENDBLOCKTEST
    
    ## test extrapolation
    
    
    
    
    
    
    
    ## Basic sanity checks
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Left and Right discontinuities
    
    
    ## Test input validation
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} fliplr (@var{x})
## Flip array left to right.
##
## Return a copy of @var{x} with the order of the columns reversed.  In other
## words, @var{x} is flipped left-to-right about a vertical axis.  For example:
##
## @example
## @group
## fliplr ([1, 2; 3, 4])
##      @result{}  2  1
##          4  3
## @end group
## @end example
##
## @seealso{flipud, flip, rot90, rotdim}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def fliplr(x=None,*args,**kwargs):
    varargin = fliplr.varargin
    nargin = fliplr.nargin

    if (nargin != 1):
        print_usage()
    
    y=flip(x,2)
# /home/lei/octave-4.0.2/scripts/general/fliplr.m:44
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test NDArrays
    
    
    
    
    
    ## Test NDArray with singleton dimensions
    
    
    
    
    
    ## Test for 1 row, i.e., returns the same
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} idivide (@var{x}, @var{y}, @var{op})
## Integer division with different rounding rules.
##
## The standard behavior of integer division such as @code{@var{a} ./ @var{b}}
## is to round the result to the nearest integer.  This is not always the
## desired behavior and @code{idivide} permits integer element-by-element
## division to be performed with different treatment for the fractional
## part of the division as determined by the @var{op} flag.  @var{op} is
## a string with one of the values:
##
## @table @asis
## @item @qcode{"fix"}
## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
## towards zero.
##
## @item @qcode{"round"}
## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
## towards the nearest integer.
##
## @item @qcode{"floor"}
## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
## towards negative infinity.
##
## @item @qcode{"ceil"}
## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
## towards positive infinity.
## @end table
##
## @noindent
## If @var{op} is not given it defaults to @qcode{"fix"}.
## An example demonstrating these rounding rules is
##
## @example
## @group
## idivide (int8 ([-3, 3]), int8 (4), "fix")
##   @result{} int8 ([0, 0])
## idivide (int8 ([-3, 3]), int8 (4), "round")
##   @result{} int8 ([-1, 1])
## idivide (int8 ([-3, 3]), int8 (4), "floor")
##   @result{} int8 ([-1, 0])
## idivide (int8 ([-3, 3]), int8 (4), "ceil")
##   @result{} int8 ([0, 1])
## @end group
## @end example
##
## @seealso{ldivide, rdivide}
## @end deftypefn
    
    
@function
def idivide(x=None,y=None,op=None,*args,**kwargs):
    varargin = idivide.varargin
    nargin = idivide.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    else:
        if (nargin == 2):
            op='fix'
# /home/lei/octave-4.0.2/scripts/general/idivide.m:72
        else:
            op=tolower(op)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:74
    
    if (strcmp(op,'round')):
        z=x / y
# /home/lei/octave-4.0.2/scripts/general/idivide.m:78
    else:
        if (isfloat(x)):
            typ=class_(y)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:81
        else:
            if (isfloat(y)):
                typ=class_(x)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:83
            else:
                typ=class_(x)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:85
                if (logical_not(strcmp(class_(x),class_(y)))):
                    error('idivide: incompatible types')
        if (strcmp(op,'fix')):
            z=cast(fix(double(x) / double(y)),typ)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:92
        else:
            if (strcmp(op,'floor')):
                z=cast(floor(double(x) / double(y)),typ)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:94
            else:
                if (strcmp(op,'ceil')):
                    z=cast(ceil(double(x) / double(y)),typ)
# /home/lei/octave-4.0.2/scripts/general/idivide.m:96
                else:
                    error('idivide: unrecognized rounding type')
    
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} flip (@var{x})
## @deftypefnx {Function File} {} flip (@var{x}, @var{dim})
## Flip array across dimension @var{dim}.
##
## Return a copy of @var{x} flipped about the dimension @var{dim}.
## @var{dim} defaults to the first non-singleton dimension.
## For example:
##
## @example
## @group
## flip ([1  2  3  4])
##       @result{}  4  3  2  1
##
## flip ([1; 2; 3; 4])
##       @result{}  4
##           3
##           2
##           1
##
## flip ([1 2; 3 4])
##       @result{}  3  4
##           1  2
##
## flip ([1 2; 3 4], 2)
##       @result{}  2  1
##           4  3
## @end group
## @end example
##
## @seealso{fliplr, flipud, rot90, rotdim, permute, transpose}
## @end deftypefn
    
    ## Author: David Bateman, Jaroslav Hajek
    
    
@function
def flip(x=None,dim=None,*args,**kwargs):
    varargin = flip.varargin
    nargin = flip.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/flip.m:61
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/flip.m:62
    if (nargin == 1):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/flip.m:None
    else:
        if (logical_not((isscalar(dim) and isindex(dim)))):
            error('flip: DIM must be a positive integer')
    
    idx[1:max(nd,dim)]=cellarray([':'])
# /home/lei/octave-4.0.2/scripts/general/flip.m:70
    idx[dim]=arange(size(x,dim),1,- 1)
# /home/lei/octave-4.0.2/scripts/general/flip.m:71
    y=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/flip.m:72
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test defaults
    
    
    
    ## Test NDArrays
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2016 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{theta}, @var{phi}, @var{r}] =} cart2sph (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {[@var{theta}, @var{phi}, @var{r}] =} cart2sph (@var{C})
## @deftypefnx {Function File} {@var{S} =} cart2sph (@dots{})
## Transform Cartesian coordinates to spherical coordinates.
##
## The inputs @var{x}, @var{y}, and @var{z} must be the same shape, or scalar.
## If called with a single matrix argument then each row of @var{C} represents
## the Cartesian coordinate (@var{x}, @var{y}, @var{z}).
##
## @var{theta} describes the angle relative to the positive x-axis.
##
## @var{phi} is the angle relative to the xy-plane.
##
## @var{r} is the distance to the origin @w{(0, 0, 0)}.
##
## If only a single return argument is requested then return a matrix @var{S}
## where each row represents one spherical coordinate
## (@var{theta}, @var{phi}, @var{r}).
## @seealso{sph2cart, cart2pol, pol2cart}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def cart2sph(x=None,y=None,z=None,*args,**kwargs):
    varargin = cart2sph.varargin
    nargin = cart2sph.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (nargin == 1):
        if (logical_not((isnumeric(x) and ismatrix(x) and columns(x) == 3))):
            error('cart2sph: matrix input must have 3 columns [X, Y, Z]')
        z=x[:,3]
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:54
        y=x[:,2]
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:55
        x=x[:,1]
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:56
    else:
        if (logical_not(((isnumeric(x) and isnumeric(y) and isnumeric(z)) and (size_equal(x,y) or isscalar(x) or isscalar(y)) and (size_equal(x,z) or isscalar(x) or isscalar(z)) and (size_equal(y,z) or isscalar(y) or isscalar(z))))):
            error('cart2sph: X, Y, Z must be numeric arrays of the same size, or scalar')
    
    theta=atan2(y,x)
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:66
    phi=atan2(z,sqrt(x ** 2 + y ** 2))
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:67
    r=sqrt(x ** 2 + y ** 2 + z ** 2)
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:68
    if (nargout <= 1):
        theta=matlabarray(cat(ravel(theta),ravel(phi),ravel(r)))
# /home/lei/octave-4.0.2/scripts/general/cart2sph.m:71
    
    return theta,phi,r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{idx} =} subsindex (@var{a})
## Convert an object to an index vector.
##
## When @var{a} is a class object defined with a class constructor, then
## @code{subsindex} is the overloading method that allows the conversion of
## this class object to a valid indexing vector.  It is important to note that
## @code{subsindex} must return a zero-based real integer vector of the class
## @qcode{"double"}.  For example, if the class constructor
##
## @example
## @group
## function b = myclass (a)
##   b = class (struct ("a", a), "myclass");
## endfunction
## @end group
## @end example
##
## @noindent
## then the @code{subsindex} function
##
## @example
## @group
## function idx = subsindex (a)
##   idx = double (a.a) - 1.0;
## endfunction
## @end group
## @end example
##
## @noindent
## can then be used as follows
##
## @example
## @group
## a = myclass (1:4);
## b = 1:10;
## b(a)
## @result{} 1  2  3  4
## @end group
## @end example
##
## @seealso{class, subsref, subsasgn}
## @end deftypefn
    
    
@function
def subsindex(a=None,*args,**kwargs):
    varargin = subsindex.varargin
    nargin = subsindex.nargin

    error('subsindex: not defined for class "%s"',class_(a))
    return idx
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2000-2015 Daniel Calvelo
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} blkdiag (@var{A}, @var{B}, @var{C}, @dots{})
## Build a block diagonal matrix from @var{A}, @var{B}, @var{C}, @dots{}
##
## All arguments must be numeric and either two-dimensional matrices or
## scalars.  If any argument is of type sparse, the output will also be sparse.
## @seealso{diag, horzcat, vertcat, sparse}
## @end deftypefn
    
    ## Author: Daniel Calvelo
## Modified by: William Poetra Yoga Hadisoeseno
    
    
@function
def blkdiag(varargin=None,*args,**kwargs):
    varargin = blkdiag.varargin
    nargin = blkdiag.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not(all(cellfun('isnumeric',varargin)))):
        error('blkdiag: all arguments must be numeric')
    
    ## Note: trailing singletons are automatically (correctly) ignored.
    if (logical_not(all(cellfun('ndims',varargin) == 2))):
        error('blkdiag: all arguments must be two-dimensional matrices')
    
    ## size is an option for cellfun, but it's a bit different from
  ## calling size directly.
    tmp=cell2mat(cellfun(size,varargin.T,'uniformoutput',false))
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:48
    csz=cumsum(cat([0,0],[tmp]),1)
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:49
    if (any(cellfun('issparse',varargin))):
        retval=sparse(csz[end(),1],csz[end(),2])
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:52
    else:
        retval=zeros(csz[end(),:])
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:54
    
    for p in arange(1,nargin).reshape(-1):
        vp=varargin[p]
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:58
        if (logical_not(isempty(vp))):
            retval[(csz[p,1] + 1):csz[p + 1,1],(csz[p,2] + 1):csz[p + 1,2]]=vp
# /home/lei/octave-4.0.2/scripts/general/blkdiag.m:60
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## regular tests
    
    
    
    
    ## tests involving empty matrices
    
    
    
    ## tests involving sparse matrices
    
    
    ## sanity checks
    
    
    ## Copyright (C) 2012-2014 Daniel Kraft
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} profshow (@var{data})
## @deftypefnx {Function File} {} profshow (@var{data}, @var{n})
## @deftypefnx {Function File} {} profshow ()
## @deftypefnx {Function File} {} profshow (@var{n})
## Display flat per-function profiler results.
##
## Print out profiler data (execution time, number of calls) for the most
## critical @var{n} functions.  The results are sorted in descending order by
## the total time spent in each function.  If @var{n} is unspecified it
## defaults to 20.
##
## The input @var{data} is the structure returned by @code{profile ("info")}.
## If unspecified, @code{profshow} will use the current profile dataset.
##
## The attribute column displays @samp{R} for recursive functions, and is blank
## for all other function types.
## @seealso{profexplore, profile}
## @end deftypefn
    
    ## Built-in profiler.
## Author: Daniel Kraft <d@domob.eu>
    
    
@function
def profshow(data=None,n=20,*args,**kwargs):
    varargin = profshow.varargin
    nargin = profshow.nargin

    if (nargin > 2):
        print_usage()
    
    if (nargin == 0):
        data=profile('info')
# /home/lei/octave-4.0.2/scripts/general/profshow.m:49
    else:
        if (nargin == 1 and logical_not(isstruct(data))):
            n=copy(data)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:51
            data=profile('info')
# /home/lei/octave-4.0.2/scripts/general/profshow.m:52
    
    n=fix(n)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:55
    if (logical_not(isscalar(n)) or logical_not(isreal(n)) or logical_not((n > 0))):
        error('profile: N must be a positive integer')
    
    m=length(data.FunctionTable)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:60
    n=min(n,m)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:61
    
    ## times to an array, then sort this, and use the resulting index permutation
  ## to print out our table.
    times=matlabarray(cat(data.FunctionTable.TotalTime))
# /home/lei/octave-4.0.2/scripts/general/profshow.m:66
    totalTime=sum(times)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:67
    __,p=sort(times,'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:69
    
    ## so that we can proportion the table accordingly.  Based on this,
  ## we can build the format used for printing table rows.
    nameLen=max(length('Function'),columns(char(data.FunctionTable(p[1:n]).FunctionName)))
# /home/lei/octave-4.0.2/scripts/general/profshow.m:74
    headerFormat=sprintf('%%4s %%%ds %%4s %%12s %%10s %%12s\n',nameLen)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:76
    rowFormat=sprintf('%%4d %%%ds %%4s %%12.3f %%10.2f %%12d\n',nameLen)
# /home/lei/octave-4.0.2/scripts/general/profshow.m:77
    printf(headerFormat,'#','Function','Attr','Time (s)','Time (%)','Calls')
    printf('%s\n',repmat('-',1,nameLen + dot(2,5) + 11 + dot(2,13)))
    for i in arange(1,n).reshape(-1):
        row=data.FunctionTable(p[i])
# /home/lei/octave-4.0.2/scripts/general/profshow.m:84
        timePercent=dot(100,row.TotalTime) / totalTime
# /home/lei/octave-4.0.2/scripts/general/profshow.m:85
        attr=''
# /home/lei/octave-4.0.2/scripts/general/profshow.m:86
        if (row.IsRecursive):
            attr='R'
# /home/lei/octave-4.0.2/scripts/general/profshow.m:88
        printf(rowFormat,p[i],row.FunctionName,attr,row.TotalTime,timePercent,row.NumCalls)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 William Poetra Yoga Hadisoeseno
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isequal (@var{x1}, @var{x2}, @dots{})
## Return true if all of @var{x1}, @var{x2}, @dots{} are equal.
## @seealso{isequaln}
## @end deftypefn
    
    
@function
def isequal(x1=None,varargin=None,*args,**kwargs):
    varargin = isequal.varargin
    nargin = isequal.nargin

    if (nargin < 2):
        print_usage()
    
    retval=__isequal__(false,x1,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/isequal.m:31
    return retval
    
if __name__ == '__main__':
    pass
    
    ## test empty input
    
    
    
    
    
    ## test size and shape
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## test all numeric built-in primitives
    
    
    
    
    
    
    
    
    
    
    
    
    ## test characters and strings
    
    
    
    
    
    
    ## test function_handle
    
    
    
    
    ## test structures
    
    
    
    
    
    
    
    
    
    ## recursive structure
    
    
    
    
    
    
    
    
    
    
    
    ## test cells
    
    
    
    
    
    
    
    
    
    
    
    
    ## recursive cell
    
    
    
    
    
    
    
    
    ## test for sparse matrices
    
    
    
    
    
    
    
    
    
    ## test NaN
    
    
    
    
    
    
    ## test input validation
    
    ## Copyright (C) 2001-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{s} =} rat (@var{x}, @var{tol})
## @deftypefnx {Function File} {[@var{n}, @var{d}] =} rat (@var{x}, @var{tol})
##
## Find a rational approximation to @var{x} within the tolerance defined by
## @var{tol} using a continued fraction expansion.
##
## For example:
##
## @example
## @group
## rat (pi) = 3 + 1/(7 + 1/16) = 355/113
## rat (e) = 3 + 1/(-4 + 1/(2 + 1/(5 + 1/(-2 + 1/(-7)))))
##         = 1457/536
## @end group
## @end example
##
## When called with two output arguments return the numerator and denominator
## separately as two matrices.
## @seealso{rats}
## @end deftypefn
    
    
@function
def rat(x=None,tol=None,*args,**kwargs):
    varargin = rat.varargin
    nargin = rat.nargin

    if (nargin != cat(1,2) or nargout > 2):
        print_usage()
    
    y=ravel(x)
# /home/lei/octave-4.0.2/scripts/general/rat.m:47
    
    y[isinf(y)]=0
# /home/lei/octave-4.0.2/scripts/general/rat.m:50
    
    if (nargin < 2):
        tol=dot(1e-06,norm(y,1))
# /home/lei/octave-4.0.2/scripts/general/rat.m:54
    
    ## First step in the approximation is the integer portion
    
    ## First element in the continued fraction.
    n=round(y)
# /home/lei/octave-4.0.2/scripts/general/rat.m:60
    d=ones(size(y))
# /home/lei/octave-4.0.2/scripts/general/rat.m:61
    frac=y - n
# /home/lei/octave-4.0.2/scripts/general/rat.m:62
    lastn=ones(size(y))
# /home/lei/octave-4.0.2/scripts/general/rat.m:63
    lastd=zeros(size(y))
# /home/lei/octave-4.0.2/scripts/general/rat.m:64
    nd=ndims(y)
# /home/lei/octave-4.0.2/scripts/general/rat.m:66
    nsz=numel(y)
# /home/lei/octave-4.0.2/scripts/general/rat.m:67
    steps=zeros(cat(nsz,0))
# /home/lei/octave-4.0.2/scripts/general/rat.m:68
    
    while (1):

        ## Determine which fractions have not yet converged.
        idx=find(abs(y - n / d) >= tol)
# /home/lei/octave-4.0.2/scripts/general/rat.m:73
        if (isempty(idx)):
            if (isempty(steps)):
                steps=NaN(nsz,1)
# /home/lei/octave-4.0.2/scripts/general/rat.m:76
            break
        ## Grab the next step in the continued fraction.
        flip=1.0 / frac[idx]
# /home/lei/octave-4.0.2/scripts/general/rat.m:82
        step=round(flip)
# /home/lei/octave-4.0.2/scripts/general/rat.m:84
        if (nargout < 2):
            tsteps=NaN(nsz,1)
# /home/lei/octave-4.0.2/scripts/general/rat.m:87
            tsteps[idx]=step
# /home/lei/octave-4.0.2/scripts/general/rat.m:88
            steps=matlabarray(cat(steps,tsteps))
# /home/lei/octave-4.0.2/scripts/general/rat.m:89
        frac[idx]=flip - step
# /home/lei/octave-4.0.2/scripts/general/rat.m:92
        nextn=copy(n)
# /home/lei/octave-4.0.2/scripts/general/rat.m:95
        nextd=copy(d)
# /home/lei/octave-4.0.2/scripts/general/rat.m:96
        n[idx]=multiply(n[idx],step) + lastn[idx]
# /home/lei/octave-4.0.2/scripts/general/rat.m:97
        d[idx]=multiply(d[idx],step) + lastd[idx]
# /home/lei/octave-4.0.2/scripts/general/rat.m:98
        lastn=copy(nextn)
# /home/lei/octave-4.0.2/scripts/general/rat.m:99
        lastd=copy(nextd)
# /home/lei/octave-4.0.2/scripts/general/rat.m:100

    
    if (nargout == 2):
        ## Move the minus sign to the top.
        n=multiply(n,sign(d))
# /home/lei/octave-4.0.2/scripts/general/rat.m:105
        d=abs(d)
# /home/lei/octave-4.0.2/scripts/general/rat.m:106
        n=reshape(n,size(x))
# /home/lei/octave-4.0.2/scripts/general/rat.m:109
        d=reshape(d,size(x))
# /home/lei/octave-4.0.2/scripts/general/rat.m:110
        n[isinf(x)]=sign(x[isinf(x)])
# /home/lei/octave-4.0.2/scripts/general/rat.m:113
        d[isinf(x)]=0
# /home/lei/octave-4.0.2/scripts/general/rat.m:114
        n=reshape(n,size(x))
# /home/lei/octave-4.0.2/scripts/general/rat.m:117
        d=reshape(d,size(x))
# /home/lei/octave-4.0.2/scripts/general/rat.m:118
    else:
        n=''
# /home/lei/octave-4.0.2/scripts/general/rat.m:120
        nsteps=columns(steps)
# /home/lei/octave-4.0.2/scripts/general/rat.m:121
        for i in arange(1,nsz).reshape(-1):
            s=matlabarray(cat(int2str(y[i]),' '))
# /home/lei/octave-4.0.2/scripts/general/rat.m:123
            j=1
# /home/lei/octave-4.0.2/scripts/general/rat.m:124
            while (true):

                step=steps[i,j]
# /home/lei/octave-4.0.2/scripts/general/rat.m:127
                if (isnan(step)):
                    break
                if (j > nsteps or isnan(steps[i,j])):
                    if (step < 0):
                        s=matlabarray(cat(s[1:end() - 1],' + 1/(',int2str(step),')'))
# /home/lei/octave-4.0.2/scripts/general/rat.m:133
                    else:
                        s=matlabarray(cat(s[1:end() - 1],' + 1/',int2str(step)))
# /home/lei/octave-4.0.2/scripts/general/rat.m:135
                    break
                else:
                    s=matlabarray(cat(s[1:end() - 1],' + 1/(',int2str(step),')'))
# /home/lei/octave-4.0.2/scripts/general/rat.m:139

            s=matlabarray(cat(s,repmat(')',1,j - 2)))
# /home/lei/octave-4.0.2/scripts/general/rat.m:142
            n_nc=columns(n)
# /home/lei/octave-4.0.2/scripts/general/rat.m:143
            s_nc=columns(s)
# /home/lei/octave-4.0.2/scripts/general/rat.m:144
            if (n_nc > s_nc):
                s[:,s_nc + 1:n_nc]=' '
# /home/lei/octave-4.0.2/scripts/general/rat.m:146
            else:
                if (s_nc > n_nc and n_nc != 0):
                    n[:,n_nc + 1:s_nc]=' '
# /home/lei/octave-4.0.2/scripts/general/rat.m:148
            n=cat(1,n,s)
# /home/lei/octave-4.0.2/scripts/general/rat.m:150
    
    return n,d
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## bug #43374
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2009 VZLU Prague
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{err}, @var{y1}, @dots{}] =} common_size (@var{x1}, @dots{})
## Determine if all input arguments are either scalar or of common size.
##
## If true, @var{err} is zero, and @var{yi} is a matrix of the common size
## with all entries equal to @var{xi} if this is a scalar or @var{xi}
## otherwise.  If the inputs cannot be brought to a common size, @var{err} is
## 1, and @var{yi} is @var{xi}.  For example:
##
## @example
## @group
## [errorcode, a, b] = common_size ([1 2; 3 4], 5)
##      @result{} errorcode = 0
##      @result{} a = [ 1, 2; 3, 4 ]
##      @result{} b = [ 5, 5; 5, 5 ]
## @end group
## @end example
##
## @noindent
## This is useful for implementing functions where arguments can either be
## scalars or of common size.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 15 October 1994
## Adapted-By: jwe
## Optimized-By: Jaroslav Hajek
    
    
@function
def common_size(varargin=None,*args,**kwargs):
    varargin = common_size.varargin
    nargin = common_size.nargin

    if (nargin < 2):
        error('common_size: only makes sense if nargin >= 2')
    
    ## Find scalar args.
    nscal=cellfun('numel',varargin) != 1
# /home/lei/octave-4.0.2/scripts/general/common_size.m:56
    i=find(nscal,1)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:58
    if (isempty(i)):
        errorcode=0
# /home/lei/octave-4.0.2/scripts/general/common_size.m:61
        varargout=copy(varargin)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:62
    else:
        match=cellfun('size_equal',varargin,varargin[i])
# /home/lei/octave-4.0.2/scripts/general/common_size.m:64
        if (any(logical_and(nscal,logical_not(match)))):
            errorcode=1
# /home/lei/octave-4.0.2/scripts/general/common_size.m:66
            varargout=copy(varargin)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:67
        else:
            errorcode=0
# /home/lei/octave-4.0.2/scripts/general/common_size.m:69
            if (nargout > 1):
                scal=logical_not(nscal)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:71
                varargout=copy(varargin)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:72
                if (any(nscal)):
                    dims=size(varargin[find(nscal,1)])
# /home/lei/octave-4.0.2/scripts/general/common_size.m:74
                    subs=arrayfun(ones,1,dims,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/common_size.m:75
                    varargout[scal]=cellindexmat(varargin[scal],subs[:])
# /home/lei/octave-4.0.2/scripts/general/common_size.m:76
    
    return errorcode,varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Jordi Gutirrez Hermoso
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} nthargout (@var{n}, @var{func}, @dots{})
## @deftypefnx {Function File} {} nthargout (@var{n}, @var{ntot}, @var{func}, @dots{})
## Return the @var{n}th output argument of the function specified by the
## function handle or string @var{func}.
##
## Any additional arguments are passed directly to @var{func}.  The total
## number of arguments to call @var{func} with can be passed in @var{ntot}; by
## default @var{ntot} is @var{n}.  The input @var{n} can also be a vector of
## indices of the output, in which case the output will be a cell array of the
## requested output arguments.
##
## The intended use @code{nthargout} is to avoid intermediate variables.  For
## example, when finding the indices of the maximum entry of a matrix, the
## following two compositions of nthargout
##
## @example
## @group
## @var{m} = magic (5);
## cell2mat (nthargout ([1, 2], @@ind2sub, size (@var{m}),
##                      nthargout (2, @@max, @var{m}(:))))
## @result{} 5   3
## @end group
## @end example
##
## @noindent
## are completely equivalent to the following lines:
##
## @example
## @group
## @var{m} = magic (5);
## [~, idx] = max (@var{M}(:));
## [i, j] = ind2sub (size (@var{m}), idx);
## [i, j]
## @result{} 5   3
## @end group
## @end example
##
## It can also be helpful to have all output arguments in a single cell in the
## following manner:
##
## @example
## @var{USV} = nthargout ([1:3], @@svd, hilb (5));
## @end example
##
## @seealso{nargin, nargout, varargin, varargout, isargout}
## @end deftypefn
    
    ## Author: Jordi Gutirrez Hermoso
    
    
@function
def nthargout(n=None,varargin=None,*args,**kwargs):
    varargin = nthargout.varargin
    nargin = nthargout.nargin

    if (nargin < 2):
        print_usage()
    
    if (isa(varargin[1],'function_handle') or ischar(varargin[1])):
        ntot=max(ravel(n))
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:75
        func=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:76
        args=varargin[2:end()]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:77
    else:
        if (isnumeric(varargin[1]) and (isa(varargin[2],'function_handle') or ischar(varargin[2]))):
            ntot=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:80
            func=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:81
            args=varargin[3:end()]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:82
        else:
            print_usage()
    
    if (any(n != fix(n)) or ntot != fix(ntot) or any(n <= 0) or ntot <= 0):
        error('nthargout: N and NTOT must consist of positive integers')
    
    outargs=cell(1,ntot)
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:91
    try:
        outargs[:]=feval(func,args[:])
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:94
        if (numel(n) > 1):
            out=outargs[n]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:96
        else:
            out=outargs[n]
# /home/lei/octave-4.0.2/scripts/general/nthargout.m:98
    finally:
        pass
    
    return out
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2005-2015 Laurent Mazet
## Copyright (C) 2010 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{m} =} cell2mat (@var{c})
## Convert the cell array @var{c} into a matrix by concatenating all
## elements of @var{c} into a hyperrectangle.
##
## Elements of @var{c} must be numeric, logical, or char matrices; or cell
## arrays; or structs; and @code{cat} must be able to concatenate them together.
## @seealso{mat2cell, num2cell}
## @end deftypefn
    
    
@function
def cell2mat(c=None,*args,**kwargs):
    varargin = cell2mat.varargin
    nargin = cell2mat.nargin

    if (nargin != 1):
        print_usage()
    
    nb=numel(c)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:36
    if (nb == 0):
        m=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:39
    else:
        if (logical_not(iscell(c))):
            error('cell2mat: C must be a cell array')
        ## Check first for valid matrix types
        valid=cellfun('isnumeric',c)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:46
        valid=cellfun('islogical',c[logical_not(valid)])
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:47
        valid=cellfun('isclass',c[logical_not(valid)],'char')
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:48
        if (logical_not(all(ravel(valid)))):
            valid=cellfun('isclass',c,'cell')
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:50
            if (logical_not(all(ravel(valid)))):
                valid=cellfun('isclass',c,'struct')
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:52
                if (logical_not(all(ravel(valid)))):
                    error('cell2mat: wrong type elements or mixed cells, structs, and matrices')
        sz=size(c)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:59
        if (all(ravel(cellfun('numel',c)) == 1)):
            ## Special case of all scalars
            m=reshape(cat(1,c[:]),sz)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:62
        else:
            ## The goal is to minimize the total number of cat() calls.
      ## The dimensions can be concatenated along in arbitrary order.
      ## The numbers of concatenations are:
      ## n / d1
      ## n / (d1 * d2)
      ## n / (d1 * d2 * d3)
      ## etc.
      ## This is minimized if d1 >= d2 >= d3...
            nd=ndims(c)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:74
            __,isz=sort(sz,'descend',nargout=2)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:75
            for idim in isz.reshape(-1):
                if (sz[idim] == 1):
                    continue
                xdim=matlabarray(cat(arange(1,idim - 1),arange(idim + 1,nd)))
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:80
                cc=num2cell(c,xdim)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:81
                c=cellfun('cat',cellarray([idim]),cc[:],'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:82
            m=c[1]
# /home/lei/octave-4.0.2/scripts/general/cell2mat.m:84
    
    return m
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Daniel Calvelo
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{s}, @var{i}] =} sortrows (@var{A})
## @deftypefnx {Function File} {[@var{s}, @var{i}] =} sortrows (@var{A}, @var{c})
## Sort the rows of the matrix @var{A} according to the order of the columns
## specified in @var{c}.
##
## If @var{c} is omitted, a lexicographical sort is used.  By default ascending
## order is used however if elements of @var{c} are negative then the
## corresponding column is sorted in descending order.
## @seealso{sort}
## @end deftypefn
    
    ## Author: Daniel Calvelo, Paul Kienzle
## Adapted-by: jwe
    
    
@function
def sortrows(A=None,c=None,*args,**kwargs):
    varargin = sortrows.varargin
    nargin = sortrows.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 2):
        if (logical_not((isnumeric(c) and isvector(c)))):
            error('sortrows: C must be a numeric vector')
        else:
            if (any(c == 0) or any(abs(c) > columns(A))):
                error('sortrows: all elements of C must be in the range [1, columns (A)]')
    
    default_mode='ascend'
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:49
    reverse_mode='descend'
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:50
    if (issparse(A)):
        ## FIXME: Eliminate this case once __sort_rows_idx__ is fixed to
    ##        handle sparse matrices.
        if (nargin == 1):
            i=sort_rows_idx_generic(default_mode,reverse_mode,A)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:56
        else:
            i=sort_rows_idx_generic(default_mode,reverse_mode,A,c)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:58
    else:
        if (nargin == 1):
            i=__sort_rows_idx__(A,default_mode)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:61
        else:
            if (all(c > 0)):
                i=__sort_rows_idx__(A[:,c],default_mode)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:63
            else:
                if (all(c < 0)):
                    i=__sort_rows_idx__(A[:,- c],reverse_mode)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:65
                else:
                    ## Otherwise, fall back to the old algorithm.
                    i=sort_rows_idx_generic(default_mode,reverse_mode,A,c)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:68
    
    ## Only bother to compute s if needed.
    if (isargout(1)):
        s=A[i,:]
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:73
    
    return s,i
    
if __name__ == '__main__':
    pass
    
    
@function
def sort_rows_idx_generic(default_mode=None,reverse_mode=None,m=None,c=None,*args,**kwargs):
    varargin = sort_rows_idx_generic.varargin
    nargin = sort_rows_idx_generic.nargin

    if (nargin == 3):
        indices=cat(arange(1,columns(m))).T
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:81
        mode[1:columns(m)]=cellarray([default_mode])
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:82
    else:
        for j in arange(1,length(c)).reshape(-1):
            if (c[j] < 0):
                mode[j]=reverse_mode
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:86
            else:
                mode[j]=default_mode
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:88
        indices=abs(ravel(c))
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:91
    
    ## Since sort is 'stable' the order of identical elements will be
  ## preserved, so by traversing the sort indices in reverse order we
  ## will make sure that identical elements in index i are subsorted by
  ## index j.
    indices=flipud(indices)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:98
    mode=flipud(mode.T)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:99
    i=cat(arange(1,rows(m))).T
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:100
    for j in arange(1,length(indices)).reshape(-1):
        __,idx=sort(m[i,indices[j]],mode[j],nargout=2)
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:102
        i=i[idx]
# /home/lei/octave-4.0.2/scripts/general/sortrows.m:103
    
    return i
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2016 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{theta}, @var{r}] =} cart2pol (@var{x}, @var{y})
## @deftypefnx {Function File} {[@var{theta}, @var{r}, @var{z}] =} cart2pol (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {[@var{theta}, @var{r}] =} cart2pol (@var{C})
## @deftypefnx {Function File} {[@var{theta}, @var{r}, @var{z}] =} cart2pol (@var{C})
## @deftypefnx {Function File} {@var{P} =} cart2pol (@dots{})
##
## Transform Cartesian coordinates to polar or cylindrical coordinates.
##
## The inputs @var{x}, @var{y} (, and @var{z}) must be the same shape, or
## scalar.  If called with a single matrix argument then each row of @var{C}
## represents the Cartesian coordinate (@var{x}, @var{y} (, @var{z})).
##
## @var{theta} describes the angle relative to the positive x-axis.
##
## @var{r} is the distance to the z-axis @w{(0, 0, z)}.
##
## If only a single return argument is requested then return a matrix @var{P}
## where each row represents one polar/(cylindrical) coordinate
## (@var{theta}, @var{phi} (, @var{z})).
## @seealso{pol2cart, cart2sph, sph2cart}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def cart2pol(x=None,y=None,z=[],*args,**kwargs):
    varargin = cart2pol.varargin
    nargin = cart2pol.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin == 1):
        if (logical_not((isnumeric(x) and ismatrix(x) and (columns(x) == 2 or columns(x) == 3)))):
            error('cart2pol: matrix input must have 2 or 3 columns [X, Y (, Z)]')
        if (columns(x) == 3):
            z=x[:,3]
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:57
        y=x[:,2]
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:59
        x=x[:,1]
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:60
    else:
        if (nargin == 2):
            if (logical_not(((isnumeric(x) and isnumeric(y)) and (size_equal(x,y) or isscalar(x) or isscalar(y))))):
                error('cart2pol: X, Y must be numeric arrays of the same size, or scalar')
        else:
            if (nargin == 3):
                if (logical_not(((isnumeric(x) and isnumeric(y) and isnumeric(z)) and (size_equal(x,y) or isscalar(x) or isscalar(y)) and (size_equal(x,z) or isscalar(x) or isscalar(z)) and (size_equal(y,z) or isscalar(y) or isscalar(z))))):
                    error('cart2pol: X, Y, Z must be numeric arrays of the same size, or scalar')
    
    theta=atan2(y,x)
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:75
    r=sqrt(x ** 2 + y ** 2)
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:76
    if (nargout <= 1):
        theta=matlabarray(cat(ravel(theta),ravel(r),ravel(z)))
# /home/lei/octave-4.0.2/scripts/general/cart2pol.m:79
    
    return theta,r,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
## Copyright (C) 2009-2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} accumarray (@var{subs}, @var{vals}, @var{sz}, @var{func}, @var{fillval}, @var{issparse})
## @deftypefnx {Function File} {} accumarray (@var{subs}, @var{vals}, @dots{})
##
## Create an array by accumulating the elements of a vector into the
## positions defined by their subscripts.
##
## The subscripts are defined by the rows of the matrix @var{subs} and the
## values by @var{vals}.  Each row of @var{subs} corresponds to one of the
## values in @var{vals}.  If @var{vals} is a scalar, it will be used for each
## of the row of @var{subs}.  If @var{subs} is a cell array of vectors, all
## vectors must be of the same length, and the subscripts in the @var{k}th
## vector must correspond to the @var{k}th dimension of the result.
##
## The size of the matrix will be determined by the subscripts
## themselves.  However, if @var{sz} is defined it determines the matrix
## size.  The length of @var{sz} must correspond to the number of columns
## in @var{subs}.  An exception is if @var{subs} has only one column, in
## which case @var{sz} may be the dimensions of a vector and the
## subscripts of @var{subs} are taken as the indices into it.
##
## The default action of @code{accumarray} is to sum the elements with
## the same subscripts.  This behavior can be modified by defining the
## @var{func} function.  This should be a function or function handle
## that accepts a column vector and returns a scalar.  The result of the
## function should not depend on the order of the subscripts.
##
## The elements of the returned array that have no subscripts associated
## with them are set to zero.  Defining @var{fillval} to some other value
## allows these values to be defined.  This behavior changes, however,
## for certain values of @var{func}.  If @var{func} is @code{min}
## (respectively, @code{max}) then the result will be filled with the
## minimum (respectively, maximum) integer if @var{vals} is of integral
## type, logical false (respectively, logical true) if @var{vals} is of
## logical type, zero if @var{fillval} is zero and all values are
## non-positive (respectively, non-negative), and NaN otherwise.
##
## By default @code{accumarray} returns a full matrix.  If
## @var{issparse} is logically true, then a sparse matrix is returned
## instead.
##
## The following @code{accumarray} example constructs a frequency table
## that in the first column counts how many occurrences each number in
## the second column has, taken from the vector @var{x}.  Note the usage
## of @code{unique}  for assigning to all repeated elements of @var{x}
## the same index (@pxref{XREFunique,,unique}).
##
## @example
## @group
## @var{x} = [91, 92, 90, 92, 90, 89, 91, 89, 90, 100, 100, 100];
## [@var{u}, ~, @var{j}] = unique (@var{x});
## [accumarray(@var{j}', 1), @var{u}']
##   @result{}  2    89
##       3    90
##       2    91
##       2    92
##       3   100
## @end group
## @end example
##
## Another example, where the result is a multi-dimensional 3-D array and
## the default value (zero) appears in the output:
##
## @example
## @group
## accumarray ([1, 1, 1;
##              2, 1, 2;
##              2, 3, 2;
##              2, 1, 2;
##              2, 3, 2], 101:105)
## @result{} ans(:,:,1) = [101, 0, 0; 0, 0, 0]
## @result{} ans(:,:,2) = [0, 0, 0; 206, 0, 208]
## @end group
## @end example
##
## The sparse option can be used as an alternative to the @code{sparse}
## constructor (@pxref{XREFsparse,,sparse}).  Thus
##
## @example
## sparse (@var{i}, @var{j}, @var{sv})
## @end example
##
## @noindent
## can be written with @code{accumarray} as
##
## @example
## accumarray ([@var{i}, @var{j}], @var{sv}', [], [], 0, true)
## @end example
##
## @noindent
## For repeated indices, @code{sparse} adds the corresponding value.  To
## take the minimum instead, use @code{min} as an accumulator function:
##
## @example
## accumarray ([@var{i}, @var{j}], @var{sv}', [], @@min, 0, true)
## @end example
##
## The complexity of accumarray in general for the non-sparse case is
## generally O(M+N), where N is the number of subscripts and M is the
## maximum subscript (linearized in multi-dimensional case).  If
## @var{func} is one of @code{@@sum} (default), @code{@@max},
## @code{@@min} or @code{@@(x) @{x@}}, an optimized code path is used.
## Note that for general reduction function the interpreter overhead can
## play a major part and it may be more efficient to do multiple
## accumarray calls and compute the results in a vectorized manner.
##
## @seealso{accumdim, unique, sparse}
## @end deftypefn
    
    
@function
def accumarray(subs=None,vals=None,sz=[],func=[],fillval=[],issparse=[],*args,**kwargs):
    varargin = accumarray.varargin
    nargin = accumarray.nargin

    if (nargin < 2 or nargin > 6):
        print_usage()
    
    lenvals=length(vals)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:135
    if (iscell(subs)):
        subs=cellfun(vec,subs,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:138
        ndims=numel(subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:139
        if (ndims == 1):
            subs=subs[1]
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:141
        lensubs=cellfun(length,subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:144
        if (any(lensubs != lensubs[1]) or (lenvals > 1 and lenvals != lensubs[1])):
            error('accumarray: dimension mismatch')
    else:
        ndims=columns(subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:151
        if (lenvals > 1 and lenvals != rows(subs)):
            error('accumarray: dimension mismatch')
    
    if (isempty(fillval)):
        fillval=0
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:158
    
    if (isempty(issparse)):
        issparse=copy(false)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:162
    
    if (issparse):
        ## Sparse case. Avoid linearizing the subscripts, because it could
    ## overflow.
        if (fillval != 0):
            error('accumarray: FILLVAL must be zero in the sparse case')
        ## Ensure subscripts are a two-column matrix.
        if (iscell(subs)):
            subs=matlabarray(cat(subs[:]))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:176
        ## Validate dimensions.
        if (ndims == 1):
            subs[:,2]=1
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:181
        else:
            if (ndims != 2):
                error('accumarray: in the sparse case, needs 1 or 2 subscripts')
        if (isnumeric(vals) or islogical(vals)):
            vals=double(vals)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:187
        else:
            error('accumarray: in the sparse case, values must be numeric or logical')
        if (logical_not((isempty(func) or func == sum))):
            ## Reduce values. This is not needed if we're about to sum them,
      ## because "sparse" can do that.
            ## Sort indices.
            subs,idx=sortrows(subs,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:198
            n=rows(subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:199
            jdx=find(any(diff(subs,1,1),2))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:201
            jdx=matlabarray(cat([jdx],[n]))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:202
            vals=cellfun(func,mat2cell(ravel(vals)(idx),diff(cat([0],[jdx]))))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:204
            subs=subs[jdx,:]
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:205
            mode='unique'
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:206
        else:
            mode='sum'
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:208
        ## Form the sparse matrix.
        if (isempty(sz)):
            A=sparse(subs[:,1],subs[:,2],vals,mode)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:213
        else:
            if (length(sz) == 2):
                ## Row vector case
                if (sz[1] == 1):
                    i,j=deal(subs[:,2],subs[:,1],nargout=2)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:218
                else:
                    i,j=deal(subs[:,1],subs[:,2],nargout=2)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:220
                A=sparse(i,j,vals,sz[1],sz[2],mode)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:222
            else:
                error('accumarray: dimensions mismatch')
    else:
        ## Linearize subscripts.
        if (ndims > 1):
            if (isempty(sz)):
                if (iscell(subs)):
                    sz=cellfun('max',subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:233
                else:
                    sz=max(subs,[],1)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:235
            else:
                if (ndims != length(sz)):
                    error('accumarray: dimensions mismatch')
            ## Convert multidimensional subscripts.
            if (isnumeric(subs)):
                subs=num2cell(subs,1)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:243
            subs=sub2ind(sz,subs[:])
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:245
        else:
            if (logical_not(isempty(sz)) and length(sz) < 2):
                error('accumarray: needs at least 2 dimensions')
            else:
                if (logical_not(isindex(subs))):
                    error('accumarray: indices must be positive integers')
        ## Some built-in reductions handled efficiently.
        if (isempty(func) or func == sum):
            ## Fast summation.
            if (isempty(sz)):
                A=__accumarray_sum__(subs,vals)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:258
            else:
                A=__accumarray_sum__(subs,vals,prod(sz))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:260
                A=reshape(A,sz)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:262
            ## we fill in nonzero fill value.
            if (fillval != 0):
                mask=true(size(A))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:267
                mask[subs]=false
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:268
                A[mask]=fillval
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:269
        else:
            if (func == max):
                ## Fast maximization.
                if (isinteger(vals)):
                    zero=intmin(class_(vals))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:275
                else:
                    if (islogical(vals)):
                        zero=copy(false)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:277
                    else:
                        if (fillval == 0 and all(ravel(vals) >= 0)):
                            ## This is a common case - fillval is zero, all numbers
        ## nonegative.
                            zero=0
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:281
                        else:
                            zero=copy(NaN)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:283
                if (isempty(sz)):
                    A=__accumarray_max__(subs,vals,zero)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:287
                else:
                    A=__accumarray_max__(subs,vals,zero,prod(sz))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:289
                    A=reshape(A,sz)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:290
                if (fillval != zero and logical_not((isnan(fillval) or isnan(zero)))):
                    mask=true(size(A))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:294
                    mask[subs]=false
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:295
                    A[mask]=fillval
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:296
            else:
                if (func == min):
                    ## Fast minimization.
                    if (isinteger(vals)):
                        zero=intmax(class_(vals))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:302
                    else:
                        if (islogical(vals)):
                            zero=copy(true)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:304
                        else:
                            if (fillval == 0 and all(ravel(vals) <= 0)):
                                ## This is a common case - fillval is zero, all numbers
        ## non-positive.
                                zero=0
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:308
                            else:
                                zero=copy(NaN)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:310
                    if (isempty(sz)):
                        A=__accumarray_min__(subs,vals,zero)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:314
                    else:
                        A=__accumarray_min__(subs,vals,zero,prod(sz))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:316
                        A=reshape(A,sz)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:317
                    if (fillval != zero and logical_not((isnan(fillval) or isnan(zero)))):
                        mask=true(size(A))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:321
                        mask[subs]=false
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:322
                        A[mask]=fillval
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:323
                else:
                    ## The general case. Reduce values.
                    n=rows(subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:328
                    if (numel(vals) == 1):
                        vals=vals[ones(1,n),1]
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:330
                    else:
                        vals=ravel(vals)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:332
                    ## Sort indices.
                    subs,idx=sort(subs,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:336
                    jdx=find(subs[1:n - 1] != subs[2:n])
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:338
                    jdx=matlabarray(cat([jdx],[n]))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:339
                    vals=mat2cell(vals[idx],diff(cat([0],[jdx])))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:340
                    ## to collect the values to cells.
                    if (logical_not(strcmp(func2str(func),simple_cell_str))):
                        vals=cellfun(func,vals)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:345
                    subs=subs[jdx]
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:347
                    if (isempty(sz)):
                        sz=max(subs)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:350
                        if (length(sz) == 1):
                            sz[2]=1
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:352
                    ## Construct matrix of fillvals.
                    if (iscell(vals)):
                        A=cell(sz)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:358
                    else:
                        if (fillval == 0):
                            A=zeros(sz,class_(vals))
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:360
                        else:
                            A=repmat(fillval,sz)
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:362
                    ## Set the reduced values.
                    A[subs]=vals
# /home/lei/octave-4.0.2/scripts/general/accumarray.m:366
    
    return A
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} num2str (@var{x})
## @deftypefnx {Function File} {} num2str (@var{x}, @var{precision})
## @deftypefnx {Function File} {} num2str (@var{x}, @var{format})
## Convert a number (or array) to a string (or a character array).
##
## The optional second argument may either give the number of significant
## digits (@var{precision}) to be used in the output or a format template
## string (@var{format}) as in @code{sprintf} (@pxref{Formatted Output}).
## @code{num2str} can also process complex numbers.
##
## Examples:
##
## @example
## @group
## num2str (123.456)
##      @result{} "123.46"
##
## num2str (123.456, 4)
##      @result{} "123.5"
##
## s = num2str ([1, 1.34; 3, 3.56], "#5.1f")
##      @result{} s =
##         1.0  1.3
##         3.0  3.6
## whos s
##      @result{}
##       Attr Name        Size                     Bytes  Class
##       ==== ====        ====                     =====  =====
##            s           2x8                         16  char
##
## num2str (1.234 + 27.3i)
##      @result{} "1.234+27.3i"
## @end group
## @end example
##
## Notes:
##
## For @sc{matlab} compatibility, leading spaces are stripped before returning
## the string.
##
## The @code{num2str} function is not very flexible.  For better control
## over the results, use @code{sprintf} (@pxref{Formatted Output}).
##
## For complex @var{x}, the format string may only contain one output
## conversion specification and nothing else.  Otherwise, results will be
## unpredictable.
## @seealso{sprintf, int2str, mat2str}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def num2str(x=None,arg=None,*args,**kwargs):
    varargin = num2str.varargin
    nargin = num2str.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    else:
        if (logical_not((isnumeric(x) or islogical(x) or ischar(x)))):
            error('num2str: X must be a numeric, logical, or character array')
    
    if (ischar(x)):
        retval=copy(x)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:80
    else:
        if (isempty(x)):
            retval=''
# /home/lei/octave-4.0.2/scripts/general/num2str.m:82
        else:
            if (isreal(x)):
                if (nargin == 2):
                    if (ischar(arg)):
                        fmt=copy(arg)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:86
                    else:
                        if (isnumeric(arg) and isscalar(arg) and arg >= 0 and arg == fix(arg)):
                            fmt=sprintf('%%%d.%dg',arg + 7,arg)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:88
                        else:
                            error('num2str: PRECISION must be a scalar integer >= 0')
                else:
                    if (isnumeric(x)):
                        ## Setup a suitable format string, ignoring inf entries
                        dgt=floor(log10(max(abs(x[logical_not(isinf(ravel(x)))]))))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:95
                        if (isempty(dgt)):
                            ## If the whole input array is inf...
                            dgt=1
# /home/lei/octave-4.0.2/scripts/general/num2str.m:98
                        if (any(ravel(x) != fix(ravel(x)))):
                            ## Floating point input
                            dgt=max(dgt + 4,5)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:103
                            dgt=min(dgt,16)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:104
                            fmt=sprintf('%%%d.%dg',dgt + 7 + any(ravel(x) < 0),dgt)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:105
                        else:
                            ## Integer input
                            dgt=max(dgt + 1,1)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:108
                            ##        See #!xtest below
                            fmt=sprintf('%%%d.%dg',dgt + 2 + any(ravel(x) < 0),dgt)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:111
                    else:
                        ## Logical input
                        fmt='%3d'
# /home/lei/octave-4.0.2/scripts/general/num2str.m:115
                fmt=matlabarray(cat(deblank(repmat(fmt,1,columns(x))),'\n'))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:118
                nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:119
                tmp=sprintf(fmt,permute(x,cat(2,1,arange(3,nd))))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:120
                retval=strtrim(char(ostrsplit(tmp[1:end() - 1],'\n')))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:121
            else:
                if (nargin == 2):
                    if (ischar(arg)):
                        fmt=matlabarray(cat(arg,'%-+',arg[2:end()],'i'))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:125
                    else:
                        if (isnumeric(arg) and isscalar(arg) and arg >= 0 and arg == fix(arg)):
                            fmt=sprintf('%%%d.%dg%%-+%d.%dgi',arg + 7,arg,arg + 7,arg)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:127
                        else:
                            error('num2str: PRECISION must be a scalar integer >= 0')
                else:
                    ## Setup a suitable format string
                    dgt=floor(log10(max(max(abs(real(x[logical_not(isinf(real(ravel(x))))]))),max(abs(imag(x[logical_not(isinf(imag(ravel(x))))]))))))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:133
                    if (isempty(dgt)):
                        ## If the whole input array is inf...
                        dgt=1
# /home/lei/octave-4.0.2/scripts/general/num2str.m:137
                    if (any(ravel(x) != fix(ravel(x)))):
                        ## Floating point input
                        dgt=max(dgt + 4,5)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:142
                        dgt=min(dgt,16)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:143
                        fmt=sprintf('%%%d.%dg%%-+%d.%dgi',dgt + 7,dgt,dgt + 7,dgt)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:144
                    else:
                        ## Integer input
                        dgt=max(1 + dgt,1)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:147
                        ##        See #!xtest below
                        fmt=sprintf('%%%d.%dg%%-+%d.%dgi',dgt + 2,dgt,dgt + 2,dgt)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:150
                ## Manipulate the complex value to have real values in the odd
    ## columns and imaginary values in the even columns.
                nc=columns(x)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:156
                nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:157
                idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:158
                perm[1:2:dot(2,nc)]=arange(1,nc)
# /home/lei/octave-4.0.2/scripts/general/num2str.m:159
                perm[2:2:dot(2,nc)]=nc + (arange(1,nc))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:160
                idx[2]=perm
# /home/lei/octave-4.0.2/scripts/general/num2str.m:161
                x=horzcat(real(x),imag(x))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:162
                x=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/num2str.m:163
                fmt=matlabarray(cat(deblank(repmat(fmt,1,nc)),'\n'))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:165
                tmp=sprintf(fmt,permute(x,cat(2,1,arange(3,nd))))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:166
                tmp=regexprep(tmp,' +i\n','i\n')
# /home/lei/octave-4.0.2/scripts/general/num2str.m:169
                tmp=regexprep(tmp,'( +)i','i$1')
# /home/lei/octave-4.0.2/scripts/general/num2str.m:170
                retval=strtrim(char(ostrsplit(tmp[1:end() - 1],'\n')))
# /home/lei/octave-4.0.2/scripts/general/num2str.m:172
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: Integers greater than bitmax() should be masked to show just
##        16 digits of precision.
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## Undocumented internal function.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{yi} =} __splinen__ (@var{x}, @var{y}, @var{xi})
## Undocumented internal function.
## @end deftypefn
    
    ## FIXME: Allow arbitrary grids..
    
    
@function
def __splinen__(x=None,y=None,xi=None,extrapval=None,f=None,*args,**kwargs):
    varargin = __splinen__.varargin
    nargin = __splinen__.nargin

    ## ND isvector function.
    isvec=lambda x=None: numel(x) == length(x)
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:30
    if (logical_not(iscell(x)) or length(x) < ndims(y) or any(logical_not(cellfun(isvec,x))) or logical_not(iscell(xi)) or length(xi) < ndims(y) or any(logical_not(cellfun(isvec,xi)))):
        error('__splinen__: %s: non-gridded data or dimensions inconsistent',f)
    
    yi=copy(y)
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:36
    for i in arange(length(x),1,- 1).reshape(-1):
        yi=permute(spline(x[i],yi,ravel(xi[i])),cat(length(x),arange(1,length(x) - 1)))
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:38
    
    xi[:]=ndgrid(cellfun(lambda x=None: ravel(x),xi,'uniformoutput',false)[:])
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:41
    if (logical_not(isempty(extrapval))):
        idx=zeros(size(xi[1]))
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:43
        for i in arange(1,length(x)).reshape(-1):
            idx |= xi[i] < logical_or(min(ravel(x[i])),xi[i]) > max(ravel(x[i]))
        yi[idx]=extrapval
# /home/lei/octave-4.0.2/scripts/general/private/__splinen__.m:47
    
    return yi
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## Undocumented internal function.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __isequal__ (@var{nans_compare_equal}, @var{x1}, @var{x2}, @dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Return true if @var{x1}, @var{x2}, @dots{} are all equal and
## @var{nans_compare_equal} evaluates to false.
##
## If @var{nans_compare_equal} evaluates to true, then assume NaN == NaN.
    
    ## Modified by: William Poetra Yoga Hadisoeseno
    
    ## Algorithm:
##
## 1. Determine the class of x
## 2. If x and all other arguments have the same class, then check that the
##    number of dimensions and then the size of each dimension match.
##    If not all arguments share the same class, then verify that all of the
##    arguments belong to a comparable "numeric" class which includes
##    numeric, logical, and character arrays.  Check that number of dimensions
##    and size of each dimension match.
## 3. For each argument after x, compare it for equality with x:
##    a. struct     compare each member by name, not by order (recursive)
##    b. object     convert to struct, and then compare as stated above
##    c. cell       compare each member by order (recursive)
##    d. char       compare each member with strcmp
##    e  fcn_handle compare using overloade 'eq' operator
##    f. <other>    compare each nonzero member, and assume NaN == NaN
##                  if nans_compare_equal is nonzero.
    
    
@function
def __isequal__(nans_compare_equal=None,x=None,varargin=None,*args,**kwargs):
    varargin = __isequal__.varargin
    nargin = __isequal__.nargin

    l_v=nargin - 2
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:53
    
    ## All arguments must either be of the same class or they must be
  ## "numeric" values.
    t=(all(strcmp(class_(x),cellfun('class',varargin,'uniformoutput',false))) or ((isreal(x) or isnumeric(x)) and all(logical_or(cellfun('isreal',varargin),cellfun('isnumeric',varargin)))))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:59
    if (t):
        ## Test that everything has the same number of dimensions.
        t=all(builtin('ndims',x) == cellfun('ndims',varargin))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:67
    
    if (t):
        ## Test that everything is the same size since the dimensionality matches.
        nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:72
        k=1
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:73
        do
        t=all(builtin('size',x,k) == cellfun('size',varargin,k))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:75
        until(logical_not(t) or k == nd)
    
    ## From here on, compare objects as if they were structures.
    if (t and isobject(x)):
        ## Locally suppress class-to-struct warning.  We know what we are doing.
        warning('off','Octave:classdef-to-struct','local')
        x=builtin('struct',x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:83
        for i in arange(1,numel(varargin)).reshape(-1):
            varargin[i]=builtin('struct',varargin[i])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:85
    
    if (t):
        ## Check individual classes.
        if (isstruct(x)):
            ## Test the number of fields.
            fn_x=fieldnames(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:93
            l_fn_x=numfields(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:94
            fn_v=cellfun('fieldnames',varargin,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:95
            t=all(l_fn_x == cellfun('numel',fn_v))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:96
            idx=0
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:99
            s_fn_x=sort(fn_x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:100
            while (t and idx < l_v):

                idx
                t=all(strcmp(s_fn_x,sort(fn_v[idx])))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:104

            idx=0
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:107
            while (t and idx < l_fn_x):

                ## Test that all field values are equal.
                idx
                args=cell(1,2 + l_v)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:111
                args[1:2]=cellarray([nans_compare_equal,cellarray([getattr(x,(fn_x[idx]))])])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:112
                for argn in arange(1,l_v).reshape(-1):
                    args[argn + 2]=cellarray([getattr(varargin[argn],(fn_x[idx]))])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:114
                ## Minimize function calls by calling for all the arguments at once.
                t=__isequal__(args[:])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:117

        else:
            if (iscell(x)):
                ## Check that each element of a cell is equal.
                l_x=numel(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:122
                idx=0
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:123
                while (t and idx < l_x):

                    idx
                    args=cell(1,2 + l_v)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:126
                    args[1:2]=cellarray([nans_compare_equal,x[idx]])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:127
                    args[3:end()]=cat(cellindexmat(varargin,idx)[:])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:128
                    t=__isequal__(args[:])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:130

            else:
                if (ischar(x) and all(cellfun('isclass',varargin,'char'))):
                    ## Sizes are equal already, so we can just make everything into a
      ## row and test the rows.
                    n_x=numel(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:136
                    strings=cell(1,l_v)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:137
                    for i in arange(1,l_v).reshape(-1):
                        strings[i]=reshape(varargin[i],1,n_x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:139
                    t=all(strcmp(reshape(x,1,n_x),strings))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:141
                else:
                    if (isa(x,'function_handle')):
                        ## The == operator is overloaded for handles.
                        t=all(cellfun('eq',cellarray([x]),varargin))
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:145
                    else:
                        ## Check the numeric types.
                        f_x=find(x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:150
                        l_f_x=length(f_x)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:151
                        x=x[f_x]
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:152
                        for argn in arange(1,l_v).reshape(-1):
                            y=varargin[argn]
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:154
                            f_y=find(y)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:155
                            t=(l_f_x == length(f_y)) and all(f_x == f_y)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:157
                            if (logical_not(t)):
                                break
                            y=y[f_y]
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:162
                            m=(x == y)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:163
                            t=all(m)
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:164
                            if (logical_not(t) and nans_compare_equal):
                                t=isnan(x[logical_not(m)]) and isnan(y[logical_not(m)])
# /home/lei/octave-4.0.2/scripts/general/private/__isequal__.m:167
                            if (logical_not(t)):
                                break
    
    return t
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} shift (@var{x}, @var{b})
## @deftypefnx {Function File} {} shift (@var{x}, @var{b}, @var{dim})
## If @var{x} is a vector, perform a circular shift of length @var{b} of
## the elements of @var{x}.
##
## If @var{x} is a matrix, do the same for each column of @var{x}.
##
## If the optional @var{dim} argument is given, operate along this dimension.
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 14 September 1994
## Adapted-By: jwe
    
    
@function
def shift(x=None,b=None,dim=None,*args,**kwargs):
    varargin = shift.varargin
    nargin = shift.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    if (numel(x) < 1):
        error('shift: X must not be empty')
    else:
        if (logical_not((isscalar(b) and b == fix(b)))):
            error('shift: B must be an integer')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/shift.m:46
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/shift.m:47
    if (nargin == 3):
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('shift: DIM must be an integer and a valid dimension')
    else:
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/shift.m:None
    
    d=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/shift.m:59
    idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/shift.m:61
    if (b > 0):
        b=rem(b,d)
# /home/lei/octave-4.0.2/scripts/general/shift.m:63
        idx[dim]=cat(arange(d - b + 1,d),arange(1,d - b))
# /home/lei/octave-4.0.2/scripts/general/shift.m:64
    else:
        if (b < 0):
            b=rem(abs(b),d)
# /home/lei/octave-4.0.2/scripts/general/shift.m:66
            idx[dim]=cat(arange(b + 1,d),arange(1,b))
# /home/lei/octave-4.0.2/scripts/general/shift.m:67
    
    y=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/shift.m:70
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{b} =} saveobj (@var{a})
## Method of a class to manipulate an object prior to saving it to a file.
##
## The function @code{saveobj} is called when the object @var{a} is saved
## using the @code{save} function.  An example of the use of @code{saveobj}
## might be to remove fields of the object that don't make sense to be saved
## or it might be used to ensure that certain fields of the object are
## initialized before the object is saved.  For example:
##
## @example
## @group
## function b = saveobj (a)
##   b = a;
##   if (isempty (b.field))
##      b.field = initfield (b);
##   endif
## endfunction
## @end group
## @end example
##
## @seealso{loadobj, class}
## @end deftypefn
    
    
@function
def saveobj(a=None,*args,**kwargs):
    varargin = saveobj.varargin
    nargin = saveobj.nargin

    error('saveobj: not defined for class "%s"',class_(a))
    return b
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2004-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} bitcmp (@var{A}, @var{k})
## Return the @var{k}-bit complement of integers in @var{A}.
##
## If @var{k} is omitted @code{k = log2 (bitmax) + 1} is assumed.
##
## @example
## @group
## bitcmp (7,4)
##   @result{} 8
## dec2bin (11)
##   @result{} 1011
## dec2bin (bitcmp (11, 6))
##   @result{} 110100
## @end group
## @end example
##
## @seealso{bitand, bitor, bitxor, bitset, bitget, bitcmp, bitshift, bitmax}
## @end deftypefn
    
    ## Liberally based on the version by Kai Habel from octave-forge
    
    
@function
def bitcmp(A=None,k=None,*args,**kwargs):
    varargin = bitcmp.varargin
    nargin = bitcmp.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 2 and (logical_not(isscalar(k)) or (floor(k) != k))):
        error('bitcmp: K must be a scalar integer')
    
    if (isa(A,'double')):
        bmax=copy(bitmax)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:52
        amax=ceil(log2(bmax))
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:53
    else:
        if (isa(A,'single')):
            bmax=bitmax('single')
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:55
            amax=ceil(log2(bmax))
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:56
        else:
            if (isinteger(A)):
                amax=dot(sizeof(ones(1,class_(A))),8)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:58
                bmax=bitpack(true(amax,1),class_(A))
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:59
            else:
                error('bitcmp: invalid class %s',class_(A))
    
    if (nargin == 1 or k == amax):
        C=bitxor(A,bmax)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:65
    else:
        m=double(k)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:67
        if (any(m < 1) or any(m > amax)):
            error('bitcmp: K must be in the range [1,%d]',amax)
        mask=bitshift(bmax,k - amax)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:71
        C=bitxor(bitand(A,mask),mask)
# /home/lei/octave-4.0.2/scripts/general/bitcmp.m:72
    
    return C
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Do not forget signed integers
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rotdim (@var{x})
## @deftypefnx {Function File} {} rotdim (@var{x}, @var{n})
## @deftypefnx {Function File} {} rotdim (@var{x}, @var{n}, @var{plane})
## Return a copy of @var{x} with the elements rotated counterclockwise in
## 90-degree increments.
##
## The second argument @var{n} is optional, and specifies how many 90-degree
## rotations are to be applied (the default value is 1).  Negative values of
## @var{n} rotate the matrix in a clockwise direction.
##
## The third argument is also optional and defines the plane of the rotation.
## If present, @var{plane} is a two element vector containing two different
## valid dimensions of the matrix.  When @var{plane} is not given the first two
## non-singleton dimensions are used.
##
## For example,
##
## @example
## @group
## rotdim ([1, 2; 3, 4], -1, [1, 2])
##      @result{}  3  1
##          4  2
## @end group
## @end example
##
## @noindent
## rotates the given matrix clockwise by 90 degrees.  The following are all
## equivalent statements:
##
## @example
## @group
## rotdim ([1, 2; 3, 4], -1, [1, 2])
## rotdim ([1, 2; 3, 4], 3, [1, 2])
## rotdim ([1, 2; 3, 4], 7, [1, 2])
## @end group
## @end example
## @seealso{rot90, fliplr, flipud, flip}
## @end deftypefn
    
    
@function
def rotdim(x=None,n=None,plane=None,*args,**kwargs):
    varargin = rotdim.varargin
    nargin = rotdim.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (nargin > 1 and logical_not(isempty(n))):
        if (logical_not(isscalar(n)) or logical_not(isreal(n)) or fix(n) != n):
            error('rotdim: N must be a scalar integer')
    else:
        n=1
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:70
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:73
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:74
    if (nargin < 3):
        if (nd > 2):
            ## Find the first two non-singleton dimension.
            plane=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:78
            dim=0
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:79
            while (dim < nd):

                dim=dim + 1
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:81
                if (sz[dim] != 1):
                    plane=matlabarray(cat(plane,dim))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:83
                    if (length(plane) == 2):
                        break

            if (length(plane) < 1):
                plane=matlabarray(cat(1,2))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:90
            else:
                if (length(plane) < 2):
                    plane=matlabarray(cat(1,plane))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:92
        else:
            plane=matlabarray(cat(1,2))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:95
    else:
        if (logical_not((isvector(plane) and length(plane) == 2 and all(plane == fix(plane)) and all(plane > 0) and all(plane < (nd + 1)) and plane[1] != plane[2]))):
            error('rotdim: PLANE must be a 2 element integer vector defining a valid PLANE')
    
    n=rem(n,4)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:105
    if (n < 0):
        n=n + 4
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:107
    
    if (n == 0):
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:110
    else:
        if (n == 2):
            y=flip(flip(x,plane[1]),plane[2])
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:112
        else:
            if (n == 1 or n == 3):
                perm=arange(1,nd)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:114
                perm[plane[1]]=plane[2]
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:115
                perm[plane[2]]=plane[1]
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:116
                y=permute(x,perm)
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:117
                if (n == 1):
                    y=flip(y,min(plane))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:119
                else:
                    y=flip(y,max(plane))
# /home/lei/octave-4.0.2/scripts/general/rotdim.m:121
            else:
                error('rotdim: internal error!')
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## FIXME: We need tests for multidimensional arrays
##        and different values of PLANE.
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} celldisp (@var{c})
## @deftypefnx {Function File} {} celldisp (@var{c}, @var{name})
## Recursively display the contents of a cell array.
##
## By default the values are displayed with the name of the variable @var{c}.
## However, this name can be replaced with the variable @var{name}.  For
## example:
##
## @example
## @group
## c = @{1, 2, @{31, 32@}@};
## celldisp (c, "b")
##    @result{}
##       b@{1@} =
##        1
##       b@{2@} =
##        2
##       b@{3@}@{1@} =
##        31
##       b@{3@}@{2@} =
##        32
## @end group
## @end example
##
## @seealso{disp}
## @end deftypefn
    
    ## This is ugly, but seems to be what matlab does..
    
    
@function
def celldisp(c=None,name=None,*args,**kwargs):
    varargin = celldisp.varargin
    nargin = celldisp.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(iscell(c))):
        error('celldisp: C must be a cell array')
    
    if (nargin == 1):
        name=inputname(1)
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:60
    
    for i in arange(1,numel(c)).reshape(-1):
        if (iscell(c[i])):
            celldisp(c[i],sprintf('%s{%s}',name,indices(size(c),i)))
        else:
            disp(sprintf('%s{%s} = \n',name,indices(size(c),i)))
            disp(c[i])
            disp('')
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def indices(dv=None,i=None,*args,**kwargs):
    varargin = indices.varargin
    nargin = indices.nargin

    if (sum(dv != 1) > 1):
        c=cell(size(dv))
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:76
        c[:]=ind2sub(dv,i)
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:77
        s=sprintf('%i,',c[:])
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:78
        s[end()]=[]
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:79
    else:
        s=sprintf('%i',i)
# /home/lei/octave-4.0.2/scripts/general/celldisp.m:81
    
    return s
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2010-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} randi (@var{imax})
## @deftypefnx {Function File} {} randi (@var{imax}, @var{n})
## @deftypefnx {Function File} {} randi (@var{imax}, @var{m}, @var{n}, @dots{})
## @deftypefnx {Function File} {} randi ([@var{imin} @var{imax}], @dots{})
## @deftypefnx {Function File} {} randi (@dots{}, "@var{class}")
## Return random integers in the range 1:@var{imax}.
##
## Additional arguments determine the shape of the return matrix.  When no
## arguments are specified a single random integer is returned.  If one
## argument @var{n} is specified then a square matrix @w{(@var{n} x @var{n})}
## is returned.  Two or more arguments will return a multi-dimensional matrix
## @w{(@var{m} x @var{n} x @dots{})}.
##
## The integer range may optionally be described by a two element matrix with a
## lower and upper bound in which case the returned integers will be on the
## interval @w{[@var{imin}, @var{imax}]}.
##
## The optional argument @var{class} will return a matrix of the requested
## type.  The default is @qcode{"double"}.
##
## The following example returns 150 integers in the range 1--10.
##
## @example
## ri = randi (10, 150, 1)
## @end example
##
## Implementation Note: @code{randi} relies internally on @code{rand} which
## uses class @qcode{"double"} to represent numbers.  This limits the maximum
## integer (@var{imax}) and range (@var{imax} - @var{imin}) to the value
## returned by the @code{flintmax} function.  For IEEE floating point numbers
## this value is @w{@math{2^{53} - 1}}.
##
## @seealso{rand}
## @end deftypefn
    
    ## Author: Rik Wehbring
    
    
@function
def randi(bounds=None,varargin=None,*args,**kwargs):
    varargin = randi.varargin
    nargin = randi.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not((isnumeric(bounds) and all(bounds == fix(bounds))))):
        error('randi: IMIN and IMAX must be integer bounds')
    
    bounds=real(double(bounds))
# /home/lei/octave-4.0.2/scripts/general/randi.m:67
    if (isscalar(bounds)):
        imin=1
# /home/lei/octave-4.0.2/scripts/general/randi.m:69
        imax=copy(bounds)
# /home/lei/octave-4.0.2/scripts/general/randi.m:70
        if (imax < 1):
            error('randi: require IMAX >= 1')
    else:
        imin=bounds[1]
# /home/lei/octave-4.0.2/scripts/general/randi.m:75
        imax=bounds[2]
# /home/lei/octave-4.0.2/scripts/general/randi.m:76
        if (imax < imin):
            error('randi: require IMIN <= IMAX')
    
    if (nargin > 1 and ischar(varargin[end()])):
        rclass=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/randi.m:83
        varargin[end()]=[]
# /home/lei/octave-4.0.2/scripts/general/randi.m:84
    else:
        rclass='double'
# /home/lei/octave-4.0.2/scripts/general/randi.m:86
    
    ## Limit set by use of class double in rand(): Any consecutive integer in the
  ## range [-flintmax(), flintmax()] can be represented by a double.
    if ((abs(imax) >= flintmax()) or (abs(imin) >= flintmax())):
        error('randi: IMIN and IMAX must be smaller than flintmax()')
    
    if ((imax - imin) >= (flintmax() - 1)):
        error('randi: integer range must be smaller than flintmax()-1')
    
    ri=imin + floor(dot((imax - imin + 1),rand(varargin[:])))
# /home/lei/octave-4.0.2/scripts/general/randi.m:98
    if (logical_not(strcmp(rclass,'double'))):
        if (strfind(rclass,'int')):
            maxval=double(intmax(rclass))
# /home/lei/octave-4.0.2/scripts/general/randi.m:102
            minval=double(intmin(rclass))
# /home/lei/octave-4.0.2/scripts/general/randi.m:103
        else:
            if (strcmp(rclass,'single')):
                maxval=double(flintmax(rclass))
# /home/lei/octave-4.0.2/scripts/general/randi.m:105
                minval=- maxval
# /home/lei/octave-4.0.2/scripts/general/randi.m:106
            else:
                error('randi: unknown requested output class \'%s\'',rclass)
        if (imax > maxval):
            warning(cat('randi: integer IMAX exceeds requested type.  ','Values might be truncated to requested type.'))
        else:
            if (imin < minval):
                warning(cat('randi: integer IMIN exceeds requested type.  ',' Values might be truncated to requested type.'))
        ri=cast(ri,rclass)
# /home/lei/octave-4.0.2/scripts/general/randi.m:118
    
    return ri
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## FIXME: Does Octave guarantee support for int64 even when underlying hardware
##        is 32-bit?
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test that no warning thrown if IMAX is exactly on the limits of the range
    
    
    
    
    
    
    
    
    
    
    ## Test exceeding range
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{y} =} circshift (@var{x}, @var{n})
## Circularly shift the values of the array @var{x}.
##
## @var{n} must be a vector of integers no longer than the number of
## dimensions in @var{x}.  The values of @var{n} can be either positive or
## negative, which determines the direction in which the values or @var{x}
## are shifted.  If an element of @var{n} is zero, then the corresponding
## dimension of @var{x} will not be shifted.  For example:
##
## @example
## @group
## x = [1, 2, 3; 4, 5, 6; 7, 8, 9];
## circshift (x, 1)
## @result{}  7, 8, 9
##     1, 2, 3
##     4, 5, 6
## circshift (x, -2)
## @result{}  7, 8, 9
##     1, 2, 3
##     4, 5, 6
## circshift (x, [0,1])
## @result{}  3, 1, 2
##     6, 4, 5
##     9, 7, 8
## @end group
## @end example
## @seealso{permute, ipermute, shiftdim}
## @end deftypefn
    
    
@function
def circshift(x=None,n=None,*args,**kwargs):
    varargin = circshift.varargin
    nargin = circshift.nargin

    if (nargin != 2):
        print_usage()
    
    if (isempty(x)):
        y=copy(x)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:56
        return y
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:60
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:61
    if (logical_not(isvector(n)) or length(n) > nd):
        error('circshift: N must be a vector, no longer than the number of dimension in X')
    else:
        if (any(n != fix(n))):
            error('circshift: all values of N must be integers')
    
    idx=repmat(cellarray([':']),1,nd)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:69
    for i in arange(1,length(n)).reshape(-1):
        b=n[i]
# /home/lei/octave-4.0.2/scripts/general/circshift.m:71
        d=sz[i]
# /home/lei/octave-4.0.2/scripts/general/circshift.m:72
        if (b > 0):
            b=rem(b,d)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:74
            idx[i]=cat(arange(d - b + 1,d),arange(1,d - b))
# /home/lei/octave-4.0.2/scripts/general/circshift.m:75
        else:
            if (b < 0):
                b=rem(abs(b),d)
# /home/lei/octave-4.0.2/scripts/general/circshift.m:77
                idx[i]=cat(arange(b + 1,d),arange(1,b))
# /home/lei/octave-4.0.2/scripts/general/circshift.m:78
    
    y=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/circshift.m:82
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2016 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{y}, @var{z}] =} sph2cart (@var{theta}, @var{phi}, @var{r})
## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} sph2cart (@var{S})
## @deftypefnx {Function File} {@var{C} =} sph2cart (@dots{})
## Transform spherical coordinates to Cartesian coordinates.
##
## The inputs @var{theta}, @var{phi}, and @var{r} must be the same shape, or
## scalar.  If called with a single matrix argument then each row of @var{S}
## represents the spherical coordinate (@var{theta}, @var{phi}, @var{r}).
##
## @var{theta} describes the angle relative to the positive x-axis.
##
## @var{phi} is the angle relative to the xy-plane.
##
## @var{r} is the distance to the origin @w{(0, 0, 0)}.
##
## If only a single return argument is requested then return a matrix @var{C}
## where each row represents one Cartesian coordinate
## (@var{x}, @var{y}, @var{z}).
## @seealso{cart2sph, pol2cart, cart2pol}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
## Adapted-by: jwe
    
    
@function
def sph2cart(theta=None,phi=None,r=None,*args,**kwargs):
    varargin = sph2cart.varargin
    nargin = sph2cart.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (nargin == 1):
        if (logical_not((isnumeric(theta) and ismatrix(theta) and columns(theta) == 3))):
            error('sph2cart: matrix input must have 3 columns [THETA, PHI, R]')
        r=theta[:,3]
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:54
        phi=theta[:,2]
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:55
        theta=theta[:,1]
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:56
    else:
        if (logical_not(((isnumeric(theta) and isnumeric(phi) and isnumeric(r)) and (size_equal(theta,phi) or isscalar(theta) or isscalar(phi)) and (size_equal(theta,r) or isscalar(theta) or isscalar(r)) and (size_equal(phi,r) or isscalar(phi) or isscalar(r))))):
            error('sph2cart: THETA, PHI, R must be numeric arrays of the same size, or scalar')
    
    x=multiply(multiply(r,cos(phi)),cos(theta))
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:66
    y=multiply(multiply(r,cos(phi)),sin(theta))
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:67
    z=multiply(r,sin(phi))
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:68
    if (nargout <= 1):
        x=matlabarray(cat(ravel(x),ravel(y),ravel(z)))
# /home/lei/octave-4.0.2/scripts/general/sph2cart.m:71
    
    return x,y,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 William Poetra Yoga Hadisoeseno
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isequaln (@var{x1}, @var{x2}, @dots{})
## Return true if all of @var{x1}, @var{x2}, @dots{} are equal under the
## additional assumption that NaN == NaN (no comparison of NaN placeholders
## in dataset).
## @seealso{isequal}
## @end deftypefn
    
    
@function
def isequaln(x1=None,varargin=None,*args,**kwargs):
    varargin = isequaln.varargin
    nargin = isequaln.nargin

    if (nargin < 2):
        print_usage()
    
    retval=__isequal__(true,x1,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/isequaln.m:33
    return retval
    
if __name__ == '__main__':
    pass
    
    ## test for equality
    
    
    ## test for inequality
    
    
    ## test for equality (struct)
    
    
    
    ## Input validation
    
    ## Copyright (C) 2012-2015 Daniel Kraft
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} profexplore ()
## @deftypefnx {Function File} {} profexplore (@var{data})
## Interactively explore hierarchical profiler output.
##
## Assuming @var{data} is the structure with profile data returned by
## @code{profile (@qcode{"info"})}, this command opens an interactive prompt
## that can be used to explore the call-tree.  Type @kbd{help} to get a list
## of possible commands.  If @var{data} is omitted, @code{profile ("info")}
## is called and used in its place.
## @seealso{profile, profshow}
## @end deftypefn
    
    ## Built-in profiler.
## Author: Daniel Kraft <d@domob.eu>
    
    
@function
def profexplore(data=None,*args,**kwargs):
    varargin = profexplore.varargin
    nargin = profexplore.nargin

    if (nargin == 0):
        data=profile('info')
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:38
    else:
        if (nargin != 1):
            print_usage()
    
    ## The actual work is done by a recursive worker function, since that
  ## is an easy way to traverse the tree datastructure.  Here, we just check
  ## the arguments (already done) and give over to it.
    
    __profexplore_worker(data.FunctionTable,data.Hierarchical,'Top\n','  ')
    return
    
if __name__ == '__main__':
    pass
    
    ## This is the worker function.  tree is the current subtree we want to
## display / explore.  parents is a string containing the already "rendered"
## data for the parents which is displayed on top of the list of current
## children.  prefix is the prefix to add to each line rendered; this
## is just a string of spaces to get indentation right.
##
## Returning 0 indicates that the user requested to totally exit the
## explorer, thus also all higher levels should exit immediately.  An integer
## greater zero indicates to exit that many levels since the user wants to go
## up (but not necessarily quit).
    
    
@function
def __profexplore_worker(fcn_table=None,tree=None,parents=None,prefix=None,*args,**kwargs):
    varargin = __profexplore_worker.varargin
    nargin = __profexplore_worker.nargin

    ## Sort children by total time.
    times=- cat(tree.TotalTime)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:65
    __,p=sort(times,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:66
    tree=tree[p]
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:67
    while (true):

        printf('\n%s',parents)
        strings=cell(length(tree),1)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:72
        for i in arange(1,length(tree)).reshape(-1):
            strings[i]=sprintf('%s: %d calls, %.3f total, %.3f self',fcn_table[tree[i].Index].FunctionName,tree[i].NumCalls,tree[i].TotalTime,tree[i].SelfTime)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:74
            printf('%s%d) %s\n',prefix,i,strings[i])
        printf('\n')
        cmd=input_('profexplore> ','s')
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:82
        option=fix(str2double(cmd))
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:83
        if (strcmp(cmd,'exit') or strcmp(cmd,'quit')):
            rv=0
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:86
            return rv
        else:
            if (strcmp(cmd,'help')):
                printf('\nCommands for profile explorer:\n\n')
                printf('exit   Return to Octave prompt.\n')
                printf('quit   Return to Octave prompt.\n')
                printf('help   Display this help message.\n')
                printf('up [N] Go up N levels, where N is an integer.  Default is 1.\n')
                printf('N      Go down a level into option N.\n')
            else:
                if (logical_not(isnan(option))):
                    if (option < 1 or option > length(tree)):
                        printf('The chosen option is out of range!\n')
                    else:
                        newParents=sprintf('%s%s%s\n',parents,prefix,strings[option])
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:99
                        newPrefix=sprintf('%s  ',prefix)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:100
                        rv=__profexplore_worker(fcn_table,tree[option].Children,newParents,newPrefix)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:102
                        if (rv == 0):
                            return rv
                        else:
                            if (rv > 1):
                                rv=rv - 1
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:108
                                return rv
                            else:
                                assert_(rv == 1)
                else:
                    if (length(cmd) >= 2 and strcmp(substr(cmd,1,2),'up')):
                        if (length(cmd) == 2):
                            rv=1
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:117
                            return rv
                        if (length(cmd) > 3 and cmd[3] == ' '):
                            opt=fix(str2double(substr(cmd,3)))
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:122
                            if (logical_not(isnan(opt)) and opt > 0):
                                rv=copy(opt)
# /home/lei/octave-4.0.2/scripts/general/profexplore.m:124
                                return rv
                        printf('Invalid \'up\' command.  Type \'help\' for further')
                        printf(' information.\n')
                    else:
                        printf('Unrecognized input.  Type \'help\' to get a list of possible')
                        printf(' commands.\n')

    
    return rv
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} flipud (@var{x})
## Flip array upside down.
##
## Return a copy of @var{x} with the order of the rows reversed.  In other
## words, @var{x} is flipped upside-down about a horizontal axis.  For example:
##
## @example
## @group
## flipud ([1, 2; 3, 4])
##      @result{}  3  4
##          1  2
## @end group
## @end example
##
## @seealso{fliplr, flip, rot90, rotdim}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def flipud(x=None,*args,**kwargs):
    varargin = flipud.varargin
    nargin = flipud.nargin

    if (nargin != 1):
        print_usage()
    
    y=flip(x,1)
# /home/lei/octave-4.0.2/scripts/general/flipud.m:44
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test NDArrays
    
    
    
    
    
    ## Test NDArray with singleton dimensions
    
    
    
    
    
    ## Test for 1 row, i.e., returns the same
    
    
    
    
    ## Copyright (C) 1993-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} rot90 (@var{A})
## @deftypefnx {Function File} {} rot90 (@var{A}, @var{k})
## Rotate array by 90 degree increments.
##
## Return a copy of @var{A} with the elements rotated counterclockwise in
## 90-degree increments.
##
## The second argument is optional, and specifies how many 90-degree rotations
## are to be applied (the default value is 1).  Negative values of @var{k}
## rotate the matrix in a clockwise direction.
## For example,
##
## @example
## @group
## rot90 ([1, 2; 3, 4], -1)
##     @result{}  3  1
##         4  2
## @end group
## @end example
##
## @noindent
## rotates the given matrix clockwise by 90 degrees.  The following are all
## equivalent statements:
##
## @example
## @group
## rot90 ([1, 2; 3, 4], -1)
## rot90 ([1, 2; 3, 4], 3)
## rot90 ([1, 2; 3, 4], 7)
## @end group
## @end example
##
## The rotation is always performed on the plane of the first two dimensions,
## i.e., rows and columns.  To perform a rotation on any other plane, use
## @code{rotdim}.
##
## @seealso{rotdim, fliplr, flipud, flip}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def rot90(A=None,k=1,*args,**kwargs):
    varargin = rot90.varargin
    nargin = rot90.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isscalar(k) and isreal(k) and k == fix(k)))):
        error('rot90: K must be a single real integer')
    
    k=mod(k,4)
# /home/lei/octave-4.0.2/scripts/general/rot90.m:71
    nd=ndims(A)
# /home/lei/octave-4.0.2/scripts/general/rot90.m:72
    if (k == 0):
        B=copy(A)
# /home/lei/octave-4.0.2/scripts/general/rot90.m:75
    else:
        if (k == 1):
            B=flipud(permute(A,cat(2,1,arange(3,nd,1))))
# /home/lei/octave-4.0.2/scripts/general/rot90.m:77
        else:
            if (k == 2):
                idx[1:nd]=cellarray([':'])
# /home/lei/octave-4.0.2/scripts/general/rot90.m:79
                idx[1]=arange(rows(A),1,- 1)
# /home/lei/octave-4.0.2/scripts/general/rot90.m:80
                idx[2]=arange(columns(A),1,- 1)
# /home/lei/octave-4.0.2/scripts/general/rot90.m:81
                B=A[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/rot90.m:82
            else:
                if (k == 3):
                    B=permute(flipud(A),cat(2,1,arange(3,nd,1)))
# /home/lei/octave-4.0.2/scripts/general/rot90.m:84
                else:
                    error('rot90: internal error!')
    
    return B
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test NDArrays
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## With non-square matrices
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{msgstr} =} nargchk (@var{minargs}, @var{maxargs}, @var{nargs})
## @deftypefnx {Function File} {@var{msgstr} =} nargchk (@var{minargs}, @var{maxargs}, @var{nargs}, "string")
## @deftypefnx {Function File} {@var{msgstruct} =} nargchk (@var{minargs}, @var{maxargs}, @var{nargs}, "struct")
## Return an appropriate error message string (or structure) if the number of
## inputs requested is invalid.
##
## This is useful for checking to see that the number of input arguments
## supplied to a function is within an acceptable range.
##
## @strong{Caution}: @code{nargchk} is scheduled for deprecation.  Use
## @code{narginchk} in all new code.
## @seealso{narginchk, nargoutchk, error, nargin, nargout}
## @end deftypefn
    
    ## Author: Bill Denney <bill@denney.ws>
    
    
@function
def nargchk(minargs=None,maxargs=None,nargs=None,outtype='string',*args,**kwargs):
    varargin = nargchk.varargin
    nargin = nargchk.nargin

    if (nargin < 3 or nargin > 4):
        print_usage()
    else:
        if (minargs > maxargs):
            error('nargchk: MINARGS must be <= MAXARGS')
        else:
            if (logical_not(any(strcmpi(outtype,cellarray(['string','struct']))))):
                error('nargchk: output type must be either "string" or "struct"')
            else:
                if (logical_not((isscalar(minargs) and isscalar(maxargs) and isscalar(nargs)))):
                    error('nargchk: MINARGS, MAXARGS, and NARGS must be scalars')
    
    msg=struct('message','','identifier','')
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:48
    if (nargs < minargs):
        msg.message = copy('not enough input arguments')
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:50
        msg.identifier = copy('Octave:nargchk:not-enough-inputs')
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:51
    else:
        if (nargs > maxargs):
            msg.message = copy('too many input arguments')
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:53
            msg.identifier = copy('Octave:nargchk:too-many-inputs')
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:54
    
    if (strcmpi(outtype,'string')):
        msg=msg.message
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:58
    else:
        if (isempty(msg.message)):
            ## Compatability: Matlab returns a 0x1 empty struct when nargchk passes
            msg=resize(msg,0,1)
# /home/lei/octave-4.0.2/scripts/general/nargchk.m:61
    
    return msg
    
if __name__ == '__main__':
    pass
    
    ## Tests
    
    
    
    
    
    
    
    
    
    
    
    ## Struct outputs
    
    
    
    
    ## Copyright (C) 2009-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{div} =} divergence (@var{x}, @var{y}, @var{z}, @var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {@var{div} =} divergence (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {@var{div} =} divergence (@var{x}, @var{y}, @var{fx}, @var{fy})
## @deftypefnx {Function File} {@var{div} =} divergence (@var{fx}, @var{fy})
## Calculate divergence of a vector field given by the arrays @var{fx},
## @var{fy}, and @var{fz} or @var{fx}, @var{fy} respectively.
##
## @tex
## $$
## div F(x,y,z) = \partial_x{F} + \partial_y{F} + \partial_z{F}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##                   d               d               d
## div F(x,y,z)  =   -- F(x,y,z)  +  -- F(x,y,z)  +  -- F(x,y,z)
##                   dx              dy              dz
## @end group
## @end example
##
## @end ifnottex
## The coordinates of the vector field can be given by the arguments @var{x},
## @var{y}, @var{z} or @var{x}, @var{y} respectively.
##
## @seealso{curl, gradient, del2, dot}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def divergence(varargin=None,*args,**kwargs):
    varargin = divergence.varargin
    nargin = divergence.nargin

    fidx=1
# /home/lei/octave-4.0.2/scripts/general/divergence.m:53
    if (nargin == 2):
        sz=size(varargin[fidx])
# /home/lei/octave-4.0.2/scripts/general/divergence.m:55
        dx=ravel((arange(1,sz[2])))
# /home/lei/octave-4.0.2/scripts/general/divergence.m:56
        dy=ravel((arange(1,sz[1])))
# /home/lei/octave-4.0.2/scripts/general/divergence.m:57
    else:
        if (nargin == 3):
            sz=size(varargin[fidx])
# /home/lei/octave-4.0.2/scripts/general/divergence.m:59
            dx=arange(1,sz[2])
# /home/lei/octave-4.0.2/scripts/general/divergence.m:60
            dy=arange(1,sz[1])
# /home/lei/octave-4.0.2/scripts/general/divergence.m:61
            dz=arange(1,sz[3])
# /home/lei/octave-4.0.2/scripts/general/divergence.m:62
        else:
            if (nargin == 4):
                fidx=3
# /home/lei/octave-4.0.2/scripts/general/divergence.m:64
                dx=varargin[1](1,arange())
# /home/lei/octave-4.0.2/scripts/general/divergence.m:65
                dy=varargin[2](arange(),1)
# /home/lei/octave-4.0.2/scripts/general/divergence.m:66
            else:
                if (nargin == 6):
                    fidx=4
# /home/lei/octave-4.0.2/scripts/general/divergence.m:68
                    dx=ravel(varargin[1](1,arange(),1))
# /home/lei/octave-4.0.2/scripts/general/divergence.m:69
                    dy=ravel(varargin[2](arange(),1,1))
# /home/lei/octave-4.0.2/scripts/general/divergence.m:70
                    dz=ravel(varargin[3](1,1,arange()))
# /home/lei/octave-4.0.2/scripts/general/divergence.m:71
                else:
                    print_usage()
    
    if (nargin == 4 or nargin == 2):
        if (logical_not(size_equal(varargin[fidx],varargin[fidx + 1]))):
            error('divergence: size of X and Y must match')
        else:
            if (ndims(varargin[fidx]) != 2):
                error('divergence: expected two-dimensional matrices X and Y')
            else:
                if (length(dx) != columns(varargin[fidx]) or length(dy) != rows(varargin[fidx])):
                    error('divergence: size of dx and dy must match the respective dimension of X and Y')
        retval=gradient(varargin[fidx],dx,dy)
# /home/lei/octave-4.0.2/scripts/general/divergence.m:86
        retval += gradient(varargin[fidx + 1].T,dy,dx).T
    else:
        if (nargin == 6 or nargin == 3):
            if (logical_not(size_equal(varargin[fidx],varargin[fidx + 1],varargin[fidx + 2]))):
                error('divergence: size of X, Y, and Z must match')
            else:
                if (ndims(varargin[fidx]) != 3):
                    error('divergence: expected two-dimensional matrices X, Y, and Z')
                else:
                    if ((length(dx) != size(varargin[fidx],2)) or (length(dy) != size(varargin[fidx],1)) or (length(dz) != size(varargin[fidx],3))):
                        error('divergence: size of dx, dy, and dz must match the respective dimesion of X, Y, and Z')
            ## x-direction
            retval=gradient(varargin[fidx],dx,dy,dz)
# /home/lei/octave-4.0.2/scripts/general/divergence.m:101
            retval += shiftdim(gradient(shiftdim(varargin[fidx + 1],2),dy),1)
            retval += shiftdim(gradient(shiftdim(varargin[fidx + 2],1),dz),2)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{vi} =} interpn (@var{x1}, @var{x2}, @dots{}, @var{v}, @var{y1}, @var{y2}, @dots{})
## @deftypefnx {Function File} {@var{vi} =} interpn (@var{v}, @var{y1}, @var{y2}, @dots{})
## @deftypefnx {Function File} {@var{vi} =} interpn (@var{v}, @var{m})
## @deftypefnx {Function File} {@var{vi} =} interpn (@var{v})
## @deftypefnx {Function File} {@var{vi} =} interpn (@dots{}, @var{method})
## @deftypefnx {Function File} {@var{vi} =} interpn (@dots{}, @var{method}, @var{extrapval})
##
## Perform @var{n}-dimensional interpolation, where @var{n} is at least two.
##
## Each element of the @var{n}-dimensional array @var{v} represents a value
## at a location given by the parameters @var{x1}, @var{x2}, @dots{}, @var{xn}.
## The parameters @var{x1}, @var{x2}, @dots{}, @var{xn} are either
## @var{n}-dimensional arrays of the same size as the array @var{v} in
## the @qcode{"ndgrid"} format or vectors.  The parameters @var{y1}, etc.
## respect a similar format to @var{x1}, etc., and they represent the points
## at which the array @var{vi} is interpolated.
##
## If @var{x1}, @dots{}, @var{xn} are omitted, they are assumed to be
## @code{x1 = 1 : size (@var{v}, 1)}, etc.  If @var{m} is specified, then
## the interpolation adds a point half way between each of the interpolation
## points.  This process is performed @var{m} times.  If only @var{v} is
## specified, then @var{m} is assumed to be @code{1}.
##
## The interpolation @var{method} is one of:
##
## @table @asis
## @item @qcode{"nearest"}
## Return the nearest neighbor.
##
## @item @qcode{"linear"} (default)
## Linear interpolation from nearest neighbors.
##
## @item @qcode{"pchip"}
## Piecewise cubic Hermite interpolating polynomial---shape-preserving
## interpolation with smooth first derivative (not implemented yet).
##
## @item @qcode{"cubic"}
## Cubic interpolation (same as @qcode{"pchip"} [not implemented yet]).
##
## @item @qcode{"spline"}
## Cubic spline interpolation---smooth first and second derivatives
## throughout the curve.
## @end table
##
## The default method is @qcode{"linear"}.
##
## @var{extrapval} is a scalar number.  It replaces values beyond the endpoints
## with @var{extrapval}.  Note that if @var{extrapval} is used, @var{method}
## must be specified as well.  If @var{extrapval} is omitted and the
## @var{method} is @qcode{"spline"}, then the extrapolated values of the
## @qcode{"spline"} are used.  Otherwise the default @var{extrapval} value for
## any other @var{method} is @qcode{"NA"}.
## @seealso{interp1, interp2, interp3, spline, ndgrid}
## @end deftypefn
    
    
@function
def interpn(varargin=None,*args,**kwargs):
    varargin = interpn.varargin
    nargin = interpn.nargin

    method='linear'
# /home/lei/octave-4.0.2/scripts/general/interpn.m:77
    extrapval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:78
    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:79
    if (nargin < 1 or logical_not(isnumeric(varargin[1]))):
        print_usage()
    
    if (nargs > 1 and ischar(varargin[end() - 1])):
        if (logical_not(isnumeric(varargin[end()])) or logical_not(isscalar(varargin[end()]))):
            error('interpn: EXTRAPVAL must be a numeric scalar')
        extrapval=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:89
        method=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:90
        nargs -= 2
    else:
        if (ischar(varargin[end()])):
            method=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:93
            nargs
    
    if (method[1] == '*'):
        warning('interpn: ignoring unsupported \'*\' flag to METHOD')
        method[1]=[]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:99
    
    method=validatestring(method,cellarray(['nearest','linear','pchip','cubic','spline']))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:101
    if (nargs < 3):
        v=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:105
        m=1
# /home/lei/octave-4.0.2/scripts/general/interpn.m:106
        if (nargs == 2):
            if (ischar(varargin[2])):
                method=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:109
            else:
                if (isnumeric(m) and isscalar(m) and fix(m) == m):
                    m=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:111
                else:
                    print_usage()
        sz=size(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:116
        nd=ndims(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:117
        x=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:118
        y=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:119
        for i in arange(1,nd).reshape(-1):
            x[i]=arange(1,sz[i])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:121
            y[i]=arange(1,sz[i],(1 / (2 ** m)))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:122
        y[1]=y[1].T
# /home/lei/octave-4.0.2/scripts/general/interpn.m:124
        y[:]=ndgrid(y[:])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:125
    else:
        if (logical_not(isvector(varargin[1])) and nargs == (ndims(varargin[1]) + 1)):
            v=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:127
            sz=size(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:128
            nd=ndims(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:129
            x=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:130
            y=varargin[2:nargs]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:131
            for i in arange(1,nd).reshape(-1):
                x[i]=arange(1,sz[i])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:133
        else:
            if (rem(nargs,2) == 1 and nargs == (dot(2,ndims(varargin[ceil(nargs / 2)]))) + 1):
                nv=ceil(nargs / 2)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:137
                v=varargin[nv]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:138
                sz=size(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:139
                nd=ndims(v)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:140
                x=varargin[1:(nv - 1)]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:141
                y=varargin[(nv + 1):nargs]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:142
            else:
                error('interpn: wrong number or incorrectly formatted input arguments')
    
    if (any(logical_not(cellfun('isvector',x)))):
        for i in arange(2,nd).reshape(-1):
            if (logical_not(size_equal(x[1],x[i])) or logical_not(size_equal(x[i],v))):
                error('interpn: dimensional mismatch')
            idx[1:nd]=cellarray([1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:152
            idx[i]=':'
# /home/lei/octave-4.0.2/scripts/general/interpn.m:153
            x[i]=ravel(x[i](idx[:]))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:154
        idx[1:nd]=cellarray([1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:156
        idx[1]=':'
# /home/lei/octave-4.0.2/scripts/general/interpn.m:157
        x[1]=ravel(x[1](idx[:]))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:158
    
    method=tolower(method)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:161
    all_vectors=all(cellfun('isvector',y))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:163
    different_lengths=numel(unique(cellfun('numel',y))) > 1
# /home/lei/octave-4.0.2/scripts/general/interpn.m:164
    if (all_vectors and different_lengths):
        foobar(arange(1,numel(y))).y=ndgrid(y[:])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:166
        y=cellarray([foobar.y])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:167
    
    if (strcmp(method,'linear')):
        vi=__lin_interpn__(x[:],v,y[:])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:171
        if (isempty(extrapval)):
            extrapval=copy(NA)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:173
        vi[isna(vi)]=extrapval
# /home/lei/octave-4.0.2/scripts/general/interpn.m:175
    else:
        if (strcmp(method,'nearest')):
            yshape=size(y[1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:177
            yidx=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:178
            for i in arange(1,nd).reshape(-1):
                y[i]=ravel(y[i])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:180
                yidx[i]=lookup(x[i],y[i],'lr')
# /home/lei/octave-4.0.2/scripts/general/interpn.m:181
            idx=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:183
            for i in arange(1,nd).reshape(-1):
                idx[i]=yidx[i] + (y[i] - ravel(x[i](yidx[i])) >= ravel(x[i](yidx[i] + 1)) - y[i])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:185
            vi=v[sub2ind(sz,idx[:])]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:188
            idx=zeros(prod(yshape),1)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:189
            for i in arange(1,nd).reshape(-1):
                idx |= y[i] < logical_or(min(ravel(x[i])),y[i]) > max(ravel(x[i]))
            if (isempty(extrapval)):
                extrapval=copy(NA)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:194
            vi[idx]=extrapval
# /home/lei/octave-4.0.2/scripts/general/interpn.m:196
            vi=reshape(vi,yshape)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:197
        else:
            if (strcmp(method,'spline')):
                if (any(logical_not(cellfun('isvector',y)))):
                    for i in arange(2,nd).reshape(-1):
                        if (logical_not(size_equal(y[1],y[i]))):
                            error('interpn: dimensional mismatch')
                        idx[1:nd]=cellarray([1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:204
                        idx[i]=':'
# /home/lei/octave-4.0.2/scripts/general/interpn.m:205
                        y[i]=y[i](idx[:])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:206
                    idx[1:nd]=cellarray([1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:208
                    idx[1]=':'
# /home/lei/octave-4.0.2/scripts/general/interpn.m:209
                    y[1]=y[1](idx[:])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:210
                vi=__splinen__(x,v,y,extrapval,'interpn')
# /home/lei/octave-4.0.2/scripts/general/interpn.m:213
                if (size_equal(y[:])):
                    ly=length(y[1])
# /home/lei/octave-4.0.2/scripts/general/interpn.m:216
                    idx=cell(1,ly)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:217
                    q=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/interpn.m:218
                    for i in arange(1,ly).reshape(-1):
                        ravel[q]=i
# /home/lei/octave-4.0.2/scripts/general/interpn.m:220
                        idx[i]=q
# /home/lei/octave-4.0.2/scripts/general/interpn.m:221
                    vi=vi[cellfun(lambda x=None: sub2ind(size(vi),x[:]),idx)]
# /home/lei/octave-4.0.2/scripts/general/interpn.m:223
                    vi=reshape(vi,size(y[1]))
# /home/lei/octave-4.0.2/scripts/general/interpn.m:224
            else:
                if (strcmp(method,'cubic')):
                    error('interpn: cubic interpolation not yet implemented')
                else:
                    error('interpn: unrecognized interpolation METHOD')
    
    return vi
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} triplequad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{za}, @var{zb})
## @deftypefnx {Function File} {} triplequad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{za}, @var{zb}, @var{tol})
## @deftypefnx {Function File} {} triplequad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{za}, @var{zb}, @var{tol}, @var{quadf})
## @deftypefnx {Function File} {} triplequad (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb}, @var{za}, @var{zb}, @var{tol}, @var{quadf}, @dots{})
## Numerically evaluate the triple integral of @var{f}.
##
## @var{f} is a function handle, inline function, or string containing the name
## of the function to evaluate.  The function @var{f} must have the form
## @math{w = f(x,y,z)} where either @var{x} or @var{y} is a vector and the
## remaining inputs are scalars.  It should return a vector of the same length
## and orientation as @var{x} or @var{y}.
##
## @var{xa}, @var{ya}, @var{za} and @var{xb}, @var{yb}, @var{zb} are the lower
## and upper limits of integration for x, y, and z respectively.  The
## underlying integrator determines whether infinite bounds are accepted.
##
## The optional argument @var{tol} defines the absolute tolerance used to
## integrate each sub-integral.  The default value is 1e-6.
##
## The optional argument @var{quadf} specifies which underlying integrator
## function to use.  Any choice but @code{quad} is available and the default
## is @code{quadcc}.
##
## Additional arguments, are passed directly to @var{f}.  To use the default
## value for @var{tol} or @var{quadf} one may pass @qcode{':'} or an empty
## matrix ([]).
## @seealso{dblquad, quad, quadv, quadl, quadgk, quadcc, trapz}
## @end deftypefn
    
    
@function
def triplequad(f=None,xa=None,xb=None,ya=None,yb=None,za=None,zb=None,tol=1e-06,quadf=quadcc,varargin=None,*args,**kwargs):
    varargin = triplequad.varargin
    nargin = triplequad.nargin

    if (nargin < 7):
        print_usage()
    
    ## Allow use of empty matrix ([]) to indicate default
    if (isempty(tol)):
        tol=1e-06
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:57
    
    if (isempty(quadf)):
        quadf=quadcc
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:60
    
    inner=__triplequad_inner__
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:63
    if (ischar(f)):
        f=lambda x=None,y=None,z=None: feval(f,x,y,z,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:65
        varargin=cellarray([])
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:66
    
    q=dblquad(lambda y=None,z=None: inner[y,z,f,xa,xb,tol,quadf,varargin[:]],ya,yb,za,zb,tol)
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:69
    return q
    
if __name__ == '__main__':
    pass
    
    
@function
def __triplequad_inner__(y=None,z=None,f=None,xa=None,xb=None,tol=None,quadf=None,varargin=None,*args,**kwargs):
    varargin = __triplequad_inner__.varargin
    nargin = __triplequad_inner__.nargin

    q=zeros(size(y))
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:75
    for i in arange(1,length(y)).reshape(-1):
        q[i]=feval(quadf,lambda x=None: f[x,y[i],z,varargin[:]],xa,xb,tol)
# /home/lei/octave-4.0.2/scripts/general/triplequad.m:77
    
    return q
    
if __name__ == '__main__':
    pass
    
    
    ## These tests are too expensive to run normally (~30 sec each).  Disable them
##!assert (triplequad (@(x,y,z) exp (-x.^2 - y.^2 - z.^2) , -1, 1, -1, 1, -1, 1, [], @quadgk), pi^(3/2) * erf (1).^3, 1e-6)
##!#assert (triplequad (@(x,y,z) exp (-x.^2 - y.^2 - z.^2) , -1, 1, -1, 1, -1, 1, [], @quadl), pi^(3/2) * erf (1).^3, 1e-6)
##!#assert (triplequad (@(x,y,z) exp (-x.^2 - y.^2 - z.^2) , -1, 1, -1, 1, -1, 1, [], @quadv), pi^(3/2) * erf (1).^3, 1e-6)
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} quadgk (@var{f}, @var{a}, @var{b})
## @deftypefnx {Function File} {@var{q} =} quadgk (@var{f}, @var{a}, @var{b}, @var{abstol})
## @deftypefnx {Function File} {@var{q} =} quadgk (@var{f}, @var{a}, @var{b}, @var{abstol}, @var{trace})
## @deftypefnx {Function File} {@var{q} =} quadgk (@var{f}, @var{a}, @var{b}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {[@var{q}, @var{err}] =} quadgk (@dots{})
##
## Numerically evaluate the integral of @var{f} from @var{a} to @var{b}
## using adaptive Gauss-Konrod quadrature.
##
## @var{f} is a function handle, inline function, or string containing the name
## of the function to evaluate.  The function @var{f} must be vectorized and
## return a vector of output values when given a vector of input values.
##
## @var{a} and @var{b} are the lower and upper limits of integration.  Either
## or both limits may be infinite or contain weak end singularities.  Variable
## transformation will be used to treat any infinite intervals and weaken the
## singularities.  For example:
##
## @example
## quadgk (@@(x) 1 ./ (sqrt (x) .* (x + 1)), 0, Inf)
## @end example
##
## @noindent
## Note that the formulation of the integrand uses the element-by-element
## operator @code{./} and all user functions to @code{quadgk} should do the
## same.
##
## The optional argument @var{tol} defines the absolute tolerance used to stop
## the integration procedure.  The default value is 1e-10.
##
## The algorithm used by @code{quadgk} involves subdividing the integration
## interval and evaluating each subinterval.  If @var{trace} is true then after
## computing each of these partial integrals display: (1) the number of
## subintervals at this step, (2) the current estimate of the error @var{err},
## (3) the current estimate for the integral @var{q}.
##
## Alternatively, properties of @code{quadgk} can be passed to the function as
## pairs @qcode{"@var{prop}", @var{val}}.  Valid properties are
##
## @table @code
## @item AbsTol
## Define the absolute error tolerance for the quadrature.  The default
## absolute tolerance is 1e-10.
##
## @item RelTol
## Define the relative error tolerance for the quadrature.  The default
## relative tolerance is 1e-5.
##
## @item MaxIntervalCount
## @code{quadgk} initially subdivides the interval on which to perform the
## quadrature into 10 intervals.  Subintervals that have an unacceptable error
## are subdivided and re-evaluated.  If the number of subintervals exceeds 650
## subintervals at any point then a poor convergence is signaled and the
## current estimate of the integral is returned.  The property
## @qcode{"MaxIntervalCount"} can be used to alter the number of subintervals
## that can exist before exiting.
##
## @item WayPoints
## Discontinuities in the first derivative of the function to integrate can be
## flagged with the @qcode{"WayPoints"} property.  This forces the ends of a
## subinterval to fall on the breakpoints of the function and can result in
## significantly improved estimation of the error in the integral, faster
## computation, or both.  For example,
##
## @example
## quadgk (@@(x) abs (1 - x.^2), 0, 2, "Waypoints", 1)
## @end example
##
## @noindent
## signals the breakpoint in the integrand at @code{@var{x} = 1}.
##
## @item Trace
## If logically true @code{quadgk} prints information on the convergence of the
## quadrature at each iteration.
## @end table
##
## If any of @var{a}, @var{b}, or @var{waypoints} is complex then the
## quadrature is treated as a contour integral along a piecewise continuous
## path defined by the above.  In this case the integral is assumed to have no
## edge singularities.  For example,
##
## @example
## @group
## quadgk (@@(z) log (z), 1+1i, 1+1i, "WayPoints",
##         [1-1i, -1,-1i, -1+1i])
## @end group
## @end example
##
## @noindent
## integrates @code{log (z)} along the square defined by
## @code{[1+1i, 1-1i, -1-1i, -1+1i]}.
##
## The result of the integration is returned in @var{q}.
##
## @var{err} is an approximate bound on the error in the integral
## @code{abs (@var{q} - @var{I})}, where @var{I} is the exact value of the
## integral.
##
## Reference: @nospell{L.F. Shampine},
## @cite{"Vectorized adaptive quadrature in @sc{matlab}"}, Journal of
## Computational and Applied Mathematics, pp. 131--140, Vol 211, Issue 2,
## Feb 2008.
##
## @seealso{quad, quadv, quadl, quadcc, trapz, dblquad, triplequad}
## @end deftypefn
    
    
@function
def quadgk(f=None,a=None,b=None,varargin=None,*args,**kwargs):
    varargin = quadgk.varargin
    nargin = quadgk.nargin

    if (nargin < 3):
        print_usage()
    
    if (b < a):
        q,err=quadgk(f,b,a,varargin[:],nargout=2)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:132
        q=- q
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:133
    else:
        abstol=1e-10
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:135
        reltol=1e-05
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:136
        waypoints=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:137
        maxint=650
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:138
        trace=copy(false)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:139
        if (nargin > 3):
            if (logical_not(ischar(varargin[1]))):
                if (logical_not(isempty(varargin[1]))):
                    abstol=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:144
                    reltol=0
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:145
                if (nargin > 4):
                    trace=varargin[2]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:148
                if (nargin > 5):
                    error('quadgk: can not pass additional arguments to user function')
            else:
                idx=1
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:154
                while (idx < nargin - 3):

                    if (ischar(varargin[idx])):
                        str=varargin[idx]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:157
                        if (strcmpi(str,'reltol')):
                            reltol=varargin[idx]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:159
                        else:
                            if (strcmpi(str,'abstol')):
                                abstol=varargin[idx]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:161
                            else:
                                if (strcmpi(str,'waypoints')):
                                    waypoints=ravel(varargin[idx])
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:163
                                    if (isreal(waypoints)):
                                        waypoints[waypoints < logical_or(a,waypoints) > b]=[]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:165
                                else:
                                    if (strcmpi(str,'maxintervalcount')):
                                        maxint=varargin[idx]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:168
                                    else:
                                        if (strcmpi(str,'trace')):
                                            trace=varargin[idx]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:170
                                        else:
                                            error('quadgk: unknown property \'%s\'',str)
                    else:
                        error('quadgk: property PROP must be a string')

                if (idx != nargin - 2):
                    error('quadgk: property/value must occur in pairs')
        ## Convert function given as a string to a function handle
        if (ischar(f)):
            f=lambda x=None: feval(f,x)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:186
        ## Use variable subsitution to weaken endpoint singularities and to
    ## perform integration with endpoints at infinity.  No transform for
    ## contour integrals.
        if (iscomplex(a) or iscomplex(b) or iscomplex(waypoints)):
            ## contour integral, no transform
            subs=matlabarray(cat([a],[waypoints],[b]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:194
            h=sum(abs(diff(subs)))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:195
            h0=copy(h)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:196
            trans=lambda t=None: t
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:197
        else:
            if (isinf(a) and isinf(b)):
                ## Standard infinite to finite integral transformation.
      ##   \int_{-\infinity_^\infinity f(x) dx = \int_-1^1 f (g(t)) g'(t) dt
      ## where
      ##   g(t)  = t / (1 - t^2)
      ##   g'(t) =  (1 + t^2) / (1 - t^2) ^ 2
      ## waypoint transform is then
      ##   t =  (2 * g(t)) ./ (1 + sqrt(1 + 4 * g(t) .^ 2))
                if (logical_not(isempty(waypoints))):
                    trans=lambda x=None: (dot(2,x)) / (1 + sqrt(1 + dot(4,x ** 2)))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:207
                    subs=matlabarray(cat([- 1],[trans[waypoints]],[1]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:208
                else:
                    subs=linspace(- 1,1,11).T
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:210
                h=2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:212
                h0=b - a
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:213
                trans=lambda t=None: t / (1 - t ** 2)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:214
                f=lambda t=None: multiply(f[t / (1 - t ** 2)],(1 + t ** 2)) / ((1 - t ** 2) ** 2)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:215
            else:
                if (isinf(a)):
                    ## Formula defined in Shampine paper as two separate steps. One to
      ## weaken singularity at finite end, then a second to transform to
      ## a finite interval. The singularity weakening transform is
      ##   \int_{-\infinity}^b f(x) dx =
      ##               - \int_{-\infinity}^0 f (b - t^2) 2 t dt
      ## (note minus sign) and the finite interval transform is
      ##   \int_{-\infinity}^0 f(b - t^2)  2 t dt =
      ##                  \int_{-1}^0 f (b - g(s) ^ 2) 2 g(s) g'(s) ds
      ## where
      ##   g(s)  = s / (1 + s)
      ##   g'(s) = 1 / (1 + s) ^ 2
      ## waypoint transform is then
      ##   t = sqrt (b - x)
      ##   s =  - t / (t + 1)
                    if (logical_not(isempty(waypoints))):
                        tmp=sqrt(b - waypoints)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:232
                        trans=lambda x=None: - x / (x + 1)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:233
                        subs=matlabarray(cat([- 1],[trans[tmp]],[0]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:234
                    else:
                        subs=linspace(- 1,0,11).T
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:236
                    h=1
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:238
                    h0=b - a
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:239
                    trans=lambda t=None: b - (t / (1 + t)) ** 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:240
                    f=lambda s=None: multiply(dot(- 2,s),f[b - (s / (1 + s)) ** 2]) / ((1 + s) ** 3)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:241
                else:
                    if (isinf(b)):
                        ## Formula defined in Shampine paper as two separate steps. One to
      ## weaken singularity at finite end, then a second to transform to
      ## a finite interval. The singularity weakening transform is
      ##   \int_a^\infinity f(x) dx = \int_0^\infinity f (a + t^2) 2 t dt
      ## and the finite interval transform is
      ##  \int_0^\infinity f(a + t^2)  2 t dt =
      ##           \int_0^1 f (a + g(s) ^ 2) 2 g(s) g'(s) ds
      ## where
      ##   g(s)  = s / (1 - s)
      ##   g'(s) = 1 / (1 - s) ^ 2
      ## waypoint transform is then
      ##   t = sqrt (x - a)
      ##   s = t / (t + 1)
                        if (logical_not(isempty(waypoints))):
                            tmp=sqrt(waypoints - a)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:257
                            trans=lambda x=None: x / (x + 1)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:258
                            subs=matlabarray(cat([0],[trans[tmp]],[1]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:259
                        else:
                            subs=linspace(0,1,11).T
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:261
                        h=1
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:263
                        h0=b - a
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:264
                        trans=lambda t=None: a + (t / (1 - t)) ** 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:265
                        f=lambda s=None: multiply(dot(2,s),f[a + (s / (1 - s)) ** 2]) / ((1 - s) ** 3)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:266
                    else:
                        ## Davis, Rabinowitz, "Methods of Numerical Integration" p441 2ed.
      ## Presented in section 5 of the Shampine paper as
      ##   g(t) = ((b - a) / 2) * (t / 2 * (3 - t^2)) + (b + a) / 2
      ##   g'(t) = ((b-a)/4) * (3 - 3t^2);
      ## waypoint transform can then be found by solving for t with
      ## Maxima (solve (c + 3*t -  3^3, t);). This gives 3 roots, two of
      ## which are complex for values between a and b and so can be
      ## ignored. The third is
      ##  c = (-4*x + 2*(b+a)) / (b-a);
      ##  k = ((sqrt(c^2 - 4) + c)/2)^(1/3);
      ##  t = (sqrt(3)* 1i * (1 - k^2) - (1 + k^2)) / 2 / k;
                        if (logical_not(isempty(waypoints))):
                            trans=__quadgk_finite_waypoint__
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:280
                            subs=matlabarray(cat([- 1],[trans[waypoints,a,b]],[1]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:281
                        else:
                            subs=linspace(- 1,1,11).T
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:283
                        h=2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:285
                        h0=b - a
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:286
                        trans=lambda t=None: multiply(dot(((b - a) / 4),t),(3 - t ** 2)) + (b + a) / 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:287
                        f=lambda t=None: multiply(multiply(multiply(f[multiply(multiply((b - a) / 4,t),(3 - t ** 2)) + (b + a) / 2],3),(b - a)) / 4,(1 - t ** 2))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:288
        ## Split interval into at least 10 subinterval with a 15 point
    ## Gauss-Kronrod rule giving a minimum of 150 function evaluations
        while (length(subs) < 11):

            subs=ravel(cat([subs.T],[subs[1:end() - 1].T + diff(subs.T) / 2,NaN]))(arange(1,end() - 1))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:295

        subs=matlabarray(cat(subs[1:end() - 1],subs[2:end()]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:297
        ## Turn off warning locally for quadgk function only.
        warning('off','Octave:divide-by-zero','local')
        warn_id='Octave:quadgk:warning-termination'
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:303
        q_subs,q_errs=__quadgk_eval__(f,subs,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:306
        q0=sum(q_subs)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:307
        err0=sum(q_errs)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:308
        if (isa(a,'single') or isa(b,'single') or isa(waypoints,'single')):
            myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:311
        else:
            myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:313
        first=copy(true)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:316
        while (true):

            ## Check for subintervals that are too small. Test must be
      ## performed in untransformed subintervals. What is a good
      ## value for this test. Shampine suggests 100*eps
            if (any(abs(diff(trans[subs],[],2) / h0) < dot(100,myeps))):
                q=copy(q0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:322
                err=copy(err0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:323
                break
            ## Quit if any evaluations are not finite (Inf or NaN)
            if (any(logical_not(isfinite(q_subs)))):
                warning(warn_id,'quadgk: non finite integrand encountered')
                q=copy(q0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:330
                err=copy(err0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:331
                break
            tol=max(abstol,multiply(reltol,abs(q0)))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:335
            if (err0 < tol):
                q=copy(q0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:339
                err=copy(err0)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:340
                break
            ## Accept the subintervals that meet the convergence criteria
            idx=find(abs(q_errs) < multiply(tol,abs(diff(subs,[],2))) / h)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:345
            if (first):
                q=sum(q_subs[idx])
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:347
                err=sum(q_errs[idx])
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:348
                first=copy(false)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:349
            else:
                q0=q + sum(q_subs)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:351
                err0=err + sum(q_errs)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:352
                q += sum(q_subs[idx])
                err += sum(q_errs[idx])
            subs[idx,:]=[]
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:356
            if (rows(subs) == 0):
                break
            if (trace):
                disp(cat(rows(subs),err,q0))
            ## Split remaining subintervals in two
            mid=(subs[:,2] + subs[:,1]) / 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:368
            subs=matlabarray(cat([subs[:,1],mid],[mid,subs[:,2]]))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:369
            ## subinterval and exit
            if (rows(subs) > maxint):
                warning(warn_id,'quadgk: maximum interval count (%d) met',maxint)
                q += sum(q_subs)
                err += sum(q_errs)
                break
            ## Evaluation of the integrand on the remaining subintervals
            q_subs,q_errs=__quadgk_eval__(f,subs,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:381

        if (err > max(abstol,dot(reltol,abs(q)))):
            warning(warn_id,'quadgk: Error tolerance not met.  Estimated error %g',err)
    
    return q,err
    
if __name__ == '__main__':
    pass
    
    
@function
def __quadgk_eval__(f=None,subs=None,*args,**kwargs):
    varargin = __quadgk_eval__.varargin
    nargin = __quadgk_eval__.nargin

    ## A (15,7) point pair of Gauss-Konrod quadrature rules. The abscissa
  ## and weights are copied directly from dqk15w.f from quadpack
    
    
    
    
    halfwidth=diff(subs,[],2) / 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:421
    center=sum(subs,2) / 2
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:422
    
    x=bsxfun(plus,dot(halfwidth,abscissa),center)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:423
    y=reshape(f[ravel(x)],size(x))
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:424
    
    ## single BLAS call, rather than rows(sub) calls to the @times
  ## function.
    q=multiply(sum(dot(y,weights15),2),halfwidth)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:429
    err=abs(multiply(sum(dot(y[:,2:2:end()],weights7),2),halfwidth) - q)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:430
    return q,err
    
if __name__ == '__main__':
    pass
    
    
@function
def __quadgk_finite_waypoint__(x=None,a=None,b=None,*args,**kwargs):
    varargin = __quadgk_finite_waypoint__.varargin
    nargin = __quadgk_finite_waypoint__.nargin

    c=(multiply(- 4,x) + dot(2.0,(b + a))) / (b - a)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:434
    k=((sqrt(c ** 2 - 4) + c) / 2) ** (1 / 3)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:435
    t=real((dot(multiply(sqrt(3),1j),(1 - k ** 2)) - (1 + k ** 2)) / 2 / k)
# /home/lei/octave-4.0.2/scripts/general/quadgk.m:436
    return t
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{cx}, @var{cy}, @var{cz}, @var{v}] =} curl (@var{x}, @var{y}, @var{z}, @var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {[@var{cz}, @var{v}] =} curl (@var{x}, @var{y}, @var{fx}, @var{fy})
## @deftypefnx {Function File} {[@dots{}] =} curl (@var{fx}, @var{fy}, @var{fz})
## @deftypefnx {Function File} {[@dots{}] =} curl (@var{fx}, @var{fy})
## @deftypefnx {Function File} {@var{v} =} curl (@dots{})
## Calculate curl of vector field given by the arrays @var{fx}, @var{fy}, and
## @var{fz} or @var{fx}, @var{fy} respectively.
## @tex
## $$ curl F(x,y,z) = \left( {\partial{d} \over \partial{y}} F_z - {\partial{d} \over \partial{z}} F_y, {\partial{d} \over \partial{z}} F_x - {\partial{d} \over \partial{x}} F_z, {\partial{d} \over \partial{x}} F_y - {\partial{d} \over \partial{y}} F_x \right)$$
## @end tex
## @ifnottex
##
## @example
## @group
##                   / d         d       d         d       d         d     \
## curl F(x,y,z)  =  | -- Fz  -  -- Fy,  -- Fx  -  -- Fz,  -- Fy  -  -- Fx |
##                   \ dy        dz      dz        dx      dx        dy    /
## @end group
## @end example
##
## @end ifnottex
## The coordinates of the vector field can be given by the arguments @var{x},
## @var{y}, @var{z} or @var{x}, @var{y} respectively.  @var{v} calculates the
## scalar component of the angular velocity vector in direction of the z-axis
## for two-dimensional input.  For three-dimensional input the scalar
## rotation is calculated at each grid point in direction of the vector field
## at that point.
## @seealso{divergence, gradient, del2, cross}
## @end deftypefn
    
    ## Author: Kai Habel <kai.habel@gmx.de>
    
    
@function
def curl(varargin=None,*args,**kwargs):
    varargin = curl.varargin
    nargin = curl.nargin

    fidx=1
# /home/lei/octave-4.0.2/scripts/general/curl.m:54
    if (nargin == 2):
        sz=size(varargin[fidx])
# /home/lei/octave-4.0.2/scripts/general/curl.m:56
        dx=ravel((arange(1,sz[2])))
# /home/lei/octave-4.0.2/scripts/general/curl.m:57
        dy=ravel((arange(1,sz[1])))
# /home/lei/octave-4.0.2/scripts/general/curl.m:58
    else:
        if (nargin == 3):
            sz=size(varargin[fidx])
# /home/lei/octave-4.0.2/scripts/general/curl.m:60
            dx=ravel((arange(1,sz[2])))
# /home/lei/octave-4.0.2/scripts/general/curl.m:61
            dy=ravel((arange(1,sz[1])))
# /home/lei/octave-4.0.2/scripts/general/curl.m:62
            dz=ravel((arange(1,sz[3])))
# /home/lei/octave-4.0.2/scripts/general/curl.m:63
        else:
            if (nargin == 4):
                fidx=3
# /home/lei/octave-4.0.2/scripts/general/curl.m:65
                dx=varargin[1](1,arange())
# /home/lei/octave-4.0.2/scripts/general/curl.m:66
                dy=varargin[2](arange(),1)
# /home/lei/octave-4.0.2/scripts/general/curl.m:67
            else:
                if (nargin == 6):
                    fidx=4
# /home/lei/octave-4.0.2/scripts/general/curl.m:69
                    dx=ravel(varargin[1](1,arange(),1))
# /home/lei/octave-4.0.2/scripts/general/curl.m:70
                    dy=ravel(varargin[2](arange(),1,1))
# /home/lei/octave-4.0.2/scripts/general/curl.m:71
                    dz=ravel(varargin[3](1,1,arange()))
# /home/lei/octave-4.0.2/scripts/general/curl.m:72
                else:
                    print_usage()
    
    if (nargin == 4 or nargin == 2):
        if (logical_not(size_equal(varargin[fidx],varargin[fidx + 1]))):
            error('curl: size of X and Y must match')
        else:
            if (ndims(varargin[fidx]) != 2):
                error('curl: expected two-dimensional matrices X and Y')
            else:
                if ((length(dx) != columns(varargin[fidx])) or (length(dy) != rows(varargin[fidx]))):
                    error('curl: size of dx and dy must match the respective dimension of X and Y')
        dFx_dy=gradient(varargin[fidx].T,dy,dx).T
# /home/lei/octave-4.0.2/scripts/general/curl.m:87
        dFy_dx=gradient(varargin[fidx + 1],dx,dy)
# /home/lei/octave-4.0.2/scripts/general/curl.m:88
        rot_z=dFy_dx - dFx_dy
# /home/lei/octave-4.0.2/scripts/general/curl.m:89
        av=rot_z / 2
# /home/lei/octave-4.0.2/scripts/general/curl.m:90
        if (nargout == 0 or nargout == 1):
            varargout[1]=av
# /home/lei/octave-4.0.2/scripts/general/curl.m:92
        else:
            varargout[1]=rot_z
# /home/lei/octave-4.0.2/scripts/general/curl.m:94
            varargout[2]=av
# /home/lei/octave-4.0.2/scripts/general/curl.m:95
    else:
        if (nargin == 6 or nargin == 3):
            if (logical_not(size_equal(varargin[fidx],varargin[fidx + 1],varargin[fidx + 2]))):
                error('curl: size of X, Y, and Z must match')
            else:
                if (ndims(varargin[fidx]) != 3):
                    error('curl: expected two-dimensional matrices X, Y, and Z')
                else:
                    if ((length(dx) != size(varargin[fidx],2)) or (length(dy) != size(varargin[fidx],1)) or (length(dz) != size(varargin[fidx],3))):
                        error('curl: size of dx, dy, and dz must match the respective dimesion of X, Y, and Z')
            __,dFx_dy,dFx_dz=gradient(varargin[fidx],dx,dy,dz,nargout=3)
# /home/lei/octave-4.0.2/scripts/general/curl.m:109
            dFy_dx,__,dFy_dz=gradient(varargin[fidx + 1],dx,dy,dz,nargout=3)
# /home/lei/octave-4.0.2/scripts/general/curl.m:110
            dFz_dx,dFz_dy=gradient(varargin[fidx + 2],dx,dy,dz,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/curl.m:111
            rot_x=dFz_dy - dFy_dz
# /home/lei/octave-4.0.2/scripts/general/curl.m:112
            rot_y=dFx_dz - dFz_dx
# /home/lei/octave-4.0.2/scripts/general/curl.m:113
            rot_z=dFy_dx - dFx_dy
# /home/lei/octave-4.0.2/scripts/general/curl.m:114
            l=sqrt(varargin[fidx] ** 2 + varargin[fidx + 1] ** 2 + varargin[fidx + 2] ** 2)
# /home/lei/octave-4.0.2/scripts/general/curl.m:115
            av=(multiply(rot_x,varargin[fidx]) + multiply(rot_y,varargin[fidx + 1]) + multiply(rot_z,varargin[fidx + 2])) / (dot(2,l))
# /home/lei/octave-4.0.2/scripts/general/curl.m:116
            if (nargout == 0 or nargout == 1):
                varargout[1]=av
# /home/lei/octave-4.0.2/scripts/general/curl.m:121
            else:
                varargout[1]=rot_x
# /home/lei/octave-4.0.2/scripts/general/curl.m:123
                varargout[2]=rot_y
# /home/lei/octave-4.0.2/scripts/general/curl.m:124
                varargout[3]=rot_z
# /home/lei/octave-4.0.2/scripts/general/curl.m:125
                varargout[4]=av
# /home/lei/octave-4.0.2/scripts/general/curl.m:126
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cplxpair (@var{z})
## @deftypefnx {Function File} {} cplxpair (@var{z}, @var{tol})
## @deftypefnx {Function File} {} cplxpair (@var{z}, @var{tol}, @var{dim})
## Sort the numbers @var{z} into complex conjugate pairs ordered by
## increasing real part.
##
## The negative imaginary complex numbers are placed first within each pair.
## All real numbers (those with
## @code{abs (imag (@var{z}) / @var{z}) < @var{tol}}) are placed after the
## complex pairs.
##
## If @var{tol} is unspecified the default value is 100*@code{eps}.
##
## By default the complex pairs are sorted along the first non-singleton
## dimension of @var{z}.  If @var{dim} is specified, then the complex pairs are
## sorted along this dimension.
##
## Signal an error if some complex numbers could not be paired.  Signal an
## error if all complex numbers are not exact conjugates (to within @var{tol}).
## Note that there is no defined order for pairs with identical real parts but
## differing imaginary parts.
## @c Set example in small font to prevent overfull line
##
## @smallexample
## cplxpair (exp(2i*pi*[0:4]'/5)) == exp(2i*pi*[3; 2; 4; 1; 0]/5)
## @end smallexample
## @end deftypefn
    
    ## FIXME: subsort returned pairs by imaginary magnitude
## FIXME: Why doesn't exp (2i*pi*[0:4]'/5) produce exact conjugates.  Does
## FIXME: it in Matlab?  The reason is that complex pairs are supposed
## FIXME: to be exact conjugates, and not rely on a tolerance test.
    
    ## 2006-05-12 David Bateman - Modified for NDArrays
    
    
@function
def cplxpair(z=None,tol=None,dim=None,*args,**kwargs):
    varargin = cplxpair.varargin
    nargin = cplxpair.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (length(z) == 0):
        y=zeros(size(z))
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:62
        return y
    
    if (nargin < 2 or isempty(tol)):
        if (isa(z,'single')):
            tol=dot(100,eps('single'))
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:68
        else:
            tol=dot(100,eps)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:70
    
    nd=ndims(z)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:74
    orig_dims=size(z)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:75
    if (nargin < 3):
        ## Find the first singleton dimension.
        dim=0
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:78
        while (dim < nd and orig_dims[dim + 1] == 1):

            dim

        dim
        if (dim > nd):
            dim=1
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:84
    else:
        dim=floor(dim)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:87
        if (dim < 1 or dim > nd):
            error('cplxpair: invalid dimension along which to sort')
    
    ## Move dimension to treat first, and convert to a 2-D matrix.
    perm=matlabarray(cat(arange(dim,nd),arange(1,dim - 1)))
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:94
    z=permute(z,perm)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:95
    sz=size(z)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:96
    n=sz[1]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:97
    m=prod(sz) / n
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:98
    z=reshape(z,n,m)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:99
    
    q,idx=sort(real(z),1,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:102
    z=z[idx + dot(dot(n,ones(n,1)),cat(arange(0,m - 1)))]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:103
    
    cls='double'
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:106
    if (isa(z,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:108
    
    idxi,idxj=find(abs(imag(z)) / (abs(z) + realmin(cls)) < tol,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:110
    q=sparse(idxi,idxj,1,n,m)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:111
    nr=sum(q,1)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:112
    q,idx=sort(q,1,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:113
    z=z[idx]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:114
    y=copy(z)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:115
    
    ## start of the returned list, and remove them from further
  ## consideration.
    for j in arange(1,m).reshape(-1):
        p=n - nr[j]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:121
        for i in arange(1,p,2).reshape(-1):
            if (i + 1 > p):
                error('cplxpair: could not pair all complex numbers')
            v,idx=min(abs(z[i + 1:p] - conj(z[i])),nargout=2)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:126
            if (v > tol):
                error('cplxpair: could not pair all complex numbers')
            if (imag(z[i]) < 0):
                y[cat(i,i + 1)]=z[cat(i,idx + i)]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:131
            else:
                y[cat(i,i + 1)]=z[cat(idx + i,i)]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:133
            z[idx + i]=z[i + 1]
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:135
    
    ## Reshape the output matrix.
    y=ipermute(reshape(y,sz),perm)
# /home/lei/octave-4.0.2/scripts/general/cplxpair.m:140
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## tolerance test
    
    ## Copyright (C) 2000-2016 Kai Habel
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{zi} =} interp2 (@var{x}, @var{y}, @var{z}, @var{xi}, @var{yi})
## @deftypefnx {Function File} {@var{zi} =} interp2 (@var{z}, @var{xi}, @var{yi})
## @deftypefnx {Function File} {@var{zi} =} interp2 (@var{z}, @var{n})
## @deftypefnx {Function File} {@var{zi} =} interp2 (@var{z})
## @deftypefnx {Function File} {@var{zi} =} interp2 (@dots{}, @var{method})
## @deftypefnx {Function File} {@var{zi} =} interp2 (@dots{}, @var{method}, @var{extrap})
##
## Two-dimensional interpolation.
##
## Interpolate reference data @var{x}, @var{y}, @var{z} to determine @var{zi}
## at the coordinates @var{xi}, @var{yi}.  The reference data @var{x}, @var{y}
## can be matrices, as returned by @code{meshgrid}, in which case the sizes of
## @var{x}, @var{y}, and @var{z} must be equal.  If @var{x}, @var{y} are
## vectors describing a grid then @code{length (@var{x}) == columns (@var{z})}
## and @code{length (@var{y}) == rows (@var{z})}.  In either case the input
## data must be strictly monotonic.
##
## If called without @var{x}, @var{y}, and just a single reference data matrix
## @var{z}, the 2-D region
## @code{@var{x} = 1:columns (@var{z}), @var{y} = 1:rows (@var{z})} is assumed.
## This saves memory if the grid is regular and the distance between points is
## not important.
##
## If called with a single reference data matrix @var{z} and a refinement
## value @var{n}, then perform interpolation over a grid where each original
## interval has been recursively subdivided @var{n} times.  This results in
## @code{2^@var{n}-1} additional points for every interval in the original
## grid.  If @var{n} is omitted a value of 1 is used.  As an example, the
## interval [0,1] with @code{@var{n}==2} results in a refined interval with
## points at [0, 1/4, 1/2, 3/4, 1].
##
## The interpolation @var{method} is one of:
##
## @table @asis
## @item @qcode{"nearest"}
## Return the nearest neighbor.
##
## @item @qcode{"linear"} (default)
## Linear interpolation from nearest neighbors.
##
## @item @qcode{"pchip"}
## Piecewise cubic Hermite interpolating polynomial---shape-preserving
## interpolation with smooth first derivative.
##
## @item @qcode{"cubic"}
## Cubic interpolation (same as @qcode{"pchip"}).
##
## @item @qcode{"spline"}
## Cubic spline interpolation---smooth first and second derivatives
## throughout the curve.
## @end table
##
## @var{extrap} is a scalar number.  It replaces values beyond the endpoints
## with @var{extrap}.  Note that if @var{extrapval} is used, @var{method} must
## be specified as well.  If @var{extrap} is omitted and the @var{method} is
## @qcode{"spline"}, then the extrapolated values of the @qcode{"spline"} are
## used.  Otherwise the default @var{extrap} value for any other @var{method}
## is @qcode{"NA"}.
## @seealso{interp1, interp3, interpn, meshgrid}
## @end deftypefn
    
    
@function
def interp2(varargin=None,*args,**kwargs):
    varargin = interp2.varargin
    nargin = interp2.nargin

    narginchk(1,7)
    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:85
    Z=X=Y=XI=YI=n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
# /home/lei/octave-4.0.2/scripts/general/interp2.m:87
    method='linear'
# /home/lei/octave-4.0.2/scripts/general/interp2.m:88
    extrap=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/interp2.m:89
    
    if (nargs > 1 and ischar(varargin[end() - 1])):
        if (logical_not(isnumeric(varargin[end()])) or logical_not(isscalar(varargin[end()]))):
            error('interp2: EXTRAP must be a numeric scalar')
        extrap=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:96
        method=varargin[end() - 1]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:97
        nargs -= 2
    else:
        if (ischar(varargin[end()])):
            method=varargin[end()]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:100
            nargs
    
    if (method[1] == '*'):
        warning('interp2: ignoring unsupported \'*\' flag to METHOD')
        method[1]=[]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:105
    
    method=validatestring(method,cellarray(['nearest','linear','pchip','cubic','spline']))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:107
    
    if 1 == (nargs):
        Z=varargin[1]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:113
        n=1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:114
    else:
        if 2 == (nargs):
            Z,n=deal(varargin[1:nargs],nargout=2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:116
        else:
            if 3 == (nargs):
                Z,XI,YI=deal(varargin[1:nargs],nargout=3)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:118
            else:
                if 5 == (nargs):
                    X,Y,Z,XI,YI=deal(varargin[1:nargs],nargout=5)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:120
                else:
                    print_usage()
    
    ## Type checking
    if (logical_not(isnumeric(Z)) or isscalar(Z) or logical_not(ismatrix(Z))):
        error('interp2: Z must be a 2-D matrix')
    
    if (logical_not(isempty(n)) and logical_not((isscalar(n) and n >= 0 and n == fix(n)))):
        error('interp2: N must be an integer >= 0')
    
    ## Define X, Y, XI, YI if needed
    zr,zc=size(Z,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:134
    if (isempty(X)):
        X=arange(1,zc)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:136
        Y=arange(1,zr)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:137
    
    if (logical_not(isnumeric(X)) or logical_not(isnumeric(Y))):
        error('interp2: X, Y must be numeric matrices')
    
    if (logical_not(isempty(n))):
        ## Calculate the interleaved input vectors.
        p=2 ** n
# /home/lei/octave-4.0.2/scripts/general/interp2.m:144
        XI=(arange(p,dot(p,zc))) / p
# /home/lei/octave-4.0.2/scripts/general/interp2.m:145
        YI=(arange(p,dot(p,zr))).T / p
# /home/lei/octave-4.0.2/scripts/general/interp2.m:146
    
    if (logical_not(isnumeric(XI)) or logical_not(isnumeric(YI))):
        error('interp2: XI, YI must be numeric')
    
    if (isvector(X) and isvector(Y)):
        X=ravel(X)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:153
        Y=ravel(Y)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:153
    else:
        if (size_equal(X,Y)):
            X=X[1,:].T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:155
            Y=Y[:,1]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:155
        else:
            error('interp2: X and Y must be matrices of equal size')
    
    if (columns(Z) != length(X) or rows(Z) != length(Y)):
        error('interp2: X and Y size must match the dimensions of Z')
    
    dx=diff(X)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:162
    if (all(dx < 0)):
        X=flipud(X)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:164
        Z=fliplr(Z)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:165
    else:
        if (any(dx <= 0)):
            error('interp2: X must be strictly monotonic')
    
    dy=diff(Y)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:169
    if (all(dy < 0)):
        Y=flipud(Y)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:171
        Z=flipud(Z)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:172
    else:
        if (any(dy <= 0)):
            error('interp2: Y must be strictly monotonic')
    
    if (any(strcmp(method,cellarray(['nearest','linear','pchip','cubic'])))):
        ## If Xi and Yi are vectors of different orientation build a grid
        if ((rows(XI) == 1 and columns(YI) == 1) or (columns(XI) == 1 and rows(YI) == 1)):
            XI,YI=meshgrid(XI,YI,nargout=2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:182
        else:
            if (logical_not(size_equal(XI,YI))):
                error('interp2: XI and YI must be matrices of equal size')
        ## if XI, YI are vectors, X and Y should share their orientation.
        if (rows(XI) == 1):
            if (rows(X) != 1):
                X=X.T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:190
            if (rows(Y) != 1):
                Y=Y.T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:193
        else:
            if (columns(XI) == 1):
                if (columns(X) != 1):
                    X=X.T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:197
                if (columns(Y) != 1):
                    Y=Y.T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:200
        xidx=lookup(X,XI,'lr')
# /home/lei/octave-4.0.2/scripts/general/interp2.m:204
        yidx=lookup(Y,YI,'lr')
# /home/lei/octave-4.0.2/scripts/general/interp2.m:205
        if (strcmp(method,'linear')):
            ## each quad satisfies the equation z(x,y)=a+b*x+c*y+d*xy
      ##
      ## a-b
      ## | |
      ## c-d
            a=Z[1:(zr - 1),1:(zc - 1)]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:213
            b=Z[1:(zr - 1),2:zc] - a
# /home/lei/octave-4.0.2/scripts/general/interp2.m:214
            c=Z[2:zr,1:(zc - 1)] - a
# /home/lei/octave-4.0.2/scripts/general/interp2.m:215
            d=Z[2:zr,2:zc] - a - b - c
# /home/lei/octave-4.0.2/scripts/general/interp2.m:216
            Xsc=(XI - X[xidx]) / (diff(X)(xidx))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:219
            Ysc=(YI - Y[yidx]) / (diff(Y)(yidx))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:220
            idx=sub2ind(size(a),yidx,xidx)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:223
            clear('xidx','yidx')
            ZI=a[idx] + multiply(b[idx],Xsc) + multiply(c[idx],Ysc) + multiply(multiply(d[idx],Xsc),Ysc)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:228
        else:
            if (strcmp(method,'nearest')):
                ii=(XI - X[xidx] >= X[xidx + 1] - XI)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:231
                jj=(YI - Y[yidx] >= Y[yidx + 1] - YI)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:232
                idx=sub2ind(size(Z),yidx + jj,xidx + ii)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:233
                ZI=Z[idx]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:234
            else:
                if (strcmp(method,'pchip') or strcmp(method,'cubic')):
                    if (length(X) < 2 or length(Y) < 2):
                        error('interp2: %s requires at least 2 points in each dimension',method)
                    ## first order derivatives
                    DX=__pchip_deriv__(X,Z,2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:244
                    DY=__pchip_deriv__(Y,Z,1)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:245
                    DXY=(__pchip_deriv__(X,DY,2) + __pchip_deriv__(Y,DX,1)) / 2
# /home/lei/octave-4.0.2/scripts/general/interp2.m:247
                    hx=diff(X)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:250
                    hx=hx[xidx]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:250
                    hy=diff(Y)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:251
                    hy=hy[yidx]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:251
                    tx=(XI - X[xidx]) / hx
# /home/lei/octave-4.0.2/scripts/general/interp2.m:253
                    ty=(YI - Y[yidx]) / hy
# /home/lei/octave-4.0.2/scripts/general/interp2.m:254
                    ## formulas:
      ## b{1,1} =    ( 2*t.^3 - 3*t.^2     + 1);
      ## b{2,1} = h.*(   t.^3 - 2*t.^2 + t    );
      ## b{1,2} =    (-2*t.^3 + 3*t.^2        );
      ## b{2,2} = h.*(   t.^3 -   t.^2        );
                    ## optimized equivalents of the above:
                    t1=tx ** 2
# /home/lei/octave-4.0.2/scripts/general/interp2.m:265
                    t2=multiply(tx,t1) - t1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:266
                    xb[2,2]=multiply(hx,t2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:267
                    t1=t2 - t1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:268
                    xb[2,1]=multiply(hx,(t1 + tx))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:269
                    t2 += t1
                    xb[1,2]=- t2
# /home/lei/octave-4.0.2/scripts/general/interp2.m:271
                    xb[1,1]=t2 + 1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:272
                    t1=ty ** 2
# /home/lei/octave-4.0.2/scripts/general/interp2.m:274
                    t2=multiply(ty,t1) - t1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:275
                    yb[2,2]=multiply(hy,t2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:276
                    t1=t2 - t1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:277
                    yb[2,1]=multiply(hy,(t1 + ty))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:278
                    t2 += t1
                    yb[1,2]=- t2
# /home/lei/octave-4.0.2/scripts/general/interp2.m:280
                    yb[1,1]=t2 + 1
# /home/lei/octave-4.0.2/scripts/general/interp2.m:281
                    ZI=zeros(size(XI))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:283
                    for i in arange(1,2).reshape(-1):
                        for j in arange(1,2).reshape(-1):
                            zidx=sub2ind(size(Z),yidx + (j - 1),xidx + (i - 1))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:286
                            ZI += multiply(multiply(xb[1,i],yb[1,j]),Z[zidx])
                            ZI += multiply(multiply(xb[2,i],yb[1,j]),DX[zidx])
                            ZI += multiply(multiply(xb[1,i],yb[2,j]),DY[zidx])
                            ZI += multiply(multiply(xb[2,i],yb[2,j]),DXY[zidx])
    else:
        ## Check dimensions of XI and YI
        if (isvector(XI) and isvector(YI) and logical_not(size_equal(XI,YI))):
            XI=ravel(XI).T
# /home/lei/octave-4.0.2/scripts/general/interp2.m:300
            YI=ravel(YI)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:300
        else:
            if (logical_not(size_equal(XI,YI))):
                error('interp2: XI and YI must be matrices of equal size')
        if (strcmp(method,'spline')):
            if (isgriddata(XI) and isgriddata(YI.T)):
                ZI=__splinen__(cellarray([Y,X]),Z,cellarray([YI[:,1],XI[1,:]]),extrap,'spline')
# /home/lei/octave-4.0.2/scripts/general/interp2.m:307
            else:
                error('interp2: XI, YI must have uniform spacing (\'meshgrid\' format)')
        return ZI
    
    ## extrapolation 'extrap'
    if (isempty(extrap)):
        extrap=copy(NA)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:319
    
    if (X[1] < X[end()]):
        if (Y[1] < Y[end()]):
            ZI[XI < logical_or(X[1,1],XI) > logical_or(X[end()],YI) < logical_or(Y[1,1],YI) > Y[end()]]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp2.m:324
        else:
            ZI[XI < logical_or(X[1],XI) > logical_or(X[end()],YI) < logical_or(Y[end()],YI) > Y[1]]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp2.m:326
    else:
        if (Y[1] < Y[end()]):
            ZI[XI < logical_or(X[end()],XI) > logical_or(X[1],YI) < logical_or(Y[1],YI) > Y[end()]]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp2.m:330
        else:
            ZI[XI < logical_or(X[1,end()],XI) > logical_or(X[1],YI) < logical_or(Y[end()],YI) > Y[1]]=extrap
# /home/lei/octave-4.0.2/scripts/general/interp2.m:332
    
    return ZI
    
if __name__ == '__main__':
    pass
    
    
@function
def isgriddata(X=None,*args,**kwargs):
    varargin = isgriddata.varargin
    nargin = isgriddata.nargin

    d1=diff(X,1,1)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:339
    b=all(ravel(d1) == 0)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:340
    return b
    
if __name__ == '__main__':
    pass
    
    ## Compute the bicubic interpolation coefficients
    
@function
def bc(x=None,*args,**kwargs):
    varargin = bc.varargin
    nargin = bc.nargin

    x=abs(x)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:345
    o=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:346
    idx1=(x < 1)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:347
    idx2=logical_and(logical_not(idx1),(x < 2))
# /home/lei/octave-4.0.2/scripts/general/interp2.m:348
    o[idx1]=1 - dot(2.0,x[idx1] ** 2) + x[idx1] ** 3
# /home/lei/octave-4.0.2/scripts/general/interp2.m:349
    o[idx2]=4 - dot(8.0,x[idx2]) + dot(5.0,x[idx2] ** 2) - x[idx2] ** 3
# /home/lei/octave-4.0.2/scripts/general/interp2.m:350
    return o
    
if __name__ == '__main__':
    pass
    
    ## This version of sub2ind behaves as if the data was symmetrically padded
    
@function
def sym_sub2ind(sz=None,Y=None,X=None,*args,**kwargs):
    varargin = sym_sub2ind.varargin
    nargin = sym_sub2ind.nargin

    Y[Y < 1]=1 - Y[Y < 1]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:355
    while (any(ravel(Y) > dot(2,sz[1]))):

        Y[Y > dot(2,sz[1])]=round(Y[Y > dot(2,sz[1])] / 2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:357

    
    Y[Y > sz[1]]=1 + dot(2,sz[1]) - Y[Y > sz[1]]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:359
    X[X < 1]=1 - X[X < 1]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:360
    while (any(ravel(X) > dot(2,sz[2]))):

        X[X > dot(2,sz[2])]=round(X[X > dot(2,sz[2])] / 2)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:362

    
    X[X > sz[2]]=1 + dot(2,sz[2]) - X[X > sz[2]]
# /home/lei/octave-4.0.2/scripts/general/interp2.m:364
    ind=sub2ind(sz,Y,X)
# /home/lei/octave-4.0.2/scripts/general/interp2.m:365
    return ind
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## 'pchip' commented out since it is the same as 'cubic'
    
    
    
    
    
    
    
    
    
    
    ## 'pchip' commented out since it is the same as 'cubic'
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## re-order monotonically decreasing (bug #41838).
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1998-2015 Walter Gautschi
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} quadl (@var{f}, @var{a}, @var{b})
## @deftypefnx {Function File} {@var{q} =} quadl (@var{f}, @var{a}, @var{b}, @var{tol})
## @deftypefnx {Function File} {@var{q} =} quadl (@var{f}, @var{a}, @var{b}, @var{tol}, @var{trace})
## @deftypefnx {Function File} {@var{q} =} quadl (@var{f}, @var{a}, @var{b}, @var{tol}, @var{trace}, @var{p1}, @var{p2}, @dots{})
##
## Numerically evaluate the integral of @var{f} from @var{a} to @var{b} using
## an adaptive Lobatto rule.
##
## @var{f} is a function handle, inline function, or string containing the name
## of the function to evaluate.  The function @var{f} must be vectorized and
## return a vector of output values when given a vector of input values.
##
## @var{a} and @var{b} are the lower and upper limits of integration.  Both
## limits must be finite.
##
## The optional argument @var{tol} defines the relative tolerance with which
## to perform the integration.  The default value is @code{eps}.
##
## The algorithm used by @code{quadl} involves recursively subdividing the
## integration interval.  If @var{trace} is defined then for each subinterval
## display: (1) the left end of the subinterval, (2) the length of the
## subinterval, (3) the approximation of the integral over the subinterval.
##
## Additional arguments @var{p1}, etc., are passed directly to the function
## @var{f}.  To use default values for @var{tol} and @var{trace}, one may pass
## empty matrices ([]).
##
## Reference: @nospell{W. Gander and W. Gautschi}, @cite{Adaptive Quadrature -
## Revisited}, BIT Vol. 40, No. 1, March 2000, pp. 84--101.
## @url{http://www.inf.ethz.ch/personal/gander/}
## @seealso{quad, quadv, quadgk, quadcc, trapz, dblquad, triplequad}
## @end deftypefn
    
    ##   Author: Walter Gautschi
##   Date: 08/03/98
##   Reference: Gander, Computermathematik, Birkhaeuser, 1992.
    
    ## 2003-08-05 Shai Ayal
##   * permission from author to release as GPL
## 2004-02-10 Paul Kienzle
##   * renamed to quadl for compatibility
##   * replace global variable terminate2 with local function need_warning
##   * add paper ref to docs
    
    
@function
def quadl(f=None,a=None,b=None,tol=[],trace=false,varargin=None,*args,**kwargs):
    varargin = quadl.varargin
    nargin = quadl.nargin

    if (nargin < 3):
        print_usage()
    
    if (isa(a,'single') or isa(b,'single')):
        myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/general/quadl.m:71
    else:
        myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:73
    
    if (isempty(tol)):
        tol=copy(myeps)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:76
    
    if (isempty(trace)):
        trace=copy(false)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:79
    
    if (tol < myeps):
        tol=copy(myeps)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:82
    
    ## Track whether recursion has occurred
    global __quadl_recurse_done__
    __quadl_recurse_done__=copy(false)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:87
    
    global __quadl_need_warning__
    __quadl_need_warning__=copy(true)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:90
    m=(a + b) / 2
# /home/lei/octave-4.0.2/scripts/general/quadl.m:92
    h=(b - a) / 2
# /home/lei/octave-4.0.2/scripts/general/quadl.m:93
    alpha=sqrt(2 / 3)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:94
    beta=1 / sqrt(5)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:95
    x1=0.942882415695
# /home/lei/octave-4.0.2/scripts/general/quadl.m:97
    x2=0.641853342346
# /home/lei/octave-4.0.2/scripts/general/quadl.m:98
    x3=0.236383199662
# /home/lei/octave-4.0.2/scripts/general/quadl.m:99
    x=matlabarray(cat(a,m - dot(x1,h),m - dot(alpha,h),m - dot(x2,h),m - dot(beta,h),m - dot(x3,h),m,m + dot(x3,h),m + dot(beta,h),m + dot(x2,h),m + dot(alpha,h),m + dot(x1,h),b))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:101
    y=feval(f,x,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadl.m:104
    fa=y[1]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:106
    fb=y[13]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:107
    i2=dot((h / 6),(y[1] + y[13] + dot(5,(y[5] + y[9]))))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:109
    i1=dot((h / 1470),(dot(77,(y[1] + y[13])) + dot(432,(y[3] + y[11])) + dot(625,(y[5] + y[9])) + dot(672,y[7])))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:111
    is_=dot(h,(dot(0.0158271919735,(y[1] + y[13])) + dot(0.0942738402189,(y[2] + y[12])) + dot(0.155071987337,(y[3] + y[11])) + dot(0.18882157396,(y[4] + y[10])) + dot(0.199773405227,(y[5] + y[9])) + dot(0.224926465333,(y[6] + y[8])) + dot(0.242611071901,y[7])))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:116
    s=sign(is_)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:124
    if (s == 0):
        s=1
# /home/lei/octave-4.0.2/scripts/general/quadl.m:126
    
    erri1=abs(i1 - is_)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:128
    erri2=abs(i2 - is_)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:129
    if (erri2 != 0):
        R=erri1 / erri2
# /home/lei/octave-4.0.2/scripts/general/quadl.m:131
    else:
        R=1
# /home/lei/octave-4.0.2/scripts/general/quadl.m:133
    
    if (R > 0 and R < 1):
        tol=tol / R
# /home/lei/octave-4.0.2/scripts/general/quadl.m:136
    
    is_=dot(dot(s,abs(is_)),tol) / myeps
# /home/lei/octave-4.0.2/scripts/general/quadl.m:138
    if (is_ == 0):
        is_=b - a
# /home/lei/octave-4.0.2/scripts/general/quadl.m:140
    
    q=adaptlobstp(f,a,b,fa,fb,is_,trace,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadl.m:143
    return q
    
if __name__ == '__main__':
    pass
    
    ## ADAPTLOBSTP  Recursive function used by QUADL.
##
##   Q = ADAPTLOBSTP('F', A, B, FA, FB, IS, TRACE) tries to
##   approximate the integral of F(X) from A to B to
##   an appropriate relative error.  The argument 'F' is
##   a string containing the name of f.  The remaining
##   arguments are generated by ADAPTLOB or by recursion.
##
##   Walter Gautschi, 08/03/98
    
    
@function
def adaptlobstp(f=None,a=None,b=None,fa=None,fb=None,is_=None,trace=None,varargin=None,*args,**kwargs):
    varargin = adaptlobstp.varargin
    nargin = adaptlobstp.nargin

    global __quadl_recurse_done__
    global __quadl_need_warning__
    h=(b - a) / 2
# /home/lei/octave-4.0.2/scripts/general/quadl.m:161
    m=(a + b) / 2
# /home/lei/octave-4.0.2/scripts/general/quadl.m:162
    alpha=sqrt(2 / 3)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:163
    beta=1 / sqrt(5)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:164
    mll=m - dot(alpha,h)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:165
    ml=m - dot(beta,h)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:166
    mr=m + dot(beta,h)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:167
    mrr=m + dot(alpha,h)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:168
    x=matlabarray(cat(mll,ml,m,mr,mrr))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:169
    y=feval(f,x,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadl.m:170
    fmll=y[1]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:171
    fml=y[2]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:172
    fm=y[3]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:173
    fmr=y[4]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:174
    fmrr=y[5]
# /home/lei/octave-4.0.2/scripts/general/quadl.m:175
    i2=dot((h / 6),(fa + fb + dot(5,(fml + fmr))))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:176
    i1=dot((h / 1470),(dot(77,(fa + fb)) + dot(432,(fmll + fmrr)) + dot(625,(fml + fmr)) + dot(672,fm)))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:177
    if ((is_ + (i1 - i2) == is_ or mll <= a or b <= mrr) and __quadl_recurse_done__):
        if ((m <= a or b <= m) and __quadl_need_warning__):
            warning('quadl: interval contains no more machine number')
            warning('quadl: required tolerance may not be met')
            __quadl_need_warning__=copy(false)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:182
        q=copy(i1)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:184
        if (trace):
            disp(cat(a,b - a,q))
    else:
        __quadl_recurse_done__=copy(true)
# /home/lei/octave-4.0.2/scripts/general/quadl.m:189
        q=(adaptlobstp(f,a,mll,fa,fmll,is_,trace,varargin[:]) + adaptlobstp(f,mll,ml,fmll,fml,is_,trace,varargin[:]) + adaptlobstp(f,ml,m,fml,fm,is_,trace,varargin[:]) + adaptlobstp(f,m,mr,fm,fmr,is_,trace,varargin[:]) + adaptlobstp(f,mr,mrr,fmr,fmrr,is_,trace,varargin[:]) + adaptlobstp(f,mrr,b,fmrr,fb,is_,trace,varargin[:]))
# /home/lei/octave-4.0.2/scripts/general/quadl.m:190
    
    return q
    
if __name__ == '__main__':
    pass
    
    ## basic functionality
    
    ## the values here are very high so it may be unavoidable that this fails
    
    
    ## extra parameters
    
    
    ## test different tolerances.
    
    
    
    
    ## Copyright (C) 1998-2015 Ariel Tankus
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{r1}, @var{r2}, @dots{}, @var{rn}] =} deal (@var{a})
## @deftypefnx {Function File} {[@var{r1}, @var{r2}, @dots{}, @var{rn}] =} deal (@var{a1}, @var{a2}, @dots{}, @var{an})
##
## Copy the input parameters into the corresponding output parameters.
##
## If only a single input parameter is supplied, its value is copied to each
## of the outputs.
##
## For example,
##
## @example
## [a, b, c] = deal (x, y, z);
## @end example
##
## @noindent
## is equivalent to
##
## @example
## @group
## a = x;
## b = y;
## c = z;
## @end group
## @end example
##
## @noindent
## and
##
## @example
## [a, b, c] = deal (x);
## @end example
##
## @noindent
## is equivalent to
##
## @example
## a = b = c = x;
## @end example
##
## Programming Note: @code{deal} is often used with comma separated lists
## derived from cell arrays or structures.  This is unnecessary as the
## interpreter can perform the same action without the overhead of a function
## call.  For example:
##
## @example
## @group
## c = @{[1 2], "Three", 4@};
## [x, y, z ] = c@{:@}
## @result{}
##    x =
##
##       1   2
##
##    y = Three
##    z =  4
## @end group
## @end example
## @seealso{cell2struct, struct2cell, repmat}
## @end deftypefn
    
    ## Author: Ariel Tankus
## Author: Paul Kienzle and Etienne Grossman
## Created: 13.11.98
## Adapted-by: jwe
    
    
@function
def deal(varargin=None,*args,**kwargs):
    varargin = deal.varargin
    nargin = deal.nargin

    if (nargin == 0):
        print_usage()
    else:
        if (nargin == 1 or nargin == nargout):
            varargout[1:nargout]=varargin
# /home/lei/octave-4.0.2/scripts/general/deal.m:90
        else:
            error('deal: nargin > 1 and nargin != nargout')
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{c} =} bitget (@var{A}, @var{n})
## Return the status of bit(s) @var{n} of the unsigned integers in @var{A}.
##
## The least significant bit is @var{n} = 1.
##
## @example
## @group
## bitget (100, 8:-1:1)
## @result{} 0  1  1  0  0  1  0  0
## @end group
## @end example
## @seealso{bitand, bitor, bitxor, bitset, bitcmp, bitshift, bitmax}
## @end deftypefn
    
    ## Liberally based of the version by Kai Habel from octave-forge
    
    
@function
def bitget(A=None,n=None,*args,**kwargs):
    varargin = bitget.varargin
    nargin = bitget.nargin

    if (nargin != 2):
        print_usage()
    
    if (isa(A,'double')):
        Amax=ceil(log2(bitmax))
# /home/lei/octave-4.0.2/scripts/general/bitget.m:43
        _conv=double
# /home/lei/octave-4.0.2/scripts/general/bitget.m:44
    else:
        if (isa(A,'single')):
            Amax=ceil(log2(bitmax('single')))
# /home/lei/octave-4.0.2/scripts/general/bitget.m:46
            _conv=single
# /home/lei/octave-4.0.2/scripts/general/bitget.m:47
        else:
            if (isa(A,'uint8')):
                Amax=8
# /home/lei/octave-4.0.2/scripts/general/bitget.m:50
                _conv=uint8
# /home/lei/octave-4.0.2/scripts/general/bitget.m:51
            else:
                if (isa(A,'uint16')):
                    Amax=16
# /home/lei/octave-4.0.2/scripts/general/bitget.m:53
                    _conv=uint16
# /home/lei/octave-4.0.2/scripts/general/bitget.m:54
                else:
                    if (isa(A,'uint32')):
                        Amax=32
# /home/lei/octave-4.0.2/scripts/general/bitget.m:56
                        _conv=uint32
# /home/lei/octave-4.0.2/scripts/general/bitget.m:57
                    else:
                        if (isa(A,'uint64')):
                            Amax=64
# /home/lei/octave-4.0.2/scripts/general/bitget.m:59
                            _conv=uint64
# /home/lei/octave-4.0.2/scripts/general/bitget.m:60
                        else:
                            if (isa(A,'int8')):
                                Amax=8
# /home/lei/octave-4.0.2/scripts/general/bitget.m:62
                                _conv=int8
# /home/lei/octave-4.0.2/scripts/general/bitget.m:63
                            else:
                                if (isa(A,'int16')):
                                    Amax=16
# /home/lei/octave-4.0.2/scripts/general/bitget.m:65
                                    _conv=int16
# /home/lei/octave-4.0.2/scripts/general/bitget.m:66
                                else:
                                    if (isa(A,'int32')):
                                        Amax=32
# /home/lei/octave-4.0.2/scripts/general/bitget.m:68
                                        _conv=int32
# /home/lei/octave-4.0.2/scripts/general/bitget.m:69
                                    else:
                                        if (isa(A,'int64')):
                                            Amax=64
# /home/lei/octave-4.0.2/scripts/general/bitget.m:71
                                            _conv=int64
# /home/lei/octave-4.0.2/scripts/general/bitget.m:72
                                        else:
                                            error('bitget: invalid class %s',class_(A))
    
    m=double(ravel(n))
# /home/lei/octave-4.0.2/scripts/general/bitget.m:78
    if (any(m < 1) or any(m > Amax)):
        error('bitget: N must be in the range [1,%d]',Amax)
    
    C=bitand(A,bitshift(_conv[1],uint8(n) - uint8(1))) != _conv[0]
# /home/lei/octave-4.0.2/scripts/general/bitget.m:83
    return C
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} chop (@var{x}, @var{ndigits}, @var{base})
## Truncate elements of @var{x} to a length of @var{ndigits} such that the
## resulting numbers are exactly divisible by @var{base}.
##
## If @var{base} is not specified it defaults to 10.
##
## @example
## @group
## chop (-pi, 5, 10)
##    @result{} -3.14200000000000
## chop (-pi, 5, 5)
##    @result{} -3.14150000000000
## @end group
## @end example
## @end deftypefn
    
    
@function
def chop(x=None,ndigits=None,base=10,*args,**kwargs):
    varargin = chop.varargin
    nargin = chop.nargin

    if (nargin == 2 or nargin == 3):
        tmp=abs(x)
# /home/lei/octave-4.0.2/scripts/general/chop.m:39
        tmp[x == 0]=1
# /home/lei/octave-4.0.2/scripts/general/chop.m:42
        tmp=floor(log10(tmp) + 1)
# /home/lei/octave-4.0.2/scripts/general/chop.m:45
        ##
    ##   round (x .* inflate)
    ##
    ## produces an integer that contains the digits we want to keep.
    ## Multiplying by deflate puts the decimal back where it belngs.
    ##
    ## Further scaling and rounding with the base factor produces a
    ## value with ndigits exactly divisible by base.  We skip that step
    ## unless base was explicitly provided.
        inflate=10 ** (ndigits - tmp)
# /home/lei/octave-4.0.2/scripts/general/chop.m:58
        deflate=1 / inflate
# /home/lei/octave-4.0.2/scripts/general/chop.m:59
        if (nargin == 2):
            retval=multiply(deflate,round(multiply(x,inflate)))
# /home/lei/octave-4.0.2/scripts/general/chop.m:61
        else:
            retval=multiply(multiply(base,deflate),round(round(multiply(x,inflate)) / base))
# /home/lei/octave-4.0.2/scripts/general/chop.m:63
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 David Bateman
## Copyright (C) 2012 Alexander Klein
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} quadv (@var{f}, @var{a}, @var{b})
## @deftypefnx {Function File} {@var{q} =} quadv (@var{f}, @var{a}, @var{b}, @var{tol})
## @deftypefnx {Function File} {@var{q} =} quadv (@var{f}, @var{a}, @var{b}, @var{tol}, @var{trace})
## @deftypefnx {Function File} {@var{q} =} quadv (@var{f}, @var{a}, @var{b}, @var{tol}, @var{trace}, @var{p1}, @var{p2}, @dots{})
## @deftypefnx {Function File} {[@var{q}, @var{nfun}] =} quadv (@dots{})
##
## Numerically evaluate the integral of @var{f} from @var{a} to @var{b}
## using an adaptive Simpson's rule.
##
## @var{f} is a function handle, inline function, or string containing the name
## of the function to evaluate.  @code{quadv} is a vectorized version of
## @code{quad} and the function defined by @var{f} must accept a scalar or
## vector as input and return a scalar, vector, or array as output.
##
## @var{a} and @var{b} are the lower and upper limits of integration.  Both
## limits must be finite.
##
## The optional argument @var{tol} defines the absolute tolerance used to stop
## the adaptation procedure.  The default value is 1e-6.
##
## The algorithm used by @code{quadv} involves recursively subdividing the
## integration interval and applying Simpson's rule on each subinterval.
## If @var{trace} is true then after computing each of these partial
## integrals display: (1) the total number of function evaluations,
## (2) the left end of the subinterval, (3) the length of the subinterval,
## (4) the approximation of the integral over the subinterval.
##
## Additional arguments @var{p1}, etc., are passed directly to the function
## @var{f}.  To use default values for @var{tol} and @var{trace}, one may pass
## empty matrices ([]).
##
## The result of the integration is returned in @var{q}
##
## @var{nfun} indicates the number of function evaluations that were made.
##
## Note: @code{quadv} is written in Octave's scripting language and can be
## used recursively in @code{dblquad} and @code{triplequad}, unlike the
## @code{quad} function.
## @seealso{quad, quadl, quadgk, quadcc, trapz, dblquad, triplequad}
## @end deftypefn
    
    
@function
def quadv(f=None,a=None,b=None,tol=None,trace=None,varargin=None,*args,**kwargs):
    varargin = quadv.varargin
    nargin = quadv.nargin

    ## TODO: Make norm for convergence testing configurable
    
    if (nargin < 3):
        print_usage()
    
    if (nargin < 4):
        tol=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:69
    
    if (nargin < 5):
        trace=matlabarray([])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:72
    
    if (isa(a,'single') or isa(b,'single')):
        myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/general/quadv.m:75
    else:
        myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:77
    
    if (isempty(tol)):
        tol=1e-06
# /home/lei/octave-4.0.2/scripts/general/quadv.m:80
    
    if (isempty(trace)):
        trace=0
# /home/lei/octave-4.0.2/scripts/general/quadv.m:83
    
    ## Split the interval into 3 abscissa, and apply a 3 point Simpson's rule
    c=(a + b) / 2
# /home/lei/octave-4.0.2/scripts/general/quadv.m:87
    fa=feval(f,a,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:88
    fc=feval(f,c,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:89
    fb=feval(f,b,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:90
    nfun=3
# /home/lei/octave-4.0.2/scripts/general/quadv.m:91
    
    ## discussed in Shampine paper used to implement quadgk
    if (any(isinf(ravel(fa)))):
        fa=feval(f,a + dot(myeps,(b - a)),varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:96
    
    if (any(isinf(ravel(fb)))):
        fb=feval(f,b - dot(myeps,(b - a)),varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:99
    
    h=(b - a)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:102
    q=dot((b - a) / 6,(fa + dot(4,fc) + fb))
# /home/lei/octave-4.0.2/scripts/general/quadv.m:103
    q,nfun,hmin=simpsonstp(f,a,b,c,fa,fb,fc,q,nfun,abs(h),tol,trace,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:105
    if (nfun > 10000):
        warning('maximum iteration count reached')
    else:
        if (any(logical_not(isfinite(ravel(q))))):
            warning('infinite or NaN function evaluations were returned')
        else:
            if (hmin < dot((b - a),myeps)):
                warning('minimum step size reached -- possibly singular integral')
    
    return q,nfun
    
if __name__ == '__main__':
    pass
    
    
@function
def simpsonstp(f=None,a=None,b=None,c=None,fa=None,fb=None,fc=None,q0=None,nfun=None,hmin=None,tol=None,trace=None,varargin=None,*args,**kwargs):
    varargin = simpsonstp.varargin
    nargin = simpsonstp.nargin

    if (nfun > 10000):
        q=copy(q0)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:120
    else:
        d=(a + c) / 2
# /home/lei/octave-4.0.2/scripts/general/quadv.m:122
        e=(c + b) / 2
# /home/lei/octave-4.0.2/scripts/general/quadv.m:123
        fd=feval(f,d,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:124
        fe=feval(f,e,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/quadv.m:125
        nfun += 2
        q1=dot((c - a) / 6,(fa + dot(4,fd) + fc))
# /home/lei/octave-4.0.2/scripts/general/quadv.m:127
        q2=dot((b - c) / 6,(fc + dot(4,fe) + fb))
# /home/lei/octave-4.0.2/scripts/general/quadv.m:128
        q=q1 + q2
# /home/lei/octave-4.0.2/scripts/general/quadv.m:129
        if (abs(a - c) < hmin):
            hmin=abs(a - c)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:132
        if (trace):
            disp(cat(nfun,a,b - a,q))
        ## Force at least one adpative step.
    ## Not vectorizing q-q0 in the norm provides a more rigid criterion for
    ## matrix-valued functions.
        if (nfun == 5 or norm(q - q0,Inf) > tol):
            q1,nfun,hmin=simpsonstp(f,a,c,d,fa,fc,fd,q1,nfun,hmin,tol,trace,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:143
            q2,nfun,hmin=simpsonstp(f,c,b,e,fc,fb,fe,q2,nfun,hmin,tol,trace,varargin[:],nargout=3)
# /home/lei/octave-4.0.2/scripts/general/quadv.m:145
            q=q1 + q2
# /home/lei/octave-4.0.2/scripts/general/quadv.m:147
    
    return q,nfun,hmin
    
if __name__ == '__main__':
    pass
    
    
    
    ## Handles weak singularities at the edge
    
    ## Handles vector-valued functions
    
    ## Handles matrix-valued functions
    
    ## Copyright (C) 2000-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{dx} =} gradient (@var{m})
## @deftypefnx {Function File} {[@var{dx}, @var{dy}, @var{dz}, @dots{}] =} gradient (@var{m})
## @deftypefnx {Function File} {[@dots{}] =} gradient (@var{m}, @var{s})
## @deftypefnx {Function File} {[@dots{}] =} gradient (@var{m}, @var{x}, @var{y}, @var{z}, @dots{})
## @deftypefnx {Function File} {[@dots{}] =} gradient (@var{f}, @var{x0})
## @deftypefnx {Function File} {[@dots{}] =} gradient (@var{f}, @var{x0}, @var{s})
## @deftypefnx {Function File} {[@dots{}] =} gradient (@var{f}, @var{x0}, @var{x}, @var{y}, @dots{})
##
## Calculate the gradient of sampled data or a function.
##
## If @var{m} is a vector, calculate the one-dimensional gradient of @var{m}.
## If @var{m} is a matrix the gradient is calculated for each dimension.
##
## @code{[@var{dx}, @var{dy}] = gradient (@var{m})} calculates the
## one-dimensional gradient for @var{x} and @var{y} direction if @var{m} is a
## matrix.  Additional return arguments can be use for multi-dimensional
## matrices.
##
## A constant spacing between two points can be provided by the @var{s}
## parameter.  If @var{s} is a scalar, it is assumed to be the spacing for all
## dimensions.  Otherwise, separate values of the spacing can be supplied by
## the @var{x}, @dots{} arguments.  Scalar values specify an equidistant
## spacing.  Vector values for the @var{x}, @dots{} arguments specify the
## coordinate for that dimension.  The length must match their respective
## dimension of @var{m}.
##
## At boundary points a linear extrapolation is applied.  Interior points
## are calculated with the first approximation of the numerical gradient
##
## @example
## y'(i) = 1/(x(i+1)-x(i-1)) * (y(i-1)-y(i+1)).
## @end example
##
## If the first argument @var{f} is a function handle, the gradient of the
## function at the points in @var{x0} is approximated using central difference.
## For example, @code{gradient (@@cos, 0)} approximates the gradient of the
## cosine function in the point @math{x0 = 0}.  As with sampled data, the
## spacing values between the points from which the gradient is estimated can
## be set via the @var{s} or @var{dx}, @var{dy}, @dots{} arguments.  By default
## a spacing of 1 is used.
## @seealso{diff, del2}
## @end deftypefn
    
    ## Author:  Kai Habel <kai.habel@gmx.de>
## Modified: David Bateman <dbateman@free.fr> Added NDArray support
    
    
@function
def gradient(m=None,varargin=None,*args,**kwargs):
    varargin = gradient.varargin
    nargin = gradient.nargin

    if (nargin < 1):
        print_usage()
    
    nargout_with_ans=max(1,nargout)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:72
    if (isnumeric(m)):
        varargout[1:nargout_with_ans]=matrix_gradient(m,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/gradient.m:74
    else:
        if (isa(m,'function_handle')):
            varargout[1:nargout_with_ans]=handle_gradient(m,varargin[:])
# /home/lei/octave-4.0.2/scripts/general/gradient.m:76
        else:
            if (ischar(m)):
                varargout[1:nargout_with_ans]=handle_gradient(str2func(m),varargin[:])
# /home/lei/octave-4.0.2/scripts/general/gradient.m:78
            else:
                error('gradient: first input must be an array or a function')
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def matrix_gradient(m=None,varargin=None,*args,**kwargs):
    varargin = matrix_gradient.varargin
    nargin = matrix_gradient.nargin

    transposed=copy(false)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:87
    if (isvector(m)):
        ## make a row vector.
        transposed=(columns(m) == 1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:90
        m=ravel(m).T
# /home/lei/octave-4.0.2/scripts/general/gradient.m:91
    
    nd=ndims(m)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:94
    sz=size(m)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:95
    if (length(sz) > 1):
        tmp=sz[1]
# /home/lei/octave-4.0.2/scripts/general/gradient.m:97
        sz[1]=sz[2]
# /home/lei/octave-4.0.2/scripts/general/gradient.m:97
        sz[2]=tmp
# /home/lei/octave-4.0.2/scripts/general/gradient.m:97
    
    if (nargin > 2 and nargin != nd + 1):
        print_usage()
    
    ## cell d stores a spacing vector for each dimension
    d=cell(1,nd)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:105
    if (nargin == 1):
        ## no spacing given - assume 1.0 for all dimensions
        for i in arange(1,nd).reshape(-1):
            d[i]=ones(sz[i] - 1,1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:109
    else:
        if (nargin == 2):
            if (isscalar(varargin[1])):
                ## single scalar value for all dimensions
                for i in arange(1,nd).reshape(-1):
                    d[i]=dot(varargin[1],ones(sz[i] - 1,1))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:115
            else:
                ## vector for one-dimensional derivative
                d[1]=diff(ravel(varargin[1]))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:119
        else:
            ## have spacing value for each dimension
            if (length(varargin) != nd):
                error('gradient: dimensions and number of spacing values do not match')
            for i in arange(1,nd).reshape(-1):
                if (isscalar(varargin[i])):
                    d[i]=dot(varargin[i],ones(sz[i] - 1,1))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:128
                else:
                    d[i]=diff(ravel(varargin[i]))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:130
    
    m=shiftdim(m,1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:135
    for i in arange(1,min(nd,nargout)).reshape(-1):
        mr=rows(m)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:137
        mc=numel(m) / mr
# /home/lei/octave-4.0.2/scripts/general/gradient.m:138
        Y=zeros(size(m),class_(m))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:139
        if (mr > 1):
            ## Top and bottom boundary.
            Y[1,:]=diff(m[1:2,:]) / d[i](1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:143
            Y[mr,:]=diff(m[mr - 1:mr,:] / d[i](mr - 1))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:144
        if (mr > 2):
            ## Interior points.
            Y[2:mr - 1,:]=((m[3:mr,:] - m[1:mr - 2,:]) / kron(d[i](arange(1,mr - 2)) + d[i](arange(2,mr - 1)),ones(1,mc)))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:149
        ## turn multi-dimensional matrix in a way, that gradient
    ## along x-direction is calculated first then y, z, ...
        if (i == 1):
            varargout[i]=shiftdim(Y,nd - 1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:157
            m=shiftdim(m,nd - 1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:158
        else:
            if (i == 2):
                varargout[i]=Y
# /home/lei/octave-4.0.2/scripts/general/gradient.m:160
                m=shiftdim(m,2)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:161
            else:
                varargout[i]=shiftdim(Y,nd - i + 1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:163
                m=shiftdim(m,1)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:164
    
    if (transposed):
        varargout[1]=varargout[1].T
# /home/lei/octave-4.0.2/scripts/general/gradient.m:169
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
@function
def handle_gradient(f=None,p0=None,varargin=None,*args,**kwargs):
    varargin = handle_gradient.varargin
    nargin = handle_gradient.nargin

    ## Input checking
    p0_size=size(p0)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:175
    if (numel(p0_size) != 2):
        error('gradient: the second input argument should either be a vector or a matrix')
    
    if (any(p0_size == 1)):
        p0=ravel(p0)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:182
        dim=1
# /home/lei/octave-4.0.2/scripts/general/gradient.m:183
        num_points=numel(p0)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:184
    else:
        num_points=p0_size[1]
# /home/lei/octave-4.0.2/scripts/general/gradient.m:186
        dim=p0_size[2]
# /home/lei/octave-4.0.2/scripts/general/gradient.m:187
    
    if (length(varargin) == 0):
        delta=1
# /home/lei/octave-4.0.2/scripts/general/gradient.m:191
    else:
        if (length(varargin) == 1 or length(varargin) == dim):
            try:
                delta=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:194
            finally:
                pass
        else:
            error('gradient: incorrect number of spacing parameters')
    
    if (isscalar(delta)):
        delta=repmat(delta,1,dim)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:203
    else:
        if (logical_not(isvector(delta))):
            error('gradient: spacing values must be scalars or a vector')
    
    ## Calculate the gradient
    p0=mat2cell(p0,num_points,ones(1,dim))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:209
    varargout=cell(1,dim)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:210
    for d in arange(1,dim).reshape(-1):
        s=delta[d]
# /home/lei/octave-4.0.2/scripts/general/gradient.m:212
        df_dx=(f[p0[1:d - 1],p0[d] + s,p0[d + 1:end()]] - f[p0[1:d - 1],p0[d] - s,p0[d + 1:end()]]) / (dot(2,s))
# /home/lei/octave-4.0.2/scripts/general/gradient.m:213
        if (dim == 1):
            varargout[d]=reshape(df_dx,p0_size)
# /home/lei/octave-4.0.2/scripts/general/gradient.m:216
        else:
            varargout[d]=df_dx
# /home/lei/octave-4.0.2/scripts/general/gradient.m:218
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2004-2015 David Bateman
## Copyright (C) 2012 Jordi Gutirrez Hermoso
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{C} =} bitset (@var{A}, @var{n})
## @deftypefnx {Function File} {@var{C} =} bitset (@var{A}, @var{n}, @var{val})
## Set or reset bit(s) @var{n} of the unsigned integers in @var{A}.
##
## @var{val} = 0 resets and @var{val} = 1 sets the bits.
## The least significant bit is @var{n} = 1.  All variables must be the same
## size or scalars.
##
## @example
## @group
## dec2bin (bitset (10, 1))
##   @result{} 1011
## @end group
## @end example
## @seealso{bitand, bitor, bitxor, bitget, bitcmp, bitshift, bitmax}
## @end deftypefn
    
    
@function
def bitset(A=None,n=None,val=None,*args,**kwargs):
    varargin = bitset.varargin
    nargin = bitset.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (any(ravel(A) < 0)):
        error('bitset: A must be >= 0')
    
    sz=size(A)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:48
    if (nargin == 2):
        val=true(sz)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:51
    
    cl=class_(A)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:54
    if (isfloat(A) and isreal(A)):
        Bmax=bitmax(cl)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:57
        Amax=ceil(log2(Bmax))
# /home/lei/octave-4.0.2/scripts/general/bitset.m:58
    else:
        if (isinteger(A)):
            Bmax=intmax(cl)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:60
            Amax=ceil(log2(Bmax))
# /home/lei/octave-4.0.2/scripts/general/bitset.m:61
        else:
            error('bitset: invalid class %s',cl)
    
    if (any(ravel((n < 1))) or any(ravel((n > Amax)))):
        error('bitset: N must be in the range [1,%d]',Amax)
    
    mask=bitshift(cast(1,cl),uint8(n) - uint8(1))
# /home/lei/octave-4.0.2/scripts/general/bitset.m:70
    on=logical(val)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:72
    off=logical_not(on)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:73
    if (isscalar(mask)):
        onmask=copy(mask)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:76
        offmask=copy(mask)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:77
    else:
        if (logical_not(size_equal(A,n))):
            error('bitset: N must be scalar or the same size as A')
        onmask=mask[on]
# /home/lei/octave-4.0.2/scripts/general/bitset.m:82
        offmask=mask[off]
# /home/lei/octave-4.0.2/scripts/general/bitset.m:83
    
    C=zeros(sz,cl)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:86
    C[on]=bitor(A[on],onmask)
# /home/lei/octave-4.0.2/scripts/general/bitset.m:87
    C[off]=bitand(A[off],bitcmp(offmask))
# /home/lei/octave-4.0.2/scripts/general/bitset.m:88
    return C
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Bug #36458
    
    
    ## Copyright (C) 1999-2015 David M. Doolin
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} polyarea (@var{x}, @var{y})
## @deftypefnx {Function File} {} polyarea (@var{x}, @var{y}, @var{dim})
##
## Determine area of a polygon by triangle method.
##
## The variables @var{x} and @var{y} define the vertex pairs, and must
## therefore have the same shape.  They can be either vectors or arrays.  If
## they are arrays then the columns of @var{x} and @var{y} are treated
## separately and an area returned for each.
##
## If the optional @var{dim} argument is given, then @code{polyarea} works
## along this dimension of the arrays @var{x} and @var{y}.
##
## @end deftypefn
    
    ## todo:  Add moments for centroid, etc.
##
## bugs and limitations:
##        Probably ought to be an optional check to make sure that
##        traversing the vertices doesn't make any sides cross
##        (Is simple closed curve the technical definition of this?).
    
    ## Author: David M. Doolin <doolin@ce.berkeley.edu>
## Date: 1999-04-14
## Modified-by:
##    2000-01-15 Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
##    * use matlab compatible interface
##    * return absolute value of area so traversal order doesn't matter
##    2005-10-13 Torsten Finke
##    * optimization saving half the sums and multiplies
    
    
@function
def polyarea(x=None,y=None,dim=None,*args,**kwargs):
    varargin = polyarea.varargin
    nargin = polyarea.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    else:
        if (size_equal(x,y)):
            if (nargin == 2):
                a=abs(sum(multiply(x,(shift(y,- 1) - shift(y,1))))) / 2
# /home/lei/octave-4.0.2/scripts/general/polyarea.m:56
            else:
                a=abs(sum(multiply(x,(shift(y,- 1,dim) - shift(y,1,dim))),dim)) / 2
# /home/lei/octave-4.0.2/scripts/general/polyarea.m:58
        else:
            error('polyarea: X and Y must have the same shape')
    
    return a
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} postpad (@var{x}, @var{l})
## @deftypefnx {Function File} {} postpad (@var{x}, @var{l}, @var{c})
## @deftypefnx {Function File} {} postpad (@var{x}, @var{l}, @var{c}, @var{dim})
## Append the scalar value @var{c} to the vector @var{x} until it is of length
## @var{l}.  If @var{c} is not given, a value of 0 is used.
##
## If @code{length (@var{x}) > @var{l}}, elements from the end of @var{x} are
## removed until a vector of length @var{l} is obtained.
##
## If @var{x} is a matrix, elements are appended or removed from each row.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## If @var{dim} is larger than the dimensions of @var{x}, the result will have
## @var{dim} dimensions.
## @seealso{prepad, cat, resize}
## @end deftypefn
    
    ## Author: Tony Richardson <arichard@stark.cc.oh.us>
## Created: June 1994
    
    
@function
def postpad(x=None,l=None,c=None,dim=None,*args,**kwargs):
    varargin = postpad.varargin
    nargin = postpad.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (nargin < 3 or isempty(c)):
        c=0
# /home/lei/octave-4.0.2/scripts/general/postpad.m:48
    else:
        if (logical_not(isscalar(c))):
            error('postpad: third argument must be empty or a scalar')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/general/postpad.m:55
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/general/postpad.m:56
    if (nargin < 4):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/general/postpad.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim) and dim >= 1))):
            error('postpad: DIM must be an integer and a valid dimension')
    
    if (logical_not(isscalar(l)) or l < 0):
        error('postpad: second argument must be a positive scaler')
    
    if (dim > nd):
        sz[nd + 1:dim]=1
# /home/lei/octave-4.0.2/scripts/general/postpad.m:71
    
    d=sz[dim]
# /home/lei/octave-4.0.2/scripts/general/postpad.m:74
    if (d >= l):
        idx=repmat(cellarray([':']),nd,1)
# /home/lei/octave-4.0.2/scripts/general/postpad.m:77
        idx[dim]=arange(1,l)
# /home/lei/octave-4.0.2/scripts/general/postpad.m:78
        y=x[idx[:]]
# /home/lei/octave-4.0.2/scripts/general/postpad.m:79
    else:
        sz[dim]=l - d
# /home/lei/octave-4.0.2/scripts/general/postpad.m:81
        y=cat(dim,x,c[ones(sz)])
# /home/lei/octave-4.0.2/scripts/general/postpad.m:82
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} errordlg (@var{msg})
## @deftypefnx {Function File} {@var{h} =} errordlg (@var{msg}, @var{title})
## @deftypefnx {Function File} {@var{h} =} errordlg (@var{msg}, @var{title}, @var{createmode})
## Display @var{msg} using an error dialog box.
##
## The message may have multiple lines separated by newline characters ("\n"),
## or it may be a cellstr array with one element for each line.
##
## The optional input @var{title} (character string) can be used to set the
## dialog caption.  The default title is @qcode{"Error Dialog"}.
##
## The return value is always 1.
##
## Compatibility Note: The optional argument @var{createmode} is accepted for
## @sc{matlab} compatibility, but is not implemented.
##
## @seealso{helpdlg, inputdlg, listdlg, msgbox, questdlg, warndlg}
## @end deftypefn
    
    
@function
def errordlg(msg=None,title='Error Dialog',varargin=None,*args,**kwargs):
    varargin = errordlg.varargin
    nargin = errordlg.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    retval=message_dialog('errordlg',msg,title,'error',varargin[:])
# /home/lei/octave-4.0.2/scripts/gui/errordlg.m:45
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uicontrol (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uicontrol (@var{parent}, @var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} uicontrol (@var{h})
##
## Create a uicontrol object and return a handle to it.
##
## uicontrols are used to create simple interactive controls such as push buttons, checkboxes, edit and list controls.
##
## If @var{parent} is omitted then a uicontrol for the current figure is
## created. If no figure is available, a new figure is created first. 
##
## If @var{parent} is given then a uicontrol relative to @var{parent} is created. 
## 
## Any provided property value pairs will override the default values of the created 
## uicontrol object. 
##
## Control of the type of uicontrol created is through the use of the @var{style} property.
## If no style property is provided, a push button will be created.
##
## Valid styles for uicontrol are:
##
## @table @asis
## @item @qcode{"checkbox"}
## Create a checkbox control that allows user on/off selection.
##
## @item @qcode{"edit"}
## Create a edit control that allows user input of single or multiple lines of text.
##
## @item @qcode{"listbox"}
## Create a listbox control that displays a lit of items and allows user slelection of 
## single or multiple items.
##
## @item @qcode{"popupmenu"}
## Create a popupmenu control that displays a list of options that can be selected 
## when the user clicks on the control.
##
## @item @qcode{"pushbutton"}
## Create a push button control that allows user to press to cause an action.
##
## @item @qcode{"radiobutton"}
## Create a radio button control intended to be used for mutually exclusive input in a group of
## of radiobutton controls.
##
## @item @qcode{"slider"}
## Create a slider control that allows user selection from a range of values by sliding 
## knob on the control.
##
## @item @qcode{"text"}
## Create a static text control to display single or multiple lines of text.
##
## @item @qcode{"togglebutton"}
## Create a toggle button control that appears like a push button but allows the user to 
## select between two states.
##
## @end table
##
## Examples:
##
## @example
## @group
## # create figure and panel on it
## f = figure;
## # create a button (default style)
## b1 = uicontrol (f, "string", "A Button", "position",[10 10 150 40]);
## # create an edit control
## e1 = uicontrol (f, "style", "edit", "string", "editable text", "position",[10 60 300 40]);
## # create a checkbox
## c1 = uicontrol (f, "style", "checkbox", "string", "a checkbox", "position",[10 120 150 40]);
## @end group
## @end example
## @seealso{figure, uipanel}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uicontrol(varargin=None,*args,**kwargs):
    varargin = uicontrol.varargin
    nargin = uicontrol.nargin

    if (nargin == 1 and ishandle(varargin[1]) and strcmpi(get(varargin[1],'type'),'uicontrol')):
        error('uicontrol focusing not implemented yet.')
    
    h,args=__uiobject_split_args__('uicontrol',varargin,cellarray(['figure','uipanel','uibuttongroup']),nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uicontrol.m:102
    hui=__go_uicontrol__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uicontrol.m:104
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{data} =} guidata (@var{h})
## @deftypefnx {Function File} {} guidata (@var{h}, @var{data})
## Query or set user-custom GUI data.
##
## The GUI data is stored in the figure handle @var{h}.  If @var{h} is not a
## figure handle then it's parent figure will be used for storage.
##
## @var{data} must be a single object which means it is usually preferable
## for it to be a data container such as a cell array or struct so that
## additional data items can be added easily.
##
## @seealso{getappdata, setappdata, get, set, getpref, setpref}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def guidata(h=None,data=None,*args,**kwargs):
    varargin = guidata.varargin
    nargin = guidata.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(ishandle(h))):
        error('guidata: H must be a valid object handle')
    
    h=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/gui/guidata.m:45
    if (isempty(h)):
        error('guidata: no ancestor figure of H found')
    
    if (nargin == 1):
        dataout=get(h,'__guidata__')
# /home/lei/octave-4.0.2/scripts/gui/guidata.m:51
    else:
        set(h,'__guidata__',data)
        if (nargout == 1):
            dataout=copy(data)
# /home/lei/octave-4.0.2/scripts/gui/guidata.m:55
    
    return dataout
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uitoggletool (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uitoggletool (@var{parent}, @var{property}, @var{value}, @dots{})
##
## Create a uitoggletool object and return a handle to it.
##
## uitoggletool are togglebuttons that appear on a figure toolbar. The button is created with a border that
## is shown when the user hovers over the button. An image can be set using the cdata property.
##
## If @var{parent} is omitted then a uitoggletool for the current figure is
## created. If no figure is available, a new figure is created first.  If a figure is
## available, but does not contain a uitoolbar, a uitoolbar will be created.
##
## If @var{parent} is given then a uitoggletool is created on the @var{parent} uitoolbar. 
## 
## Any provided property value pairs will override the default values of the created 
## uitoggletool object.
##
## Examples:
##
## @example
## @group
## # create figure without a default toolbar
## f = figure ("toolbar", "none");
## # create empty toolbar
## t = uitoolbar (f);
## # create a 19x19x3 black square
## img=zeros(19,19,3);
## # add uitoggletool button to toolbar
## b = uitoggletool (t, "cdata", img);
## @end group
## @end example
## @seealso{figure, uitoolbar, uipushtool}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uitoggletool(varargin=None,*args,**kwargs):
    varargin = uitoggletool.varargin
    nargin = uitoggletool.nargin

    h,args=__uiobject_split_args__('uitoggletool',varargin,cellarray(['uitoolbar']),0,nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uitoggletool.m:58
    if (isempty(h)):
        h=findobj(gcf,'-depth',1,'type','uitoolbar')
# /home/lei/octave-4.0.2/scripts/gui/uitoggletool.m:61
        if (isempty(h)):
            h=uitoolbar()
# /home/lei/octave-4.0.2/scripts/gui/uitoggletool.m:63
        else:
            h=h[1]
# /home/lei/octave-4.0.2/scripts/gui/uitoggletool.m:65
    
    hui=__go_uitoggletool__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uitoggletool.m:68
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{sel}, @var{ok}] =} listdlg (@var{key}, @var{value}, @dots{})
## Return user inputs from a list dialog box in a vector of selection indices
## @var{sel} and a flag @var{ok} indicating how the user closed the dialog
## box.
##
## The value of @var{ok} is 1 if the user closed the box with the OK button,
## otherwise it is 0 and @var{sel} is empty.
##
## The indices in @var{sel} are 1-based.
##
## The arguments are specified in form of @var{key}, @var{value} pairs.
## The @qcode{"ListString"} argument pair must be specified.
##
## Valid @var{key} and @var{value} pairs are:
##
## @table @asis
## @item @qcode{"ListString"}
## a cell array of strings comprising the content of the list.
##
## @item @qcode{"SelectionMode"}
## can be either @qcode{"Single"} or @qcode{"Multiple"} (default).
##
## @item @qcode{"ListSize"}
## a vector with two elements @var{width} and @var{height} defining the size
## of the list field in pixels.  Default is [160 300].
##
## @item @qcode{"InitialValue"}
## a vector containing 1-based indices of preselected elements.
## Default is 1 (first item).
##
## @item @qcode{"Name"}
## a string to be used as the dialog caption.  Default is "".
##
## @item @qcode{"PromptString"}
## a cell array of strings to be displayed above the list field.
## Default is @{@}.
##
## @item @qcode{"OKString"}
## a string used to label the OK button.  Default is @qcode{"OK"}.
##
## @item @qcode{"CancelString"}
## a string used to label the Cancel button.  Default is @qcode{"Cancel"}.
## @end table
##
## Example:
##
## @example
## @group
## [sel, ok] = listdlg ("ListString", @{"An item", "another", "yet another"@},
##                      "SelectionMode", "Multiple");
## if (ok == 1)
##   for i = 1:numel (sel)
##     disp (sel(i));
##   endfor
## endif
## @end group
## @end example
##
## @seealso{menu, errordlg, helpdlg, inputdlg, msgbox, questdlg, warndlg}
## @end deftypefn
    
    
@function
def listdlg(varargin=None,*args,**kwargs):
    varargin = listdlg.varargin
    nargin = listdlg.nargin

    if (nargin < 2):
        print_usage()
    
    listcell=cellarray([''])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:87
    selmode='Multiple'
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:88
    listsize=matlabarray(cat(160,300))
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:89
    initialvalue=1
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:90
    name=''
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:91
    prompt=cellarray([])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:92
    okstring='OK'
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:93
    cancelstring='Cancel'
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:94
    
    for i in arange(1,nargin - 1,2).reshape(-1):
        if (strcmpi(varargin[i],'ListString')):
            listcell=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:99
        else:
            if (strcmpi(varargin[i],'SelectionMode')):
                selmode=tolower(varargin[i + 1])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:101
            else:
                if (strcmpi(varargin[i],'ListSize')):
                    listsize=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:103
                else:
                    if (strcmpi(varargin[i],'InitialValue')):
                        initialvalue=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:105
                    else:
                        if (strcmpi(varargin[i],'Name')):
                            name=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:107
                        else:
                            if (strcmpi(varargin[i],'PromptString')):
                                prompt=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:109
                            else:
                                if (strcmpi(varargin[i],'OKString')):
                                    okstring=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:111
                                else:
                                    if (strcmpi(varargin[i],'CancelString')):
                                        cancelstring=varargin[i + 1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:113
    
    ## make sure prompt strings are a cell array
    if (logical_not(iscell(prompt))):
        prompt=cellarray([prompt])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:119
    
    ## make sure listcell strings are a cell array
    if (logical_not(iscell(listcell))):
        listcell=cellarray([listcell])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:124
    else:
        if (iscellstr(listcell[1])):
            listcell=listcell[1]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:126
    
    ## make sure valid selection mode
    if (logical_not(strcmpi(selmode,'multiple')) and logical_not(strcmpi(selmode,'single'))):
        error('listdlg: invalid SelectionMode')
    
    if (__octave_link_enabled__()):
        sel,ok=__octave_link_list_dialog__(listcell,selmode,listsize,initialvalue,name,prompt,okstring,cancelstring,nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:135
    else:
        if (__have_feature__('JAVA')):
            ## transform matrices to cell arrays of strings
    ## swap width and height to correct calling format for JDialogBox
            listsize=cellarray([num2str(listsize[2]),num2str(listsize[1])])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:141
            initialvalue=arrayfun(num2str,initialvalue,'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:142
            if (isempty(prompt)):
                prompt=cellarray([''])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:144
            ret=javaMethod('listdlg','org.octave.JDialogBox',listcell,selmode,listsize,initialvalue,name,prompt,okstring,cancelstring)
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:147
            if (numel(ret) > 0):
                sel=zeros(1,numel(ret))
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:152
                for i in arange(1,numel(ret)).reshape(-1):
                    sel[i]=ret[i]
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:155
                ok=1
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:157
            else:
                sel=matlabarray([])
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:159
                ok=0
# /home/lei/octave-4.0.2/scripts/gui/listdlg.m:160
        else:
            error('listdlg is not available in this version of Octave')
    
    return sel,ok
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uipanel (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uipanel (@var{parent}, "@var{property}, @var{value}, @dots{})
##
## Create a uipanel object and return a handle to it.
##
## uipanels are used as containers to group other uicontrol objects.
##
## If @var{parent} is omitted then a uipanel for the current figure is
## created. If no figure is available, a new figure is created first. 
##
## If @var{parent} is given then a uipanel relative to @var{parent} is created. 
## 
## Any provided property value pairs will override the default values of the created 
## uipanel object.
##
## Examples:
##
## @example
## @group
## # create figure and panel on it
## f = figure;
## p = uipanel ("title", "Panel Title", "position", [.25 .25 .5 .5]);
##
## # add two buttons to the panel
## b1 = uicontrol ("parent", p, "string", "A Button", "position",[18 10 150 36]);
## b2 = uicontrol ("parent", p, "string", "Another Button", "position",[18 60 150 36]);
##
## @end group
## @end example
## @seealso{figure, uicontrol}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uipanel(varargin=None,*args,**kwargs):
    varargin = uipanel.varargin
    nargin = uipanel.nargin

    h,args=__uiobject_split_args__('uipanel',varargin,cellarray(['figure','uipanel','uibuttongroup']),nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uipanel.m:56
    hui=__go_uipanel__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uipanel.m:58
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{hui} =} uicontextmenu (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uicontextmenu (@var{h}, @var{property}, @var{value}, @dots{})
##
## Create a uicontextmenu object and return a handle to it.
##
## If @var{h} is omitted then a uicontextmenu for the current figure is
## created. If no figure is available, a new figure is created first. 
##
## If @var{h} is given then a uicontextmenu relative to @var{h} is created. 
## 
## Any provided property value pairs will override the default values of the created 
## uicontextmenu object.
##
## Examples:
##
## @example
## @group
## # create figure and uicontextmenu
## f = figure;
## c = uicontextmenu (f);
##
## # create menus in the context menu
## m1 = uimenu ("parent",c,"label","Menu item 1","callback","disp('menu item 1')");
## m2 = uimenu ("parent",c,"label","Menu item 2","callback","disp('menu item 2')");
##
## # set the context menu for the figure
## set (f, "uicontextmenu", c);
## @end group
## @end example
## @seealso{figure, uimenu}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uicontextmenu(varargin=None,*args,**kwargs):
    varargin = uicontextmenu.varargin
    nargin = uicontextmenu.nargin

    h,args=__uiobject_split_args__('uicontextmenu',varargin,cellarray(['figure']),nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uicontextmenu.m:56
    hui=__go_uicontextmenu__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uicontextmenu.m:57
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} warndlg (@var{msg})
## @deftypefnx {Function File} {@var{h} =} warndlg (@var{msg}, @var{title})
## @deftypefnx {Function File} {@var{h} =} warndlg (@var{msg}, @var{title}, @var{createmode})
## Display @var{msg} using a warning dialog box.
##
## The message may have multiple lines separated by newline characters ("\n"),
## or it may be a cellstr array with one element for each line.
##
## The optional input @var{title} (character string) can be used to set the
## dialog caption.  The default title is @qcode{"Warning Dialog"}.
##
## The return value is always 1.
##
## Compatibility Note: The optional argument @var{createmode} is accepted for
## @sc{matlab} compatibility, but is not implemented.
##
## @seealso{helpdlg, inputdlg, listdlg, questdlg}
## @end deftypefn
    
    
@function
def warndlg(msg=None,title='Warning Dialog',varargin=None,*args,**kwargs):
    varargin = warndlg.varargin
    nargin = warndlg.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    retval=message_dialog('warndlg',msg,title,'warn',varargin[:])
# /home/lei/octave-4.0.2/scripts/gui/warndlg.m:45
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} uiresume (@var{h})
## Resume program execution suspended with @code{uiwait}.
##
## The handle @var{h} must be the same as the on specified in @code{uiwait}.
## If the handle is invalid or there is no @code{uiwait} call pending for the
## figure with handle @var{h}, this function does nothing.
## @seealso{uiwait}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uiresume(h=None,*args,**kwargs):
    varargin = uiresume.varargin
    nargin = uiresume.nargin

    if (logical_not(isfigure(h))):
        error('uiresume: invalid figure handle H')
    
    try:
        uiwait_state=get(h,'__uiwait_state__')
# /home/lei/octave-4.0.2/scripts/gui/uiresume.m:38
        if (strcmp(uiwait_state,'active')):
            set(h,'__uiwait_state__','triggered')
    finally:
        pass
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{btn} =} questdlg (@var{msg})
## @deftypefnx {Function File} {@var{btn} =} questdlg (@var{msg}, @var{title})
## @deftypefnx {Function File} {@var{btn} =} questdlg (@var{msg}, @var{title}, @var{default})
## @deftypefnx {Function File} {@var{btn} =} questdlg (@var{msg}, @var{title}, @var{btn1}, @var{btn2}, @var{default})
## @deftypefnx {Function File} {@var{btn} =} questdlg (@var{msg}, @var{title}, @var{btn1}, @var{btn2}, @var{btn3}, @var{default})
## Display @var{msg} using a question dialog box and return the caption of
## the activated button.
##
## The dialog may contain two or three buttons which will all close the dialog.
##
## The message may have multiple lines separated by newline characters ("\n"),
## or it may be a cellstr array with one element for each line.
##
## The optional @var{title} (character string) can be used to decorate the
## dialog caption.
##
## The string @var{default} identifies the default button, which is activated
## by pressing the @key{ENTER} key.  It must match one of the strings given
## in @var{btn1}, @var{btn2}, or @var{btn3}.
##
## If only @var{msg} and @var{title} are specified, three buttons with the
## default captions @qcode{"Yes"}, @qcode{"No"}, and @qcode{"Cancel"} are used.
##
## If only two button captions, @var{btn1} and @var{btn2}, are specified the
## dialog will have only these two buttons.
##
## @seealso{errordlg, helpdlg, inputdlg, listdlg, warndlg}
## @end deftypefn
    
    
@function
def questdlg(msg=None,title='Question Dialog',varargin=None,*args,**kwargs):
    varargin = questdlg.varargin
    nargin = questdlg.nargin

    if (nargin < 1 or nargin > 6):
        print_usage()
    
    if (logical_not(ischar(msg))):
        if (iscell(msg)):
            msg=sprintf('%s\n',msg[:])
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:57
            msg[end()]=''
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:58
        else:
            error('questdlg: MSG must be a character string or cellstr array')
    
    if (logical_not(ischar(title))):
        error('questdlg: TITLES must be a character string')
    
    options[1]='Yes'
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:68
    
    options[2]='No'
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:69
    
    options[3]='Cancel'
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:70
    
    options[4]='Yes'
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:71
    
    defbtn_error_msg='questdlg: DEFAULT must match one of the button options'
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:73
    if 0 == (numel(varargin)):
        ## use default default
        pass
    else:
        if 1 == (numel(varargin)):
            ## default button string
            options[4]=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:81
            if (logical_not(any(strcmp(options[4],options[1:3])))):
                error(defbtn_error_msg)
        else:
            if 3 == (numel(varargin)):
                ## two buttons and default button string
                options[1]=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:88
                options[2]=''
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:89
                options[3]=varargin[2]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:90
                options[4]=varargin[3]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:91
                if (logical_not(any(strcmp(options[4],options[cat(1,3)])))):
                    error(defbtn_error_msg)
            else:
                if 4 == (numel(varargin)):
                    ## three buttons and default button string
                    options[1]=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:98
                    options[2]=varargin[2]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:99
                    options[3]=varargin[3]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:100
                    options[4]=varargin[4]
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:101
                    if (logical_not(any(strcmp(options[4],options[1:3])))):
                        error(defbtn_error_msg)
                else:
                    print_usage()
    
    if (__octave_link_enabled__()):
        btn=__octave_link_question_dialog__(msg,title,options[1],options[2],options[3],options[4])
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:112
    else:
        if (__have_feature__('JAVA')):
            btn=javaMethod('questdlg','org.octave.JDialogBox',msg,title,options)
# /home/lei/octave-4.0.2/scripts/gui/questdlg.m:115
        else:
            error('questdlg is not available in this version of Octave')
    
    return btn
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uimenu (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uimenu (@var{h}, @var{property}, @var{value}, @dots{})
## Create a uimenu object and return a handle to it.
##
## If @var{h} is omitted then a top-level menu for the current figure is
## created.  If @var{h} is given then a submenu relative to @var{h} is created.
##
## uimenu objects have the following specific properties:
##
## @table @asis
## @item @qcode{"accelerator"}
## A string containing the key combination together with CTRL to execute this
## menu entry (e.g., @qcode{"x"} for CTRL+x).
##
## @item @qcode{"callback"}
## Is the function called when this menu entry is executed.  It can be either a
## function string (e.g., @qcode{"myfun"}), a function handle (e.g., @@myfun)
## or a cell array containing the function handle and arguments for the
## callback function (e.g., @{@@myfun, arg1, arg2@}).
##
## @item @qcode{"checked"}
## Can be set @qcode{"on"} or @qcode{"off"}.  Sets a mark at this menu entry.
##
## @item @qcode{"enable"}
## Can be set @qcode{"on"} or @qcode{"off"}.  If disabled the menu entry
## cannot be selected and it is grayed out.
##
## @item @qcode{"foregroundcolor"}
## A color value setting the text color for this menu entry.
##
## @item @qcode{"label"}
## A string containing the label for this menu entry.  A @qcode{"&"}-symbol
## can be used to mark the @qcode{"accelerator"} character (e.g.,
## @nospell{@qcode{"E&xit"}})
##
## @item @qcode{"position"}
## An scalar value containing the relative menu position.  The entry with the
## lowest value is at the first position starting from left or top.
##
## @item @qcode{"separator"}
## Can be set @qcode{"on"} or @qcode{"off"}.  If enabled it draws a separator
## line above the current position.  It is ignored for top level entries.
##
## @end table
##
## Examples:
##
## @example
## @group
## f = uimenu ("label", "&File", "accelerator", "f");
## e = uimenu ("label", "&Edit", "accelerator", "e");
## uimenu (f, "label", "Close", "accelerator", "q", ...
##            "callback", "close (gcf)");
## uimenu (e, "label", "Toggle &Grid", "accelerator", "g", ...
##            "callback", "grid (gca)");
## @end group
## @end example
## @seealso{figure}
## @end deftypefn
    
    ## Author: Kai Habel
    
    
@function
def uimenu(varargin=None,*args,**kwargs):
    varargin = uimenu.varargin
    nargin = uimenu.nargin

    h,args=__uiobject_split_args__('uimenu',varargin,cellarray(['figure','uicontextmenu','uimenu']),nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uimenu.m:84
    tmp=__go_uimenu__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uimenu.m:87
    if (nargout > 0):
        hui=copy(tmp)
# /home/lei/octave-4.0.2/scripts/gui/uimenu.m:90
    
    return hui
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## check for top level menus file and edit
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2010-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{dirname} =} uigetdir ()
## @deftypefnx {Function File} {@var{dirname} =} uigetdir (@var{init_path})
## @deftypefnx {Function File} {@var{dirname} =} uigetdir (@var{init_path}, @var{dialog_name})
## Open a GUI dialog for selecting a directory.
##
## If @var{init_path} is not given the current working directory is used.
##
## @var{dialog_name} may be used to customize the dialog title.
## @seealso{uigetfile, uiputfile}
## @end deftypefn
    
    ## Author: Kai Habel
    
    
@function
def uigetdir(init_path=pwd,dialog_name='Select Directory to Open',*args,**kwargs):
    varargin = uigetdir.varargin
    nargin = uigetdir.nargin

    if (nargin > 2):
        print_usage()
    
    if (logical_not(ischar(init_path)) or logical_not(ischar(dialog_name))):
        error('uigetdir: INIT_PATH and DIALOG_NAME must be string arguments')
    
    if (logical_not(isdir(init_path))):
        init_path=fileparts(init_path)
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:44
    
    if (__octave_link_enabled__()):
        file_filter=cell(0,2)
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:48
        default_file_name=''
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:49
        dialog_position=matlabarray(cat(240,120))
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:50
        dialog_mode='dir'
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:51
        filename,dirname,filterindex=__octave_link_file_dialog__(file_filter,dialog_name,default_file_name,dialog_position,dialog_mode,init_path,nargout=3)
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:54
    else:
        funcname=__get_funcname__(mfilename())
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:58
        dirname=feval(funcname,init_path,dialog_name)
# /home/lei/octave-4.0.2/scripts/gui/uigetdir.m:59
    
    return dirname
    
if __name__ == '__main__':
    pass
    
    
    
    ## Remove from test statistics.  No real tests possible.
    
    ## Copyright (C) 2012-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} waitbar (@var{frac})
## @deftypefnx {Function File} {@var{h} =} waitbar (@var{frac}, @var{msg})
## @deftypefnx {Function File} {@var{h} =} waitbar (@dots{}, "FigureProperty", "Value", @dots{})
## @deftypefnx {Function File} {} waitbar (@var{frac})
## @deftypefnx {Function File} {} waitbar (@var{frac}, @var{hwbar})
## @deftypefnx {Function File} {} waitbar (@var{frac}, @var{hwbar}, @var{msg})
## Return a handle @var{h} to a new waitbar object.
##
## The waitbar is filled to fraction @var{frac} which must be in the range
## [0, 1].
##
## The optional message @var{msg} is centered and displayed above the waitbar.
##
## The appearance of the waitbar figure window can be configured by passing
## property/value pairs to the function.
##
## When called with a single input the current waitbar, if it exists, is
## updated to the new value @var{frac}.  If there are multiple outstanding
## waitbars they can be updated individually by passing the handle @var{hwbar}
## of the specific waitbar to modify.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def waitbar(varargin=None,*args,**kwargs):
    varargin = waitbar.varargin
    nargin = waitbar.nargin

    
    if (nargin < 1):
        print_usage()
    
    frac=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:52
    varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:53
    if (logical_not((isnumeric(frac) and isscalar(frac) and frac >= 0 and frac <= 1))):
        error('waitbar: FRAC must be between 0 and 1')
    
    ## Use existing waitbar if it still points to a valid graphics handle.
    if (nargin == 1 and ishandle(curr_waitbar)):
        hf=copy(curr_waitbar)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:61
    else:
        hf=copy(false)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:63
    
    if (logical_not(isempty(varargin)) and isnumeric(varargin[1])):
        hf=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:67
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:68
        if (logical_not(isfigure(hf)) or logical_not(strcmp(get(hf,'tag'),'waitbar'))):
            error('waitbar: H must be a handle to a waitbar object')
    
    msg=copy(false)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:74
    if (logical_not(isempty(varargin))):
        msg=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:77
        varargin[1]=[]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:78
        if (logical_not((ischar(msg) or iscellstr(msg)))):
            error('waitbar: MSG must be a character string or cell array of strings')
    
    if (rem(numel(varargin),2) != 0):
        error('waitbar: invalid number of property/value pairs')
    
    if (hf):
        gd=get(hf,'__guidata__')
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:89
        ax=gd[1]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:91
        hp=gd[2]
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:92
        set(hp,'xdata',cat([0],[frac],[frac],[0]))
        if (ischar(msg) or iscellstr(msg)):
            th=get(ax,'title')
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:97
            curr_msg=get(th,'string')
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:98
            if (iscellstr(msg)):
                msg=ravel(msg)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:101
            cmp=strcmp(msg,curr_msg)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:103
            if (logical_not(all(ravel(cmp)))):
                set(th,'string',msg)
    else:
        ## Save and restore current figure
        cf=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:110
        hf=figure('units','pixels','position',cat(250,500,400,100),'numbertitle','off','menubar','none','toolbar','none','integerhandle','off','handlevisibility','callback','tag','waitbar',varargin[:])
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:112
        ax=axes('parent',hf,'xtick',[],'ytick',[],'xlim',cat(0,1),'ylim',cat(0,1),'position',cat(0.1,0.3,0.8,0.2))
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:121
        hp=patch(ax,cat([0],[frac],[frac],[0]),cat([0],[0],[1],[1]),cat(0,0.35,0.75))
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:126
        set(hf,'__guidata__',cat(ax,hp))
        if (logical_not((ischar(msg) or iscellstr(msg)))):
            msg='Please wait...'
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:132
        title(ax,msg)
        set(0,'currentfigure',cf)
    
    drawnow()
    if (nargout > 0):
        h=copy(hf)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:142
    
    ## If there were no errors, update current waitbar.
    curr_waitbar=copy(hf)
# /home/lei/octave-4.0.2/scripts/gui/waitbar.m:146
    return h
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 Petr Mikulik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} waitforbuttonpress ()
## @deftypefnx {Function File} {@var{b} =} waitforbuttonpress ()
## Wait for mouse click or key press over the current figure window.
##
## The return value of @var{b} is 0 if a mouse button was pressed or 1 if a
## key was pressed.
## @seealso{waitfor, ginput, kbhit}
## @end deftypefn
    
    ## The original version of this code bore the copyright
## Author: Petr Mikulik
## License: public domain
    
    
@function
def waitforbuttonpress(*args,**kwargs):
    varargin = waitforbuttonpress.varargin
    nargin = waitforbuttonpress.nargin

    if (nargin != 0 or nargout > 1):
        print_usage()
    
    x,y,k=ginput(1,nargout=3)
# /home/lei/octave-4.0.2/scripts/gui/waitforbuttonpress.m:39
    if (nargout == 1):
        if (k <= 5):
            b=0
# /home/lei/octave-4.0.2/scripts/gui/waitforbuttonpress.m:43
        else:
            b=1
# /home/lei/octave-4.0.2/scripts/gui/waitforbuttonpress.m:45
    
    return b
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hdata} =} guihandles (@var{h})
## @deftypefnx {Function File} {@var{hdata} =} guihandles
## Return a structure of object handles for the figure associated with
## handle @var{h}.
##
## If no handle is specified the current figure returned by @code{gcf} is used.
##
## The fieldname for each entry of @var{hdata} is taken from the @qcode{"tag"}
## property of the graphic object.  If the tag is empty then the handle is not
## returned.  If there are multiple graphic objects with the same tag then
## the entry in @var{hdata} will be a vector of handles.  @code{guihandles}
## includes all possible handles, including those for
## which @qcode{"HandleVisibility"} is @qcode{"off"}.
## @seealso{guidata, findobj, findall, allchild}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def guihandles(h=None,*args,**kwargs):
    varargin = guihandles.varargin
    nargin = guihandles.nargin

    if (nargin > 2):
        print_usage()
    
    if (nargin == 1):
        if (logical_not(ishandle(h))):
            error('guidata: H must be a valid object handle')
        h=ancestor(h,'figure')
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:48
        if (isempty(h)):
            error('guidata: no ancestor figure of H found')
    else:
        h=gcf()
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:53
    
    hdata=__make_guihandles_struct__(h,[])
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:56
    return hdata
    
if __name__ == '__main__':
    pass
    
    
@function
def __make_guihandles_struct__(h=None,hdata=None,*args,**kwargs):
    varargin = __make_guihandles_struct__.varargin
    nargin = __make_guihandles_struct__.nargin

    tag=get(h,'tag')
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:62
    if (logical_not(isempty(tag))):
        if (isfield(hdata,tag)):
            setattr(hdata,tag,cat(getattr(hdata,(tag)),h))
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:65
        else:
            try:
                setattr(hdata,tag,h)
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:68
            finally:
                pass
    
    kids=allchild(h)
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:74
    for hkid in kids.T.reshape(-1):
        hdata=__make_guihandles_struct__(hkid,hdata)
# /home/lei/octave-4.0.2/scripts/gui/guihandles.m:76
    
    return hdata
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{cstr} =} inputdlg (@var{prompt})
## @deftypefnx {Function File} {@var{cstr} =} inputdlg (@var{prompt}, @var{title})
## @deftypefnx {Function File} {@var{cstr} =} inputdlg (@var{prompt}, @var{title}, @var{rowscols})
## @deftypefnx {Function File} {@var{cstr} =} inputdlg (@var{prompt}, @var{title}, @var{rowscols}, @var{defaults})
## Return user input from a multi-textfield dialog box in a cell array of
## strings, or an empty cell array if the dialog is closed by the Cancel
## button.
##
## Inputs:
##
## @table @var
## @item prompt
## A cell array with strings labeling each text field.  This input is required.
##
## @item title
## String to use for the caption of the dialog.  The default is
## @qcode{"Input Dialog"}.
##
## @item rowscols
## Specifies the size of the text fields and can take three forms:
##
## @enumerate
## @item a scalar value which defines the number of rows used for each text field.
##
## @item a vector which defines the individual number of rows used for each text field.
##
## @item a matrix which defines the individual number of rows and columns used for each text field.  In the matrix each row describes a single text field.  The first column specifies the number of input rows to use and the second column specifies the text field width.
## @end enumerate
##
## @item defaults
## A list of default values to place in each text fields.  It must be a cell
## array of strings with the same size as @var{prompt}.
## @end table
## @seealso{errordlg, helpdlg, listdlg, msgbox, questdlg, warndlg}
## @end deftypefn
    
    
@function
def inputdlg(prompt=None,title='Input Dialog',varargin=None,*args,**kwargs):
    varargin = inputdlg.varargin
    nargin = inputdlg.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (iscell(prompt)):
        ## Silently extract only char elements
        prompt=prompt[cellfun('isclass',prompt,'char')]
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:64
    else:
        if (ischar(prompt)):
            prompt=cellarray([prompt])
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:66
        else:
            error('inputdlg: PROMPT must be a character string or cellstr array')
    
    if (logical_not(ischar(title))):
        error('inputdlg: TITLE must be a character string')
    
    if 0 == (numel(varargin)):
        linespec=1
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:77
        defaults=cellstr(cell(size(prompt)))
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:78
    else:
        if 1 == (numel(varargin)):
            linespec=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:81
            defaults=cellstr(cell(size(prompt)))
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:82
        else:
            if 2 == (numel(varargin)):
                linespec=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:85
                defaults=varargin[2]
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:86
    
    ## specification of text field sizes as in Matlab
  ## Matlab requires a matrix for linespec, not a cell array...
  ## rc = [1,10; 2,20; 3,30];
  ##     c1  c2
  ## r1  1   10   first  text field is 1x10
  ## r2  2   20   second text field is 2x20
  ## r3  3   30   third  text field is 3x30
    if (logical_not(isnumeric(linespec))):
        error('inputdlg: ROWSCOLS must be numeric')
    
    if (isscalar(linespec)):
        ## only scalar value in lineTo, copy from linespec and add defaults
        rowscols=zeros(numel(prompt),2)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:102
        rowscols[:,2]=25
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:104
        rowscols[:,1]=linespec
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:105
    else:
        if (isvector(linespec)):
            if (numel(linespec) == numel(prompt)):
                ## only one column in lineTo, copy from vector linespec and add defaults
                rowscols=zeros(numel(prompt),2)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:109
                rowscols[:,2]=25
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:111
                rowscols[:,1]=ravel(linespec)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:112
            else:
                error('inputdlg: ROWSCOLS vector does not match size of PROMPT')
        else:
            if (ismatrix(linespec)):
                if (rows(linespec) == columns(prompt) and columns(linespec) == 2):
                    ## (rows x columns) match, copy array linespec
                    rowscols=copy(linespec)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:119
                else:
                    error('inputdlg: ROWSCOLS matrix does not match size of PROMPT')
            else:
                ## dunno
                error('inputdlg: unknown form of ROWSCOLS argument')
    
    rowscols=ceil(rowscols)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:127
    
    defs=cellfun(num2str,defaults,'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:130
    rc=arrayfun(num2str,rowscols,'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:131
    if (__octave_link_enabled__()):
        cstr=__octave_link_input_dialog__(prompt,title,rowscols,defs)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:134
    else:
        if (__have_feature__('JAVA')):
            user_inputs=javaMethod('inputdlg','org.octave.JDialogBox',prompt,title,rc,defs)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:136
            if (isempty(user_inputs)):
                cstr=cellarray([])
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:139
            else:
                cstr=cellstr(user_inputs)
# /home/lei/octave-4.0.2/scripts/gui/inputdlg.m:141
        else:
            error('inputdlg is not available in this version of Octave')
    
    return cstr
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{dirname} =} __uigetdir_fltk__ (@var{start_path}, @var{dialog_title})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michael Goffioul
    
    
@function
def __uigetdir_fltk__(start_path=None,dialog_title=None,*args,**kwargs):
    varargin = __uigetdir_fltk__.varargin
    nargin = __uigetdir_fltk__.nargin

    if (exist('__fltk_uigetfile__') != 3):
        error('uigetdir: fltk graphics toolkit required')
    
    dirname=__fltk_uigetfile__('',dialog_title,start_path,cat(240,120),'dir')
# /home/lei/octave-4.0.2/scripts/gui/private/__uigetdir_fltk__.m:32
    return dirname
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{filterspec} =} __fltk_file_filter__ (@var{filter})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michael Goffioul
    
    
@function
def __fltk_file_filter__(file_filter=None,*args,**kwargs):
    varargin = __fltk_file_filter__.varargin
    nargin = __fltk_file_filter__.nargin

    retval=''
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:28
    r,c=size(file_filter,nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:29
    if ((c == 0) or (c > 2)):
        error('expecting 1 or to 2 columns for file filter cell')
    
    fltk_str=''
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:33
    for idx in arange(1,r).reshape(-1):
        curr_ext=file_filter[idx,1]
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:36
        curr_ext=ostrsplit(curr_ext,';')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:37
        if (length(curr_ext) > 1):
            curr_ext=regexprep(curr_ext,'\\*\\.',',')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:40
            curr_ext=strcat(curr_ext[:])(arange(2,end()))
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:41
            curr_ext=strcat('*.{',curr_ext,'}')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:42
        else:
            curr_ext=curr_ext[:]
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:44
        curr_desc=strcat(curr_ext[3:end()],'-Files')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:47
        if (c == 2):
            curr_desc=file_filter[idx,2]
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:50
            curr_desc=regexprep(curr_desc,'\\(','<')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:51
            curr_desc=regexprep(curr_desc,'\\)','>')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:52
        if (length(fltk_str) > 0):
            fltk_str=strcat(fltk_str,'\t',curr_desc,' (',curr_ext,')')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:56
        else:
            fltk_str=strcat(curr_desc,' (',curr_ext,')')
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:58
    
    retval=copy(fltk_str)
# /home/lei/octave-4.0.2/scripts/gui/private/__fltk_file_filter__.m:62
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{h} =} message_dialog (@var{caller}, @var{msg}, @var{title}, @var{icon}, @var{createmode})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def message_dialog(caller=None,msg=None,title='',icon=None,createmode=None,*args,**kwargs):
    varargin = message_dialog.varargin
    nargin = message_dialog.nargin

    if (logical_not(ischar(msg))):
        if (iscell(msg)):
            msg=sprintf('%s\n',msg[:])
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:28
            msg[end()]=''
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:29
        else:
            error('%s: MSG must be a character string or cellstr array',caller)
    
    if (logical_not(ischar(title))):
        error('%s: TITLE must be a character string',caller)
    
    dlg='emptydlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:39
    if (nargin >= 4):
        if 'error' == (icon):
            dlg='errordlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:43
        else:
            if 'help' == (icon):
                dlg='helpdlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:45
            else:
                if 'warn' == (icon):
                    dlg='warndlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:47
                else:
                    if 'none' == (icon):
                        dlg='emptydlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:49
                    else:
                        if 'custom' == (icon):
                            icon='emptydlg'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:51
                            warning('%s: custom icons not yet supported',caller)
                        else:
                            error('%s: ICON is not a valid type',caller)
    else:
        icon='none'
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:57
    
    if (nargin == 5):
        if ((isstruct(createmode)) and (isfield(createmode,'WindowStyle'))):
            createmode=createmode.WindowStyle
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:62
        if cellarray(['nonmodal','non-modal','modal','replace']) == (createmode):
            warning('%s: %s is not yet supported',caller,createmode)
        else:
            error('%s: CREATEMODE is not a valid type',caller)
    
    if (__octave_link_enabled__()):
        retval=__octave_link_message_dialog__(icon,msg,title)
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:73
    else:
        if (__have_feature__('JAVA')):
            retval=javaMethod(dlg,'org.octave.JDialogBox',msg,title)
# /home/lei/octave-4.0.2/scripts/gui/private/message_dialog.m:75
        else:
            error('%s is not available in this version of Octave',dlg)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Andreas Weber
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{funcname} =} __get_funcname__ (@var{basename})
## Internal function.
##
## Build function name for the current graphics toolkit according to the schema
## __[basename]_[graphics_toolkit]__, use fltk as default.
## @end deftypefn
    
    ## Author: Andreas Weber
    
    
@function
def __get_funcname__(basename=None,*args,**kwargs):
    varargin = __get_funcname__.varargin
    nargin = __get_funcname__.nargin

    if (logical_not(__octave_link_enabled__())):
        tk=graphics_toolkit()
# /home/lei/octave-4.0.2/scripts/gui/private/__get_funcname__.m:32
        funcname=strcat('__',basename,'_',tk,'__')
# /home/lei/octave-4.0.2/scripts/gui/private/__get_funcname__.m:33
        if (numel(tk) > 0 and logical_not(strcmp(tk,'fltk')) and logical_not(__is_function__(funcname))):
            warning('%s: no implementation for toolkit \'%s\', using \'fltk\' instead',basename,tk)
        funcname=strcat('__',basename,'_fltk__')
# /home/lei/octave-4.0.2/scripts/gui/private/__get_funcname__.m:39
    else:
        funcname=''
# /home/lei/octave-4.0.2/scripts/gui/private/__get_funcname__.m:41
    
    return funcname
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{p}, @var{args}] =} __uiobject_split_args__ (@var{who}, @var{args}, @var{parent_type}, @var{use_gcf})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def __uiobject_split_args__(who=None,in_args=None,parent_type=cellarray([]),use_gcf=1,*args,**kwargs):
    varargin = __uiobject_split_args__.varargin
    nargin = __uiobject_split_args__.nargin

    parent=matlabarray([])
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:28
    args=cellarray([])
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:29
    offset=1
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:30
    if (logical_not(isempty(in_args))):
        if (ishandle(in_args[1])):
            parent=in_args[1]
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:34
            offset=2
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:35
        else:
            if (logical_not(ischar(in_args[1]))):
                error('%s: invalid parent handle.',who)
        args=in_args[offset:end()]
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:40
    
    if (rem(length(args),2)):
        error('%s: expecting PROPERTY/VALUE pairs',who)
    
    if (logical_not(isempty(args))):
        i=find(strcmpi(args[1:2:end()],'parent'),1,'first')
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:48
        if (logical_not(isempty(i)) and length(args) >= dot(2,i)):
            parent=args[dot(2,i)]
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:50
            if (logical_not(ishandle(parent))):
                error('%s: invalid parent handle.',who)
            args[cat(dot(2,i) - 1,dot(2,i))]=[]
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:54
    
    if (logical_not(isempty(parent))):
        if (logical_not(isempty(parent_type)) and isempty(find(strcmpi(get(parent,'type'),parent_type)))):
            error('%s: invalid parent, the parent type must be: %s',who,sprintf('%s, ',parent_type[:])(arange(1,end() - 2)))
    else:
        if (use_gcf):
            parent=gcf()
# /home/lei/octave-4.0.2/scripts/gui/private/__uiobject_split_args__.m:65
    
    return parent,args
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{fname}, @var{fpath}, @var{fltidx}] =} __uiputfile_fltk__ ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michael Goffioul
    
    
@function
def __uiputfile_fltk__(filters=None,title=None,defval=None,position=None,tag=None,defdir=None,*args,**kwargs):
    varargin = __uiputfile_fltk__.varargin
    nargin = __uiputfile_fltk__.nargin

    if (exist('__fltk_uigetfile__') != 3):
        error('uiputfile: fltk graphics toolkit required')
    
    filters=__fltk_file_filter__(filters)
# /home/lei/octave-4.0.2/scripts/gui/private/__uiputfile_fltk__.m:32
    if (length(defdir) > 0):
        defval=fullfile(defdir,defval)
# /home/lei/octave-4.0.2/scripts/gui/private/__uiputfile_fltk__.m:34
    
    retval,retpath,retindex=__fltk_uigetfile__(filters,title,defval,position,tag,nargout=3)
# /home/lei/octave-4.0.2/scripts/gui/private/__uiputfile_fltk__.m:36
    return retval,retpath,retindex
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010-2015 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __file_filter__ (@var{file_filter})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Kai Habel
    
    
@function
def __file_filter__(file_filter=None,name=None,*args,**kwargs):
    varargin = __file_filter__.varargin
    nargin = __file_filter__.nargin

    revtal=cellarray([])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:28
    defname=''
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:29
    defdir=''
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:30
    if (iscell(file_filter)):
        r,c=size(file_filter,nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:33
        if (c != 1 and c != 2):
            error('%s: invalid filter specification',name)
        if (c == 1):
            retval=cell(r,2)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:38
            for i in arange(1,r).reshape(-1):
                retval[i,1]=file_filter[i]
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:40
                retval[i,2]=__default_filtername__(file_filter[i])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:41
        else:
            retval=copy(file_filter)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:44
            for i in arange(1,r).reshape(-1):
                if (isempty(retval[i,2])):
                    retval[i,2]=__default_filtername__(retval[i,1])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:47
    else:
        if (ischar(file_filter)):
            defdir,fname,fext=fileparts(file_filter,nargout=3)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:52
            if (logical_not(strcmp(fname,'*'))):
                defname=strcat(fname,fext)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:54
            if ((length(fext) > 0) and (logical_not(strcmp(fext,'.*')))):
                fext=strcat('*',fext)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:57
                retval=cellarray([fext,__default_filtername__(fext)])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:58
    
    retval[end() + 1,:]=cellarray(['*',__default_filtername__('*')])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:62
    return retval,defname,defdir
    
if __name__ == '__main__':
    pass
    
    
@function
def __default_filtername__(filterext=None,*args,**kwargs):
    varargin = __default_filtername__.varargin
    nargin = __default_filtername__.nargin

    name=''
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:68
    if '*' == (filterext):
        name='All Files'
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:72
    else:
        if '*.m' == (filterext):
            name='Octave Source Files'
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:74
        else:
            if '*.c' == (filterext):
                name='C Source Files'
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:76
            else:
                if cellarray(['*.cc','*.c++','*.cpp']) == (filterext):
                    name='C++ Source Files'
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:78
                else:
                    if '*.oct' == (filterext):
                        name='Octave Compiled Files'
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:80
    
    if (isempty(name)):
        extlist=ostrsplit(filterext,';')
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:84
        extlist=strrep(extlist,'*.','')
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:85
        extlist=toupper(extlist)
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:86
        extlist[end() + 1,:]=repmat(cellarray([',']),1,length(extlist))
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:87
        extlist=strcat(extlist[:])
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:88
        extlist=extlist[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:89
        name=strcat(extlist,'-Files')
# /home/lei/octave-4.0.2/scripts/gui/private/__file_filter__.m:90
    
    return name
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{result} =} __is_function__ (@var{func})
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michael Goffioul
    
    
@function
def __is_function__(func=None,*args,**kwargs):
    varargin = __is_function__.varargin
    nargin = __is_function__.nargin

    existval=exist(func)
# /home/lei/octave-4.0.2/scripts/gui/private/__is_function__.m:28
    result=(existval == 2 or existval == 3 or existval == 5)
# /home/lei/octave-4.0.2/scripts/gui/private/__is_function__.m:29
    return result
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{fname}, @var{fpath}, @var{fltidx}] =} __uigetfile_fltk__ ()
## Undocumented internal function.
## @end deftypefn
    
    ## Author: Michael Goffioul
    
    
@function
def __uigetfile_fltk__(filters=None,title=None,defval=None,position=None,multiselect=None,defdir=None,*args,**kwargs):
    varargin = __uigetfile_fltk__.varargin
    nargin = __uigetfile_fltk__.nargin

    if (exist('__fltk_uigetfile__') != 3):
        error('uigetfile: fltk graphics toolkit required')
    
    filters=__fltk_file_filter__(filters)
# /home/lei/octave-4.0.2/scripts/gui/private/__uigetfile_fltk__.m:32
    if (length(defdir) > 0):
        defval=fullfile(defdir,defval)
# /home/lei/octave-4.0.2/scripts/gui/private/__uigetfile_fltk__.m:34
    
    retval,retpath,retindex=__fltk_uigetfile__(filters,title,defval,position,multiselect,nargout=3)
# /home/lei/octave-4.0.2/scripts/gui/private/__uigetfile_fltk__.m:36
    return retval,retpath,retindex
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} msgbox (@var{msg})
## @deftypefnx {Function File} {@var{h} =} msgbox (@var{msg}, @var{title})
## @deftypefnx {Function File} {@var{h} =} msgbox (@var{msg}, @var{title}, @var{icon})
## @deftypefnx {Function File} {@var{h} =} msgbox (@dots{}, @var{createmode})
## Display @var{msg} using a message dialog box.
##
## The message may have multiple lines separated by newline characters ("\n"),
## or it may be a cellstr array with one element for each line.
##
## The optional input @var{title} (character string) can be used to decorate
## the dialog caption.
##
## The optional argument @var{icon} selects a dialog icon.
## It can be one of @qcode{"none"} (default), @qcode{"error"}, @qcode{"help"},
## or @qcode{"warn"}.
##
## The return value is always 1.
##
## Compatibility Note: The optional argument @var{createmode} is accepted for
## @sc{matlab} compatibility, but is not implemented.
##
## @seealso{errordlg, helpdlg, inputdlg, listdlg, questdlg, warndlg}
## @end deftypefn
    
    
@function
def msgbox(msg=None,title='',varargin=None,*args,**kwargs):
    varargin = msgbox.varargin
    nargin = msgbox.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    retval=message_dialog('msgbox',msg,title,varargin[:])
# /home/lei/octave-4.0.2/scripts/gui/msgbox.m:50
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{h} =} helpdlg (@var{msg})
## @deftypefnx {Function File} {@var{h} =} helpdlg (@var{msg}, @var{title})
## Display @var{msg} in a help dialog box.
##
## The message may have multiple lines separated by newline characters
## ("\n"), or it may be a cellstr array with one element for each
## line.
##
## The optional input @var{title} (character string) can be used to
## set the dialog caption.  The default title is @qcode{"Help Dialog"}.
##
## The return value is always 1.
## @seealso{errordlg, inputdlg, listdlg, msgbox, questdlg, warndlg}
## @end deftypefn
    
    
@function
def helpdlg(msg=None,title='Help Dialog',*args,**kwargs):
    varargin = helpdlg.varargin
    nargin = helpdlg.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    retval=message_dialog('helpdlg',msg,title,'help')
# /home/lei/octave-4.0.2/scripts/gui/helpdlg.m:41
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} uiwait
## @deftypefnx {Function File} {} uiwait (@var{h})
## @deftypefnx {Function File} {} uiwait (@var{h}, @var{timeout})
## Suspend program execution until the figure with handle @var{h} is deleted
## or @code{uiresume} is called.
##
## When no figure handle is specified this function uses the current figure.
## If the figure handle is invalid or there is no current figure, this
## functions returns immediately.
##
## When specified, @var{timeout} defines the number of seconds to wait
## for the figure deletion or the @code{uiresume} call.  The timeout value
## must be at least 1.  If a smaller value is specified, a warning is issued
## and a timeout value of 1 is used instead.  If a non-integer value is
## specified, it is truncated towards 0.  If @var{timeout} is not specified,
## the program execution is suspended indefinitely.
## @seealso{uiresume, waitfor}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uiwait(varargin=None,*args,**kwargs):
    varargin = uiwait.varargin
    nargin = uiwait.nargin

    h=matlabarray([])
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:43
    timeout=matlabarray([])
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:44
    if (nargin == 0):
        h=get(0,'currentfigure')
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:47
    else:
        h=varargin[1]
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:49
        if (logical_not(isfigure(h))):
            error('uiwait: invalid figure handle H')
        if (nargin > 1):
            timeout=varargin[2]
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:54
    
    if (logical_not(isempty(h))):
        try:
            try:
                addproperty('__uiwait_state__',h,'radio','none|{active}|triggered')
            finally:
                pass
            waitfor_args=cellarray([h,'__uiwait_state__','triggered'])
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:68
            if (logical_not(isempty(timeout))):
                waitfor_args[end() + 1:end() + 2]=cellarray(['timeout',timeout])
# /home/lei/octave-4.0.2/scripts/gui/uiwait.m:70
            waitfor(waitfor_args[:])
        finally:
            if (ishandle(h) and isprop(h,'__uiwait_state__')):
                set(h,'__uiwait_state__','none')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uitoolbar (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uitoolbar (@var{parent}, @var{property}, @var{value}, @dots{})
##
## Create a uitoolbar object and return a handle to it. A uitoolbar displays uitoggletool and uipushtool buttons.
##
## If @var{parent} is omitted then a uitoolbar for the current figure is
## created. If no figure is available, a new figure is created first. 
##
## If @var{parent} is given then a uitoolbar relative to @var{parent} is created. 
## 
## Any provided property value pairs will override the default values of the created 
## uitoolbar object. 
##
## Examples:
##
## @example
## @group
## # create figure without a default toolbar 
## f = figure ("toolbar", "none");
## # create empty toolbar
## t = uitoolbar (f);
## @end group
## @end example
## @seealso{figure, uitoggletool, uipushtool}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uitoolbar(varargin=None,*args,**kwargs):
    varargin = uitoolbar.varargin
    nargin = uitoolbar.nargin

    h,args=__uiobject_split_args__('uitoolbar',varargin,cellarray(['figure']),nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uitoolbar.m:50
    hui=__go_uitoolbar__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uitoolbar.m:51
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hui} =} uipushtool (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {@var{hui} =} uipushtool (@var{parent}, @var{property}, @var{value}, @dots{})
##
## Create a uipushtool object and return a handle to it.
##
## uipushtools are buttons that appear on a figure toolbar. The button is created with a border that
## is shown when the user hovers over the button. An image can be set using the cdata property.
##
## If @var{parent} is omitted then a uipushtool for the current figure is
## created. If no figure is available, a new figure is created first.  If a figure is
## available, but does not contain a uitoolbar, a uitoolbar will be created.
##
## If @var{parent} is given then a uipushtools is created on the @var{parent} uitoolbar. 
## 
## Any provided property value pairs will override the default values of the created 
## uipushtool object.
##
## Examples:
##
## @example
## @group
## # create figure without a default toolbar
## f = figure ("toolbar", "none");
## # create empty toolbar
## t = uitoolbar (f);
## # create a 19x19x3 black square
## img=zeros(19,19,3);
## # add pushtool button to toolbar
## b = uipushtool (t, "cdata", img);
## @end group
## @end example
## @seealso{figure, uitoolbar, uitoggletool}
## @end deftypefn
    
    ## Author: goffioul
    
    
@function
def uipushtool(varargin=None,*args,**kwargs):
    varargin = uipushtool.varargin
    nargin = uipushtool.nargin

    h,args=__uiobject_split_args__('uipushtool',varargin,cellarray(['uitoolbar']),0,nargout=2)
# /home/lei/octave-4.0.2/scripts/gui/uipushtool.m:58
    if (isempty(h)):
        h=findobj(gcf,'-depth',1,'type','uitoolbar')
# /home/lei/octave-4.0.2/scripts/gui/uipushtool.m:61
        if (isempty(h)):
            h=uitoolbar()
# /home/lei/octave-4.0.2/scripts/gui/uipushtool.m:63
        else:
            h=h[1]
# /home/lei/octave-4.0.2/scripts/gui/uipushtool.m:65
    
    hui=__go_uipushtool__(h,args[:])
# /home/lei/octave-4.0.2/scripts/gui/uipushtool.m:68
    return hui
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 Bill Denney
## Copyright (C) 2008 Jaroslav Hajek
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} pqpnonneg (@var{c}, @var{d})
## @deftypefnx {Function File} {@var{x} =} pqpnonneg (@var{c}, @var{d}, @var{x0})
## @deftypefnx {Function File} {[@var{x}, @var{minval}] =} pqpnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{minval}, @var{exitflag}] =} pqpnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{minval}, @var{exitflag}, @var{output}] =} pqpnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{minval}, @var{exitflag}, @var{output}, @var{lambda}] =} pqpnonneg (@dots{})
## Minimize @code{1/2*x'*c*x + d'*x} subject to @code{@var{x} >= 0}.
##
## @var{c} ## and @var{d} must be real, and @var{c} must be symmetric and
## positive definite.
##
## @var{x0} is an optional initial guess for @var{x}.
##
## Outputs:
##
## @itemize @bullet
## @item minval
##
## The minimum attained model value, 1/2*xmin'*c*xmin + d'*xmin
##
## @item exitflag
##
## An indicator of convergence.  0 indicates that the iteration count was
## exceeded, and therefore convergence was not reached; >0 indicates that the
## algorithm converged.  (The algorithm is stable and will converge given
## enough iterations.)
##
## @item output
##
## A structure with two fields:
##
## @itemize @bullet
## @item @qcode{"algorithm"}: The algorithm used (@qcode{"nnls"})
##
## @item @qcode{"iterations"}: The number of iterations taken.
## @end itemize
##
## @item lambda
##
## Not implemented.
## @end itemize
## @seealso{optimset, lsqnonneg, qp}
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("pqpnonneg");
    
    ## This is analogical to the lsqnonneg implementation, which is
## implemented from Lawson and Hanson's 1973 algorithm on page
## 161 of Solving Least Squares Problems.
## It shares the convergence guarantees.
    
    
@function
def pqpnonneg(c=None,d=None,x=[],options=struct(),*args,**kwargs):
    varargin = pqpnonneg.varargin
    nargin = pqpnonneg.nargin

    if (nargin == 1 and ischar(c) and strcmp(c,'defaults')):
        x=optimset('MaxIter',100000.0)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:77
        return x,minval,exitflag,output,lambda_
    
    if (nargin < 2 or nargin > 4 or logical_not((isnumeric(c) and ismatrix(c))) or logical_not((isnumeric(d) and ismatrix(d))) or logical_not(isstruct(options))):
        print_usage()
    
    ## Lawson-Hanson Step 1 (LH1): initialize the variables.
    m=rows(c)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:89
    n=columns(c)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:90
    if (m != n):
        error('pqpnonneg: matrix must be square')
    
    if (isempty(x)):
        ## Initial guess is 0s.
        x=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:97
    else:
        ## ensure nonnegative guess.
        x=max(x,0)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:100
    
    max_iter=optimget(options,'MaxIter',100000.0)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:103
    
    p=find(x > 0).T
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:106
    
    r=chol(c[p,p])
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:108
    usechol=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:109
    iter=0
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:111
    
    while (iter < max_iter):

        while (iter < max_iter):

            iter
            ## of the positive problem.
            if (usechol):
                xtmp=- (numpy.linalg.solve(r,(numpy.linalg.solve(r.T,d[p]))))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:121
            else:
                xtmp=- (numpy.linalg.solve(c[p,p],d[p]))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:123
            idx=find(xtmp < 0)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:125
            if (isempty(idx)):
                ## LH7: tmp solution found, iterate.
                ravel[x]=0
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:129
                x[p]=xtmp
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:130
                break
            else:
                ## LH8, LH9: find the scaling factor.
                pidx=p[idx]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:134
                sf=x[pidx] / (x[pidx] - xtmp[idx])
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:135
                alpha=min(sf)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:136
                xx=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:138
                xx[p]=xtmp
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:139
                x += dot(alpha,(xx - x))
                ## This corresponds to those indices where minimum of sf is attained.
                idx=idx[sf == alpha]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:143
                p[idx]=[]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:144
                if (usechol):
                    ## update the Cholesky factorization.
                    r=choldelete(r,idx)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:147

        ## compute the gradient.
        w=- (d + dot(c,x))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:153
        w[p]=[]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:154
        if (logical_not(any(w > 0))):
            if (usechol):
                ## verify the solution achieved using qr updating.
        ## in the best case, this should only take a single step.
                usechol=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:159
                continue
            else:
                ## we're finished.
                break
        ## find the maximum gradient.
        idx=find(w == max(w))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:168
        if (numel(idx) > 1):
            warning('pqpnonneg:nonunique','a non-unique solution may be returned due to equal gradients')
            idx=idx[1]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:172
        ## move the index from Z to P. Keep P sorted.
        z=matlabarray(cat(arange(1,n)))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:175
        z[p]=[]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:175
        zidx=z[idx]
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:176
        jdx=1 + lookup(p,zidx)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:177
        p=matlabarray(cat(p[1:jdx - 1],zidx,p[jdx:end()]))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:178
        if (usechol):
            ## insert the column into the Cholesky factorization.
            r,bad=cholinsert(r,jdx,c[p,zidx],nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:181
            if (bad):
                ## If the insertion failed, we switch off updates and go on.
                usechol=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:184

    
    ## LH12: complete.
    
    ## Generate the additional output arguments.
    if (nargout > 1):
        minval=dot(1 / 2,(dot(dot(x.T,c),x))) + dot(d.T,x)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:193
    
    exitflag=copy(iter)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:195
    if (nargout > 2 and iter >= max_iter):
        exitflag=0
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:197
    
    if (nargout > 3):
        output=struct('algorithm','nnls-pqp','iterations',iter)
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:200
    
    if (nargout > 4):
        lambda_=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:203
        lambda_[p]=w
# /home/lei/octave-4.0.2/scripts/optimization/pqpnonneg.m:204
    
    return x,minval,exitflag,output,lambda_
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test equivalence of lsq and pqp
    
    
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Author: Jaroslav Hajek <highegg@gmail.com>
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{x}, @var{fval}, @var{info}, @var{output}] =} fminbnd (@var{fun}, @var{a}, @var{b}, @var{options})
## Find a minimum point of a univariate function.
##
## @var{fun} should be a function handle or name.  @var{a}, @var{b} specify a
## starting interval.  @var{options} is a structure specifying additional
## options.  Currently, @code{fminbnd} recognizes these options:
## @qcode{"FunValCheck"}, @qcode{"OutputFcn"}, @qcode{"TolX"},
## @qcode{"MaxIter"}, @qcode{"MaxFunEvals"}.  For a description of these
## options, see @ref{XREFoptimset,,optimset}.
##
## On exit, the function returns @var{x}, the approximate minimum point and
## @var{fval}, the function value thereof.
##
## @var{info} is an exit flag that can have these values:
##
## @itemize
## @item 1
## The algorithm converged to a solution.
##
## @item 0
## Maximum number of iterations or function evaluations has been exhausted.
##
## @item -1
## The algorithm has been terminated from user output function.
## @end itemize
##
## Notes: The search for a minimum is restricted to be in the interval bound by
## @var{a} and @var{b}.  If you only have an initial point to begin searching
## from you will need to use an unconstrained minimization algorithm such as
## @code{fminunc} or @code{fminsearch}.  @code{fminbnd} internally uses a
## Golden Section search strategy.
## @seealso{fzero, fminunc, fminsearch, optimset}
## @end deftypefn
    
    ## This is patterned after opt/fmin.f from Netlib, which in turn is taken from
## Richard Brent: Algorithms For Minimization Without Derivatives,
## Prentice-Hall (1973)
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("fminbnd");
    
    
@function
def fminbnd(fun=None,xmin=None,xmax=None,options=struct(),*args,**kwargs):
    varargin = fminbnd.varargin
    nargin = fminbnd.nargin

    ## Get default options if requested.
    if (nargin == 1 and ischar(fun) and strcmp(fun,'defaults')):
        x=optimset('MaxIter',Inf,'MaxFunEvals',Inf,'TolX',1e-08,'OutputFcn',[],'FunValCheck','off')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:67
        return x,fval,info,output
    
    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (xmin > xmax):
        error('Octave:invalid-input-arg','fminbnd: the lower bound cannot be greater than the upper one')
    
    if (ischar(fun)):
        fun=str2func(fun,'global')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:82
    
    displ=optimget(options,'Display','notify')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:85
    funvalchk=strcmpi(optimget(options,'FunValCheck','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:86
    outfcn=optimget(options,'OutputFcn')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:87
    tolx=optimget(options,'TolX',1e-08)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:88
    maxiter=optimget(options,'MaxIter',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:89
    maxfev=optimget(options,'MaxFunEvals',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:90
    if (funvalchk):
        ## Replace fun with a guarded version.
        fun=lambda x=None: guarded_eval(fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:94
    
    ## The default exit flag if exceeded number of iterations.
    info=0
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:98
    niter=0
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:99
    nfev=0
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:100
    sqrteps=eps(class_(xmin + xmax))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:101
    c=dot(0.5,(3 - sqrt(5)))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:103
    a=copy(xmin)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:104
    b=copy(xmax)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:104
    v=a + dot(c,(b - a))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:105
    w=x=copy(v)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:106
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:106
    e=0
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:107
    fv=fw=fval=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:108
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:108
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:108
    nfev
    
    iter(1).funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:112
    iter[1].x = copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:113
    iter[1].fx = copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:114
    while (niter < maxiter and nfev < maxfev):

        xm=dot(0.5,(a + b))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:117
        ## sometimes.  Sometimes not, it depends on the function.  This is the
    ## strategy from the Netlib code.  Something yet smarter would be good.
        tol=dot(dot(2,sqrteps),abs(x)) + tolx / 3
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:121
        if (abs(x - xm) <= (dot(2,tol) - dot(0.5,(b - a)))):
            info=1
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:123
            break
        if (abs(e) > tol):
            dogs=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:128
            iter[niter + 1].procedure = copy('parabolic')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:130
            r=dot((x - w),(fval - fv))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:132
            q=dot((x - v),(fval - fw))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:133
            p=dot((x - v),q) - dot((x - w),r)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:134
            q=dot(2,(q - r))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:135
            p *= - sign(q)
            q=abs(q)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:137
            r=copy(e)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:138
            e=copy(d)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:139
            if (abs(p) < abs(dot(dot(0.5,q),r)) and p > dot(q,(a - x)) and p < dot(q,(b - x))):
                ## The parabolic step is acceptable.
                d=p / q
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:143
                u=x + d
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:144
                if (min(u - a,b - u) < dot(2,tol)):
                    d=dot(tol,(sign(xm - x) + (xm == x)))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:148
            else:
                dogs=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:151
        else:
            dogs=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:154
        if (dogs):
            ## Default to golden section step.
            ## WARNING: This is also the "initial" procedure following
      ## MATLAB nomenclature. After the loop we'll fix the string
      ## for the first step.
            iter[niter + 1].procedure = copy('golden')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:162
            e=ifelse(x >= xm,a - x,b - x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:164
            d=dot(c,e)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:165
        ## f must not be evaluated too close to x.
        u=x + dot(max(abs(d),tol),(sign(d) + (d == 0)))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:169
        fu=fun[u]
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:170
        niter
        iter[niter].funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:174
        iter[niter].x = copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:175
        iter[niter].fx = copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:176
        if (fu < fval):
            if (u < x):
                b=copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:182
            else:
                a=copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:184
            v=copy(w)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:186
            fv=copy(fw)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:186
            w=copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:187
            fw=copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:187
            x=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:188
            fval=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:188
        else:
            ## The following if-statement was originally executed even if fu == fval.
            if (u < x):
                a=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:192
            else:
                b=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:194
            if (fu <= fw or w == x):
                v=copy(w)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:197
                fv=copy(fw)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:197
                w=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:198
                fw=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:198
            else:
                if (fu <= fv or v == x or v == w):
                    v=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:200
                    fv=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:201
        ## If there's an output function, use it now.
        if (outfcn):
            optv.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:207
            optv.fval = copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:208
            optv.iteration = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:209
            if (outfcn[x,optv,'iter']):
                info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:211
                break

    
    ## Fix the first step procedure.
    iter[1].procedure = copy('initial')
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:218
    
    if 'iter' == (displ):
        print_formatted_table(iter)
        print_exit_msg(info,struct('TolX',tolx,'fx',fval))
    else:
        if 'notify' == (displ):
            if (info == 0):
                print_exit_msg(info,struct('fx',fval))
        else:
            if 'final' == (displ):
                print_exit_msg(info,struct('TolX',tolx,'fx',fval))
            else:
                if 'off' == (displ):
                    'skip'
                else:
                    warning('unknown option for Display: \'%s\'',displ)
    
    output.iterations = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:237
    output.funcCount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:238
    output.bracket = copy(cat(a,b))
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:239
    
    return x,fval,info,output
    
if __name__ == '__main__':
    pass
    
    ## An assistant function that evaluates a function handle and checks for
## bad results.
    
@function
def guarded_eval(fun=None,x=None,*args,**kwargs):
    varargin = guarded_eval.varargin
    nargin = guarded_eval.nargin

    fx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:247
    fx=fx[1]
# /home/lei/octave-4.0.2/scripts/optimization/fminbnd.m:248
    if (logical_not(isreal(fx))):
        error('fminbnd:notreal','fminbnd: non-real value encountered')
    else:
        if (isnan(fx)):
            error('fminbnd:isnan','fminbnd: NaN value encountered')
    
    return fx
    
if __name__ == '__main__':
    pass
    
    ## A hack for printing a formatted table
    
@function
def print_formatted_table(table=None,*args,**kwargs):
    varargin = print_formatted_table.varargin
    nargin = print_formatted_table.nargin

    printf('\n Func-count     x          f(x)         Procedure\n')
    for row in table.reshape(-1):
        printf('%5.5s        %7.7s    %8.8s\t%s\n',int2str(row.funccount),num2str(row.x,'%.5f'),num2str(row.fx,'%.6f'),row.procedure)
    
    printf('\n')
    return
    
if __name__ == '__main__':
    pass
    
    ## Print either a success termination message or bad news
    
@function
def print_exit_msg(info=None,opt=struct(),*args,**kwargs):
    varargin = print_exit_msg.varargin
    nargin = print_exit_msg.nargin

    printf('')
    if 1 == (info):
        printf('Optimization terminated:\n')
        printf(' the current x satisfies the termination criteria using OPTIONS.TolX of %e\n',opt.TolX)
    else:
        if 0 == (info):
            printf('Exiting: Maximum number of iterations has been exceeded\n')
            printf('         - increase MaxIter option.\n')
            printf('         Current function value: %.6f\n',opt.fx)
        else:
            if - 1 == (info):
                'FIXME'
            else:
                error('internal error - fminbnd() is bug, sorry!')
    
    printf('\n')
    return
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2005-2015 Nicolo' Giorgetti
## Copyright (C) 2013-2015 Sbastien Villemot <sebastien@debian.org>
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{xopt}, @var{fmin}, @var{errnum}, @var{extra}] =} glpk (@var{c}, @var{A}, @var{b}, @var{lb}, @var{ub}, @var{ctype}, @var{vartype}, @var{sense}, @var{param})
## Solve a linear program using the GNU @sc{glpk} library.
##
## Given three arguments, @code{glpk} solves the following standard LP:
## @tex
## $$
##   \min_x C^T x
## $$
## @end tex
## @ifnottex
##
## @example
## min C'*x
## @end example
##
## @end ifnottex
## subject to
## @tex
## $$
##   Ax = b \qquad x \geq 0
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## A*x  = b
##   x >= 0
## @end group
## @end example
##
## @end ifnottex
## but may also solve problems of the form
## @tex
## $$
##   [ \min_x | \max_x ] C^T x
## $$
## @end tex
## @ifnottex
##
## @example
## [ min | max ] C'*x
## @end example
##
## @end ifnottex
## subject to
## @tex
## $$
##  Ax [ = | \leq | \geq ] b \qquad LB \leq x \leq UB
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## A*x [ "=" | "<=" | ">=" ] b
##   x >= LB
##   x <= UB
## @end group
## @end example
##
## @end ifnottex
##
## Input arguments:
##
## @table @var
## @item c
## A column array containing the objective function coefficients.
##
## @item A
## A matrix containing the constraints coefficients.
##
## @item b
## A column array containing the right-hand side value for each constraint in
## the constraint matrix.
##
## @item lb
## An array containing the lower bound on each of the variables.  If @var{lb}
## is not supplied, the default lower bound for the variables is zero.
##
## @item ub
## An array containing the upper bound on each of the variables.  If @var{ub}
## is not supplied, the default upper bound is assumed to be infinite.
##
## @item ctype
## An array of characters containing the sense of each constraint in the
## constraint matrix.  Each element of the array may be one of the following
## values
##
## @table @asis
## @item @qcode{"F"}
## A free (unbounded) constraint (the constraint is ignored).
##
## @item @qcode{"U"}
## An inequality constraint with an upper bound (@code{A(i,:)*x <= b(i)}).
##
## @item @qcode{"S"}
## An equality constraint (@code{A(i,:)*x = b(i)}).
##
## @item @qcode{"L"}
## An inequality with a lower bound (@code{A(i,:)*x >= b(i)}).
##
## @item @qcode{"D"}
## An inequality constraint with both upper and lower bounds
## (@code{A(i,:)*x >= -b(i)}) @emph{and} (@code{A(i,:)*x <= b(i)}).
## @end table
##
## @item vartype
## A column array containing the types of the variables.
##
## @table @asis
## @item @qcode{"C"}
## A continuous variable.
##
## @item @qcode{"I"}
## An integer variable.
## @end table
##
## @item sense
## If @var{sense} is 1, the problem is a minimization.  If @var{sense} is -1,
## the problem is a maximization.  The default value is 1.
##
## @item param
## A structure containing the following parameters used to define the
## behavior of solver.  Missing elements in the structure take on default
## values, so you only need to set the elements that you wish to change from
## the default.
##
## Integer parameters:
##
## @table @code
## @item msglev (default: 1)
## Level of messages output by solver routines:
##
## @table @asis
## @item 0 (@w{@code{GLP_MSG_OFF}})
## No output.
##
## @item 1 (@w{@code{GLP_MSG_ERR}})
## Error and warning messages only.
##
## @item 2 (@w{@code{GLP_MSG_ON}})
## Normal output.
##
## @item 3 (@w{@code{GLP_MSG_ALL}})
## Full output (includes informational messages).
## @end table
##
## @item scale (default: 16)
## Scaling option.  The values can be combined with the bitwise OR operator and
## may be the following:
##
## @table @asis
## @item 1 (@w{@code{GLP_SF_GM}})
## Geometric mean scaling.
##
## @item 16 (@w{@code{GLP_SF_EQ}})
## Equilibration scaling.
##
## @item 32 (@w{@code{GLP_SF_2N}})
## Round scale factors to power of two.
##
## @item 64 (@w{@code{GLP_SF_SKIP}})
## Skip if problem is well scaled.
## @end table
##
## Alternatively, a value of 128 (@w{@env{GLP_SF_AUTO}}) may be also
## specified, in which case the routine chooses the scaling options
## automatically.
##
## @item dual (default: 1)
## Simplex method option:
##
## @table @asis
## @item 1 (@w{@code{GLP_PRIMAL}})
## Use two-phase primal simplex.
##
## @item 2 (@w{@code{GLP_DUALP}})
## Use two-phase dual simplex, and if it fails, switch to the primal simplex.
##
## @item 3 (@w{@code{GLP_DUAL}})
## Use two-phase dual simplex.
## @end table
##
## @item price (default: 34)
## Pricing option (for both primal and dual simplex):
##
## @table @asis
## @item 17 (@w{@code{GLP_PT_STD}})
## Textbook pricing.
##
## @item 34 (@w{@code{GLP_PT_PSE}})
## Steepest edge pricing.
## @end table
##
## @item itlim (default: intmax)
## Simplex iterations limit.  It is decreased by one each time when one simplex
## iteration has been performed, and reaching zero value signals the solver to
## stop the search.
##
## @item outfrq (default: 200)
## Output frequency, in iterations.  This parameter specifies how frequently
## the solver sends information about the solution to the standard output.
##
## @item branch (default: 4)
## Branching technique option (for MIP only):
##
## @table @asis
## @item 1 (@w{@code{GLP_BR_FFV}})
## First fractional variable.
##
## @item 2 (@w{@code{GLP_BR_LFV}})
## Last fractional variable.
##
## @item 3 (@w{@code{GLP_BR_MFV}})
## Most fractional variable.
##
## @item 4 (@w{@code{GLP_BR_DTH}})
## Heuristic by @nospell{Driebeck and Tomlin}.
##
## @item 5 (@w{@code{GLP_BR_PCH}})
## Hybrid @nospell{pseudocost} heuristic.
## @end table
##
## @item btrack (default: 4)
## Backtracking technique option (for MIP only):
##
## @table @asis
## @item 1 (@w{@code{GLP_BT_DFS}})
## Depth first search.
##
## @item 2 (@w{@code{GLP_BT_BFS}})
## Breadth first search.
##
## @item 3 (@w{@code{GLP_BT_BLB}})
## Best local bound.
##
## @item 4 (@w{@code{GLP_BT_BPH}})
## Best projection heuristic.
## @end table
##
## @item presol (default: 1)
## If this flag is set, the simplex solver uses the built-in LP presolver.
## Otherwise the LP presolver is not used.
##
## @item lpsolver (default: 1)
## Select which solver to use.  If the problem is a MIP problem this flag
## will be ignored.
##
## @table @asis
## @item 1
## Revised simplex method.
##
## @item 2
## Interior point method.
## @end table
##
## @item rtest (default: 34)
## Ratio test technique:
##
## @table @asis
## @item 17 (@w{@code{GLP_RT_STD}})
## Standard ("textbook").
##
## @item 34 (@w{@code{GLP_RT_HAR}})
## Harris' two-pass ratio test.
## @end table
##
## @item tmlim (default: intmax)
## Searching time limit, in milliseconds.
##
## @item outdly (default: 0)
## Output delay, in seconds.  This parameter specifies how long the solver
## should delay sending information about the solution to the standard output.
##
## @item save (default: 0)
## If this parameter is nonzero, save a copy of the problem in CPLEX LP
## format to the file @file{"outpb.lp"}.  There is currently no way to change
## the name of the output file.
## @end table
##
## Real parameters:
##
## @table @code
## @item tolbnd (default: 1e-7)
## Relative tolerance used to check if the current basic solution is primal
## feasible.  It is not recommended that you change this parameter unless you
## have a detailed understanding of its purpose.
##
## @item toldj (default: 1e-7)
## Absolute tolerance used to check if the current basic solution is dual
## feasible.  It is not recommended that you change this parameter unless you
## have a detailed understanding of its purpose.
##
## @item tolpiv (default: 1e-10)
## Relative tolerance used to choose eligible pivotal elements of the simplex
## table.  It is not recommended that you change this parameter unless you have
## a detailed understanding of its purpose.
##
## @item objll (default: -DBL_MAX)
## Lower limit of the objective function.  If the objective function reaches
## this limit and continues decreasing, the solver stops the search.  This
## parameter is used in the dual simplex method only.
##
## @item objul (default: +DBL_MAX)
## Upper limit of the objective function.  If the objective function reaches
## this limit and continues increasing, the solver stops the search.  This
## parameter is used in the dual simplex only.
##
## @item tolint (default: 1e-5)
## Relative tolerance used to check if the current basic solution is integer
## feasible.  It is not recommended that you change this parameter unless you
## have a detailed understanding of its purpose.
##
## @item tolobj (default: 1e-7)
## Relative tolerance used to check if the value of the objective function is
## not better than in the best known integer feasible solution.  It is not
## recommended that you change this parameter unless you have a detailed
## understanding of its purpose.
## @end table
## @end table
##
## Output values:
##
## @table @var
## @item xopt
## The optimizer (the value of the decision variables at the optimum).
##
## @item fopt
## The optimum value of the objective function.
##
## @item errnum
## Error code.
##
## @table @asis
## @item 0
## No error.
##
## @item 1 (@w{@code{GLP_EBADB}})
## Invalid basis.
##
## @item 2 (@w{@code{GLP_ESING}})
## Singular matrix.
##
## @item 3 (@w{@code{GLP_ECOND}})
## Ill-conditioned matrix.
##
## @item 4 (@w{@code{GLP_EBOUND}})
## Invalid bounds.
##
## @item 5 (@w{@code{GLP_EFAIL}})
## Solver failed.
##
## @item 6 (@w{@code{GLP_EOBJLL}})
## Objective function lower limit reached.
##
## @item 7 (@w{@code{GLP_EOBJUL}})
## Objective function upper limit reached.
##
## @item 8 (@w{@code{GLP_EITLIM}})
## Iterations limit exhausted.
##
## @item 9 (@w{@code{GLP_ETMLIM}})
## Time limit exhausted.
##
## @item 10 (@w{@code{GLP_ENOPFS}})
## No primal feasible solution.
##
## @item 11 (@w{@code{GLP_ENODFS}})
## No dual feasible solution.
##
## @item 12 (@w{@code{GLP_EROOT}})
## Root LP optimum not provided.
##
## @item 13 (@w{@code{GLP_ESTOP}})
## Search terminated by application.
##
## @item 14 (@w{@code{GLP_EMIPGAP}})
## Relative MIP gap tolerance reached.
##
## @item 15 (@w{@code{GLP_ENOFEAS}})
## No primal/dual feasible solution.
##
## @item 16 (@w{@code{GLP_ENOCVG}})
## No convergence.
##
## @item 17 (@w{@code{GLP_EINSTAB}})
## Numerical instability.
##
## @item 18 (@w{@code{GLP_EDATA}})
## Invalid data.
##
## @item 19 (@w{@code{GLP_ERANGE}})
## Result out of range.
## @end table
##
## @item extra
## A data structure containing the following fields:
##
## @table @code
## @item lambda
## Dual variables.
##
## @item redcosts
## Reduced Costs.
##
## @item time
## Time (in seconds) used for solving LP/MIP problem.
##
## @item status
## Status of the optimization.
##
## @table @asis
## @item 1 (@w{@code{GLP_UNDEF}})
## Solution status is undefined.
##
## @item 2 (@w{@code{GLP_FEAS}})
## Solution is feasible.
##
## @item 3 (@w{@code{GLP_INFEAS}})
## Solution is infeasible.
##
## @item 4 (@w{@code{GLP_NOFEAS}})
## Problem has no feasible solution.
##
## @item 5 (@w{@code{GLP_OPT}})
## Solution is optimal.
##
## @item 6 (@w{@code{GLP_UNBND}})
## Problem has no unbounded solution.
## @end table
## @end table
## @end table
##
## Example:
##
## @example
## @group
## c = [10, 6, 4]';
## A = [ 1, 1, 1;
##      10, 4, 5;
##       2, 2, 6];
## b = [100, 600, 300]';
## lb = [0, 0, 0]';
## ub = [];
## ctype = "UUU";
## vartype = "CCC";
## s = -1;
##
## param.msglev = 1;
## param.itlim = 100;
##
## [xmin, fmin, status, extra] = ...
##    glpk (c, A, b, lb, ub, ctype, vartype, s, param);
## @end group
## @end example
## @end deftypefn
    
    ## Author: Nicolo' Giorgetti <giorgetti@dii.unisi.it>
## Adapted-by: jwe
    
    
@function
def glpk(c=None,A=None,b=None,lb=None,ub=None,ctype=None,vartype=None,sense=None,param=None,*args,**kwargs):
    varargin = glpk.varargin
    nargin = glpk.nargin

    ## If there is no input output the version and syntax
    if (nargin < 3 or nargin > 9):
        print_usage()
        return xopt,fmin,errnum,extra
    
    if (all(size(c) > 1) or iscomplex(c) or ischar(c)):
        error('glpk:C must be a real vector')
        return xopt,fmin,errnum,extra
    
    nx=length(c)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:494
    
    c=ravel(c)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:496
    
    if (isempty(A)):
        error('glpk: A cannot be an empty matrix')
        return xopt,fmin,errnum,extra
    
    nc,nxa=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:504
    if (logical_not(isreal(A)) or nxa != nx):
        error('glpk: A must be a real valued %d by %d matrix',nc,nx)
        return xopt,fmin,errnum,extra
    
    ## 3) RHS
    
    if (isempty(b)):
        error('glpk: B cannot be an empty vector')
        return xopt,fmin,errnum,extra
    
    if (logical_not(isreal(b)) or length(b) != nc):
        error('glpk: B must be a real valued %d by 1 vector',nc)
        return xopt,fmin,errnum,extra
    
    ## 4) Vector with the lower bound of each variable
    
    if (nargin > 3):
        if (isempty(lb)):
            lb=zeros(nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:525
        else:
            if (logical_not(isreal(lb)) or all(size(lb) > 1) or length(lb) != nx):
                error('glpk: LB must be a real valued %d by 1 column vector',nx)
                return xopt,fmin,errnum,extra
    else:
        lb=zeros(nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:531
    
    ## 5) Vector with the upper bound of each variable
    
    if (nargin > 4):
        if (isempty(ub)):
            ub=Inf(nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:538
        else:
            if (logical_not(isreal(ub)) or all(size(ub) > 1) or length(ub) != nx):
                error('glpk: UB must be a real valued %d by 1 column vector',nx)
                return xopt,fmin,errnum,extra
    else:
        ub=Inf(nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:544
    
    ## 6) Sense of each constraint
    
    if (nargin > 5):
        if (isempty(ctype)):
            ctype=repmat('S',nc,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:551
        else:
            if (logical_not(ischar(ctype)) or all(size(ctype) > 1) or length(ctype) != nc):
                error('glpk: CTYPE must be a char valued vector of length %d',nc)
                return xopt,fmin,errnum,extra
            else:
                if (logical_not(all(ctype == logical_or('F',ctype) == logical_or('U',ctype) == logical_or('S',ctype) == logical_or('L',ctype) == 'D'))):
                    error('glpk: CTYPE must contain only F, U, S, L, or D')
                    return xopt,fmin,errnum,extra
    else:
        ctype=repmat('S',nc,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:561
    
    ## 7) Vector with the type of variables
    
    if (nargin > 6):
        if (isempty(vartype)):
            vartype=repmat('C',nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:568
        else:
            if (logical_not(ischar(vartype)) or all(size(vartype) > 1) or length(vartype) != nx):
                error('glpk: VARTYPE must be a char valued vector of length %d',nx)
                return xopt,fmin,errnum,extra
            else:
                if (logical_not(all(vartype == logical_or('C',vartype) == 'I'))):
                    error('glpk: VARTYPE must contain only C or I')
                    return xopt,fmin,errnum,extra
    else:
        ## As default we consider continuous vars
        vartype=repmat('C',nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:579
    
    ## 8) Sense of optimization
    
    if (nargin > 7):
        if (isempty(sense)):
            sense=1
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:586
        else:
            if (ischar(sense) or all(size(sense) > 1) or logical_not(isreal(sense))):
                error('glpk: SENSE must be an integer value')
            else:
                if (sense >= 0):
                    sense=1
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:590
                else:
                    sense=- 1
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:592
    else:
        sense=1
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:595
    
    ## 9) Parameters vector
    
    if (nargin > 8):
        if (logical_not(isstruct(param))):
            error('glpk: PARAM must be a structure')
            return xopt,fmin,errnum,extra
    else:
        param=struct()
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:606
    
    xopt,fmin,errnum,extra=__glpk__(c,A,b,lb,ub,ctype,vartype,sense,param,nargout=4)
# /home/lei/octave-4.0.2/scripts/optimization/glpk.m:609
    return xopt,fmin,errnum,extra
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Author: Jaroslav Hajek <highegg@gmail.com>
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fsolve (@var{fcn}, @var{x0}, @var{options})
## @deftypefnx {Function File} {[@var{x}, @var{fvec}, @var{info}, @var{output}, @var{fjac}] =} fsolve (@var{fcn}, @dots{})
## Solve a system of nonlinear equations defined by the function @var{fcn}.
##
## @var{fcn} should accept a vector (array) defining the unknown variables,
## and return a vector of left-hand sides of the equations.  Right-hand sides
## are defined to be zeros.  In other words, this function attempts to
## determine a vector @var{x} such that @code{@var{fcn} (@var{x})} gives
## (approximately) all zeros.
##
## @var{x0} determines a starting guess.  The shape of @var{x0} is preserved
## in all calls to @var{fcn}, but otherwise it is treated as a column vector.
##
## @var{options} is a structure specifying additional options.  Currently,
## @code{fsolve} recognizes these options:
## @qcode{"FunValCheck"}, @qcode{"OutputFcn"}, @qcode{"TolX"},
## @qcode{"TolFun"}, @qcode{"MaxIter"}, @qcode{"MaxFunEvals"},
## @qcode{"Jacobian"}, @qcode{"Updating"}, @qcode{"ComplexEqn"}
## @qcode{"TypicalX"}, @qcode{"AutoScaling"} and @qcode{"FinDiffType"}.
##
## If @qcode{"Jacobian"} is @qcode{"on"}, it specifies that @var{fcn}, called
## with 2 output arguments also returns the Jacobian matrix of right-hand sides
## at the requested point.  @qcode{"TolX"} specifies the termination tolerance
## in the unknown variables, while @qcode{"TolFun"} is a tolerance for
## equations.  Default is @code{1e-7} for both @qcode{"TolX"} and
## @qcode{"TolFun"}.
##
## If @qcode{"AutoScaling"} is on, the variables will be automatically scaled
## according to the column norms of the (estimated) Jacobian.  As a result,
## TolF becomes scaling-independent.  By default, this option is off because
## it may sometimes deliver unexpected (though mathematically correct) results.
##
## If @qcode{"Updating"} is @qcode{"on"}, the function will attempt to use
## @nospell{Broyden} updates to update the Jacobian, in order to reduce the
## amount of Jacobian calculations.  If your user function always calculates the
## Jacobian (regardless of number of output arguments) then this option provides
## no advantage and should be set to false.
##
## @qcode{"ComplexEqn"} is @qcode{"on"}, @code{fsolve} will attempt to solve
## complex equations in complex variables, assuming that the equations possess
## a complex derivative (i.e., are holomorphic).  If this is not what you want,
## you should unpack the real and imaginary parts of the system to get a real
## system.
##
## For description of the other options, see @code{optimset}.
##
## On return, @var{fval} contains the value of the function @var{fcn}
## evaluated at @var{x}.
##
## @var{info} may be one of the following values:
##
## @table @asis
## @item 1
## Converged to a solution point.  Relative residual error is less than
## specified by TolFun.
##
## @item 2
## Last relative step size was less that TolX.
##
## @item 3
## Last relative decrease in residual was less than TolF.
##
## @item 0
## Iteration limit exceeded.
##
## @item -3
## The trust region radius became excessively small.
## @end table
##
## Note: If you only have a single nonlinear equation of one variable, using
## @code{fzero} is usually a much better idea.
##
## Note about user-supplied Jacobians:
## As an inherent property of the algorithm, a Jacobian is always requested for
## a solution vector whose residual vector is already known, and it is the last
## accepted successful step.  Often this will be one of the last two calls, but
## not always.  If the savings by reusing intermediate results from residual
## calculation in Jacobian calculation are significant, the best strategy is to
## employ OutputFcn: After a vector is evaluated for residuals, if OutputFcn is
## called with that vector, then the intermediate results should be saved for
## future Jacobian evaluation, and should be kept until a Jacobian evaluation
## is requested or until OutputFcn is called with a different vector, in which
## case they should be dropped in favor of this most recent vector.  A short
## example how this can be achieved follows:
##
## @example
## function [fvec, fjac] = user_func (x, optimvalues, state)
## persistent sav = [], sav0 = [];
## if (nargin == 1)
##   ## evaluation call
##   if (nargout == 1)
##     sav0.x = x; # mark saved vector
##     ## calculate fvec, save results to sav0.
##   elseif (nargout == 2)
##     ## calculate fjac using sav.
##   endif
## else
##   ## outputfcn call.
##   if (all (x == sav0.x))
##     sav = sav0;
##   endif
##   ## maybe output iteration status, etc.
## endif
## endfunction
##
## ## @dots{}
##
## fsolve (@@user_func, x0, optimset ("OutputFcn", @@user_func, @dots{}))
## @end example
## @seealso{fzero, optimset}
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("fsolve");
    
    
@function
def fsolve(fcn=None,x0=None,options=struct(),*args,**kwargs):
    varargin = fsolve.varargin
    nargin = fsolve.nargin

    ## Get default options if requested.
    if (nargin == 1 and ischar(fcn) and strcmp(fcn,'defaults')):
        x=optimset('MaxIter',400,'MaxFunEvals',Inf,'Jacobian','off','TolX',1e-07,'TolFun',1e-07,'OutputFcn',[],'Updating','on','FunValCheck','off','ComplexEqn','off','FinDiffType','central','TypicalX',[],'AutoScaling','off')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:141
        return x,fvec,info,output,fjac
    
    if (nargin < 2 or nargin > 3 or logical_not(isnumeric(x0))):
        print_usage()
    
    if (ischar(fcn)):
        fcn=str2func(fcn,'global')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:154
    else:
        if (iscell(fcn)):
            fcn=lambda x=None: make_fcn_jac(x,fcn[1],fcn[2])
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:156
    
    xsiz=size(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:159
    n=numel(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:160
    has_jac=strcmpi(optimget(options,'Jacobian','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:162
    cdif=strcmpi(optimget(options,'FinDiffType','central'),'central')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:163
    maxiter=optimget(options,'MaxIter',400)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:164
    maxfev=optimget(options,'MaxFunEvals',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:165
    outfcn=optimget(options,'OutputFcn')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:166
    updating=strcmpi(optimget(options,'Updating','on'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:167
    complexeqn=strcmpi(optimget(options,'ComplexEqn','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:168
    
    ## scaling matrix is estimated using the Jacobian.
    typicalx=optimget(options,'TypicalX')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:172
    if (isempty(typicalx)):
        typicalx=ones(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:174
    
    autoscale=strcmpi(optimget(options,'AutoScaling','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:176
    if (logical_not(autoscale)):
        dg=1 / typicalx
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:178
    
    funvalchk=strcmpi(optimget(options,'FunValCheck','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:181
    if (funvalchk):
        ## Replace fcn with a guarded version.
        fcn=lambda x=None: guarded_eval(fcn,x,complexeqn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:185
    
    ## These defaults are rather stringent. I think that normally, user
  ## prefers accuracy to performance.
    
    macheps=eps(class_(x0))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:191
    tolx=optimget(options,'TolX',1e-07)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:193
    tolf=optimget(options,'TolFun',1e-07)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:194
    factor=1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:196
    niter=1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:198
    nfev=1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:199
    x=ravel(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:201
    info=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:202
    
    ## Handle arbitrary shapes of x and f and remember them.
    fvec=fcn[reshape(x,xsiz)]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:206
    fsiz=size(fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:207
    fvec=ravel(fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:208
    fn=norm(fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:209
    m=length(fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:210
    n=length(x)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:211
    if (logical_not(isempty(outfcn))):
        optimvalues.iter = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:214
        optimvalues.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:215
        optimvalues.fval = copy(fn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:216
        optimvalues.searchdirection = copy(zeros(n,1))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:217
        state='init'
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:218
        stop=outfcn[x,optimvalues,state]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:219
        if (stop):
            info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:221
            break
    
    nsuciter=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:226
    
    while (niter < maxiter and nfev < maxfev and logical_not(info)):

        ## Calculate function value and Jacobian (possibly via FD).
        if (has_jac):
            fvec,fjac=fcn[reshape(x,xsiz)]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:233
            if (issparse(fjac)):
                updating=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:236
            fvec=ravel(fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:238
            nfev
        else:
            fjac=__fdjac__(fcn,reshape(x,xsiz),fvec,typicalx,cdif)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:241
            nfev += dot((1 + cdif),length(x))
        ## For square and overdetermined systems, we update a QR
    ## factorization of the Jacobian to avoid solving a full system in each
    ## step. In this case, we pass a triangular matrix to __dogleg__.
        useqr=updating and m >= n and n > 10
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:248
        if (useqr):
            ## FIXME: Currently, pivoting is mostly useless because the \ operator
      ## cannot exploit the resulting props of the triangular factor.
      ## Unpivoted QR is significantly faster so it doesn't seem right to pivot
      ## just to get invariance. Original MINPACK didn't pivot either, at least
      ## when qr updating was used.
            q,r=qr(fjac,0,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:256
        if (autoscale):
            ## Get column norms, use them as scaling factors.
            jcn=norm(fjac,'columns').T
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:261
            if (niter == 1):
                dg=copy(jcn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:263
                dg[dg == 0]=1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:264
            else:
                ## Rescale adaptively.
        ## FIXME: the original minpack used the following rescaling strategy:
        ##   dg = max (dg, jcn);
        ## but it seems not good if we start with a bad guess yielding Jacobian
        ## columns with large norms that later decrease, because the
        ## corresponding variable will still be overscaled. So instead, we only
        ## give the old scaling a small momentum, but do not honor it.
                dg=max(dot(0.1,dg),jcn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:274
        if (niter == 1):
            xn=norm(multiply(dg,x))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:279
            delta=dot(factor,max(xn,1))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:281
        ## It also seems that in the case of fast (and inhomogeneously) changing
    ## Jacobian, the Broyden updates are of little use, so maybe we could
    ## skip them if a big disproportional change is expected. The question is,
    ## of course, how to define the above terms :)
        lastratio=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:289
        nfail=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:290
        nsuc=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:291
        decfac=0.5
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:292
        while (niter <= maxiter and nfev < maxfev and logical_not(info)):

            ## Get trust-region model (dogleg) minimizer.
            if (useqr):
                qtf=dot(q.T,fvec)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:299
                s=- __dogleg__(r,qtf,dg,delta)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:300
                w=qtf + dot(r,s)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:301
            else:
                s=- __dogleg__(fjac,fvec,dg,delta)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:303
                w=fvec + dot(fjac,s)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:304
            sn=norm(multiply(dg,s))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:307
            if (niter == 1):
                delta=min(delta,sn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:309
            fvec1=ravel(fcn[reshape(x + s,xsiz)])
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:312
            fn1=norm(fvec1)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:313
            nfev
            if (fn1 < fn):
                ## Scaled actual reduction.
                actred=1 - (fn1 / fn) ** 2
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:318
            else:
                actred=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:320
            ## Scaled predicted reduction, and ratio.
            t=norm(w)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:324
            if (t < fn):
                prered=1 - (t / fn) ** 2
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:326
                ratio=actred / prered
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:327
            else:
                prered=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:329
                ratio=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:330
            ## Update delta.
            if (ratio < min(max(0.1,dot(0.8,lastratio)),0.9)):
                nsuc=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:335
                nfail
                delta *= decfac
                decfac ^= 1.4142
                if (delta <= dot(dot(10.0,macheps),xn)):
                    ## Trust region became uselessly small.
                    info=- 3
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:341
                    break
            else:
                lastratio=copy(ratio)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:345
                decfac=0.5
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:346
                nfail=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:347
                nsuc
                if (abs(1 - ratio) <= 0.1):
                    delta=dot(1.4142,sn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:350
                else:
                    if (ratio >= 0.5 or nsuc > 1):
                        delta=max(delta,dot(1.4142,sn))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:352
            if (ratio >= 0.0001):
                ## Successful iteration.
                x += s
                xn=norm(multiply(dg,x))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:359
                fvec=copy(fvec1)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:360
                fn=copy(fn1)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:361
                nsuciter
            niter
            if (logical_not(isempty(outfcn))):
                optimvalues.iter = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:369
                optimvalues.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:370
                optimvalues.fval = copy(fn)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:371
                optimvalues.searchdirection = copy(s)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:372
                state='iter'
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:373
                stop=outfcn[x,optimvalues,state]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:374
                if (stop):
                    info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:376
                    break
            ## Tests for termination conditions. A mysterious place, anything
      ## can happen if you change something here...
            ## The rule of thumb (which I'm not sure M*b is quite following)
      ## is that for a tolerance that depends on scaling, only 0 makes
      ## sense as a default value. But 0 usually means uselessly long
      ## iterations, so we need scaling-independent tolerances wherever
      ## possible.
            ## FIXME: Why tolf*n*xn? If abs (e) ~ abs(x) * eps is a vector
      ## of perturbations of x, then norm (fjac*e) <= eps*n*xn, i.e. by
      ## tolf ~ eps we demand as much accuracy as we can expect.
            if (fn <= dot(dot(tolf,n),xn)):
                info=1
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:394
            else:
                if (ratio >= 0.0001):
                    ## This one is classic. Note that we use scaled variables again,
        ## but compare to scaled step, so nothing bad.
                    if (sn <= dot(tolx,xn)):
                        info=2
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:400
                        ## for two different tests, but that's what M*b manual appears
          ## to say.
                    else:
                        if (actred < tolf):
                            info=3
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:405
            ## Criterion for recalculating Jacobian.
            if (logical_not(updating) or nfail == 2 or nsuciter < 2):
                break
            ## Compute the scaled Broyden update.
            if (useqr):
                u=(fvec1 - dot(q,w)) / sn
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:416
                v=multiply(dg,((multiply(dg,s)) / sn))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:417
                q,r=qrupdate(q,r,u,v,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:420
            else:
                u=(fvec1 - w)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:422
                v=multiply(dg,((multiply(dg,s)) / sn))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:423
                fjac += dot(u,v.T)


    
    ## Restore original shapes.
    x=reshape(x,xsiz)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:432
    fvec=reshape(fvec,fsiz)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:433
    output.iterations = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:435
    output.successful = copy(nsuciter)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:436
    output.funcCount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:437
    return x,fvec,info,output,fjac
    
if __name__ == '__main__':
    pass
    
    ## An assistant function that evaluates a function handle and checks for
## bad results.
    
@function
def guarded_eval(fun=None,x=None,complexeqn=None,*args,**kwargs):
    varargin = guarded_eval.varargin
    nargin = guarded_eval.nargin

    if (nargout > 1):
        fx,jx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:445
    else:
        fx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:447
        jx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:448
    
    if (logical_not(complexeqn) and logical_not((isreal(fx) and isreal(jx)))):
        error('fsolve:notreal','fsolve: non-real value encountered')
    else:
        if (complexeqn and logical_not((isnumeric(fx) and isnumeric(jx)))):
            error('fsolve:notnum','fsolve: non-numeric value encountered')
        else:
            if (any(isnan(ravel(fx)))):
                error('fsolve:isnan','fsolve: NaN value encountered')
            else:
                if (any(isinf(ravel(fx)))):
                    error('fsolve:isinf','fsolve: Inf value encountered')
    
    return fx,jx
    
if __name__ == '__main__':
    pass
    
    
@function
def make_fcn_jac(x=None,fcn=None,fjac=None,*args,**kwargs):
    varargin = make_fcn_jac.varargin
    nargin = make_fcn_jac.nargin

    fx=fcn[x]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:463
    if (nargout == 2):
        jx=fjac[x]
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:465
    
    return fx,jx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Solve the double dogleg trust-region least-squares problem:
## Minimize norm(r*x-b) subject to the constraint norm(d.*x) <= delta,
## x being a convex combination of the gauss-newton and scaled gradient.
    
    ## TODO: error checks
## TODO: handle singularity, or leave it up to mldivide?
    
    
@function
def __dogleg__(r=None,b=None,d=None,delta=None,*args,**kwargs):
    varargin = __dogleg__.varargin
    nargin = __dogleg__.nargin

    ## Get Gauss-Newton direction.
    x=numpy.linalg.solve(r,b)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:587
    xn=norm(multiply(d,x))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:588
    if (xn > delta):
        ## GN is too big, get scaled gradient.
        s=(dot(r.T,b)) / d
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:591
        sn=norm(s)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:592
        if (sn > 0):
            ## Normalize and rescale.
            s=(s / sn) / d
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:595
            tn=norm(dot(r,s))
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:597
            snm=(sn / tn) / tn
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:598
            if (snm < delta):
                ## Get the dogleg path minimizer.
                bn=norm(b)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:601
                dxn=delta / xn
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:602
                snmd=snm / delta
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:602
                t=dot(dot((bn / sn),(bn / xn)),snmd)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:603
                t -= dot(dxn,snmd ** 2) - sqrt((t - dxn) ** 2 + dot((1 - dxn ** 2),(1 - snmd ** 2)))
                alpha=dot(dxn,(1 - snmd ** 2)) / t
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:605
            else:
                alpha=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:607
        else:
            alpha=delta / xn
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:610
            snm=0
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:611
        ## Form the appropriate convex combination.
        x=dot(alpha,x) + dot((dot((1 - alpha),min(snm,delta))),s)
# /home/lei/octave-4.0.2/scripts/optimization/fsolve.m:614
    
    return x
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 John W. Eaton
## Copyright (C) 2013-2015 Arun Giridhar
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{obj}, @var{info}, @var{iter}, @var{nf}, @var{lambda}] =} sqp (@var{x0}, @var{phi})
## @deftypefnx {Function File} {[@dots{}] =} sqp (@var{x0}, @var{phi}, @var{g})
## @deftypefnx {Function File} {[@dots{}] =} sqp (@var{x0}, @var{phi}, @var{g}, @var{h})
## @deftypefnx {Function File} {[@dots{}] =} sqp (@var{x0}, @var{phi}, @var{g}, @var{h}, @var{lb}, @var{ub})
## @deftypefnx {Function File} {[@dots{}] =} sqp (@var{x0}, @var{phi}, @var{g}, @var{h}, @var{lb}, @var{ub}, @var{maxiter})
## @deftypefnx {Function File} {[@dots{}] =} sqp (@var{x0}, @var{phi}, @var{g}, @var{h}, @var{lb}, @var{ub}, @var{maxiter}, @var{tol})
## Minimize an objective function using sequential quadratic programming (SQP).
##
## Solve the nonlinear program
## @tex
## $$
## \min_x \phi (x)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## min phi (x)
##  x
## @end group
## @end example
##
## @end ifnottex
## subject to
## @tex
## $$
##  g(x) = 0 \qquad h(x) \geq 0 \qquad lb \leq x \leq ub
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## g(x)  = 0
## h(x) >= 0
## lb <= x <= ub
## @end group
## @end example
##
## @end ifnottex
## @noindent
## using a sequential quadratic programming method.
##
## The first argument is the initial guess for the vector @var{x0}.
##
## The second argument is a function handle pointing to the objective function
## @var{phi}.  The objective function must accept one vector argument and
## return a scalar.
##
## The second argument may also be a 2- or 3-element cell array of function
## handles.  The first element should point to the objective function, the
## second should point to a function that computes the gradient of the
## objective function, and the third should point to a function that computes
## the Hessian of the objective function.  If the gradient function is not
## supplied, the gradient is computed by finite differences.  If the Hessian
## function is not supplied, a BFGS update formula is used to approximate the
## Hessian.
##
## When supplied, the gradient function @code{@var{phi}@{2@}} must accept one
## vector argument and return a vector.  When supplied, the Hessian function
## @code{@var{phi}@{3@}} must accept one vector argument and return a matrix.
##
## The third and fourth arguments @var{g} and @var{h} are function handles
## pointing to functions that compute the equality constraints and the
## inequality constraints, respectively.  If the problem does not have
## equality (or inequality) constraints, then use an empty matrix ([]) for
## @var{g} (or @var{h}).  When supplied, these equality and inequality
## constraint functions must accept one vector argument and return a vector.
##
## The third and fourth arguments may also be 2-element cell arrays of
## function handles.  The first element should point to the constraint
## function and the second should point to a function that computes the
## gradient of the constraint function:
## @tex
## $$
##  \Bigg( {\partial f(x) \over \partial x_1},
##         {\partial f(x) \over \partial x_2}, \ldots,
##         {\partial f(x) \over \partial x_N} \Bigg)^T
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##             [ d f(x)   d f(x)        d f(x) ]
## transpose ( [ ------   -----   ...   ------ ] )
##             [  dx_1     dx_2          dx_N  ]
## @end group
## @end example
##
## @end ifnottex
## The fifth and sixth arguments, @var{lb} and @var{ub}, contain lower and
## upper bounds on @var{x}.  These must be consistent with the equality and
## inequality constraints @var{g} and @var{h}.  If the arguments are vectors
## then @var{x}(i) is bound by @var{lb}(i) and @var{ub}(i).  A bound can also
## be a scalar in which case all elements of @var{x} will share the same
## bound.  If only one bound (lb, ub) is specified then the other will
## default to (-@var{realmax}, +@var{realmax}).
##
## The seventh argument @var{maxiter} specifies the maximum number of
## iterations.  The default value is 100.
##
## The eighth argument @var{tol} specifies the tolerance for the stopping
## criteria.  The default value is @code{sqrt (eps)}.
##
## The value returned in @var{info} may be one of the following:
##
## @table @asis
## @item 101
## The algorithm terminated normally.
## All constraints meet the specified tolerance.
##
## @item 102
## The BFGS update failed.
##
## @item 103
## The maximum number of iterations was reached.
##
## @item 104
## The stepsize has become too small, i.e.,
## @tex
## $\Delta x,$
## @end tex
## @ifnottex
## delta @var{x},
## @end ifnottex
## is less than @code{@var{tol} * norm (x)}.
## @end table
##
## An example of calling @code{sqp}:
##
## @example
## function r = g (x)
##   r = [ sumsq(x)-10;
##         x(2)*x(3)-5*x(4)*x(5);
##         x(1)^3+x(2)^3+1 ];
## endfunction
##
## function obj = phi (x)
##   obj = exp (prod (x)) - 0.5*(x(1)^3+x(2)^3+1)^2;
## endfunction
##
## x0 = [-1.8; 1.7; 1.9; -0.8; -0.8];
##
## [x, obj, info, iter, nf, lambda] = sqp (x0, @@phi, @@g, [])
##
## x =
##
##   -1.71714
##    1.59571
##    1.82725
##   -0.76364
##   -0.76364
##
## obj = 0.053950
## info = 101
## iter = 8
## nf = 10
## lambda =
##
##   -0.0401627
##    0.0379578
##   -0.0052227
## @end example
##
## @seealso{qp}
## @end deftypefn
    
    
@function
def sqp(x0=None,objf=None,cef=None,cif=None,lb=None,ub=None,maxiter=None,tolerance=None,*args,**kwargs):
    varargin = sqp.varargin
    nargin = sqp.nargin

    globals=struct()
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:192
    
    if (nargin < 2 or nargin > 8 or nargin == 5):
        print_usage()
    
    if (logical_not(isvector(x0))):
        error('sqp: X0 must be a vector')
    
    if (rows(x0) == 1):
        x0=x0.T
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:202
    
    have_hess=0
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:205
    if (iscell(objf)):
        if 1 == (numel(objf)):
            obj_fun=objf[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:209
            obj_grd=lambda x=None: fd_obj_grd(x,obj_fun)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:210
        else:
            if 2 == (numel(objf)):
                obj_fun=objf[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:212
                obj_grd=objf[2]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:213
            else:
                if 3 == (numel(objf)):
                    obj_fun=objf[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:215
                    obj_grd=objf[2]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:216
                    obj_hess=objf[3]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:217
                    have_hess=1
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:218
                else:
                    error('sqp: invalid objective function specification')
    else:
        obj_fun=copy(objf)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:223
        obj_grd=lambda x=None: fd_obj_grd(x,obj_fun)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:224
    
    ce_fun=empty_cf
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:227
    ce_grd=empty_jac
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:228
    if (nargin > 2):
        if (iscell(cef)):
            if 1 == (numel(cef)):
                ce_fun=cef[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:233
                ce_grd=lambda x=None: fd_ce_jac(x,ce_fun)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:234
            else:
                if 2 == (numel(cef)):
                    ce_fun=cef[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:236
                    ce_grd=cef[2]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:237
                else:
                    error('sqp: invalid equality constraint function specification')
        else:
            if (logical_not(isempty(cef))):
                ce_fun=copy(cef)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:242
                ce_grd=lambda x=None: fd_ce_jac(x,ce_fun)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:243
    
    ci_fun=empty_cf
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:247
    ci_grd=empty_jac
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:248
    if (nargin > 3):
        ## constraint function given by user with possible gradient
        globals.cif = copy(cif)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:251
        globals.cifcn = copy(empty_cf)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:253
        if (iscell(cif)):
            if (length(cif) > 0):
                globals.cifcn = copy(cif[1])
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:256
        else:
            if (logical_not(isempty(cif))):
                globals.cifcn = copy(cif)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:259
        if (nargin < 5 or (nargin > 5 and isempty(lb) and isempty(ub))):
            ## constraint inequality function only without any bounds
            ci_grd=lambda x=None: fd_ci_jac(x,globals.cifcn)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:264
            if (iscell(cif)):
                if 1 == (length(cif)):
                    ci_fun=cif[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:268
                else:
                    if 2 == (length(cif)):
                        ci_fun=cif[1]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:270
                        ci_grd=cif[2]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:271
                    else:
                        error('sqp: invalid inequality constraint function specification')
            else:
                if (logical_not(isempty(cif))):
                    ci_fun=copy(cif)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:276
        else:
            ## constraint inequality function with bounds present
            lb_idx=ub_idx=true(size(x0))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:280
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:280
            ub_grad=- (lb_grad=eye(rows(x0))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:281)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:281
            if (isvector(lb)):
                globals.lb = copy(tmp_lb=ravel(lb)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:283)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:283
                ravel[lb_idx]=tmp_idx=(lb != - Inf)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:284
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:284
                globals.lb = copy(globals.lb(tmp_idx,1))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:285
                lb_grad=lb_grad[lb_idx,:]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:286
            else:
                if (isempty(lb)):
                    if (isa(x0,'single')):
                        globals.lb = copy(tmp_lb=- realmax('single')
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:289)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:289
                    else:
                        globals.lb = copy(tmp_lb=- realmax
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:291)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:291
                else:
                    error('sqp: invalid lower bound')
            if (isvector(ub)):
                globals.ub = copy(tmp_ub=ravel(ub)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:298)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:298
                ravel[ub_idx]=tmp_idx=(ub != Inf)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:299
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:299
                globals.ub = copy(globals.ub(tmp_idx,1))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:300
                ub_grad=ub_grad[ub_idx,:]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:301
            else:
                if (isempty(ub)):
                    if (isa(x0,'single')):
                        globals.ub = copy(tmp_ub=realmax('single')
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:304)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:304
                    else:
                        globals.ub = copy(tmp_ub=copy(realmax)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:306)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:306
                else:
                    error('sqp: invalid upper bound')
            if (any(tmp_lb > tmp_ub)):
                error('sqp: upper bound smaller than lower bound')
            bounds_grad=matlabarray(cat([lb_grad],[ub_grad]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:315
            ci_fun=lambda x=None: cf_ub_lb(x,lb_idx,ub_idx,globals)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:316
            ci_grd=lambda x=None: cigrad_ub_lb(x,bounds_grad,globals)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:317
    
    iter_max=100
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:322
    if (nargin > 6 and logical_not(isempty(maxiter))):
        if (isscalar(maxiter) and maxiter > 0 and fix(maxiter) == maxiter):
            iter_max=copy(maxiter)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:325
        else:
            error('sqp: invalid number of maximum iterations')
    
    tol=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:331
    if (nargin > 7 and logical_not(isempty(tolerance))):
        if (isscalar(tolerance) and tolerance > 0):
            tol=copy(tolerance)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:334
        else:
            error('sqp: invalid value for TOLERANCE')
    
    ## Initialize variables for search loop
  ## Seed x with initial guess and evaluate objective function, constraints,
  ## and gradients at initial value x0.
  ##
  ## obj_fun   -- objective function
  ## obj_grad  -- objective gradient
  ## ce_fun    -- equality constraint functions
  ## ci_fun    -- inequality constraint functions
  ## A == [grad_{x_1} cx_fun, grad_{x_2} cx_fun, ..., grad_{x_n} cx_fun]^T
    x=copy(x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:349
    obj=feval(obj_fun,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:351
    globals.nfun = copy(1)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:352
    c=feval(obj_grd,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:354
    
    n=length(x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:357
    if (have_hess):
        B=feval(obj_hess,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:359
    else:
        B=eye(n,n)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:361
    
    ce=feval(ce_fun,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:364
    F=feval(ce_grd,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:365
    ci=feval(ci_fun,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:367
    C=feval(ci_grd,x0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:368
    A=matlabarray(cat([F],[C]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:370
    
    lambda_=dot(100,ones(rows(A),1))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:373
    qp_iter=1
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:375
    alpha=1
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:376
    info=0
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:378
    iter=0
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:379
    
    # report (iter, qp_iter, alpha, __sqp_nfun__, obj);
    
    while (++ iter < iter_max):

        ## Check convergence.  This is just a simple check on the first
    ## order necessary conditions.
        nr_f=rows(F)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:387
        lambda_e=lambda_[(arange(1,nr_f)).T]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:389
        lambda_i=lambda_[(arange(nr_f + 1,end())).T]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:390
        con=matlabarray(cat([ce],[ci]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:392
        t0=norm(c - dot(A.T,lambda_))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:394
        t1=norm(ce)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:395
        t2=all(ci >= 0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:396
        t3=all(lambda_i >= 0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:397
        t4=norm(multiply(lambda_,con))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:398
        ## and objective has converged.
        if (t2 and t3 and max(cat([t0],[t1],[t4])) < tol):
            info=101
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:403
            break
        ## Compute search direction p by solving QP.
        g=- ce
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:408
        d=- ci
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:409
        p,obj_qp,INFO,lambda_=qp(x,B,c,F,g,[],[],d,C,Inf(size(d)),nargout=4)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:411
        info=INFO.info
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:414
        ##        For now, just warn about possible problems.
        id='Octave:SQP-QP-subproblem'
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:419
        if 2 == (info):
            warning(id,'sqp: QP subproblem is non-convex and unbounded')
        else:
            if 3 == (info):
                warning(id,'sqp: QP subproblem failed to converge in %d iterations',INFO.solveiter)
            else:
                if 6 == (info):
                    warning(id,'sqp: QP subproblem is infeasible')
        ## Choose mu such that p is a descent direction for the chosen
    ## merit function phi.
        x_new,alpha,obj_new,globals=linesearch_L1(x,p,obj_fun,obj_grd,ce_fun,ci_fun,lambda_,obj,globals,nargout=4)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:432
        c_new=feval(obj_grd,x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:437
        ce_new=feval(ce_fun,x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:439
        F_new=feval(ce_grd,x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:440
        ci_new=feval(ci_fun,x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:442
        C_new=feval(ci_grd,x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:443
        A_new=matlabarray(cat([F_new],[C_new]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:445
        ##
    ## s = alpha * p
    ## y = grad_x L (x_new, lambda) - grad_x L (x, lambda})
        y=c_new - c
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:452
        if (logical_not(isempty(A))):
            t=(dot((A_new - A).T,lambda_))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:455
            y -= t
        delx=x_new - x
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:459
        if (norm(delx) < dot(tol,norm(x))):
            info=104
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:463
            break
        if (have_hess):
            B=feval(obj_hess,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:469
        else:
            ## Update B using a quasi-Newton formula.
            delxt=delx.T
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:473
            ## of the Lagrangian, computed directly?
            d1=dot(dot(delxt,B),delx)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:477
            t1=dot(0.2,d1)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:479
            t2=dot(delxt,y)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:480
            if (t2 < t1):
                theta=dot(0.8,d1) / (d1 - t2)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:483
            else:
                theta=1
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:485
            r=dot(theta,y) + dot(dot((1 - theta),B),delx)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:488
            d2=dot(delxt,r)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:490
            ## If d1 or d2 vanish, the BFGS update will fail.
            if (d1 == 0 or d2 == 0):
                info=102
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:495
                break
            B=B - dot(dot(dot(B,delx),delxt),B) / d1 + dot(r,r.T) / d2
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:499
        x=copy(x_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:503
        obj=copy(obj_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:505
        c=copy(c_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:507
        ce=copy(ce_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:509
        F=copy(F_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:510
        ci=copy(ci_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:512
        C=copy(C_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:513
        A=copy(A_new)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:515

    
    ## Check if we've spent too many iterations without converging.
    if (iter >= iter_max):
        info=103
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:523
    
    nf=globals.nfun
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:526
    return x,obj,info,iter,nf,lambda_
    
if __name__ == '__main__':
    pass
    
    
@function
def phi_L1(obj=None,obj_fun=None,ce_fun=None,ci_fun=None,x=None,mu=None,globals=None,*args,**kwargs):
    varargin = phi_L1.varargin
    nargin = phi_L1.nargin

    ce=feval(ce_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:534
    ci=feval(ci_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:535
    idx=ci < 0
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:537
    con=matlabarray(cat([ce],[ci[idx]]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:539
    if (isempty(obj)):
        obj=feval(obj_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:542
        globals.nfun
    
    merit=copy(obj)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:546
    t=norm(con,1) / mu
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:547
    if (logical_not(isempty(t))):
        merit += t
    
    return merit,obj,globals
    
if __name__ == '__main__':
    pass
    
    
@function
def linesearch_L1(x=None,p=None,obj_fun=None,obj_grd=None,ce_fun=None,ci_fun=None,lambda_=None,obj=None,globals=None,*args,**kwargs):
    varargin = linesearch_L1.varargin
    nargin = linesearch_L1.nargin

    ## Choose parameters
  ##
  ## eta in the range (0, 0.5)
  ## tau in the range (0, 1)
    
    eta=0.25
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:565
    tau=0.5
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:566
    delta_bar=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:568
    if (isempty(lambda_)):
        mu=1 / delta_bar
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:571
    else:
        mu=1 / (norm(lambda_,Inf) + delta_bar)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:573
    
    alpha=1
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:576
    c=feval(obj_grd,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:578
    ce=feval(ce_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:579
    phi_x_mu,obj,globals=phi_L1(obj,obj_fun,ce_fun,ci_fun,x,mu,globals,nargout=3)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:581
    D_phi_x_mu=dot(c.T,p)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:584
    d=feval(ci_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:585
    
    ## to violated constraints should be included.
    idx=d < 0
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:588
    t=- norm(cat([ce],[d[idx]]),1) / mu
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:589
    if (logical_not(isempty(t))):
        D_phi_x_mu += t
    
    while (1):

        p1,obj,globals=phi_L1([],obj_fun,ce_fun,ci_fun,x + dot(alpha,p),mu,globals,nargout=3)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:595
        p2=phi_x_mu + dot(dot(eta,alpha),D_phi_x_mu)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:597
        if (p1 > p2):
            ## Reset alpha = tau_alpha * alpha for some tau_alpha in the
      ## range (0, tau).
            tau_alpha=dot(0.9,tau)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:601
            alpha=dot(tau_alpha,alpha)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:602
        else:
            break

    
    x_new=x + dot(alpha,p)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:608
    return x_new,alpha,obj,globals
    
if __name__ == '__main__':
    pass
    
    
@function
def fdgrd(f=None,x=None,*args,**kwargs):
    varargin = fdgrd.varargin
    nargin = fdgrd.nargin

    if (logical_not(isempty(f))):
        y0=feval(f,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:616
        nx=length(x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:617
        grd=zeros(nx,1)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:618
        deltax=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:619
        for i in arange(1,nx).reshape(-1):
            t=x[i]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:621
            x[i] += deltax
            grd[i]=(feval(f,x) - y0) / deltax
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:623
            x[i]=t
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:624
    else:
        grd=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:627
    
    return grd
    
if __name__ == '__main__':
    pass
    
    
@function
def fdjac(f=None,x=None,*args,**kwargs):
    varargin = fdjac.varargin
    nargin = fdjac.nargin

    nx=length(x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:635
    if (logical_not(isempty(f))):
        y0=feval(f,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:637
        nf=length(y0)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:638
        nx=length(x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:639
        jac=zeros(nf,nx)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:640
        deltax=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:641
        for i in arange(1,nx).reshape(-1):
            t=x[i]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:643
            x[i] += deltax
            jac[:,i]=(feval(f,x) - y0) / deltax
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:645
            x[i]=t
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:646
    else:
        jac=zeros(0,nx)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:649
    
    return jac
    
if __name__ == '__main__':
    pass
    
    
@function
def fd_obj_grd(x=None,obj_fun=None,*args,**kwargs):
    varargin = fd_obj_grd.varargin
    nargin = fd_obj_grd.nargin

    grd=fdgrd(obj_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:657
    return grd
    
if __name__ == '__main__':
    pass
    
    
@function
def empty_cf(x=None,*args,**kwargs):
    varargin = empty_cf.varargin
    nargin = empty_cf.nargin

    res=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:664
    return res
    
if __name__ == '__main__':
    pass
    
    
@function
def empty_jac(x=None,*args,**kwargs):
    varargin = empty_jac.varargin
    nargin = empty_jac.nargin

    res=zeros(0,length(x))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:671
    return res
    
if __name__ == '__main__':
    pass
    
    
@function
def fd_ce_jac(x=None,ce_fun=None,*args,**kwargs):
    varargin = fd_ce_jac.varargin
    nargin = fd_ce_jac.nargin

    jac=fdjac(ce_fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:678
    return jac
    
if __name__ == '__main__':
    pass
    
    
@function
def fd_ci_jac(x=None,cifcn=None,*args,**kwargs):
    varargin = fd_ci_jac.varargin
    nargin = fd_ci_jac.nargin

    ## cifcn = constraint function without gradients and lb or ub
    jac=fdjac(cifcn,x)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:686
    return jac
    
if __name__ == '__main__':
    pass
    
    
@function
def cf_ub_lb(x=None,lbidx=None,ubidx=None,globals=None,*args,**kwargs):
    varargin = cf_ub_lb.varargin
    nargin = cf_ub_lb.nargin

    ## combine constraint function with ub and lb
    if (isempty(globals.cifcn)):
        res=matlabarray(cat([x[lbidx,1] - globals.lb],[globals.ub - x[ubidx,1]]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:695
    else:
        res=matlabarray(cat([feval(globals.cifcn,x)],[x[lbidx,1] - globals.lb],[globals.ub - x[ubidx,1]]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:697
    
    return res
    
if __name__ == '__main__':
    pass
    
    
@function
def cigrad_ub_lb(x=None,bgrad=None,globals=None,*args,**kwargs):
    varargin = cigrad_ub_lb.varargin
    nargin = cigrad_ub_lb.nargin

    cigradfcn=lambda x=None: fd_ci_jac(x,globals.cifcn)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:706
    if (iscell(globals.cif) and length(globals.cif) > 1):
        cigradfcn=globals.cif[2]
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:709
    
    if (isempty(cigradfcn)):
        res=copy(bgrad)
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:713
    else:
        res=matlabarray(cat([feval(cigradfcn,x)],[bgrad]))
# /home/lei/octave-4.0.2/scripts/optimization/sqp.m:715
    
    return res
    
if __name__ == '__main__':
    pass
    
    ## Utility function used to debug sqp
    
@function
def report(iter=None,qp_iter=None,alpha=None,nfun=None,obj=None,*args,**kwargs):
    varargin = report.varargin
    nargin = report.nargin

    if (nargin == 0):
        printf('  Itn ItQP     Step  Nfun     Objective\n')
    else:
        printf('%5d %4d %8.1g %5d %13.6e\n',iter,qp_iter,alpha,nfun,obj)
    
    return
    
if __name__ == '__main__':
    pass
    
    ################################################################################
## Test Code
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Jaroslav Hajek
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} optimget (@var{options}, @var{parname})
## @deftypefnx {Function File} {} optimget (@var{options}, @var{parname}, @var{default})
## Return the specific option @var{parname} from the optimization options
## structure @var{options} created by @code{optimset}.
##
## If @var{parname} is not defined then return @var{default} if supplied,
## otherwise return an empty matrix.
## @seealso{optimset}
## @end deftypefn
    
    
@function
def optimget(options=None,parname=None,default=None,*args,**kwargs):
    varargin = optimget.varargin
    nargin = optimget.nargin

    if (nargin < 2 or nargin > 4 or logical_not(isstruct(options)) or logical_not(ischar(parname))):
        print_usage()
    
    ## Expand partial-length names into full names
    opts=__all_opts__()
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:38
    idx=strncmpi(opts,parname,length(parname))
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:39
    nmatch=sum(idx)
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:40
    if (nmatch == 1):
        parname=opts[idx]
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:43
    else:
        if (nmatch == 0):
            warning('optimget: unrecognized option: %s',parname)
        else:
            fmt=sprintf('optimget: ambiguous option: %%s (%s%%s)',repmat('%s, ',1,nmatch - 1))
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:47
            warning(fmt,parname,opts[idx])
    
    if (isfield(options,parname) and logical_not(isempty(getattr(options,(parname))))):
        retval=getattr(options,(parname))
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:53
    else:
        if (nargin > 2):
            retval=copy(default)
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:55
        else:
            retval=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/optimget.m:57
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{names} =} __all_opts__ (@dots{})
## Undocumented internal function.
## @end deftypefn
    
    ## Query all options from all known optimization functions and return a
## list of possible values.
    
    
@function
def __all_opts__(varargin=None,*args,**kwargs):
    varargin = __all_opts__.varargin
    nargin = __all_opts__.nargin

    
    
    mlock()
    
    
    if (recursive):
        names=cellarray([])
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:38
    else:
        if (nargin == 0):
            names=copy(saved_names)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:40
        else:
            ## query all options from all known functions. These will call optimset,
    ## which will in turn call us, but we won't answer.
            recursive=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:44
            names=copy(saved_names)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:45
            for i in arange(1,nargin).reshape(-1):
                try:
                    opts=optimset(varargin[i])
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:48
                    fn=fieldnames(opts).T
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:49
                    names=matlabarray(cat(names,fn))
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:50
                finally:
                    pass
            names=unique(names)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:56
            lnames,idx=unique(tolower(names),nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:57
            if (length(lnames) < length(names)):
                ## This is bad.
                error('__all_opts__: duplicate options with inconsistent case')
            else:
                names=names[idx]
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:62
            saved_names=copy(names)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:64
            recursive=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/__all_opts__.m:65
    
    return names
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 2013-2015 Julien Bect
## Copyright (C) 2000-2015 Gabriele Pannocchia.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@var{x0}, @var{H})
## @deftypefnx {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@var{x0}, @var{H}, @var{q})
## @deftypefnx {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@var{x0}, @var{H}, @var{q}, @var{A}, @var{b})
## @deftypefnx {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@var{x0}, @var{H}, @var{q}, @var{A}, @var{b}, @var{lb}, @var{ub})
## @deftypefnx {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@var{x0}, @var{H}, @var{q}, @var{A}, @var{b}, @var{lb}, @var{ub}, @var{A_lb}, @var{A_in}, @var{A_ub})
## @deftypefnx {Function File} {[@var{x}, @var{obj}, @var{info}, @var{lambda}] =} qp (@dots{}, @var{options})
## Solve a quadratic program (QP).
##
## Solve the quadratic program defined by
## @tex
## $$
##  \min_x {1 \over 2} x^T H x + x^T q
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## min 0.5 x'*H*x + x'*q
##  x
## @end group
## @end example
##
## @end ifnottex
## subject to
## @tex
## $$
##  Ax = b \qquad lb \leq x \leq ub \qquad A_{lb} \leq A_{in} \leq A_{ub}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## A*x = b
## lb <= x <= ub
## A_lb <= A_in*x <= A_ub
## @end group
## @end example
##
## @end ifnottex
## @noindent
## using a null-space active-set method.
##
## Any bound (@var{A}, @var{b}, @var{lb}, @var{ub}, @var{A_lb}, @var{A_ub})
## may be set to the empty matrix (@code{[]}) if not present.  If the initial
## guess is feasible the algorithm is faster.
##
## @table @var
## @item options
## An optional structure containing the following parameter(s) used to define
## the behavior of the solver.  Missing elements in the structure take on
## default values, so you only need to set the elements that you wish to
## change from the default.
##
## @table @code
## @item MaxIter (default: 200)
## Maximum number of iterations.
## @end table
## @end table
##
## @table @var
## @item info
## Structure containing run-time information about the algorithm.  The
## following fields are defined:
##
## @table @code
## @item solveiter
## The number of iterations required to find the solution.
##
## @item info
## An integer indicating the status of the solution.
##
## @table @asis
## @item 0
## The problem is feasible and convex.  Global solution found.
##
## @item 1
## The problem is not convex.  Local solution found.
##
## @item 2
## The problem is not convex and unbounded.
##
## @item 3
## Maximum number of iterations reached.
##
## @item 6
## The problem is infeasible.
## @end table
## @end table
## @end table
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("qp");
    
    
@function
def qp(x0=None,H=None,varargin=None,*args,**kwargs):
    varargin = qp.varargin
    nargin = qp.nargin

    nargs=copy(nargin)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:119
    if (nargin == 1 and ischar(x0) and strcmp(x0,'defaults')):
        x=optimset('MaxIter',200)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:122
        return x,obj,INFO,lambda_
    
    if (nargs > 2 and isstruct(varargin[end()])):
        options=varargin[end()]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:127
        nargs
    else:
        options=struct()
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:130
    
    if (nargs >= 3):
        q=varargin[1]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:134
    else:
        q=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:136
    
    if (nargs >= 5):
        A=varargin[2]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:140
        b=varargin[3]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:141
    else:
        A=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:143
        b=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:144
    
    if (nargs >= 7):
        lb=varargin[4]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:148
        ub=varargin[5]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:149
    else:
        lb=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:151
        ub=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:152
    
    if (nargs == 10):
        A_lb=varargin[6]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:156
        A_in=varargin[7]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:157
        A_ub=varargin[8]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:158
    else:
        A_lb=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:160
        A_in=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:161
        A_ub=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:162
    
    if (nargs == 2 or nargs == 3 or nargs == 5 or nargs == 7 or nargs == 10):
        maxit=optimget(options,'MaxIter',200)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:167
        if (logical_not(issquare(H))):
            error('qp: quadratic penalty matrix not square')
        else:
            if (logical_not(ishermitian(H))):
                ## warning ("qp: quadratic penalty matrix not hermitian");
                H=(H + H.T) / 2
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:174
        n=rows(H)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:176
        ## right dimension and filled with 0)
        if (isempty(x0)):
            x0=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:181
        else:
            if (numel(x0) != n):
                error('qp: the initial guess has incorrect length')
        ## Linear penalty.
        if (isempty(q)):
            q=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:188
        else:
            if (numel(q) != n):
                error('qp: the linear term has incorrect length')
        ## Equality constraint matrices
        if (isempty(A) or isempty(b)):
            A=zeros(0,n)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:195
            b=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:196
            n_eq=0
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:197
        else:
            n_eq,n1=size(A,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:199
            if (n1 != n):
                error('qp: equality constraint matrix has incorrect column dimension')
            if (numel(b) != n_eq):
                error('qp: equality constraint matrix and vector have inconsistent dimension')
        ## Bound constraints
        Ain=zeros(0,n)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:209
        bin=zeros(0,1)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:210
        n_in=0
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:211
        if (nargs > 5):
            if (logical_not(isempty(lb))):
                if (numel(lb) != n):
                    error('qp: lower bound has incorrect length')
                else:
                    if (isempty(ub)):
                        Ain=matlabarray(cat([Ain],[eye(n)]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:217
                        bin=matlabarray(cat([bin],[lb]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:218
            if (logical_not(isempty(ub))):
                if (numel(ub) != n):
                    error('qp: upper bound has incorrect length')
                else:
                    if (isempty(lb)):
                        Ain=matlabarray(cat([Ain],[- eye(n)]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:226
                        bin=matlabarray(cat([bin],[- ub]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:227
            if (logical_not(isempty(lb)) and logical_not(isempty(ub))):
                rtol=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:232
                for i in arange(1,n).reshape(-1):
                    if (abs(lb[i] - ub[i]) < dot(rtol,(1 + max(abs(lb[i] + ub[i]))))):
                        ## These are actually an equality constraint
                        tmprow=zeros(1,n)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:236
                        tmprow[i]=1
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:237
                        A=matlabarray(cat([A],[tmprow]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:238
                        b=matlabarray(cat([b],[dot(0.5,(lb[i] + ub[i]))]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:239
                        n_eq=n_eq + 1
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:240
                    else:
                        tmprow=zeros(1,n)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:242
                        tmprow[i]=1
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:243
                        Ain=matlabarray(cat([Ain],[tmprow],[- tmprow]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:244
                        bin=matlabarray(cat([bin],[lb[i]],[- ub[i]]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:245
                        n_in=n_in + 2
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:246
        ## Inequality constraints
        if (nargs > 7):
            dimA_in,n1=size(A_in,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:254
            if (n1 != n):
                error('qp: inequality constraint matrix has incorrect column dimension')
            else:
                if (logical_not(isempty(A_lb))):
                    if (numel(A_lb) != dimA_in):
                        error('qp: inequality constraint matrix and lower bound vector inconsistent')
                    else:
                        if (isempty(A_ub)):
                            Ain=matlabarray(cat([Ain],[A_in]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:262
                            bin=matlabarray(cat([bin],[A_lb]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:263
                if (logical_not(isempty(A_ub))):
                    if (numel(A_ub) != dimA_in):
                        error('qp: inequality constraint matrix and upper bound vector inconsistent')
                    else:
                        if (isempty(A_lb)):
                            Ain=matlabarray(cat([Ain],[- A_in]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:270
                            bin=matlabarray(cat([bin],[- A_ub]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:271
                if (logical_not(isempty(A_lb)) and logical_not(isempty(A_ub))):
                    rtol=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:276
                    for i in arange(1,dimA_in).reshape(-1):
                        if (abs(A_lb[i] - A_ub[i]) < dot(rtol,(1 + max(abs(A_lb[i] + A_ub[i]))))):
                            ## These are actually an equality constraint
                            tmprow=A_in[i,:]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:281
                            A=matlabarray(cat([A],[tmprow]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:282
                            b=matlabarray(cat([b],[dot(0.5,(A_lb[i] + A_ub[i]))]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:283
                            n_eq=n_eq + 1
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:284
                        else:
                            tmprow=A_in[i,:]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:286
                            Ain=matlabarray(cat([Ain],[tmprow],[- tmprow]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:287
                            bin=matlabarray(cat([bin],[A_lb[i]],[- A_ub[i]]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:288
                            n_in=n_in + 2
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:289
        ## Now we should have the following QP:
    ##
    ##   min_x  0.5*x'*H*x + x'*q
    ##   s.t.   A*x = b
    ##          Ain*x >= bin
        ## Discard inequality constraints that have -Inf bounds since those
    ## will never be active.
        idx=logical_and(isinf(bin),bin) < 0
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:304
        bin[idx]=[]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:306
        Ain[idx,:]=[]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:307
        n_in=numel(bin)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:309
        if (isa(x0,'single') or isa(H,'single') or isa(q,'single') or isa(A,'single') or isa(b,'single')):
            rtol=sqrt(eps('single'))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:314
        else:
            rtol=sqrt(eps)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:316
        eq_infeasible=(n_eq > 0 and norm(dot(A,x0) - b) > dot(rtol,(1 + abs(b))))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:319
        in_infeasible=(n_in > 0 and any(dot(Ain,x0) - bin < dot(- rtol,(1 + abs(bin)))))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:320
        info=0
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:322
        if (eq_infeasible or in_infeasible):
            ## The initial guess is not feasible.
      ## First define xbar that is feasible with respect to the equality
      ## constraints.
            if (eq_infeasible):
                if (rank(A) < n_eq):
                    error('qp: equality constraint matrix must be full row rank')
                xbar=dot(pinv(A),b)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:331
            else:
                xbar=copy(x0)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:333
            ## Check if xbar is feasible with respect to the inequality
      ## constraints also.
            if (n_in > 0):
                res=dot(Ain,xbar) - bin
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:339
                if (any(res < dot(- rtol,(1 + abs(bin))))):
                    ## xbar is not feasible with respect to the inequality
          ## constraints.  Compute a step in the null space of the
          ## equality constraints, by solving a QP.  If the slack is
          ## small, we have a feasible initial guess.  Otherwise, the
          ## problem is infeasible.
                    if (n_eq > 0):
                        Z=null(A)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:347
                        if (isempty(Z)):
                            ## The problem is infeasible because A is square and full
              ## rank, but xbar is not feasible.
                            info=6
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:351
                    if (info != 6):
                        ## Solve an LP with additional slack variables to find
            ## a feasible starting point.
                        gamma=eye(n_in)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:358
                        if (n_eq > 0):
                            Atmp=matlabarray(cat(dot(Ain,Z),gamma))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:360
                            btmp=- res
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:361
                        else:
                            Atmp=matlabarray(cat(Ain,gamma))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:363
                            btmp=copy(bin)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:364
                        ctmp=matlabarray(cat([zeros(n - n_eq,1)],[ones(n_in,1)]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:366
                        lb=matlabarray(cat([- Inf(n - n_eq,1)],[zeros(n_in,1)]))
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:367
                        ub=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:368
                        ctype=repmat('L',n_in,1)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:369
                        P,dummy,status=glpk(ctmp,Atmp,btmp,lb,ub,ctype,nargout=3)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:370
                        if ((status == 0) and all(abs(P[n - n_eq + 1:end()]) < dot(rtol,(1 + norm(btmp))))):
                            ## We found a feasible starting point
                            if (n_eq > 0):
                                x0=xbar + dot(Z,P[1:n - n_eq])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:375
                            else:
                                x0=P[1:n]
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:377
                        else:
                            ## The problem is infeasible
                            info=6
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:381
                else:
                    ## xbar is feasible.  We use it a starting point.
                    x0=copy(xbar)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:386
            else:
                ## xbar is feasible.  We use it a starting point.
                x0=copy(xbar)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:390
        if (info == 0):
            ## The initial (or computed) guess is feasible.
      ## We call the solver.
            x,lambda_,info,iter=__qp__(x0,H,q,A,b,Ain,bin,maxit,nargout=4)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:397
        else:
            iter=0
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:399
            x=copy(x0)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:400
            lambda_=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:401
        obj=dot(dot(dot(0.5,x.T),H),x) + dot(q.T,x)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:403
        INFO.solveiter = copy(iter)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:404
        INFO.info = copy(info)
# /home/lei/octave-4.0.2/scripts/optimization/qp.m:405
    else:
        print_usage()
    
    return x,obj,INFO,lambda_
    
if __name__ == '__main__':
    pass
    
    ## Test infeasible initial guess (bug #40536)
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __fdjac__ (@var{fcn}, @var{x}, @var{fvec}, @var{err})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __fdjac__(fcn=None,x=None,fvec=None,typicalx=None,cdif=None,err=0,*args,**kwargs):
    varargin = __fdjac__.varargin
    nargin = __fdjac__.nargin

    if (cdif):
        err=(max(eps,err)) ** (1 / 3)
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:26
        h=dot(typicalx,err)
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:27
        fjac=zeros(length(fvec),numel(x))
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:28
        for i in arange(1,numel(x)).reshape(-1):
            x1=x2=copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:30
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:30
            x1[i] += h[i]
            x2[i] -= h[i]
            fjac[:,i]=(ravel(fcn[x1]) - ravel(fcn[x2])) / (x1[i] - x2[i])
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:33
    else:
        err=sqrt(max(eps,err))
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:36
        h=dot(typicalx,err)
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:37
        fjac=zeros(length(fvec),numel(x))
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:38
        for i in arange(1,numel(x)).reshape(-1):
            x1=copy(x)
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:40
            x1[i] += h[i]
            fjac[:,i]=(ravel(fcn[x1]) - fvec) / (x1[i] - x[i])
# /home/lei/octave-4.0.2/scripts/optimization/private/__fdjac__.m:42
    
    return fjac
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Author: Jaroslav Hajek <highegg@gmail.com>
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fminunc (@var{fcn}, @var{x0})
## @deftypefnx {Function File} {} fminunc (@var{fcn}, @var{x0}, @var{options})
## @deftypefnx {Function File} {[@var{x}, @var{fval}, @var{info}, @var{output}, @var{grad}, @var{hess}] =} fminunc (@var{fcn}, @dots{})
## Solve an unconstrained optimization problem defined by the function
## @var{fcn}.
##
## @var{fcn} should accept a vector (array) defining the unknown variables, and
## return the objective function value, optionally with gradient.
## @code{fminunc} attempts to determine a vector @var{x} such that
## @code{@var{fcn} (@var{x})} is a local minimum.
##
## @var{x0} determines a starting guess.  The shape of @var{x0} is preserved in
## all calls to @var{fcn}, but otherwise is treated as a column vector.
##
## @var{options} is a structure specifying additional options.  Currently,
## @code{fminunc} recognizes these options:
## @qcode{"FunValCheck"}, @qcode{"OutputFcn"}, @qcode{"TolX"},
## @qcode{"TolFun"}, @qcode{"MaxIter"}, @qcode{"MaxFunEvals"},
## @qcode{"GradObj"}, @qcode{"FinDiffType"}, @qcode{"TypicalX"},
## @qcode{"AutoScaling"}.
##
## If @qcode{"GradObj"} is @qcode{"on"}, it specifies that @var{fcn}, when
## called with 2 output arguments, also returns the Jacobian matrix of partial
## first derivatives at the requested point.  @code{TolX} specifies the
## termination tolerance for the unknown variables @var{x}, while @code{TolFun}
## is a tolerance for the objective function value @var{fval}.  The default is
## @code{1e-7} for both options.
##
## For a description of the other options, see @code{optimset}.
##
## On return, @var{x} is the location of the minimum and @var{fval} contains
## the value of the objective function at @var{x}.
##
## @var{info} may be one of the following values:
##
## @table @asis
## @item 1
## Converged to a solution point.  Relative gradient error is less than
## specified by @code{TolFun}.
##
## @item 2
## Last relative step size was less than @code{TolX}.
##
## @item 3
## Last relative change in function value was less than @code{TolFun}.
##
## @item 0
## Iteration limit exceeded---either maximum number of algorithm iterations
## @code{MaxIter} or maximum number of function evaluations @code{MaxFunEvals}.
##
## @item -1
## Algorithm terminated by @code{OutputFcn}.
##
## @item -3
## The trust region radius became excessively small.
## @end table
##
## Optionally, @code{fminunc} can return a structure with convergence statistics
## (@var{output}), the output gradient (@var{grad}) at the solution @var{x},
## and approximate Hessian (@var{hess}) at the solution @var{x}.
##
## Application Notes: If have only a single nonlinear equation of one variable
## then using @code{fminbnd} is usually a better choice.
##
## The algorithm used by @code{fminsearch} is a gradient search which depends
## on the objective function being differentiable.  If the function has
## discontinuities it may be better to use a derivative-free algorithm such as
## @code{fminsearch}.
## @seealso{fminbnd, fminsearch, optimset}
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("fminunc");
    
    
@function
def fminunc(fcn=None,x0=None,options=struct(),*args,**kwargs):
    varargin = fminunc.varargin
    nargin = fminunc.nargin

    ## Get default options if requested.
    if (nargin == 1 and ischar(fcn) and strcmp(fcn,'defaults')):
        x=optimset('MaxIter',400,'MaxFunEvals',Inf,'GradObj','off','TolX',1e-07,'TolFun',1e-07,'OutputFcn',[],'FunValCheck','off','FinDiffType','central','TypicalX',[],'AutoScaling','off')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:100
        return x,fval,info,output,grad,hess
    
    if (nargin < 2 or nargin > 3 or logical_not(isnumeric(x0))):
        print_usage()
    
    if (ischar(fcn)):
        fcn=str2func(fcn,'global')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:113
    
    xsiz=size(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:116
    n=numel(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:117
    has_grad=strcmpi(optimget(options,'GradObj','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:119
    cdif=strcmpi(optimget(options,'FinDiffType','central'),'central')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:120
    maxiter=optimget(options,'MaxIter',400)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:121
    maxfev=optimget(options,'MaxFunEvals',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:122
    outfcn=optimget(options,'OutputFcn')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:123
    
    ## scaling matrix is estimated using the jacobian.
    typicalx=optimget(options,'TypicalX')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:127
    if (isempty(typicalx)):
        typicalx=ones(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:129
    
    autoscale=strcmpi(optimget(options,'AutoScaling','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:131
    if (logical_not(autoscale)):
        dg=1 / typicalx
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:133
    
    funvalchk=strcmpi(optimget(options,'FunValCheck','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:136
    if (funvalchk):
        ## Replace fcn with a guarded version.
        fcn=lambda x=None: guarded_eval(fcn,x)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:140
    
    ## These defaults are rather stringent. I think that normally, user
  ## prefers accuracy to performance.
    
    macheps=eps(class_(x0))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:146
    tolx=optimget(options,'TolX',1e-07)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:148
    tolf=optimget(options,'TolFun',1e-07)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:149
    factor=0.1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:151
    
    autodg=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:153
    niter=1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:155
    nfev=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:156
    x=ravel(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:158
    info=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:159
    
    fval=fcn[reshape(x,xsiz)]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:162
    n=length(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:163
    if (logical_not(isempty(outfcn))):
        optimvalues.iter = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:166
        optimvalues.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:167
        optimvalues.fval = copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:168
        optimvalues.searchdirection = copy(zeros(n,1))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:169
        state='init'
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:170
        stop=outfcn[x,optimvalues,state]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:171
        if (stop):
            info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:173
            break
    
    nsuciter=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:178
    lastratio=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:179
    grad=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:181
    
    while (niter < maxiter and nfev < maxfev and logical_not(info)):

        grad0=copy(grad)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:186
        if (has_grad):
            fval,grad=fcn[reshape(x,xsiz)]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:190
            grad=ravel(grad)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:191
            nfev
        else:
            grad=ravel(__fdjac__(fcn,reshape(x,xsiz),fval,typicalx,cdif))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:194
            nfev += dot((1 + cdif),length(x))
        if (niter == 1):
            ## Initialize by identity matrix.
            hesr=eye(n)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:200
        else:
            ## Use the damped BFGS formula.
            y=grad - grad0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:203
            sBs=sumsq(w)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:204
            Bs=dot(hesr.T,w)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:205
            sy=dot(y.T,s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:206
            theta=0.8 / max(1 - sy / sBs,0.8)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:207
            r=dot(theta,y) + dot((1 - theta),Bs)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:208
            hesr=cholupdate(hesr,r / sqrt(dot(s.T,r)),'+')
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:209
            hesr,info=cholupdate(hesr,Bs / sqrt(sBs),'-',nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:210
            if (info):
                hesr=eye(n)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:212
        if (autoscale):
            ## Second derivatives approximate the hessian.
            d2f=norm(hesr,'columns').T
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:218
            if (niter == 1):
                dg=copy(d2f)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:220
            else:
                ## FIXME: maybe fixed lower and upper bounds?
                dg=max(dot(0.1,dg),d2f)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:223
        if (niter == 1):
            xn=norm(multiply(dg,x))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:228
            delta=dot(factor,max(xn,1))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:230
        ## FIXME: why tolf*n*xn?  If abs (e) ~ abs(x) * eps is a vector
    ## of perturbations of x, then norm (hesr*e) <= eps*xn, i.e. by
    ## tolf ~ eps we demand as much accuracy as we can expect.
        if (norm(grad) <= dot(dot(tolf,n),xn)):
            info=1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:237
            break
        suc=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:241
        decfac=0.5
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:242
        while (logical_not(suc) and niter <= maxiter and nfev < maxfev and logical_not(info)):

            s=- __doglegm__(hesr,grad,dg,delta)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:247
            sn=norm(multiply(dg,s))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:249
            if (niter == 1):
                delta=min(delta,sn)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:251
            fval1=ravel(fcn[reshape(x + s,xsiz)])
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:254
            nfev
            if (fval1 < fval):
                ## Scaled actual reduction.
                actred=(fval - fval1) / (abs(fval1) + abs(fval))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:259
            else:
                actred=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:261
            w=dot(hesr,s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:264
            t=dot(1 / 2,sumsq(w)) + dot(grad.T,s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:266
            if (t < 0):
                prered=- t / (abs(fval) + abs(fval + t))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:268
                ratio=actred / prered
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:269
            else:
                prered=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:271
                ratio=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:272
            ## Update delta.
            if (ratio < min(max(0.1,dot(0.8,lastratio)),0.9)):
                delta *= decfac
                decfac ^= 1.4142
                if (delta <= dot(dot(10.0,macheps),xn)):
                    ## Trust region became uselessly small.
                    info=- 3
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:281
                    break
            else:
                lastratio=copy(ratio)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:285
                decfac=0.5
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:286
                if (abs(1 - ratio) <= 0.1):
                    delta=dot(1.4142,sn)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:288
                else:
                    if (ratio >= 0.5):
                        delta=max(delta,dot(1.4142,sn))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:290
            if (ratio >= 0.0001):
                ## Successful iteration.
                x += s
                xn=norm(multiply(dg,x))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:297
                fval=copy(fval1)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:298
                nsuciter
                suc=copy(true)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:300
            niter
            if (logical_not(isempty(outfcn))):
                optimvalues.iter = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:307
                optimvalues.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:308
                optimvalues.fval = copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:309
                optimvalues.searchdirection = copy(s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:310
                state='iter'
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:311
                stop=outfcn[x,optimvalues,state]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:312
                if (stop):
                    info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:314
                    break
            ## Tests for termination conditions. A mysterious place, anything
      ## can happen if you change something here...
            ## The rule of thumb (which I'm not sure M*b is quite following)
      ## is that for a tolerance that depends on scaling, only 0 makes
      ## sense as a default value. But 0 usually means uselessly long
      ## iterations, so we need scaling-independent tolerances wherever
      ## possible.
            ## The following tests done only after successful step.
            if (ratio >= 0.0001):
                ## This one is classic. Note that we use scaled variables again,
        ## but compare to scaled step, so nothing bad.
                if (sn <= dot(tolx,xn)):
                    info=2
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:333
                else:
                    if (actred < tolf):
                        info=3
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:336


    
    ## Restore original shapes.
    x=reshape(x,xsiz)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:344
    output.iterations = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:346
    output.successful = copy(nsuciter)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:347
    output.funcCount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:348
    if (nargout > 5):
        hess=dot(hesr.T,hesr)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:351
    
    return x,fval,info,output,grad,hess
    
if __name__ == '__main__':
    pass
    
    ## A helper function that evaluates a function and checks for bad results.
    
@function
def guarded_eval(fun=None,x=None,*args,**kwargs):
    varargin = guarded_eval.varargin
    nargin = guarded_eval.nargin

    if (nargout > 1):
        fx,gx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:359
    else:
        fx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:361
        gx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:362
    
    if (logical_not((isreal(fx) and isreal(gx)))):
        error('fminunc:notreal','fminunc: non-real value encountered')
    else:
        if (any(isnan(ravel(fx)))):
            error('fminunc:isnan','fminunc: NaN value encountered')
        else:
            if (any(isinf(ravel(fx)))):
                error('fminunc:isinf','fminunc: Inf value encountered')
    
    return fx,gx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test FunValCheck works correctly
    
    
    ## Solve the double dogleg trust-region minimization problem:
## Minimize 1/2*norm(r*x)^2  subject to the constraint norm(d.*x) <= delta,
## x being a convex combination of the gauss-newton and scaled gradient.
    
    ## TODO: error checks
## TODO: handle singularity, or leave it up to mldivide?
    
    
@function
def __doglegm__(r=None,g=None,d=None,delta=None,*args,**kwargs):
    varargin = __doglegm__.varargin
    nargin = __doglegm__.nargin

    ## Get Gauss-Newton direction.
    b=numpy.linalg.solve(r.T,g)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:409
    x=numpy.linalg.solve(r,b)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:410
    xn=norm(multiply(d,x))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:411
    if (xn > delta):
        ## GN is too big, get scaled gradient.
        s=g / d
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:414
        sn=norm(s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:415
        if (sn > 0):
            ## Normalize and rescale.
            s=(s / sn) / d
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:418
            tn=norm(dot(r,s))
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:420
            snm=(sn / tn) / tn
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:421
            if (snm < delta):
                ## Get the dogleg path minimizer.
                bn=norm(b)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:424
                dxn=delta / xn
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:425
                snmd=snm / delta
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:425
                t=dot(dot((bn / sn),(bn / xn)),snmd)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:426
                t -= dot(dxn,snmd ** 2) - sqrt((t - dxn) ** 2 + dot((1 - dxn ** 2),(1 - snmd ** 2)))
                alpha=dot(dxn,(1 - snmd ** 2)) / t
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:428
            else:
                alpha=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:430
        else:
            alpha=delta / xn
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:433
            snm=0
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:434
        ## Form the appropriate convex combination.
        x=dot(alpha,x) + dot((dot((1 - alpha),min(snm,delta))),s)
# /home/lei/octave-4.0.2/scripts/optimization/fminunc.m:437
    
    return x
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 Bill Denney
## Copyright (C) 2008 Jaroslav Hajek
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} lsqnonneg (@var{c}, @var{d})
## @deftypefnx {Function File} {@var{x} =} lsqnonneg (@var{c}, @var{d}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} lsqnonneg (@var{c}, @var{d}, @var{x0}, @var{options})
## @deftypefnx {Function File} {[@var{x}, @var{resnorm}] =} lsqnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{resnorm}, @var{residual}] =} lsqnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{resnorm}, @var{residual}, @var{exitflag}] =} lsqnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{resnorm}, @var{residual}, @var{exitflag}, @var{output}] =} lsqnonneg (@dots{})
## @deftypefnx {Function File} {[@var{x}, @var{resnorm}, @var{residual}, @var{exitflag}, @var{output}, @var{lambda}] =} lsqnonneg (@dots{})
## Minimize @code{norm (@var{c}*@var{x} - d)} subject to
## @code{@var{x} >= 0}.
##
## @var{c} and @var{d} must be real.
##
## @var{x0} is an optional initial guess for @var{x}.
##
## Currently, @code{lsqnonneg} recognizes these options: @qcode{"MaxIter"},
## @qcode{"TolX"}.  For a description of these options, see
## @ref{XREFoptimset,,optimset}.
##
## Outputs:
##
## @itemize @bullet
## @item resnorm
##
## The squared 2-norm of the residual: norm (@var{c}*@var{x}-@var{d})^2
##
## @item residual
##
## The residual: @var{d}-@var{c}*@var{x}
##
## @item exitflag
##
## An indicator of convergence.  0 indicates that the iteration count was
## exceeded, and therefore convergence was not reached; >0 indicates that the
## algorithm converged.  (The algorithm is stable and will converge given
## enough iterations.)
##
## @item output
##
## A structure with two fields:
##
## @itemize @bullet
## @item @qcode{"algorithm"}: The algorithm used (@qcode{"nnls"})
##
## @item @qcode{"iterations"}: The number of iterations taken.
## @end itemize
##
## @item lambda
##
## Not implemented.
## @end itemize
## @seealso{optimset, pqpnonneg, lscov}
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("lsqnonneg");
    
    ## This is implemented from Lawson and Hanson's 1973 algorithm on page
## 161 of Solving Least Squares Problems.
    
    
@function
def lsqnonneg(c=None,d=None,x=[],options=struct(),*args,**kwargs):
    varargin = lsqnonneg.varargin
    nargin = lsqnonneg.nargin

    if (nargin == 1 and ischar(c) and strcmp(c,'defaults')):
        x=optimset('MaxIter',100000.0)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:85
        return x,resnorm,residual,exitflag,output,lambda_
    
    if (nargin < 2 or nargin > 4 or logical_not((isnumeric(c) and ismatrix(c))) or logical_not((isnumeric(d) and ismatrix(d))) or logical_not(isstruct(options))):
        print_usage()
    
    ## Lawson-Hanson Step 1 (LH1): initialize the variables.
    m=rows(c)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:97
    n=columns(c)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:98
    if (isempty(x)):
        ## Initial guess is 0s.
        x=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:101
    else:
        ## ensure nonnegative guess.
        x=max(x,0)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:104
    
    useqr=m >= n
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:107
    max_iter=optimget(options,'MaxIter',100000.0)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:108
    
    p=find(x > 0).T
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:111
    if (useqr):
        ## Initialize the QR factorization, economized form.
        q,r=qr(c[:,p],0,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:114
    
    iter=0
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:117
    
    while (iter < max_iter):

        while (iter < max_iter):

            iter
            ## of the positive problem.
            if (useqr):
                xtmp=dot(numpy.linalg.solve(r,q.T),d)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:127
            else:
                xtmp=numpy.linalg.solve(c[:,p],d)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:129
            idx=find(xtmp < 0)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:131
            if (isempty(idx)):
                ## LH7: tmp solution found, iterate.
                ravel[x]=0
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:135
                x[p]=xtmp
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:136
                break
            else:
                ## LH8, LH9: find the scaling factor.
                pidx=p[idx]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:140
                sf=x[pidx] / (x[pidx] - xtmp[idx])
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:141
                alpha=min(sf)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:142
                xx=zeros(n,1)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:144
                xx[p]=xtmp
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:145
                x += dot(alpha,(xx - x))
                ## This corresponds to those indices where minimum of sf is attained.
                idx=idx[sf == alpha]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:149
                p[idx]=[]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:150
                if (useqr):
                    ## update the QR factorization.
                    q,r=qrdelete(q,r,idx,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:153

        ## compute the gradient.
        w=dot(c.T,(d - dot(c,x)))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:159
        w[p]=[]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:160
        tolx=optimget(options,'TolX',dot(dot(dot(10,eps),norm(c,1)),length(c)))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:161
        if (logical_not(any(w > tolx))):
            if (useqr):
                ## verify the solution achieved using qr updating.
        ## in the best case, this should only take a single step.
                useqr=copy(false)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:166
                continue
            else:
                ## we're finished.
                break
        ## find the maximum gradient.
        idx=find(w == max(w))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:175
        if (numel(idx) > 1):
            warning('lsqnonneg:nonunique','a non-unique solution may be returned due to equal gradients')
            idx=idx[1]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:179
        ## move the index from Z to P. Keep P sorted.
        z=matlabarray(cat(arange(1,n)))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:182
        z[p]=[]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:182
        zidx=z[idx]
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:183
        jdx=1 + lookup(p,zidx)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:184
        p=matlabarray(cat(p[1:jdx - 1],zidx,p[jdx:end()]))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:185
        if (useqr):
            ## insert the column into the QR factorization.
            q,r=qrinsert(q,r,jdx,c[:,zidx],nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:188

    
    ## LH12: complete.
    
    ## Generate the additional output arguments.
    if (nargout > 1):
        resnorm=norm(dot(c,x) - d) ** 2
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:196
    
    if (nargout > 2):
        residual=d - dot(c,x)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:199
    
    exitflag=copy(iter)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:201
    if (nargout > 3 and iter >= max_iter):
        exitflag=0
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:203
    
    if (nargout > 4):
        output=struct('algorithm','nnls','iterations',iter)
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:206
    
    if (nargout > 5):
        lambda_=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:209
        lambda_[p]=w
# /home/lei/octave-4.0.2/scripts/optimization/lsqnonneg.m:210
    
    return x,resnorm,residual,exitflag,output,lambda_
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2003,2012 Andy Adler
## Copyright (C) 2002, 2013 N.J.Higham
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} fminsearch (@var{fun}, @var{x0})
## @deftypefnx {Function File} {@var{x} =} fminsearch (@var{fun}, @var{x0}, @var{options})
## @deftypefnx {Function File} {[@var{x}, @var{fval}] =} fminsearch (@dots{})
##
## Find a value of @var{x} which minimizes the function @var{fun}.
##
## The search begins at the point @var{x0} and iterates using the
## @nospell{Nelder & Mead} Simplex algorithm (a derivative-free method).  This
## algorithm is better-suited to functions which have discontinuities or for
## which a gradient-based search such as @code{fminunc} fails.
##
## Options for the search are provided in the parameter @var{options} using the
## function @code{optimset}.  Currently, @code{fminsearch} accepts the options:
## @qcode{"TolX"}, @qcode{"MaxFunEvals"}, @qcode{"MaxIter"}, @qcode{"Display"}.
## For a description of these options, see @code{optimset}.
##
## On exit, the function returns @var{x}, the minimum point, and @var{fval},
## the function value thereof.
##
## Example usages:
##
## @example
## @group
## fminsearch (@@(x) (x(1)-5).^2+(x(2)-8).^4, [0;0])
##
## fminsearch (inline ("(x(1)-5).^2+(x(2)-8).^4", "x"), [0;0])
## @end group
## @end example
## @seealso{fminbnd, fminunc, optimset}
## @end deftypefn
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("fminsearch");
    
    ## FIXME: Add support for "exitflag" output variable
## FIXME: Add support for "output" output variable
## FIXME: For Display option, add 'final' and 'notify' options.  Not too hard.
## FIXME: Add support for OutputFcn.  See fminunc for a template
## FIXME: Add support for exiting based on TolFun.  See fminunc for an idea.
    
    
@function
def fminsearch(fun=None,x0=None,options=struct(),*args,**kwargs):
    varargin = fminsearch.varargin
    nargin = fminsearch.nargin

    ## Get default options if requested.
    if (nargin == 1 and ischar(fun) and strcmp(fun,'defaults')):
        x=optimset('Display','notify','FunValCheck','off','MaxFunEvals',400,'MaxIter',400,'OutputFcn',[],'TolFun',1e-07,'TolX',0.0001)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:65
        return x,fval
    
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    x=nmsmax(fun,x0,options)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:76
    if (isargout(2)):
        fval=feval(fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:79
    
    return x,fval
    
if __name__ == '__main__':
    pass
    
    ##NMSMAX  Nelder-Mead simplex method for direct search optimization.
##        [x, fmax, nf] = NMSMAX(FUN, x0, STOPIT, SAVIT) attempts to
##        maximize the function FUN, using the starting vector x0.
##        The Nelder-Mead direct search method is used.
##        Output arguments:
##               x    = vector yielding largest function value found,
##               fmax = function value at x,
##               nf   = number of function evaluations.
##        The iteration is terminated when either
##               - the relative size of the simplex is <= STOPIT(1)
##                 (default 1e-3),
##               - STOPIT(2) function evaluations have been performed
##                 (default inf, i.e., no limit), or
##               - a function value equals or exceeds STOPIT(3)
##                 (default inf, i.e., no test on function values).
##        The form of the initial simplex is determined by STOPIT(4):
##           STOPIT(4) = 0: regular simplex (sides of equal length, the default)
##           STOPIT(4) = 1: right-angled simplex.
##        Progress of the iteration is not shown if STOPIT(5) = 0 (default 1).
##           STOPIT(6) indicates the direction (ie. minimization or
##                   maximization.) Default is 1, maximization.
##                   set STOPIT(6)=-1 for minimization
##        If a non-empty fourth parameter string SAVIT is present, then
##        'SAVE SAVIT x fmax nf' is executed after each inner iteration.
##        NB: x0 can be a matrix.  In the output argument, in SAVIT saves,
##            and in function calls, x has the same shape as x0.
##        NMSMAX(fun, x0, STOPIT, SAVIT, P1, P2,...) allows additional
##        arguments to be passed to fun, via feval(fun,x,P1,P2,...).
## References:
## N. J. Higham, Optimization by direct search in matrix computations,
##    SIAM J. Matrix Anal. Appl, 14(2): 317-333, 1993.
## C. T. Kelley, Iterative Methods for Optimization, Society for Industrial
##    and Applied Mathematics, Philadelphia, PA, 1999.
    
    ## From Matrix Toolbox
## Copyright (C) 2002, 2013 N.J.Higham
## www.maths.man.ac.uk/~higham/mctoolbox
##
## Modifications for Octave by A.Adler 2003
    
    
@function
def parse_options(options=None,x=None,*args,**kwargs):
    varargin = parse_options.varargin
    nargin = parse_options.nargin

    
    stopit[1]=tol=optimget(options,'TolX',0.0001)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:127
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:127
    
    stopit[2]=optimget(options,'MaxFunEvals',dot(length(x),200))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:130
    
    maxiter=optimget(options,'MaxIter',dot(length(x),200))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:133
    
    stopit[3]=Inf
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:136
    
    ## Default initial simplex.
    stopit[4]=0
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:139
    
    ## Default: show progress.
    display=optimget(options,'Display','notify')
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:142
    if (strcmp(display,'iter')):
        stopit[5]=1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:144
    else:
        stopit[5]=0
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:146
    
    trace=stopit[5]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:148
    
    stopit[6]=dirn=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:151
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:151
    
    savit=matlabarray([])
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:154
    
    return stopit,savit,dirn,trace,tol,maxiter
    
if __name__ == '__main__':
    pass
    
    
@function
def nmsmax(fun=None,x=None,options=None,savit=None,varargin=None,*args,**kwargs):
    varargin = nmsmax.varargin
    nargin = nmsmax.nargin

    stopit,savit,dirn,trace,tol,maxiter=parse_options(options,x,nargout=6)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:160
    if (strcmpi(optimget(options,'FunValCheck','off'),'on')):
        ## Replace fcn with a guarded version.
        fun=lambda x=None: guarded_eval(fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:164
    
    x0=ravel(x)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:167
    
    n=length(x0)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:168
    V=matlabarray(cat(zeros(n,1),eye(n)))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:170
    f=zeros(n + 1,1)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:171
    V[:,1]=x0
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:172
    f[1]=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:173
    fmax_old=f[1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:174
    if (trace):
        fprintf('f(x0) = %9.4e\n',f[1])
    
    k=0
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:180
    m=0
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:180
    
    scale=max(norm(x0,Inf),1)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:183
    if (stopit[4] == 0):
        ## Regular simplex - all edges have same length.
    ## Generated from construction given in reference [18, pp. 80-81] of [1].
        alpha=dot(scale / (dot(n,sqrt(2))),cat(sqrt(n + 1) - 1 + n,sqrt(n + 1) - 1))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:187
        V[:,2:n + 1]=dot((x0 + dot(alpha[2],ones(n,1))),ones(1,n))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:188
        for j in arange(2,n + 1).reshape(-1):
            V[j - 1,j]=x0[j - 1] + alpha[1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:190
            ravel[x]=V[:,j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:191
            f[j]=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:192
    else:
        ## Right-angled simplex based on co-ordinate axes.
        alpha=dot(scale,ones(n + 1,1))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:196
        for j in arange(2,n + 1).reshape(-1):
            V[:,j]=x0 + dot(alpha[j],V[:,j])
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:198
            ravel[x]=V[:,j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:199
            f[j]=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:200
    
    nf=n + 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:203
    how='initial  '
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:204
    __,j=sort(f,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:206
    j=j[n + 1:- 1:1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:207
    f=f[j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:208
    V=V[:,j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:209
    alpha=1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:211
    beta=1 / 2
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:211
    gamma=2
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:211
    while (1):

        k
        if (k > maxiter):
            msg='Exceeded maximum iterations...quitting\n'
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:217
            break
        fmax=f[1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:221
        if (fmax > fmax_old):
            if (logical_not(isempty(savit))):
                ravel[x]=V[:,1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:224
                eval(cat('save ',savit,' x fmax nf'))
        if (trace):
            fprintf('Iter. %2.0f,',k)
            fprintf(cat('  how = ',how,'  '))
            fprintf('nf = %3.0f,  f = %9.4e  (%2.1f%%)\n',nf,fmax,dot(100,(fmax - fmax_old)) / (abs(fmax_old) + eps))
        fmax_old=copy(fmax)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:234
        ## Stopping Test 1 - f reached target value?
        if (fmax >= stopit[3]):
            msg='Exceeded target...quitting\n'
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:240
            break
        ## Stopping Test 2 - too many f-evals?
        if (nf >= stopit[2]):
            msg='Max no. of function evaluations exceeded...quitting\n'
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:246
            break
        ## Stopping Test 3 - converged?   This is test (4.3) in [1].
        v1=V[:,1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:251
        size_simplex=norm(V[:,2:n + 1] - v1[:,ones(1,n)],1) / max(1,norm(v1,1))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:252
        if (size_simplex <= tol):
            msg=sprintf('Simplex size %9.4e <= %9.4e...quitting\n',size_simplex,tol)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:254
            break
        ##  One step of the Nelder-Mead simplex algorithm
    ##  NJH: Altered function calls and changed CNT to NF.
    ##       Changed each 'fr < f(1)' type test to '>' for maximization
    ##       and re-ordered function values after sort.
        vbar=(sum(V[:,1:n].T) / n).T
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:264
        vr=dot((1 + alpha),vbar) - dot(alpha,V[:,n + 1])
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:265
        ravel[x]=vr
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:266
        fr=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:267
        nf=nf + 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:268
        vk=copy(vr)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:269
        fk=copy(fr)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:269
        how='reflect, '
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:269
        if (fr > f[n]):
            if (fr > f[1]):
                ve=dot(gamma,vr) + dot((1 - gamma),vbar)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:272
                ravel[x]=ve
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:273
                fe=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:274
                nf=nf + 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:275
                if (fe > f[1]):
                    vk=copy(ve)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:277
                    fk=copy(fe)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:278
                    how='expand,  '
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:279
        else:
            vt=V[:,n + 1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:283
            ft=f[n + 1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:284
            if (fr > ft):
                vt=copy(vr)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:286
                ft=copy(fr)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:287
            vc=dot(beta,vt) + dot((1 - beta),vbar)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:289
            ravel[x]=vc
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:290
            fc=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:291
            nf=nf + 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:292
            if (fc > f[n]):
                vk=copy(vc)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:294
                fk=copy(fc)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:294
                how='contract,'
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:295
            else:
                for j in arange(2,n).reshape(-1):
                    V[:,j]=(V[:,1] + V[:,j]) / 2
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:298
                    ravel[x]=V[:,j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:299
                    f[j]=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:300
                nf=nf + n - 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:302
                vk=(V[:,1] + V[:,n + 1]) / 2
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:303
                ravel[x]=vk
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:304
                fk=dot(dirn,feval(fun,x,varargin[:]))
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:305
                nf=nf + 1
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:306
                how='shrink,  '
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:307
        V[:,n + 1]=vk
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:310
        f[n + 1]=fk
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:311
        __,j=sort(f,nargout=2)
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:312
        j=j[n + 1:- 1:1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:313
        f=f[j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:314
        V=V[:,j]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:315

    
    ## Finished.
    if (trace):
        fprintf(msg)
    
    ravel[x]=V[:,1]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:323
    return x,fmax,nf
    
if __name__ == '__main__':
    pass
    
    ## A helper function that evaluates a function and checks for bad results.
    
@function
def guarded_eval(fun=None,x=None,*args,**kwargs):
    varargin = guarded_eval.varargin
    nargin = guarded_eval.nargin

    y=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fminsearch.m:330
    if (logical_not((isreal(f)))):
        error('fminsearch:notreal','fminsearch: non-real value encountered')
    else:
        if (any(isnan(ravel(f)))):
            error('fminsearch:isnan','fminsearch: NaN value encountered')
        else:
            if (any(isinf(ravel(f)))):
                error('fminsearch:isinf','fminsearch: Inf value encountered')
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2008-2015 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Author: Jaroslav Hajek <highegg@gmail.com>
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} fzero (@var{fun}, @var{x0})
## @deftypefnx {Function File} {} fzero (@var{fun}, @var{x0}, @var{options})
## @deftypefnx {Function File} {[@var{x}, @var{fval}, @var{info}, @var{output}] =} fzero (@dots{})
## Find a zero of a univariate function.
##
## @var{fun} is a function handle, inline function, or string containing the
## name of the function to evaluate.
##
## @var{x0} should be a two-element vector specifying two points which
## bracket a zero.  In other words, there must be a change in sign of the
## function between @var{x0}(1) and @var{x0}(2).  More mathematically, the
## following must hold
##
## @example
## sign (@var{fun}(@var{x0}(1))) * sign (@var{fun}(@var{x0}(2))) <= 0
## @end example
##
## If @var{x0} is a single scalar then several nearby and distant values are
## probed in an attempt to obtain a valid bracketing.  If this is not
## successful, the function fails.
##
## @var{options} is a structure specifying additional options.  Currently,
## @code{fzero} recognizes these options:
## @qcode{"FunValCheck"}, @qcode{"OutputFcn"}, @qcode{"TolX"},
## @qcode{"MaxIter"}, @qcode{"MaxFunEvals"}.
## For a description of these options, see @ref{XREFoptimset,,optimset}.
##
## On exit, the function returns @var{x}, the approximate zero point and
## @var{fval}, the function value thereof.
##
## @var{info} is an exit flag that can have these values:
##
## @itemize
## @item 1
##  The algorithm converged to a solution.
##
## @item 0
##  Maximum number of iterations or function evaluations has been reached.
##
## @item -1
## The algorithm has been terminated from user output function.
##
## @item -5
## The algorithm may have converged to a singular point.
## @end itemize
##
## @var{output} is a structure containing runtime information about the
## @code{fzero} algorithm.  Fields in the structure are:
##
## @itemize
## @item iterations
##  Number of iterations through loop.
##
## @item nfev
##  Number of function evaluations.
##
## @item bracketx
##  A two-element vector with the final bracketing of the zero along the x-axis.
##
## @item brackety
##  A two-element vector with the final bracketing of the zero along the y-axis.
## @end itemize
## @seealso{optimset, fsolve}
## @end deftypefn
    
    ## This is essentially the ACM algorithm 748: Enclosing Zeros of
## Continuous Functions due to Alefeld, Potra and Shi, ACM Transactions
## on Mathematical Software, Vol. 21, No. 3, September 1995. Although
## the workflow should be the same, the structure of the algorithm has
## been transformed non-trivially; instead of the authors' approach of
## sequentially calling building blocks subprograms we implement here a
## FSM version using one interior point determination and one bracketing
## per iteration, thus reducing the number of temporary variables and
## simplifying the algorithm structure. Further, this approach reduces
## the need for external functions and error handling. The algorithm has
## also been slightly modified.
    
    ## PKG_ADD: ## Discard result to avoid polluting workspace with ans at startup.
## PKG_ADD: [~] = __all_opts__ ("fzero");
    
    
@function
def fzero(fun=None,x0=None,options=struct(),*args,**kwargs):
    varargin = fzero.varargin
    nargin = fzero.nargin

    ## Get default options if requested.
    if (nargin == 1 and ischar(fun) and strcmp(fun,'defaults')):
        x=optimset('MaxIter',Inf,'MaxFunEvals',Inf,'TolX',eps,'OutputFcn',[],'FunValCheck','off')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:106
        return x,fval,info,output
    
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (ischar(fun)):
        fun=str2func(fun,'global')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:116
    
    ## TODO
  ## displev = optimget (options, "Display", "notify");
    funvalchk=strcmpi(optimget(options,'FunValCheck','off'),'on')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:121
    outfcn=optimget(options,'OutputFcn')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:122
    tolx=optimget(options,'TolX',eps)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:123
    maxiter=optimget(options,'MaxIter',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:124
    maxfev=optimget(options,'MaxFunEvals',Inf)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:125
    
    if (funvalchk):
        ## Replace fun with a guarded version.
        fun=lambda x=None: guarded_eval(fun,x)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:131
    
    ## The default exit flag if exceeded number of iterations.
    info=0
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:135
    niter=0
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:136
    nfev=0
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:137
    x=fval=a=fa=b=fb=copy(NaN)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:139
    
    a=x0[1]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:142
    fa=fun[a]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:143
    nfev=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:144
    if (length(x0) > 1):
        b=x0[2]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:146
        fb=fun[b]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:147
        nfev += 1
    else:
        ## Try to get b.
        if (a == 0):
            aa=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:152
        else:
            aa=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:154
        for b in cat(dot(0.9,aa),dot(1.1,aa),aa - 1,aa + 1,dot(0.5,aa),dot(1.5,aa),- aa,dot(2,aa),dot(- 10,aa),dot(10,aa)).reshape(-1):
            fb=fun[b]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:157
            nfev += 1
            if (dot(sign(fa),sign(fb)) <= 0):
                break
    
    if (b < a):
        u=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:165
        a=copy(b)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:166
        b=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:167
        fu=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:169
        fa=copy(fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:170
        fb=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:171
    
    if (logical_not((dot(sign(fa),sign(fb)) <= 0))):
        error('fzero:bracket','fzero: not a valid initial bracketing')
    
    slope0=(fb - fa) / (b - a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:178
    if (fa == 0):
        b=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:181
        fb=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:182
    else:
        if (fb == 0):
            a=copy(b)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:184
            fa=copy(fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:185
    
    itype=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:188
    if (abs(fa) < abs(fb)):
        u=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:191
        fu=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:191
    else:
        u=copy(b)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:193
        fu=copy(fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:193
    
    if (isa(x0,'single') or isa(fa,'single')):
        macheps=eps('single')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:197
    else:
        macheps=eps('double')
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:199
    
    d=e=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:202
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:202
    fd=fe=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:203
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:203
    mba=dot(mu,(b - a))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:204
    while (niter < maxiter and nfev < maxfev):

        if 1 == (itype):
            ## The initial test.
            if (b - a <= dot(2,(dot(dot(2,abs(u)),macheps) + tolx))):
                x=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:210
                fval=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:210
                info=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:211
                break
            if (abs(fa) <= dot(1000.0,abs(fb)) and abs(fb) <= dot(1000.0,abs(fa))):
                ## Secant step.
                c=u - dot((a - b) / (fa - fb),fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:216
            else:
                ## Bisection step.
                c=dot(0.5,(a + b))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:219
            d=copy(u)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:221
            fd=copy(fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:221
            itype=5
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:222
        else:
            if cellarray([2,3]) == (itype):
                l=length(unique(cat(fa,fb,fd,fe)))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:224
                if (l == 4):
                    ## Inverse cubic interpolation.
                    q11=dot((d - e),fd) / (fe - fd)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:227
                    q21=dot((b - d),fb) / (fd - fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:228
                    q31=dot((a - b),fa) / (fb - fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:229
                    d21=dot((b - d),fd) / (fd - fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:230
                    d31=dot((a - b),fb) / (fb - fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:231
                    q22=dot((d21 - q11),fb) / (fe - fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:232
                    q32=dot((d31 - q21),fa) / (fd - fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:233
                    d32=dot((d31 - q21),fd) / (fd - fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:234
                    q33=dot((d32 - q22),fa) / (fe - fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:235
                    c=a + q31 + q32 + q33
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:236
                if (l < 4 or dot(sign(c - a),sign(c - b)) > 0):
                    ## Quadratic interpolation + newton.
                    a0=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:240
                    a1=(fb - fa) / (b - a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:241
                    a2=((fd - fb) / (d - b) - a1) / (d - a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:242
                    c=a - a0 / a1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:244
                    if (a2 != 0):
                        c=a - a0 / a1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:246
                        for i in arange(1,itype).reshape(-1):
                            pc=a0 + dot((a1 + dot(a2,(c - b))),(c - a))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:248
                            pdc=a1 + dot(a2,(dot(2,c) - a - b))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:249
                            if (pdc == 0):
                                c=a - a0 / a1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:251
                                break
                            c -= pc / pdc
                itype += 1
            else:
                if 4 == (itype):
                    ## Double secant step.
                    c=u - dot(dot(2,(b - a)) / (fb - fa),fu)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:261
                    if (abs(c - u) > dot(0.5,(b - a))):
                        c=dot(0.5,(b + a))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:264
                    itype=5
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:266
                else:
                    if 5 == (itype):
                        ## Bisection step.
                        c=dot(0.5,(b + a))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:269
                        itype=2
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:270
        ## Don't let c come too close to a or b.
        delta=dot(dot(2,0.7),(dot(dot(2,abs(u)),macheps) + tolx))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:274
        if ((b - a) <= dot(2,delta)):
            c=(a + b) / 2
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:276
        else:
            c=max(a + delta,min(b - delta,c))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:278
        ## Calculate new point.
        x=copy(c)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:282
        fval=fc=fun[c]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:283
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:283
        niter
        nfev
        ## nonmonotonicity is detected.
        if (dot(sign(fc - fa),sign(fc - fb)) >= 0):
            ## The new point broke monotonicity.
      ## Disable inverse cubic.
            fe=copy(fc)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:291
        else:
            e=copy(d)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:293
            fe=copy(fd)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:293
        ## Bracketing.
        if (dot(sign(fa),sign(fc)) < 0):
            d=copy(b)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:298
            fd=copy(fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:298
            b=copy(c)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:299
            fb=copy(fc)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:299
        else:
            if (dot(sign(fb),sign(fc)) < 0):
                d=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:301
                fd=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:301
                a=copy(c)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:302
                fa=copy(fc)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:302
            else:
                if (fc == 0):
                    a=b=copy(c)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:304
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:304
                    fa=fb=copy(fc)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:304
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:304
                    info=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:305
                    break
                else:
                    ## This should never happen.
                    error('fzero:bracket','fzero: zero point is not bracketed')
        ## If there's an output function, use it now.
        if (logical_not(isempty(outfcn))):
            optv.funccount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:314
            optv.fval = copy(fval)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:315
            optv.iteration = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:316
            if (outfcn[x,optv,'iter']):
                info=- 1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:318
                break
        if (abs(fa) < abs(fb)):
            u=copy(a)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:324
            fu=copy(fa)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:324
        else:
            u=copy(b)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:326
            fu=copy(fb)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:326
        if (b - a <= dot(2,(dot(dot(2,abs(u)),macheps) + tolx))):
            info=1
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:329
            break
        ## Skip bisection step if successful reduction.
        if (itype == 5 and (b - a) <= mba):
            itype=2
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:335
        if (itype == 2):
            mba=dot(mu,(b - a))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:338

    
    ## Check solution for a singularity by examining slope
    if (info == 1):
        if ((b - a) != 0 and abs((fb - fa) / (b - a) / slope0) > max(1000000.0,0.5 / (macheps + tolx))):
            info=- 5
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:346
    
    output.iterations = copy(niter)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:350
    output.funcCount = copy(nfev)
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:351
    output.bracketx = copy(cat(a,b))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:352
    output.brackety = copy(cat(fa,fb))
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:353
    return x,fval,info,output
    
if __name__ == '__main__':
    pass
    
    ## An assistant function that evaluates a function handle and checks for
## bad results.
    
@function
def guarded_eval(fun=None,x=None,*args,**kwargs):
    varargin = guarded_eval.varargin
    nargin = guarded_eval.nargin

    fx=fun[x]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:360
    fx=fx[1]
# /home/lei/octave-4.0.2/scripts/optimization/fzero.m:361
    if (logical_not(isreal(fx))):
        error('fzero:notreal','fzero: non-real value encountered')
    else:
        if (isnan(fx)):
            error('fzero:isnan','fzero: NaN value encountered')
    
    return fx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2013-2015 Mike Miller
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __gripe_missing_component__ (@var{caller}, @var{component})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __gripe_missing_component__(caller=None,component=None,*args,**kwargs):
    varargin = __gripe_missing_component__.varargin
    nargin = __gripe_missing_component__.nargin

    if (nargin != 2):
        print_usage()
    
    msg=''
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:30
    fcn=missing_component_hook()
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:31
    ftype=exist(fcn)
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:33
    if (ftype == 2 or ftype == 3 or ftype == 5 or ftype == 103):
        msg=feval(fcn,component)
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:35
    
    if (isempty(msg)):
        if 'info-file' == (component):
            msg='unable to find the Octave info manual, Octave installation is incomplete'
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:41
        else:
            if 'mkoctfile' == (component):
                msg='unable to find the mkoctfile command, Octave installation is incomplete'
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:43
            else:
                if 'octave' == (component):
                    msg='unable to find the octave executable, Octave installation is incomplete'
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:45
                else:
                    if 'octave-config' == (component):
                        msg='unable to find the octave-config command, Octave installation is incomplete'
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:47
                    else:
                        msg=matlabarray(cat('unable to find required Octave component "',component,'"'))
# /home/lei/octave-4.0.2/scripts/help/__gripe_missing_component__.m:49
    
    error('%s: %s\n',caller,msg)
    return
    
if __name__ == '__main__':
    pass
    
    ## Some trivial testing
    
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} help @var{name}
## @deftypefnx {Command} {} help @code{--list}
## @deftypefnx {Command} {} help @code{.}
## @deftypefnx {Command} {} help
## Display the help text for @var{name}.
##
## For example, the command @kbd{help help} prints a short message describing
## the @code{help} command.
##
## Given the single argument @code{--list}, list all operators, keywords,
## built-in functions, and loadable functions available in the current session
## of Octave.
##
## Given the single argument @code{.}, list all operators available in the
## current session of Octave.
##
## If invoked without any arguments, @code{help} display instructions on how to
## access help from the command line.
##
## The help command can provide information about most operators, for example
## @code{help +}, but not the comma and semicolon characters which are used
## by the Octave interpreter as command separators.  For help on either of
## these type @kbd{help comma} or @kbd{help semicolon}.
## @seealso{doc, lookfor, which, info}
## @end deftypefn
    
    
@function
def help(name=None,*args,**kwargs):
    varargin = help.varargin
    nargin = help.nargin

    if (nargin == 0):
        text='\n  For help with individual commands and functions type\n\n    help NAME\n\n  (replace NAME with the name of the command or function you would\n  like to learn more about).\n\n  For a more detailed introduction to GNU Octave, please consult the\n  manual.  To read the manual from the prompt type\n\n    doc\n\n  GNU Octave is supported and developed by its user community.\n  For more information visit http://www.octave.org.\n\n'
# /home/lei/octave-4.0.2/scripts/help/help.m:50
        if (nargout == 0):
            puts(text)
        else:
            retval=copy(text)
# /home/lei/octave-4.0.2/scripts/help/help.m:55
    else:
        if (nargin == 1 and ischar(name)):
            if (strcmp(name,'--list')):
                list=do_list_functions()
# /home/lei/octave-4.0.2/scripts/help/help.m:61
                if (nargout == 0):
                    printf('%s',list)
                else:
                    retval=copy(list)
# /home/lei/octave-4.0.2/scripts/help/help.m:65
                return retval
            if (strcmp(name,'.')):
                list=do_list_operators()
# /home/lei/octave-4.0.2/scripts/help/help.m:71
                if (nargout == 0):
                    printf('%s',list)
                else:
                    retval=copy(list)
# /home/lei/octave-4.0.2/scripts/help/help.m:75
                return retval
            ## Get help text
            text,format=get_help_text(name,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:81
            if 'plain text' == (lower(format)):
                status=0
# /home/lei/octave-4.0.2/scripts/help/help.m:86
            else:
                if 'texinfo' == (lower(format)):
                    text,status=__makeinfo__(text,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:88
                else:
                    if 'html' == (lower(format)):
                        text,status=strip_html_tags(text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:90
                    else:
                        if 'not documented' == (lower(format)):
                            error('help: \'%s\' is not documented\n',name)
                        else:
                            if 'not found' == (lower(format)):
                                do_contents(name)
                                return retval
                            else:
                                error('help: internal error: unsupported help text format: \'%s\'\n',format)
            ## Print text
            if (status != 0):
                warning('help: Texinfo formatting filter exited abnormally; raw Texinfo source of help text follows...\n')
            if (nargout == 0):
                which(name)
                printf('\n%s\n%s',text,__additional_help_message__())
            else:
                retval=copy(text)
# /home/lei/octave-4.0.2/scripts/help/help.m:109
        else:
            error('help: invalid input\n')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def do_list_operators(*args,**kwargs):
    varargin = do_list_operators.varargin
    nargin = do_list_operators.nargin

    retval=sprintf('*** operators:\n\n%s\n\n',list_in_columns(__operators__()))
# /home/lei/octave-4.0.2/scripts/help/help.m:120
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def do_list_functions(*args,**kwargs):
    varargin = do_list_functions.varargin
    nargin = do_list_functions.nargin

    operators=do_list_operators()
# /home/lei/octave-4.0.2/scripts/help/help.m:126
    keywords=sprintf('*** keywords:\n\n%s\n\n',list_in_columns(__keywords__()))
# /home/lei/octave-4.0.2/scripts/help/help.m:128
    builtins=sprintf('*** builtins:\n\n%s\n\n',list_in_columns(__builtins__()))
# /home/lei/octave-4.0.2/scripts/help/help.m:131
    dirs=ostrsplit(path,pathsep)
# /home/lei/octave-4.0.2/scripts/help/help.m:134
    flist=''
# /home/lei/octave-4.0.2/scripts/help/help.m:135
    for i in arange(2,numel(dirs)).reshape(-1):
        files=sort(cellarray([dir(fullfile(dirs[i],'*.m')).name,dir(fullfile(dirs[i],'*.oct')).name,dir(fullfile(dirs[i],'*.mex')).name]))
# /home/lei/octave-4.0.2/scripts/help/help.m:137
        if (logical_not(isempty(files))):
            flist=sprintf('%s*** functions in %s:\n\n%s\n\n',flist,dirs[i],list_in_columns(files))
# /home/lei/octave-4.0.2/scripts/help/help.m:142
    
    retval=matlabarray(cat(operators,keywords,builtins,flist))
# /home/lei/octave-4.0.2/scripts/help/help.m:147
    return retval
    
if __name__ == '__main__':
    pass
    
    
@function
def do_contents(name=None,*args,**kwargs):
    varargin = do_contents.varargin
    nargin = do_contents.nargin

    found=copy(false)
# /home/lei/octave-4.0.2/scripts/help/help.m:153
    dlist=dir_in_loadpath(name,'all')
# /home/lei/octave-4.0.2/scripts/help/help.m:155
    for i in arange(1,numel(dlist)).reshape(-1):
        fname=make_absolute_filename(fullfile(dlist[i],'Contents.m'))
# /home/lei/octave-4.0.2/scripts/help/help.m:158
        text,format=get_help_text_from_file(fname,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:160
        if 'plain text' == (lower(format)):
            status=0
# /home/lei/octave-4.0.2/scripts/help/help.m:165
        else:
            if 'texinfo' == (lower(format)):
                text,status=__makeinfo__(text,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:167
            else:
                if 'html' == (lower(format)):
                    text,status=strip_html_tags(text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/help.m:169
        if (logical_not(isempty(text))):
            found=copy(true)
# /home/lei/octave-4.0.2/scripts/help/help.m:173
            if (status != 0):
                warning('help: Texinfo formatting filter exited abnormally; raw Texinfo source of help text follows...\n')
            printf('%s:\n\n%s\n',fname,text)
    
    if (found):
        puts(__additional_help_message__())
    else:
        msg=feval(missing_function_hook,name)
# /home/lei/octave-4.0.2/scripts/help/help.m:186
        if (isempty(msg)):
            msg=sprintf('\'%s\' not found',name)
# /home/lei/octave-4.0.2/scripts/help/help.m:189
        error('help: %s\n',msg)
    
    return
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} doc_cache_create (@var{out_file}, @var{directory})
## @deftypefnx {Function File} {} doc_cache_create (@var{out_file})
## @deftypefnx {Function File} {} doc_cache_create ()
## Generate documentation cache for all functions in @var{directory}.
##
## A documentation cache is generated for all functions in @var{directory}
## which may be a single string or a cell array of strings.  The cache is used
## to speed up the function @code{lookfor}.
##
## The cache is saved in the file @var{out_file} which defaults to the value
## @file{doc-cache} if not given.
##
## If no directory is given (or it is the empty matrix), a cache for built-in
## operators, etc. is generated.
##
## @seealso{doc_cache_file, lookfor, path}
## @end deftypefn
    
    
@function
def doc_cache_create(out_file='doc-cache',directory=[],*args,**kwargs):
    varargin = doc_cache_create.varargin
    nargin = doc_cache_create.nargin

    ## Check input
    if (logical_not(ischar(out_file))):
        print_usage()
    
    ## Generate cache
    if (isempty(directory)):
        cache=gen_builtin_cache()
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:47
    else:
        if (iscell(directory)):
            if (all(cellfun('isclass',directory,'char'))):
                cache=gen_doc_cache_in_dir(directory)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:50
            else:
                error('doc_cache_create: cell must contain only strings')
        else:
            if (ischar(directory)):
                cache=gen_doc_cache_in_dir(directory)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:55
            else:
                error('doc_cache_create: second input argument must be a string or a cell of strings')
    
    ## Save cache
    if (logical_not(isempty(cache))):
        save_header_format_string(cat('# doc-cache created by Octave ',OCTAVE_VERSION),'local')
        save('-text',out_file,'cache')
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def handle_function(f=None,text=None,format=None,*args,**kwargs):
    varargin = handle_function.varargin
    nargin = handle_function.nargin

    first_sentence=''
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:69
    
    if (length(f) > 2 and all(f[1:2] == '_')):
        status=1
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:72
        return text,first_sentence,status
    
    ## Take action depending on help text format
    if 'plain text' == (lower(format)):
        status=0
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:79
    else:
        if 'texinfo' == (lower(format)):
            text,status=__makeinfo__(text,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:81
        else:
            if 'html' == (lower(format)):
                text,status=strip_html_tags(text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:83
            else:
                status=1
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:85
    
    ## Did we get the help text?
    if (status != 0 or isempty(text)):
        warning('doc_cache_create: unusable help text found in file \'%s\'',f)
        return text,first_sentence,status
    
    ## Get first sentence of help text
    first_sentence=get_first_help_sentence(f)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:95
    return text,first_sentence,status
    
if __name__ == '__main__':
    pass
    
    
@function
def create_cache(list=None,*args,**kwargs):
    varargin = create_cache.varargin
    nargin = create_cache.nargin

    cache=cellarray([])
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:99
    
    for n in arange(1,length(list)).reshape(-1):
        f=list[n]
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:103
        text,format=get_help_text(f,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:106
        text,first_sentence,status=handle_function(f,text,format,nargout=3)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:108
        if (status != 0):
            continue
        ## Store the help text
        cache[1,end() + 1]=f
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:116
        cache[2,end()]=text
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:117
        cache[3,end()]=first_sentence
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:118
    
    return cache
    
if __name__ == '__main__':
    pass
    
    
@function
def gen_doc_cache_in_dir(directory=None,*args,**kwargs):
    varargin = gen_doc_cache_in_dir.varargin
    nargin = gen_doc_cache_in_dir.nargin

    ## If 'directory' is not in the current path, add it so we search it
    dir_in_path=ismember(directory,ostrsplit(path(),pathsep()))
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:125
    
    if (logical_not(iscell(directory))):
        directory=cellarray([directory])
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:129
    
    dirs_notpath=cellarray([directory[logical_not(dir_in_path)]])
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:131
    
    if (logical_not(isempty(dirs_notpath))):
        addpath(dirs_notpath[:])
    
    ## create cache
    func=lambda s_=None: create_cache(__list_functions__(s_))
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:139
    cache=cellfun(func,directory,'UniformOutput',false)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:140
    
    cache=matlabarray(cat(cache[:]))
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:143
    
    if (logical_not(isempty(dirs_notpath))):
        rmpath(dirs_notpath[:])
    
    return cache
    
if __name__ == '__main__':
    pass
    
    
@function
def gen_builtin_cache(*args,**kwargs):
    varargin = gen_builtin_cache.varargin
    nargin = gen_builtin_cache.nargin

    operators=__operators__()
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:153
    keywords=__keywords__()
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:154
    builtins=__builtins__()
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:155
    list=cellarray([operators[:],keywords[:],builtins[:]])
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:156
    cache=create_cache(list)
# /home/lei/octave-4.0.2/scripts/help/doc_cache_create.m:158
    return cache
    
if __name__ == '__main__':
    pass
    
    ## No true tests desirable for this function.
## Test input validation
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} lookfor @var{str}
## @deftypefnx {Command} {} lookfor -all @var{str}
## @deftypefnx {Function File} {[@var{fcn}, @var{help1str}] =} lookfor (@var{str})
## @deftypefnx {Function File} {[@var{fcn}, @var{help1str}] =} lookfor ("-all", @var{str})
## Search for the string @var{str} in the documentation of all functions in the
## current function search path.
##
## By default, @code{lookfor} looks for @var{str} in just the first sentence of
## the help string for each function found.  The entire help text of each
## function can be searched by using the @qcode{"-all"} argument.  All searches
## are case insensitive.
##
## When called with no output arguments, @code{lookfor} prints the list of
## matching functions to the terminal.  Otherwise, the output argument
## @var{fcns} contains the function names and @var{help1str} contains the first
## sentence from the help string of each function.
##
## Programming Note: The ability of @code{lookfor} to correctly identify the
## first sentence of the help text is dependent on the format of the function's
## help.  All Octave core functions are correctly formatted, but the same can
## not be guaranteed for external packages and user-supplied functions.
## Therefore, the use of the @qcode{"-all"} argument may be necessary to find
## related functions that are not a part of Octave.
##
## The speed of lookup is greatly enhanced by having a cached documentation
## file.  See @code{doc_cache_create} for more information.
## @seealso{help, doc, which, path, doc_cache_create}
## @end deftypefn
    
    
@function
def lookfor(str=None,arg2=None,*args,**kwargs):
    varargin = lookfor.varargin
    nargin = lookfor.nargin

    if (strcmpi(str,'-all')):
        ## The difference between using '-all' and not is which part of the caches
    ## we search.  The cache is organized such that row
    ## 1) contains the function name
    ## 2) contains the full help text
    ## 3) contains the first sentence of the help text.
        str=copy(arg2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:57
        search_type=2
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:58
    else:
        search_type=3
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:60
    
    str=lower(str)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:62
    
    ## Search functions, operators, and keywords that come with Octave
    cache_file=doc_cache_file()
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:65
    if (exist(cache_file,'file')):
        fcnlist,help_text=search_cache(str,cache_file,search_type,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:67
        had_core_cache=copy(true)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:68
    else:
        fcnlist=help_text=cellarray([])
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:70
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:70
        had_core_cache=copy(false)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:71
    
    ## Search functions in new path dirs.
    orig_path=ostrsplit(__pathorig__(),pathsep())
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:75
    
    new_path=ostrsplit(path(),pathsep())
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:78
    
    if (had_core_cache):
        new_path=setdiff(new_path,orig_path)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:82
    
    for n in arange(1,numel(new_path)).reshape(-1):
        fcndir=new_path[n]
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:86
        cache_file=fullfile(fcndir,'doc-cache')
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:87
        if (exist(cache_file,'file')):
            ## We have a cache in the directory, then read it and search it!
            fcns,htext=search_cache(str,cache_file,search_type,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:90
            fcnlist[end() + 1:end() + length(fcns)]=fcns
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:91
            help_text[end() + 1:end() + length(htext)]=htext
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:92
        else:
            ## We don't have a cache.  Search files.
            for fcn_in_fcndir in (__list_functions__(fcndir)).T.reshape(-1):
                fn=fcn_in_fcndir[1]
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:97
                if (strncmp(fn,'__',2)):
                    continue
                status=0
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:104
                try:
                    warn_state=warning()
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:108
                    try:
                        warning('off')
                        first_sentence=get_first_help_sentence(fn,1024)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:111
                    finally:
                        warning(warn_state)
                finally:
                    pass
                if (status):
                    ## Error getting first help sentence
                    pass
                else:
                    if (search_type == 3):
                        ## only search the first sentence of the help text
                        text=copy(first_sentence)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:123
                    else:
                        if (search_type == 2):
                            ## search entire help text
                            try:
                                warn_state=warning()
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:127
                                try:
                                    warning('off')
                                    text,fmt=get_help_text(fn,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:130
                                    if 'plain text' == (lower(fmt)):
                                        status=0
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:133
                                    else:
                                        if 'texinfo' == (lower(fmt)):
                                            text,status=__makeinfo__(text,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:135
                                        else:
                                            if 'html' == (lower(fmt)):
                                                text,status=strip_html_tags(text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:137
                                            else:
                                                status=1
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:139
                                finally:
                                    warning(warn_state)
                            finally:
                                pass
                ## Search the help text
                if (status == 0 and strfind(lower(text),str)):
                    fcnlist[end() + 1]=fn
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:151
                    help_text[end() + 1]=first_sentence
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:152
    
    if (nargout == 0):
        ## Print the results (FIXME: it would be nice to break at word boundaries)
        indent=20
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:160
        term_width=(terminal_size())(2)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:161
        desc_width=term_width - indent - 2
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:162
        indent_space=blanks(indent)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:163
        for k in arange(1,length(fcnlist)).reshape(-1):
            f=fcnlist[k]
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:165
            f[end() + 1:indent - 1]=' '
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:166
            puts(cat(f,' '))
            lf=length(f)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:168
            desc=strtrim(strrep(help_text[k],'\n',' '))
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:169
            ldesc=length(desc)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:170
            printf('%s\n',desc[1:min(ldesc,desc_width - (lf - indent))])
            for start in arange((desc_width - (lf - indent) + 1),ldesc,desc_width).reshape(-1):
                stop=min(start + desc_width,ldesc)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:173
                printf('%s%s\n',indent_space,strtrim(desc[start:stop]))
    else:
        ## Return the results instead of displaying them
        fcn=copy(fcnlist)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:179
        help1str=copy(help_text)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:180
    
    return fcn,help1str
    
if __name__ == '__main__':
    pass
    
    
@function
def search_cache(str=None,cache_file=None,search_type=None,*args,**kwargs):
    varargin = search_cache.varargin
    nargin = search_cache.nargin

    load(cache_file)
    if (logical_not(isempty(cache))):
        t1=strfind(lower(cache(1,arange())),str)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:188
        t2=strfind(lower(cache(search_type,arange())),str)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:189
        cache_idx=find(logical_not((logical_and(cellfun('isempty',t1),cellfun('isempty',t2)))))
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:190
        fcns=cache(1,cache_idx)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:191
        help_texts=cache(3,cache_idx)
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:192
    else:
        fcns=help_texts=cellarray([])
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:194
# /home/lei/octave-4.0.2/scripts/help/lookfor.m:194
    
    return fcns,help_texts
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Command} {} which name @dots{}
## Display the type of each @var{name}.
##
## If @var{name} is defined from a function file, the full name of the file is
## also displayed.
## @seealso{help, lookfor}
## @end deftypefn
    
    
@function
def which(varargin=None,*args,**kwargs):
    varargin = which.varargin
    nargin = which.nargin

    if (nargin > 0 and iscellstr(varargin)):
        m=__which__(varargin[:])
# /home/lei/octave-4.0.2/scripts/help/which.m:31
        ## functions in name resolution.
        for i in arange(1,nargin).reshape(-1):
            m[i].is_variable = copy(evalin('caller',cat('exist ("',m[i].name,'", "var")'),false))
# /home/lei/octave-4.0.2/scripts/help/which.m:36
            if (m[i].is_variable):
                m[i].file = copy('variable')
# /home/lei/octave-4.0.2/scripts/help/which.m:39
        if (nargout == 0):
            for i in arange(1,nargin).reshape(-1):
                if (m[i].is_variable):
                    printf('\'%s\' is a variable\n',m[i].name)
                else:
                    if (isempty(m[i].file)):
                        if (logical_not(isempty(m[i].type))):
                            printf('\'%s\' is a %s\n',m[i].name,m[i].type)
                    else:
                        if (isempty(m[i].type)):
                            printf('\'%s\' is the file %s\n',m[i].name,m[i].file)
                        else:
                            printf('\'%s\' is a %s from the file %s\n',m[i].name,m[i].type,m[i].file)
        else:
            varargout=cellarray([m.file])
# /home/lei/octave-4.0.2/scripts/help/which.m:63
    else:
        print_usage()
    
    return varargout
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{retval}, @var{status}] =} __makeinfo__ (@var{text}, @var{output_type})
## @deftypefnx {Function File} {[@var{retval}, @var{status}] =} __makeinfo__ (@var{text}, @var{output_type}, @var{see_also})
## Undocumented internal function.
## @end deftypefn
    
    ## Run @code{makeinfo} on a given text.
##
## The string @var{text} is run through the @code{__makeinfo__} program
## to generate output in various formats. This string must contain valid
## Texinfo formatted text.
##
## The @var{output_type} selects the format of the output. This can be either
## @t{"html"}, @t{"texinfo"}, or @t{"plain text"}. By default this is
## @t{"plain text"}. If @var{output_type} is @t{"texinfo"}, the @t{@@seealso}
## macro is expanded, but otherwise the text is unaltered.
##
## If the optional argument @var{see_also} is present, it is used to expand the
## Octave specific @t{@@seealso} macro. This argument must be a function handle,
## that accepts a cell array of strings as input argument (each elements of the
## array corresponds to the arguments to the @t{@@seealso} macro), and return
## the expanded string. If this argument is not given, the @t{@@seealso} macro
## will be expanded to the text
##
## @example
## See also: arg1, arg2, ...
## @end example
##
## @noindent
## for @t{"plain text"} output, and
##
## @example
## See also: @@ref@{arg1@}, @@ref@{arg2@}, ...
## @end example
##
## @noindent
## otherwise.
##
## The optional output argument @var{status} contains the exit status of the
## @code{makeinfo} program as returned by @code{system}.
    
    
@function
def __makeinfo__(text=None,output_type='plain text',fsee_also=None,*args,**kwargs):
    varargin = __makeinfo__.varargin
    nargin = __makeinfo__.nargin

    ## Check input
    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(ischar(text))):
        error('__makeinfo__: first input argument must be a string')
    
    if (logical_not(ischar(output_type))):
        error('__makeinfo__: second input argument must be a string')
    
    ## NOTE: The 3rd argument is used by Octave-Forge function
  ##       generate_package_html, not by core Octave.  This functionality
  ##       can only be removed when that function has been updated.
    if (nargin < 3):
        if (strcmpi(output_type,'plain text')):
            fsee_also=lambda T=None: strcat('\nSee also:',sprintf(' %s,',T[:])(arange(1,end() - 1)),'\n')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:80
        else:
            fsee_also=lambda T=None: strcat('\nSee also:',sprintf(' @ref{%s},',T[:])(arange(1,end() - 1)),'\n')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:83
    
    if (logical_not(isa(fsee_also,'function_handle'))):
        error('__makeinfo__: third input argument must be a function handle')
    
    ## Formatting in m-files has an extra space at the beginning of every line.
  ## Remove these unwanted spaces if present.  First text char is "\n" delim.
    if (text[2] == ' '):
        text=strrep(text,'\n ','\n')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:95
    
    ## Texinfo crashes if @end tex does not appear first on the line.
    text=regexprep(text,'^ +@end tex','@end tex','lineanchors')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:98
    file=texi_macros_file()
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:100
    fid=fopen(file,'r')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:101
    if (fid < 0):
        error('unable to open %s for reading',file)
    else:
        macros_text=fread(fid,Inf,'*char').T
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:105
        text=matlabarray(cat(macros_text,text))
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:106
    
    fclose(fid)
    if (strcmpi(output_type,'texinfo')):
        status=0
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:111
        retval=copy(text)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:112
        return retval,status
    
    ## Create the final TeXinfo input string
    text=sprintf('\\input texinfo\n\n%s\n\n@bye\n',text)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:117
    try:
        ## Write Texinfo to tmp file
        template='octave-help-XXXXXX'
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:121
        fid,name=mkstemp(fullfile(tempdir,template),true,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:122
        if (fid < 0):
            error('__makeinfo__: could not create temporary file')
        fprintf(fid,'%s',text)
        fclose(fid)
        if 'plain text' == (lower(output_type)):
            cmd=sprintf('%s --no-headers --no-warn --force --no-validate --output=- %s',makeinfo_program(),name)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:132
        else:
            if 'html' == (lower(output_type)):
                cmd=sprintf('%s --no-headers --html --no-warn --no-validate --force --output=- %s',makeinfo_program(),name)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:135
            else:
                error('__makeinfo__: unsupported output type: \'%s\'',output_type)
        ## Call makeinfo
        status,retval=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:142
        if (strcmpi(output_type,'plain text')):
            if (numel(retval) > 2 and retval[end() - 1:end()] == '\n\n'):
                retval=retval[1:end() - 2]
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:147
        ## Clean up start of @deftypefn expansion which includes extra ':'
        retval=regexprep(retval,'^ -- : +',' -- ','lineanchors')
# /home/lei/octave-4.0.2/scripts/help/__makeinfo__.m:152
    finally:
        if (exist(name,'file')):
            delete(name)
    
    return retval,status
    
if __name__ == '__main__':
    pass
    
    ## No test needed for internal helper function.
    
    ## Copyright (C) 2010-2015 John W. Eaton
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{txt} =} __unimplemented__ (@var{fcn})
## Return specific help text for the unimplemented function @var{fcn}.
##
## This is usually a suggestion for an existing compatible function to use in
## place of @var{fcn}.
##
## This function is not called by users, but by the Octave interpreter when it
## fails to recognize an input string as a valid function name.  See
## @code{missing_function_hook} for using a different handler for this event.
## @seealso{missing_function_hook}
## @end deftypefn
    
    
@function
def __unimplemented__(fcn=None,*args,**kwargs):
    varargin = __unimplemented__.varargin
    nargin = __unimplemented__.nargin

    if (nargin != 1):
        print_usage()
    
    is_matlab_function=copy(true)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:40
    
    if cellarray(['avifile','aviinfo','aviread']) == (fcn):
        txt=matlabarray(cat('Basic video file support is provided in the video package.  ','See @url{http://octave.sf.net/video/}.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:45
    else:
        if 'exifread' == (fcn):
            txt=matlabarray(cat('exifread is deprecated.  ','The functionality is available in the imfinfo function.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:49
        else:
            if 'gsvd' == (fcn):
                txt=matlabarray(cat('gsvd is not currently part of core Octave.  ','See the linear-algebra package at ','@url{http://octave.sourceforge.net/linear-algebra/}.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:53
            else:
                if 'funm' == (fcn):
                    txt=matlabarray(cat('funm is not currently part of core Octave.  ','See the linear-algebra package at ','@url{http://octave.sourceforge.net/linear-algebra/}.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:58
                else:
                    if 'griddedInterpolant' == (fcn):
                        txt=matlabarray(cat('griddedInterpolant is not implemented.  ','Consider using griddata.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:63
                    else:
                        if 'integral' == (fcn):
                            txt=matlabarray(cat('Octave provides many routines for 1-D numerical integration.  ','Consider quadcc, quad, quadv, quadl, quadgk.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:67
                        else:
                            if 'integral2' == (fcn):
                                txt=matlabarray(cat('integral2 is not implemented.  Consider using dblquad.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:71
                            else:
                                if 'integral3' == (fcn):
                                    txt=matlabarray(cat('integral3 is not implemented.  Consider using triplequad'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:74
                                else:
                                    if 'linprog' == (fcn):
                                        txt=matlabarray(cat('Octave does not currently provide linprog.  ','Linear programming problems may be solved using @code{glpk}.  ','Try @code{help glpk} for more info.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:77
                                    else:
                                        if 'matlabrc' == (fcn):
                                            txt=matlabarray(cat('matlabrc is not implemented.  ','Octave uses the file ".octaverc" instead.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:82
                                        else:
                                            if cellarray(['ode113','ode15i','ode15s','ode23','ode23s','ode23t','ode23tb','ode45','odeget','odeset']) == (fcn):
                                                txt=matlabarray(cat('Octave provides lsode for solving differential equations.  ','For more information try @code{help lsode}.  ','Matlab-compatible ODE functions are provided by the odepkg ','package.  See @url{http://octave.sourceforge.net/odepkg/}.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:87
                                            else:
                                                if 'startup' == (fcn):
                                                    txt=matlabarray(cat('startup is not implemented.  ','Octave uses the file ".octaverc" instead.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:93
                                                else:
                                                    if 'quad2d' == (fcn):
                                                        txt=matlabarray(cat('quad2d is not implemented.  Consider using dblquad.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:97
                                                    else:
                                                        if cellarray(['xlsread','xlsfinfo','xlswrite','wk1read','wk1finfo','wk1write']) == (fcn):
                                                            txt=matlabarray(cat('Functions for spreadsheet style I/O ','(.xls .xlsx .sxc .ods .dbf .wk1 etc.) ','are provided in the io package. ','See @url{http://octave.sf.net/io/}.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:100
                                                        else:
                                                            if cellarray(['absorbDelay','allmargin','append','augstate','balreal','balred','balredOptions','bdschur','bode','bodemag','bodeoptions','bodeplot','c2d','c2dOptions','canon','care','chgFreqUnit','chgTimeUnit','connect','connectOptions','covar','ctrb','ctrbf','ctrlpref','d2c','d2cOptions','d2d','d2dOptions','damp','dare','db2mag','dcgain','delay2z','delayss','dlqr','dlyap','dlyapchol','drss','dsort','dss','dssdata','esort','estim','evalfr','feedback','filt','frd','frdata','freqresp','gcare','gdare','genfrd','genmat','gensig','genss','get','getBlockValue','getDelayModel','getGainCrossover','getIOTransfer','getLFTModel','getLoopTransfer','getNominal','getoptions','getPeakGain','getSwitches','getValue','gram','hasdelay','hasInternalDelay','hsvd','hsvdOptions','hsvoptions','hsvplot','imp2exp','impulse','impulseplot','initial','initialplot','iopzmap','iopzplot','isct','isdt','isempty','isfinite','isParametric','isproper','isreal','issiso','isstable','isstatic','kalman','kalmd','lft','loopswitch','lqg','lqgreg','lqgtrack','lqi','lqr','lqrd','lqry','lsim','lsiminfo','lsimplot','ltiview','lyap','lyapchol','mag2db','margin','minreal','modred','modsep','nblocks','ndims','ngrid','nichols','nicholsoptions','nicholsplot','nmodels','norm','nyquist','nyquistoptions','nyquistplot','obsv','obsvf','order','pade','parallel','permute','pid','piddata','pidstd','pidstddata','pidtool','pidtune','pidtuneOptions','place','pole','prescale','pzmap','pzoptions','pzplot','realp','reg','replaceBlock','repsys','reshape','rlocus','rlocusplot','rss','series','set','setBlockValue','setDelayModel','setoptions','setValue','sgrid','showBlockValue','showTunable','sigma','sigmaoptions','sigmaplot','sisoinit','sisotool','size','sminreal','ss','ss2ss','ssdata','stabsep','stabsepOptions','stack','step','stepDataOptions','stepinfo','stepplot','sumblk','tf','tfdata','thiran','timeoptions','totaldelay','tzero','updateSystem','upsample','xperm','zero','zgrid','zpk','zpkdata']) == (fcn):
                                                                txt=check_package(fcn,'control')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:142
                                                            else:
                                                                if cellarray(['algdeintrlv','algintrlv','alignsignals','amdemod','ammod','arithdeco','arithenco','awgn','bchdec','bchenc','bchgenpoly','bchnumerr','berawgn','bercoding','berconfint','berfading','berfit','bersync','bertool','bi2de','bin2gray','biterr','bsc','cma','commscope','compand','convdeintrlv','convenc','convintrlv','convmtx','cosets','cyclgen','cyclpoly','de2bi','decode','deintrlv','dfe','dftmtx','distspec','doppler','dpcmdeco','dpcmenco','dpcmopt','dpskdemod','dpskmod','dvbs2ldpc','encode','equalize','eyediagram','EyeScope','finddelay','fmdemod','fmmod','fskdemod','fskmod','gaussdesign','gen2par','genqamdemod','genqammod','gf','gfadd','gfconv','gfcosets','gfdeconv','gfdiv','gffilter','gflineq','gfminpol','gfmul','gfpretty','gfprimck','gfprimdf','gfprimfd','gfrank','gfrepcov','gfroots','gfsub','gftable','gftrunc','gftuple','gfweight','gray2bin','hammgen','heldeintrlv','helintrlv','helscandeintrlv','helscanintrlv','huffmandeco','huffmandict','huffmanenco','intdump','intrlv','iscatastrophic','isprimitive','istrellis','legacychannelsim','lineareq','lloyds','lms','log','lteZadoffChuSeq','marcumq','mask2shift','matdeintrlv','matintrlv','minpol','mldivide','mlseeq','modnorm','muxdeintrlv','muxintrlv','noisebw','normlms','oct2dec','oqpskdemod','oqpskmod','pamdemod','pammod','pmdemod','pmmod','poly2trellis','primpoly','pskdemod','pskmod','qamdemod','qammod','qfunc','qfuncinv','quantiz','randdeintrlv','randerr','randintrlv','randsrc','rayleighchan','rcosdesign','rectpulse','reset','ricianchan','rls','rsdec','rsenc','rsgenpoly','rsgenpolycoeffs','scatterplot','sdrexamples','sdrfgensysace','sdrfroot','sdrinfo','sdrload','sdrsetup','semianalytic','shift2mask','signlms','ssbdemod','ssbmod','stdchan','supportPackageInstaller','symerr','syndtable','varlms','vec2mat','vitdec','wgn']) == (fcn):
                                                                    txt=check_package(fcn,'communications')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:178
                                                                else:
                                                                    if cellarray(['abs2active','accrfrac','acrubond','acrudisc','active2abs','addEquality','addEquality','addEquality','addGroupRatio','addGroupRatio','addGroupRatio','addGroups','addGroups','addGroups','addInequality','addInequality','addInequality','adline','adosc','amortize','annurate','annuterm','arith2geom','ascii2fts','beytbill','binprice','blkimpv','blkprice','blsdelta','blsgamma','blsimpv','blslambda','blsprice','blsrho','blstheta','blsvega','bndconvp','bndconvy','bnddurp','bnddury','bndkrdur','bndprice','bndspread','bndtotalreturn','bndyield','bolling','bollinger','boxcox','busdate','busdays','candle','cdai','cdprice','cdyield','cfamounts','cfbyzero','cfconv','cfdates','cfdur','cfplot','cfport','cfprice','cfspread','cftimes','cfyield','chaikosc','chaikvolat','chartfts','checkFeasibility','checkFeasibility','checkFeasibility','chfield','convert2sur','convertto','corr2cov','cov2corr','cpncount','cpndaten','cpndatenq','cpndatep','cpndaysp','cpnpersz','createholidays','cumsum','cur2frac','cur2str','date2time','dateaxis','datedisp','datefind','datemnth','datewrkdy','day','days360','days360e','days360isda','days360psa','days365','daysact','daysadd','daysdif','dec2thirtytwo','depfixdb','depgendb','deprdv','depsoyd','depstln','diff','disc2zero','discrate','ecmmvnrfish','ecmmvnrmle','ecmmvnrobj','ecmmvnrstd','ecmnfish','ecmnhess','ecmninit','ecmnmle','ecmnobj','ecmnstd','effrr','elpm','emaxdrawdown','end','eomdate','estimateAssetMoments','estimateBounds','estimateBounds','estimateBounds','estimateFrontier','estimateFrontier','estimateFrontier','estimateFrontierByReturn','estimateFrontierByReturn','estimateFrontierByReturn','estimateFrontierByRisk','estimateFrontierByRisk','estimateFrontierByRisk','estimateFrontierLimits','estimateFrontierLimits','estimateFrontierLimits','estimateMaxSharpeRatio','estimatePortMoments','estimatePortReturn','estimatePortReturn','estimatePortReturn','estimatePortRisk','estimatePortRisk','estimatePortRisk','estimatePortStd','estimatePortStd','estimatePortVaR','estimateScenarioMoments','estimateScenarioMoments','ewstats','exp','extfield','fbusdate','fetch','fieldnames','fillts','fints','floatdiscmargin','floatmargin','fpctkd','frac2cur','freqnum','freqstr','frontcon','frontier','fts2ascii','fts2mat','ftsbound','ftsgui','ftsinfo','ftstool','ftsuniq','fvdisc','fvfix','fvvar','fwd2zero','geom2arith','getAssetMoments','getBounds','getBounds','getBounds','getBudget','getBudget','getBudget','getCosts','getCosts','getCosts','getEquality','getEquality','getEquality','getGroupRatio','getGroupRatio','getGroupRatio','getGroups','getGroups','getGroups','getInequality','getInequality','getInequality','getnameidx','getOneWayTurnover','getOneWayTurnover','getOneWayTurnover','getScenarios','getScenarios','hhigh','highlow','holdings2weights','holidays','horzcat','hour','inforatio','irr','isbusday','iscompatible','isempty','isfield','issorted','kagi','lagts','lbusdate','leadts','length','linebreak','llow','log','log10','log2','lpm','lweekdate','m2xdate','macd','maxdrawdown','medprice','merge','minus','minute','mirr','month','months','movavg','mrdivide','mtimes','mvnrfish','mvnrmle','mvnrobj','mvnrstd','nancov','nanmax','nanmean','nanmedian','nanmin','nanstd','nansum','nanvar','negvolidx','nomrr','nweekdate','nyseclosures','onbalvol','opprofit','payadv','payodd','payper','payuni','pcalims','pcgcomp','pcglims','pcpval','peravg','periodicreturns','plotFrontier','plotFrontier','plotFrontier','plus','pointfig','portalloc','portalpha','portcons','Portfolio','PortfolioCVaR','PortfolioMAD','portopt','portrand','portror','portsim','portstats','portvar','portvrisk','posvolidx','power','prbyzero','prcroc','prdisc','priceandvol','prmat','prtbill','pvfix','pvtrend','pvvar','pyld2zero','rdivide','renko','resamplets','ret2tick','rmfield','rsindex','selectreturn','setAssetList','setAssetList','setAssetList','setAssetMoments','setBounds','setBounds','setBounds','setBudget','setBudget','setBudget','setCosts','setCosts','setCosts','setDefaultConstraints','setDefaultConstraints','setDefaultConstraints','setEquality','setEquality','setEquality','setGroupRatio','setGroupRatio','setGroupRatio','setGroups','setGroups','setGroups','setInequality','setInequality','setInequality','setInitPort','setInitPort','setInitPort','setOneWayTurnover','setOneWayTurnover','setOneWayTurnover','setProbabilityLevel','setScenarios','setScenarios','setSolver','setSolver','setSolver','setTurnover','setTurnover','setTurnover','sharpe','simulateNormalScenariosByData','simulateNormalScenariosByData','simulateNormalScenariosByMoments','simulateNormalScenariosByMoments','size','smoothts','sortfts','spctkd','stochosc','subsasgn','subsref','targetreturn','taxedrr','tbilldisc2yield','tbillprice','tbillrepo','tbillval01','tbillyield','tbillyield2disc','tbl2bond','thirdwednesday','thirtytwo2dec','tick2ret','time2date','times','toannual','todaily','today','todecimal','tomonthly','toquarterly','toquoted','tosemi','totalreturnprice','toweekly','tr2bonds','transprob','transprobbytotals','transprobfromthresholds','transprobgrouptotals','transprobprep','transprobtothresholds','tsaccel','tsmom','tsmovavg','typprice','ugarch','ugarchllf','ugarchpred','ugarchsim','uicalendar','uminus','uplus','vertcat','volarea','volroc','wclose','weeknum','weights2holdings','willad','willpctr','wrkdydif','x2mdate','xirr','year','yeardays','yearfrac','ylddisc','yldmat','yldtbill','zbtprice','zbtyield','zero2disc','zero2fwd','zero2pyld']) == (fcn):
                                                                        txt=check_package(fcn,'financial')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:279
                                                                    else:
                                                                        if cellarray(['activecontour','adapthisteq','affine2d','affine3d','analyze75info','analyze75read','applycform','applylut','axes2pix','bestblk','blockproc','bwarea','bwareaopen','bwboundaries','bwconncomp','bwconvhull','bwdist','bwdistgeodesic','bweuler','bwhitmiss','bwlabel','bwlabeln','bwlookup','bwmorph','bwpack','bwperim','bwselect','bwtraceboundary','bwulterode','bwunpack','checkerboard','col2im','colfilt','conndef','convmtx2','corner','cornermetric','corr2','cp2tform','cpcorr','cpselect','cpstruct2pairs','dct2','dctmtx','deconvblind','deconvlucy','deconvreg','deconvwnr','decorrstretch','demosaic','dicomanon','dicomdict','dicominfo','dicomlookup','dicomread','dicomuid','dicomwrite','edge','edgetaper','entropy','entropyfilt','fan2para','fanbeam','findbounds','fitgeotrans','fliptform','freqz2','fsamp2','fspecial','ftrans2','fwind1','fwind2','getheight','getimage','getimagemodel','getline','getneighbors','getnhood','getpts','getrect','getsequence','graycomatrix','graycoprops','graydist','grayslice','graythresh','hdrread','hdrwrite','histeq','hough','houghlines','houghpeaks','iccfind','iccread','iccroot','iccwrite','idct2','ifanbeam','im2bw','im2col','im2double','im2int16','im2java2d','im2single','im2uint16','im2uint8','imabsdiff','imadd','imadjust','ImageAdapter','imageinfo','imapplymatrix','imapprox','imattributes','imbothat','imclearborder','imclose','imcolormaptool','imcomplement','imcontour','imcontrast','imcrop','imdilate','imdisplayrange','imdistline','imdivide','imellipse','imerode','imextendedmax','imextendedmin','imfill','imfilter','imfindcircles','imfreehand','imfuse','imgca','imgcf','imgetfile','imgradient','imgradientxy','imhandles','imhist','imhistmatch','imhmax','imhmin','imimposemin','imlincomb','imline','immagbox','immovie','immultiply','imnoise','imopen','imoverview','imoverviewpanel','impixel','impixelinfo','impixelinfoval','impixelregion','impixelregionpanel','implay','impoint','impoly','improfile','impyramid','imquantize','imreconstruct','imrect','imref2d','imref3d','imregconfig','imregionalmax','imregionalmin','imregister','imregtform','imresize','imroi','imrotate','imsave','imscrollpanel','imsharpen','imshowpair','imsubtract','imtool','imtophat','imtransform','imwarp','interfileinfo','interfileread','intlut','iptaddcallback','iptcheckconn','iptcheckhandle','iptgetapi','iptGetPointerBehavior','iptgetpref','ipticondir','iptPointerManager','iptprefs','iptremovecallback','iptSetPointerBehavior','iptsetpref','iptwindowalign','iradon','isflat','isicc','isrset','lab2double','lab2uint16','lab2uint8','label2rgb','labelmatrix','makecform','makeConstrainToRectFcn','makehdr','makelut','makeresampler','maketform','mat2gray','mean2','medfilt2','montage','multithresh','nitfinfo','nitfread','nlfilter','normxcorr2','openrset','ordfilt2','otf2psf','padarray','para2fan','phantom','poly2mask','projective2d','psf2otf','qtdecomp','qtgetblk','qtsetblk','radon','rangefilt','reflect','regionprops','rgb2gray','rgb2ycbcr','roicolor','roifill','roifilt2','roipoly','rsetwrite','std2','stdfilt','strel','stretchlim','subimage','tformarray','tformfwd','tforminv','tonemap','translate','truesize','viscircles','warp','watershed','whitepoint','wiener2','xyz2double','xyz2uint16','ycbcr2rgb']) == (fcn):
                                                                            txt=check_package(fcn,'image')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:341
                                                                        else:
                                                                            if cellarray(['ac2poly','ac2rc','angle','arburg','arcov','armcov','aryule','bandpower','barthannwin','besselap','besself','bilinear','bitrevorder','blackmanharris','bohmanwin','buffer','buttap','butter','buttord','cceps','cconv','cell2sos','cfirpm','cheb1ap','cheb1ord','cheb2ap','cheb2ord','chebwin','cheby1','cheby2','chirp','convmtx','corrmtx','cpsd','czt','db','db2mag','db2pow','dct','decimate','demod','design','designmethods','designopts','dfilt','dftmtx','digitrevorder','diric','downsample','dpss','dpssclear','dpssdir','dpssload','dspdata','dspfwiz','dutycycle','ellip','ellipap','ellipord','enbw','equiripple','falltime','fdatool','fdesign','filt2block','filterbuilder','filternorm','filtfilt','filtic','filtord','findpeaks','fir1','fir2','fircls','fircls1','firls','firpm','firpmord','firrcos','firtype','flattopwin','freqs','freqsamp','fvtool','fwht','gauspuls','gaussdesign','gaussfir','gausswin','gmonopuls','goertzel','grpdelay','hann','hilbert','icceps','idct','ifwht','impinvar','impz','impzlength','interp','intfilt','invfreqs','invfreqz','is2rc','isallpass','islinphase','ismaxphase','isminphase','isstable','kaiser','kaiserord','kaiserwin','lar2rc','latc2tf','latcfilt','levinson','lp2bp','lp2bs','lp2hp','lp2lp','lpc','lsf2poly','mag2db','marcumq','maxflat','medfilt1','midcross','modulate','mscohere','nuttallwin','overshoot','parzenwin','pburg','pcov','peak2peak','peak2rms','peig','phasedelay','phasez','pmcov','pmtm','pmusic','poly2ac','poly2lsf','poly2rc','polyscale','polystab','pow2db','prony','pulseperiod','pulsesep','pulsewidth','pulstran','pwelch','pyulear','rc2ac','rc2is','rc2lar','rc2poly','rceps','rcosdesign','realizemdl','rectpuls','rectwin','resample','residuez','risetime','rlevinson','rms','rooteig','rootmusic','rssq','sawtooth','schurrc','seqperiod','setspecs','settlingtime','sfdr','sgolay','sgolayfilt','shiftdata','sigwin','sinad','slewrate','snr','sos2cell','sos2ss','sos2tf','sos2zp','sosfilt','spectrogram','spectrum','sptool','square','ss2sos','ss2tf','ss2zp','statelevels','stepz','stmcb','strips','taylorwin','tf2latc','tf2sos','tf2ss','tf2zp','tf2zpk','tfestimate','thd','toi','triang','tripuls','tukeywin','udecode','uencode','undershoot','unshiftdata','upfirdn','upsample','validstructures','vco','window','wintool','wvtool','xcorr','xcorr2','xcov','yulewalk','zerophase','zp2sos','zp2ss','zp2tf','zplane']) == (fcn):
                                                                                txt=check_package(fcn,'signal')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:387
                                                                            else:
                                                                                if cellarray(['addedvarplot','addlevels','addTerms','addTerms','adtest','andrewsplot','anova1','anova2','anovan','ansaribradley','aoctool','barttest','bbdesign','betafit','betalike','betastat','binofit','binostat','biplot','bootci','bootstrp','boxplot','candexch','candgen','canoncorr','capability','capaplot','caseread','casewrite','ccdesign','cdf','cdf','cdfplot','cell2dataset','chi2gof','chi2stat','cholcov','ClassificationBaggedEnsemble','ClassificationDiscriminant','ClassificationEnsemble','ClassificationKNN','ClassificationPartitionedEnsemble','ClassificationPartitionedModel','ClassificationTree','classify','classregtree','cluster','clusterdata','cmdscale','coefCI','coefCI','coefCI','coefCI','coefTest','coefTest','coefTest','coefTest','combnk','compact','CompactClassificationDiscriminant','CompactClassificationEnsemble','CompactClassificationTree','CompactRegressionEnsemble','CompactRegressionTree','CompactTreeBagger','compare','confusionmat','controlchart','controlrules','cophenet','copulacdf','copulafit','copulaparam','copulapdf','copularnd','copulastat','cordexch','corrcov','covarianceParameters','coxphfit','createns','crosstab','crossval','cvpartition','datasample','dataset','dataset2cell','dataset2struct','dataset2table','datasetfun','daugment','dcovary','dendrogram','designMatrix','devianceTest','dfittool','disp','disp','disp','disp','disttool','droplevels','dummyvar','dwtest','dwtest','ecdf','ecdfhist','evalclusters','evcdf','evfit','evinv','evlike','evpdf','evrnd','evstat','ExhaustiveSearcher','expfit','explike','export','expstat','factoran','feval','feval','feval','ff2n','fitdist','fitensemble','fitglm','fitlm','fitlme','fitlmematrix','fitnlm','fitted','fixedEffects','fracfact','fracfactgen','friedman','fsurfht','fullfact','gagerr','gamfit','gamlike','gamstat','GeneralizedLinearModel','geomean','geostat','getlabels','getlevels','gevcdf','gevfit','gevinv','gevlike','gevpdf','gevrnd','gevstat','gline','glmfit','glmval','glyphplot','gmdistribution','gname','gpcdf','gpfit','gpinv','gplike','gplotmatrix','gppdf','gprnd','gpstat','grp2idx','grpstats','gscatter','haltonset','harmmean','hist3','histfit','hmmdecode','hmmestimate','hmmgenerate','hmmtrain','hmmviterbi','hougen','hygestat','icdf','icdf','inconsistent','interactionplot','invpred','islevel','ismissing','isundefined','iwishrnd','jackknife','jbtest','johnsrnd','join','KDTreeSearcher','kmeans','knnsearch','kruskalwallis','ksdensity','kstest','kstest2','labels','lasso','lassoglm','lassoPlot','levelcounts','leverage','lhsdesign','lhsnorm','lillietest','LinearMixedModel','LinearModel','linhyptest','linkage','lognfit','lognlike','lognstat','lsline','mad','mahal','maineffectsplot','makedist','manova1','manovacluster','mat2dataset','mdscale','mergelevels','mhsample','mle','mlecov','mnpdf','mnrfit','mnrnd','mnrval','multcompare','multivarichart','mvncdf','mvnpdf','mvnrnd','mvregress','mvregresslike','mvtcdf','mvtpdf','mvtrnd','NaiveBayes','nancov','nanmax','nanmean','nanmedian','nanmin','nanstd','nansum','nanvar','nbinfit','nbinstat','ncfcdf','ncfinv','ncfpdf','ncfrnd','ncfstat','nctcdf','nctinv','nctpdf','nctrnd','nctstat','ncx2cdf','ncx2inv','ncx2pdf','ncx2rnd','ncx2stat','negloglik','negloglik','nlinfit','nlintool','nlmefit','nlmefitsa','nlparci','nlpredci','nnmf','nominal','NonLinearModel','normfit','normlike','normplot','normspec','normstat','optimalleaforder','ordinal','parallelcoords','paramci','paretotails','partialcorr','partialcorri','pca','pcacov','pcares','pdf','pdf','pdist','pdist2','pearsrnd','perfcurve','plotAdded','plotAdjustedResponse','plotDiagnostics','plotDiagnostics','plotDiagnostics','plotEffects','plotInteraction','plotResiduals','plotResiduals','plotResiduals','plotResiduals','plotSlice','plotSlice','plotSlice','plsregress','poissfit','poisstat','polyconf','polytool','ppca','predict','predict','predict','predict','predict','predict','predict','predict','princomp','ProbDistUnivKernel','ProbDistUnivParam','probplot','procrustes','proflik','qrandset','qrandstream','random','random','random','random','random','random','randomEffects','randsample','randtool','rangesearch','ranksum','raylcdf','raylfit','raylinv','raylpdf','raylrnd','raylstat','rcoplot','refcurve','refline','regress','RegressionBaggedEnsemble','RegressionEnsemble','RegressionPartitionedEnsemble','RegressionPartitionedModel','RegressionTree','regstats','relieff','removeTerms','removeTerms','residuals','response','ridge','robustdemo','robustfit','rotatefactors','rowexch','rsmdemo','rstool','runstest','sampsizepwr','scatterhist','sequentialfs','setlabels','signrank','signtest','silhouette','slicesample','sobolset','squareform','statget','statset','step','step','stepwise','stepwisefit','stepwiseglm','stepwiselm','struct2dataset','surfht','svmclassify','svmtrain','table2dataset','tabulate','tblread','tblwrite','tdfread','tiedrank','TreeBagger','trimmean','truncate','tstat','ttest','ttest2','unidstat','unifit','unifstat','vartest','vartest2','vartestn','wblfit','wbllike','wblplot','wblstat','wishrnd','x2fx','xlsread','xptread','ztest']) == (fcn):
                                                                                    txt=check_package(fcn,'statistics')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:481
                                                                                else:
                                                                                    if cellarray(['argnames','bernoulli','catalan','charpoly','chebyshevT','chebyshevU','children','coshint','cosint','dawson','digits','dilog','dirac','divisors','dsolve','ei','ellipticCE','ellipticCK','ellipticCPi','ellipticE','ellipticF','ellipticK','ellipticPi','euler','eulergamma','finverse','formula','fresnelc','fresnels','funtool','gegenbauerC','harmonic','heaviside','hermiteH','hypergeom','igamma','jacobiP','kroneckerDelta','kummerU','laguerreL','legendreP','logint','minpoly','pochhammer','poles','poly2sym','polylog','pretty','quorem','rectangularPulse','signIm','simplify','sinhint','sinint','solve','ssinint','sym','sym2poly','symfun','sympref','syms','symvar','triangularPulse','vpa','vpasolve','whittakerM','whittakerW','zeta']) == (fcn):
                                                                                        txt=check_package(fcn,'symbolic')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:498
                                                                                    else:
                                                                                        if cellarray(['bintprog','color','fgoalattain','fmincon','fminimax','fminsearch','fseminf','fzmult','gangstr','ktrlink','linprog','lsqcurvefit','lsqlin','lsqnonlin','optimoptions','optimtool','quadprog']) == (fcn):
                                                                                            txt=check_package(fcn,'optim')
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:505
                                                                                        else:
                                                                                            if (ismember(fcn,missing_functions())):
                                                                                                txt=matlabarray(cat('the \'',fcn,'\' function is not yet implemented in Octave'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:509
                                                                                            else:
                                                                                                is_matlab_function=copy(false)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:511
                                                                                                txt=''
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:512
    
    if (is_matlab_function):
        txt=matlabarray(cat(txt,'\n\n@noindent\nPlease read ','@url{http://www.octave.org/missing.html} to learn how ','you can contribute missing functionality.'))
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:517
        txt=__makeinfo__(txt)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:520
    
    if (nargout == 0):
        warning('Octave:missing-function','%s',txt)
    
    return txt
    
if __name__ == '__main__':
    pass
    
    
@function
def check_package(fcn=None,name=None,*args,**kwargs):
    varargin = check_package.varargin
    nargin = check_package.nargin

    txt=sprintf('the \'%s\' function belongs to the %s package from Octave Forge',fcn,name)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:530
    __,status=pkg('describe',name,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:533
    if 'loaded' == (tolower(status[1])):
        txt=sprintf('%s but has not yet been implemented.',txt)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:536
    else:
        if 'not loaded' == (tolower(status[1])):
            txt=sprintf(cat('%s which you have installed but not loaded. To ','load the package, run `pkg load %s\' from the ','Octave prompt.'),txt,name)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:538
        else:
            ## this includes "not installed" and anything else if pkg changes
      ## the output of describe
            txt=sprintf('%s which seems to not be installed in your system.',txt)
# /home/lei/octave-4.0.2/scripts/help/__unimplemented__.m:544
    
    return txt
    
if __name__ == '__main__':
    pass
    
    
@function
def missing_functions(*args,**kwargs):
    varargin = missing_functions.varargin
    nargin = missing_functions.nargin

    
    return list
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{text}, @var{status}] =} __strip_html_tags__ (@var{html_text})
## Undocumented internal function.
## @end deftypefn
    
    ## Remove HTML tags from text.  This is used as a simple HTML-to-text
## function.
    
    
@function
def __strip_html_tags__(html_text=None,*args,**kwargs):
    varargin = __strip_html_tags__.varargin
    nargin = __strip_html_tags__.nargin

    start=find(html_text == '<')
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:28
    stop=find(html_text == '>')
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:29
    if (length(start) == length(stop)):
        text=copy(html_text)
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:31
        for n in arange(length(start),1,- 1).reshape(-1):
            text[start[n]:stop[n]]=[]
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:33
        text=strip_superfluous_endlines(text)
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:35
        status=0
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:36
    else:
        warning('help: invalid HTML data -- raw HTML source follows...')
        disp(html_text)
        text=''
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:40
        status=1
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:41
    
    return text,status
    
if __name__ == '__main__':
    pass
    
    ## This function removes end-lines (\n) that makes printing look bad
    
@function
def strip_superfluous_endlines(text=None,*args,**kwargs):
    varargin = strip_superfluous_endlines.varargin
    nargin = strip_superfluous_endlines.nargin

    ## Find groups of end-lines
    els=find(text == '\n')
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:48
    dels=diff(els)
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:49
    groups=matlabarray(cat(els[1],1))
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:50
    
    for k in arange(1,length(dels)).reshape(-1):
        if (dels[k] == 1):
            groups[end(),2]
        else:
            groups[end() + 1,1:2]=cat(els[k + 1],1)
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:55
    
    keep=true(size(text))
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:59
    
    if (groups[1,1] == 1):
        keep[1:groups[1,2]]=false
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:63
    
    ## Remove end-lines from the end
    if (sum(groups[end(),:]) - 1 == length(text)):
        keep[groups[end(),1]:end()]=false
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:68
    
    ## Remove groups of end-lines with more than 3 end-lines next to each other
    idx=find(groups[:,2] >= 3)
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:72
    for k in arange(1,length(idx)).reshape(-1):
        start=groups[idx[k],1]
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:74
        stop=start + groups[idx[k],2] - 1
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:75
        keep[start + 2:stop]=false
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:76
    
    ## Actually remove the elements
    text=text[keep]
# /home/lei/octave-4.0.2/scripts/help/private/__strip_html_tags__.m:80
    return text
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} __additional_help_message__ ()
## Undocumented internal function.
## @end deftypefn
    
    
@function
def __additional_help_message__(*args,**kwargs):
    varargin = __additional_help_message__.varargin
    nargin = __additional_help_message__.nargin

    if (suppress_verbose_help_message()):
        msg=''
# /home/lei/octave-4.0.2/scripts/help/private/__additional_help_message__.m:27
    else:
        msg='\nAdditional help for built-in functions and operators is\navailable in the online version of the manual.  Use the command\n\'doc <topic>\' to search the manual index.\n\nHelp and information about Octave is also available on the WWW\nat http://www.octave.org and via the help@octave.org\nmailing list.\n'
# /home/lei/octave-4.0.2/scripts/help/private/__additional_help_message__.m:29
    
    return msg
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} doc @var{function_name}
## @deftypefnx {Command} {} doc
## Display documentation for the function @var{function_name} directly from an
## online version of the printed manual, using the GNU Info browser.
##
## If invoked without an argument, the manual is shown from the beginning.
##
## For example, the command @kbd{doc rand} starts the GNU Info browser at the
## @code{rand} node in the online version of the manual.
##
## Once the GNU Info browser is running, help for using it is available using
## the command @kbd{C-h}.
## @seealso{help}
## @end deftypefn
    
    ## Author: Soren Hauberg <soren@hauberg.org>
## Adapted-by: jwe
    
    
@function
def doc(fname=None,*args,**kwargs):
    varargin = doc.varargin
    nargin = doc.nargin

    if (nargin == 0 or nargin == 1):
        ftype=0
# /home/lei/octave-4.0.2/scripts/help/doc.m:42
        if (nargin == 1):
            ## Get the directory where the function lives.
      ## FIXME: Maybe we should have a better way of doing this?
            if (ischar(fname)):
                ftype=exist(fname)
# /home/lei/octave-4.0.2/scripts/help/doc.m:49
            else:
                error('doc: expecting argument to be a character string')
        else:
            fname=''
# /home/lei/octave-4.0.2/scripts/help/doc.m:54
        ## if GUI is running, let it display the function
        if (isguirunning()):
            __octave_link_show_doc__(fname)
        else:
            if (ftype == 2 or ftype == 3):
                ffile=which(fname)
# /home/lei/octave-4.0.2/scripts/help/doc.m:63
            else:
                ffile=''
# /home/lei/octave-4.0.2/scripts/help/doc.m:65
            if (isempty(ffile)):
                info_dir=octave_config_info('infodir')
# /home/lei/octave-4.0.2/scripts/help/doc.m:69
            else:
                info_dir=fileparts(ffile)
# /home/lei/octave-4.0.2/scripts/help/doc.m:71
            ## Determine if a file called doc.info exist in the same
      ## directory as the function.
            info_file_name=fullfile(info_dir,'doc.info')
# /home/lei/octave-4.0.2/scripts/help/doc.m:77
            stat_info,err=stat(info_file_name,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/doc.m:79
            if (err < 0):
                info_file_name=info_file()
# /home/lei/octave-4.0.2/scripts/help/doc.m:82
                if (logical_not(exist(info_file_name,'file')) and logical_not(exist(cat(info_file_name,'.gz'),'file')) and logical_not(exist(cat(info_file_name,'.bz2'),'file'))):
                    __gripe_missing_component__('doc','info-file')
            ## FIXME: Don't change the order of the arguments below because
      ## the info-emacs-info script currently expects --directory DIR as
      ## the third and fourth arguments.  Someone should fix that.
            cmd=sprintf('"%s" --file "%s" --directory "%s"',info_program(),info_file_name,info_dir)
# /home/lei/octave-4.0.2/scripts/help/doc.m:95
            have_fname=logical_not(isempty(fname))
# /home/lei/octave-4.0.2/scripts/help/doc.m:98
            if (have_fname):
                status=system(sprintf('%s --index-search "%s"',cmd,fname))
# /home/lei/octave-4.0.2/scripts/help/doc.m:101
            if (logical_not((have_fname and status == 0))):
                status=system(cmd)
# /home/lei/octave-4.0.2/scripts/help/doc.m:106
                if (status == 127):
                    warning('unable to find info program \'%s\'',info_program())
            if (nargout > 0):
                retval=copy(status)
# /home/lei/octave-4.0.2/scripts/help/doc.m:113
    else:
        print_usage()
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} print_usage ()
## @deftypefnx {Function File} {} print_usage (@var{name})
## Print the usage message for the function @var{name}.
##
## When called with no input arguments the @code{print_usage} function displays
## the usage message of the currently executing function.
## @seealso{help}
## @end deftypefn
    
    
@function
def print_usage(name=None,*args,**kwargs):
    varargin = print_usage.varargin
    nargin = print_usage.nargin

    x=dbstack()
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:30
    
    if (nargin == 0):
        ## Determine the name of the calling function
        if (numel(x) > 1):
            name=x[2].name
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:35
        else:
            error('Octave:invalid-context','print_usage: invalid function\n')
        fullpath=evalin('caller','mfilename ("fullpath")')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:39
        if (strcmp(fullpath[end() - length(name) + 1:end()],name)):
            fullname=matlabarray(cat(fullpath,'.m'))
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:41
    else:
        if (logical_not(ischar(name))):
            error('Octave:invalid-input-arg','print_usage: input argument must be a string')
        else:
            fullname=copy(name)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:47
    
    ## Determine if we were called from top level.
    at_toplev=length(x) < 2 or (length(x) == 2 and strcmp(x[2].name,name))
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:51
    
    text,format=get_help_text(fullname,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:54
    max_len=80
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:55
    if 'plain text' == (lower(format)):
        usage_string,status=get_usage_plain_text(text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:58
    else:
        if 'texinfo' == (lower(format)):
            usage_string,status=get_usage_texinfo(text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:60
        else:
            if 'html' == (lower(format)):
                usage_string,status=get_usage_html(text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:62
            else:
                if 'not documented' == (lower(format)):
                    error('print_usage: \'%s\' is not documented\n',name)
                else:
                    if 'not found' == (lower(format)):
                        error('print_usage: \'%s\' not found\n',name)
                    else:
                        error('print_usage: internal error: unsupported help text format: \'%s\'\n',format)
    
    ## Raise the final error
    if (status != 0):
        warning('print_usage: Texinfo formatting filter exited abnormally')
        warning('print_usage: raw Texinfo source of help text follows...\n')
    
    if (at_toplev):
        error('Octave:invalid-fun-call','Invalid call to %s.  Correct usage is:\n\n%s\n%s',name,usage_string,__additional_help_message__())
    else:
        msg=sprintf('Invalid call to %s.  Correct usage is:\n\n%s',name,usage_string)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:82
        ## backtraces.
        if (msg[end()] == '\n'):
            msg[end()]=' '
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:87
        error('Octave:invalid-fun-call',msg)
    
    return
    
if __name__ == '__main__':
    pass
    
    
@function
def get_usage_plain_text(help_text=None,max_len=None,*args,**kwargs):
    varargin = get_usage_plain_text.varargin
    nargin = get_usage_plain_text.nargin

    ## Extract first line by searching for a double line-end.
    line_end_idx=strfind(help_text,'\n\n')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:97
    retval=help_text[1:min(cat(line_end_idx,max_len,length(help_text)))]
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:98
    status=0
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:99
    return retval,status
    
if __name__ == '__main__':
    pass
    
    
@function
def get_usage_texinfo(help_text=None,max_len=None,*args,**kwargs):
    varargin = get_usage_texinfo.varargin
    nargin = get_usage_texinfo.nargin

    ## Lines ending with "@\n" are continuation lines, so they should be
  ## concatenated with the following line.
    help_text=strrep(help_text,'@\n',' ')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:105
    
    ## include things such as @deftypefn, @deftypefnx, @defvar, etc. and their
  ## corresponding @end's.
    def_idx=strfind(help_text,'@def')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:110
    if (logical_not(isempty(def_idx))):
        endf_idx=strfind(help_text,'@end def')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:112
        def_idx=sort(cat(def_idx,endf_idx))
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:113
        endl_idx=find(help_text == '\n')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:114
        buffer=''
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:115
        for k in arange(1,length(def_idx)).reshape(-1):
            endl=endl_idx[find(endl_idx > def_idx[k],1)]
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:117
            if (isempty(endl)):
                buffer=strcat(buffer,help_text[def_idx[k]:end()],'\n')
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:119
            else:
                buffer=strcat(buffer,help_text[def_idx[k]:endl])
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:121
    else:
        retval,status=get_usage_plain_text(help_text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:125
    
    ## Run makeinfo to generate plain text
    retval,status=__makeinfo__(buffer,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:129
    return retval,status
    
if __name__ == '__main__':
    pass
    
    
@function
def get_usage_html(help_text=None,max_len=None,*args,**kwargs):
    varargin = get_usage_html.varargin
    nargin = get_usage_html.nargin

    ## Strip tags
    help_text,status=strip_html_tags(help_text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:134
    
    retval=get_usage_plain_text(help_text,max_len)
# /home/lei/octave-4.0.2/scripts/help/print_usage.m:137
    return retval,status
    
if __name__ == '__main__':
    pass
    
    ## Stop reporting function as missing tests.  No good tests possible.
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{text} =} get_first_help_sentence (@var{name})
## @deftypefnx {Function File} {@var{text} =} get_first_help_sentence (@var{name}, @var{max_len})
## @deftypefnx {Function File} {[@var{text}, @var{status}] =} get_first_help_sentence (@dots{})
## Return the first sentence of a function's help text.
##
## The first sentence is defined as the text after the function declaration
## until either the first period (".") or the first appearance of two
## consecutive newlines ("\n\n").  The text is truncated to a maximum length of
## @var{max_len}, which defaults to 80.
##
## The optional output argument @var{status} returns the status reported by
## @code{makeinfo}.  If only one output argument is requested, and @var{status}
## is nonzero, a warning is displayed.
##
## As an example, the first sentence of this help text is
##
## @example
## @group
## get_first_help_sentence ("get_first_help_sentence")
## @print{} ans = Return the first sentence of a function's help text.
## @end group
## @end example
## @end deftypefn
    
    
@function
def get_first_help_sentence(name=None,max_len=80,*args,**kwargs):
    varargin = get_first_help_sentence.varargin
    nargin = get_first_help_sentence.nargin

    ## Check input
    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not(ischar(name))):
        error('get_first_help_sentence: NAME must be a string')
    
    if (logical_not(isnumeric(max_len)) or max_len <= 0 or max_len != fix(max_len)):
        error('get_first_help_sentence: MAX_LEN must be positive integer')
    
    ## First, we get the raw help text
    help_text,format=get_help_text(name,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:59
    
    if 'plain text' == (lower(format)):
        text,status=first_sentence_plain_text(help_text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:64
    else:
        if 'texinfo' == (lower(format)):
            text,status=first_sentence_texinfo(help_text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:66
        else:
            if 'html' == (lower(format)):
                text,status=first_sentence_html(help_text,max_len,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:68
            else:
                if 'not documented' == (lower(format)):
                    error('get_first_help_sentence: \'%s\' is not documented\n',name)
                else:
                    if 'not found' == (lower(format)):
                        error('get_first_help_sentence: \'%s\' not found\n',name)
                    else:
                        error('get_first_help_sentence: internal error: unsupported help text format: \'%s\'\n',format)
    
    if (nargout <= 1 and status != 0):
        warning('get_first_help_sentence: couldn\'t run makeinfo on \'%s\'',name)
    
    return text,status
    
if __name__ == '__main__':
    pass
    
    ## This function extracts the first sentence from a plain text help text
    
@function
def first_sentence_plain_text(help_text=None,max_len=None,*args,**kwargs):
    varargin = first_sentence_plain_text.varargin
    nargin = first_sentence_plain_text.nargin

    ## Extract first line by searching for a period followed by a space class
  ## character (to support periods in numbers or words) ...
    period_idx=regexp(help_text,'\\.\\s','once')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:86
    
    ## in capturing the first newline).
    line_end_idx=regexp(help_text,'\n\n','once') - 1
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:89
    text=help_text[1:min(cat([period_idx],[line_end_idx],[max_len],[length(help_text)]))]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:90
    status=0
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:91
    return text,status
    
if __name__ == '__main__':
    pass
    
    ## This function extracts the first sentence from a Texinfo help text.
## The function works by removing @def* from the texinfo text. After this, we
## render the text to plain text using makeinfo, and then extract the first
## line.
    
@function
def first_sentence_texinfo(help_text=None,max_len=None,*args,**kwargs):
    varargin = first_sentence_texinfo.varargin
    nargin = first_sentence_texinfo.nargin

    ## Lines ending with "@\n" are continuation lines, so they should be
  ## concatenated with the following line.
    help_text=strrep(help_text,'@\n',' ')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:101
    
    ## such as @deftypefn, @deftypefnx, @defvar, etc.
    keep=true(size(help_text))
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:105
    def_idx=strfind(help_text,'@def')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:106
    if (logical_not(isempty(def_idx))):
        endl_idx=find(help_text == '\n')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:108
        for k in arange(1,length(def_idx)).reshape(-1):
            endl=endl_idx[find(endl_idx > def_idx[k],1)]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:110
            if (isempty(endl)):
                endl=numel(keep)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:112
            keep[def_idx[k]:endl]=false
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:114
        ## Remove the @end ... that corresponds to the @def we removed above
        def1=def_idx[1]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:118
        space_idx=find(help_text == ' ')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:119
        space_idx=space_idx[find(space_idx > def1,1)]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:120
        bracket_idx=find(help_text == logical_or('{',help_text) == '}')
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:121
        bracket_idx=bracket_idx[find(bracket_idx > def1,1)]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:122
        if (isempty(space_idx) and isempty(bracket_idx)):
            error('get_first_help_sentence: couldn\'t parse texinfo')
        sep_idx=min(space_idx,bracket_idx)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:126
        def_type=help_text[def1 + 1:sep_idx - 1]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:127
        end_idx=strfind(help_text,sprintf('@end %s',def_type))
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:129
        if (isempty(end_idx)):
            error('get_first_help_sentence: couldn\'t parse texinfo')
        keep[end_idx[1]:end()]=false
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:133
        help_text=help_text[keep]
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:135
    
    ## Run makeinfo to generate plain text
    help_text,status=__makeinfo__(help_text,'plain text',nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:139
    
    text=first_sentence_plain_text(help_text,max_len)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:142
    return text,status
    
if __name__ == '__main__':
    pass
    
    ## This function extracts the first sentence from a html help text.
## The function simply removes the tags and treats the text as plain text.
    
@function
def first_sentence_html(help_text=None,max_len=None,*args,**kwargs):
    varargin = first_sentence_html.varargin
    nargin = first_sentence_html.nargin

    ## Strip tags
    help_text,status=strip_html_tags(help_text,nargout=2)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:149
    
    text=first_sentence_plain_text(help_text,max_len)
# /home/lei/octave-4.0.2/scripts/help/get_first_help_sentence.m:152
    return text,status
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2009-2015 Sren Hauberg
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} type @var{name} @dots{}
## @deftypefnx {Command} {} type -q @var{name} @dots{}
## @deftypefnx {Function File} {text =} type ("@var{name}", @dots{})
## Display the contents of @var{name} which may be a file, function (m-file),
## variable, operator, or keyword.
##
## @code{type} normally prepends a header line describing the category of
## @var{name} such as function or variable; The @option{-q} option suppresses
## this behavior.
##
## If no output variable is used the contents are displayed on screen.
## Otherwise, a cell array of strings is returned, where each element
## corresponds to the contents of each requested function.
## @end deftypefn
    
    
@function
def type_(varargin=None,*args,**kwargs):
    varargin = type_.varargin
    nargin = type_.nargin

    if (nargin == 0):
        print_usage()
    else:
        if (logical_not(iscellstr(varargin))):
            error('type: input arguments must be strings')
    
    quiet=copy(false)
# /home/lei/octave-4.0.2/scripts/help/type.m:43
    idx=logical_or(strcmpi(varargin,'-q'),strcmpi(varargin,'-quiet'))
# /home/lei/octave-4.0.2/scripts/help/type.m:44
    if (any(idx)):
        quiet=copy(true)
# /home/lei/octave-4.0.2/scripts/help/type.m:46
        varargin[idx]=[]
# /home/lei/octave-4.0.2/scripts/help/type.m:47
    
    if (nargout > 0):
        text=cell(size(varargin))
# /home/lei/octave-4.0.2/scripts/help/type.m:51
    
    for n in arange(1,length(varargin)).reshape(-1):
        name=varargin[n]
# /home/lei/octave-4.0.2/scripts/help/type.m:55
        txt=''
# /home/lei/octave-4.0.2/scripts/help/type.m:58
        cmd=sprintf('exist (\'%s\')',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:59
        e=evalin('caller',cmd)
# /home/lei/octave-4.0.2/scripts/help/type.m:60
        if (e == 1):
            ## Variable
            cmd=sprintf('disp (%s);',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:63
            desc=evalin('caller',cmd)
# /home/lei/octave-4.0.2/scripts/help/type.m:64
            if (quiet):
                txt=copy(desc)
# /home/lei/octave-4.0.2/scripts/help/type.m:66
            else:
                txt=sprintf('%s is a variable\n%s',name,desc)
# /home/lei/octave-4.0.2/scripts/help/type.m:68
        else:
            if (e == 2):
                ## m-file or ordinary file
                file=which(name)
# /home/lei/octave-4.0.2/scripts/help/type.m:72
                if (length(file) > 2):
                    ext=file[end() - 1:end()]
# /home/lei/octave-4.0.2/scripts/help/type.m:74
                if (isempty(file) or logical_not(strcmpi(ext,'.m'))):
                    ## 'name' is an ordinary file, and not a function name.
                    file=file_in_loadpath(name)
# /home/lei/octave-4.0.2/scripts/help/type.m:78
                    quiet=copy(true)
# /home/lei/octave-4.0.2/scripts/help/type.m:79
                ## Read the file
                fid=fopen(file,'r')
# /home/lei/octave-4.0.2/scripts/help/type.m:83
                if (fid < 0):
                    error('type: couldn\'t open \'%s\' for reading',file)
                contents=char(fread(fid).T)
# /home/lei/octave-4.0.2/scripts/help/type.m:87
                fclose(fid)
                if (quiet):
                    txt=copy(contents)
# /home/lei/octave-4.0.2/scripts/help/type.m:91
                else:
                    txt=sprintf('%s is the user-defined function defined from: %s\n\n%s',name,file,contents)
# /home/lei/octave-4.0.2/scripts/help/type.m:93
            else:
                if (e == 3):
                    txt=sprintf('%s is a dynamically-linked function',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:97
                else:
                    if (e == 5):
                        txt=sprintf('%s is a built-in function',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:99
                    else:
                        if (any(strcmp(__operators__(),name))):
                            txt=sprintf('%s is an operator',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:101
                        else:
                            if (any(strcmp(__keywords__(),name))):
                                txt=sprintf('%s is a keyword',name)
# /home/lei/octave-4.0.2/scripts/help/type.m:103
                            else:
                                error('type: \'%s\' undefined\n',name)
        if (nargout == 0):
            disp(txt)
        else:
            text[n]=txt
# /home/lei/octave-4.0.2/scripts/help/type.m:111
    
    return text
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} stdnormal_pdf (@var{x})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the standard normal distribution
## (mean = 0, standard deviation = 1).
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: PDF of the standard normal distribution
    
    
@function
def stdnormal_pdf(x=None,*args,**kwargs):
    varargin = stdnormal_pdf.varargin
    nargin = stdnormal_pdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('stdnormal_pdf: X must not be complex')
    
    pdf=dot((dot(2,pi)) ** (- 1 / 2),exp(- x ** 2 / 2))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_pdf.m:40
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} geornd (@var{p})
## @deftypefnx {Function File} {} geornd (@var{p}, @var{r})
## @deftypefnx {Function File} {} geornd (@var{p}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} geornd (@var{p}, [@var{sz}])
## Return a matrix of random samples from the geometric distribution with
## parameter @var{p}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{p}.
##
## The geometric distribution models the number of failures (@var{x}-1) of a
## Bernoulli trial with probability @var{p} before the first success (@var{x}).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the geometric distribution
    
    
@function
def geornd(p=None,varargin=None,*args,**kwargs):
    varargin = geornd.varargin
    nargin = geornd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:51
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:54
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:56
                else:
                    error('geornd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('geornd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:64
    
    if (logical_not(isscalar(p)) and logical_not(isequal(size(p),sz))):
        error('geornd: P must be scalar or of size SZ')
    
    if (iscomplex(p)):
        error('geornd: P must not be complex')
    
    if (isa(p,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:76
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:78
    
    if (isscalar(p)):
        if (p > 0 and p < 1):
            rnd=floor(- rande(sz,cls) / log(1 - p))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:83
        else:
            if (p == 0):
                rnd=Inf(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:85
            else:
                if (p == 1):
                    rnd=zeros(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:87
                else:
                    if (p < 0 or p > 1):
                        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:89
    else:
        rnd=floor(- rande(sz,cls) / log(1 - p))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:92
        k=logical_or(logical_not((p >= 0)),logical_not((p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:94
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:95
        k=(p == 0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:97
        rnd[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geornd.m:98
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} fpdf (@var{x}, @var{m}, @var{n})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the F distribution with @var{m} and @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the F distribution
    
    
@function
def fpdf(x=None,m=None,n=None,*args,**kwargs):
    varargin = fpdf.varargin
    nargin = fpdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,m,n=common_size(x,m,n,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:36
        if (retval > 0):
            error('fpdf: X, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(m) or iscomplex(n)):
        error('fpdf: X, M, and N must not be complex')
    
    if (isa(x,'single') or isa(m,'single') or isa(n,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:47
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:49
    
    k=logical_or(logical_or(logical_or(logical_or(isnan(x),logical_not((m > 0))),logical_not((m < Inf))),logical_not((n > 0))),logical_not((n < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:52
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:53
    k=logical_and(logical_and(logical_and(logical_and(logical_and((x > 0),(x < Inf)),(m > 0)),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:55
    if (isscalar(m) and isscalar(n)):
        tmp=dot(m / n,x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:57
        pdf[k]=(dot(exp(dot((m / 2 - 1),log(tmp)) - dot(((m + n) / 2),log(1 + tmp))),(m / n)) / beta(m / 2,n / 2))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:58
    else:
        tmp=multiply(m[k],x[k]) / n[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:62
        pdf[k]=(multiply(exp(multiply((m[k] / 2 - 1),log(tmp)) - multiply(((m[k] + n[k]) / 2),log(1 + tmp))),(m[k] / n[k])) / beta(m[k] / 2,n[k] / 2))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fpdf.m:63
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    ## F (x, 1, m) == T distribution (sqrt (x), m) / sqrt (x)
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} trnd (@var{n})
## @deftypefnx {Function File} {} trnd (@var{n}, @var{r})
## @deftypefnx {Function File} {} trnd (@var{n}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} trnd (@var{n}, [@var{sz}])
## Return a matrix of random samples from the t (Student) distribution with
## @var{n} degrees of freedom.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{n}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the t distribution
    
    
@function
def trnd(n=None,varargin=None,*args,**kwargs):
    varargin = trnd.varargin
    nargin = trnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:48
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:51
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:53
                else:
                    error('trnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('trnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:61
    
    if (logical_not(isscalar(n)) and logical_not(isequal(size(n),sz))):
        error('trnd: N must be scalar or of size SZ')
    
    if (iscomplex(n)):
        error('trnd: N must not be complex')
    
    if (isa(n,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:73
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:75
    
    if (isscalar(n)):
        if ((n > 0) and (n < Inf)):
            rnd=randn(sz,cls) / sqrt(dot(2,randg(n / 2,sz,cls)) / n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:80
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:82
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:85
        k=logical_and((n > 0),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:87
        rnd[k]=randn(sum(ravel(k)),1,cls) / ravel(sqrt(dot(2,randg(n[k] / 2,cls)) / n[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/trnd.m:88
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} laplace_inv (@var{x})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the Laplace distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Laplace distribution
    
    
@function
def laplace_inv(x=None,*args,**kwargs):
    varargin = laplace_inv.varargin
    nargin = laplace_inv.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('laplace_inv: X must not be complex')
    
    if (isa(x,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_inv.m:40
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_inv.m:42
    
    k=logical_and((x >= 0),(x <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_inv.m:45
    inv[k]=(multiply((x[k] < 1 / 2),log(dot(2,x[k]))) - multiply((x[k] > 1 / 2),log(dot(2,(1 - x[k])))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_inv.m:46
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unifcdf (@var{x})
## @deftypefnx {Function File} {} unifcdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the uniform distribution on the interval
## [@var{a}, @var{b}].
##
## Default values are @var{a} = 0, @var{b} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the uniform distribution
    
    
@function
def unifcdf(x=None,a=0,b=1,*args,**kwargs):
    varargin = unifcdf.varargin
    nargin = unifcdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:40
        if (retval > 0):
            error('unifcdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('unifcdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:51
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:53
    
    k=logical_or(isnan(x),logical_not((a < b)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:56
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:57
    k=logical_and((x >= b),(a < b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:59
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:60
    k=logical_and((x > a),(x < b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:62
    if (isscalar(a) and isscalar(b)):
        cdf[k]=multiply((x[k] < b),(x[k] - a)) / (b - a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:64
    else:
        cdf[k]=multiply((x[k] < b[k]),(x[k] - a[k])) / (b[k] - a[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifcdf.m:66
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} gamrnd (@var{a}, @var{b})
## @deftypefnx {Function File} {} gamrnd (@var{a}, @var{b}, @var{r})
## @deftypefnx {Function File} {} gamrnd (@var{a}, @var{b}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} gamrnd (@var{a}, @var{b}, [@var{sz}])
## Return a matrix of random samples from the Gamma distribution with
## shape parameter @var{a} and scale @var{b}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{a} and @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Gamma distribution
    
    
@function
def gamrnd(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = gamrnd.varargin
    nargin = gamrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,a,b=common_size(a,b,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:48
        if (retval > 0):
            error('gamrnd: A and B must be of common size or scalars')
    
    if (iscomplex(a) or iscomplex(b)):
        error('gamrnd: A and B must not be complex')
    
    if (nargin == 2):
        sz=size(a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:64
                else:
                    error('gamrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('gamrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:72
    
    if (logical_not(isscalar(a)) and logical_not(isequal(size(a),sz))):
        error('gamrnd: A and B must be scalar or of size SZ')
    
    if (isa(a,'single') or isa(b,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:82
    
    if (isscalar(a) and isscalar(b)):
        if ((a > 0) and (a < Inf) and (b > 0) and (b < Inf)):
            rnd=dot(b,randg(a,sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:89
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:92
        k=logical_and(logical_and(logical_and((a > 0),(a < Inf)),(b > 0)),(b < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:94
        rnd[k]=multiply(b[k],randg(a[k],cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamrnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} laplace_rnd (@var{r})
## @deftypefnx {Function File} {} laplace_rnd (@var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} laplace_rnd ([@var{sz}])
## Return a matrix of random samples from the Laplace distribution.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Laplace distribution
    
    
@function
def laplace_rnd(varargin=None,*args,**kwargs):
    varargin = laplace_rnd.varargin
    nargin = laplace_rnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        if (isscalar(varargin[1]) and varargin[1] >= 0):
            sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_rnd.m:44
        else:
            if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                sz=ravel(varargin[1]).T
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_rnd.m:46
            else:
                error('laplace_rnd: dimension vector must be row vector of non-negative integers')
    else:
        if (nargin > 1):
            if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                error('laplace_rnd: dimensions must be non-negative integers')
            sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_rnd.m:54
    
    tmp=rand(sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_rnd.m:57
    rnd=multiply((tmp < 1 / 2),log(dot(2,tmp))) - multiply((tmp > 1 / 2),log(dot(2,(1 - tmp))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_rnd.m:58
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} betainv (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the Beta distribution with parameters @var{a} and @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Beta distribution
    
    
@function
def betainv(x=None,a=None,b=None,*args,**kwargs):
    varargin = betainv.varargin
    nargin = betainv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:36
        if (retval > 0):
            error('betainv: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('betainv: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        inv=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:47
    else:
        inv=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:49
    
    k=logical_or(logical_or(logical_or(logical_or((x < 0),(x > 1)),logical_not((a > 0))),logical_not((b > 0))),isnan(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:52
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:53
    k=logical_and(logical_and((x == 1),(a > 0)),(b > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:55
    inv[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:56
    k=find(logical_and(logical_and(logical_and((x > 0),(x < 1)),(a > 0)),(b > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:58
    if (any(k)):
        if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
            a=a[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:61
            b=b[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:62
            y=a / (a + b)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:63
        else:
            y=dot(a / (a + b),ones(size(k)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:65
        x=x[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:67
        if (isa(y,'single')):
            myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:70
        else:
            myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:72
        l=find(y < myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:75
        if (any(l)):
            y[l]=dot(sqrt(myeps),ones(length(l),1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:77
        l=find(y > 1 - myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:79
        if (any(l)):
            y[l]=1 - dot(sqrt(myeps),ones(length(l),1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:81
        y_old=copy(y)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:84
        for i in arange(1,10000).reshape(-1):
            h=(betacdf(y_old,a,b) - x) / betapdf(y_old,a,b)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:86
            y_new=y_old - h
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:87
            ind=find(y_new <= myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:88
            if (any(ind)):
                y_new[ind]=y_old[ind] / 10
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:90
            ind=find(y_new >= 1 - myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:92
            if (any(ind)):
                y_new[ind]=1 - (1 - y_old[ind]) / 10
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:94
            h=y_old - y_new
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:96
            if (max(abs(h)) < sqrt(myeps)):
                break
            y_old=copy(y_new)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:100
        inv[k]=y_new
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betainv.m:103
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} geoinv (@var{x}, @var{p})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the geometric distribution with parameter @var{p}.
##
## The geometric distribution models the number of failures (@var{x}-1) of a
## Bernoulli trial with probability @var{p} before the first success (@var{x}).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the geometric distribution
    
    
@function
def geoinv(x=None,p=None,*args,**kwargs):
    varargin = geoinv.varargin
    nargin = geoinv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(p))):
        retval,x,p=common_size(x,p,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:39
        if (retval > 0):
            error('geoinv: X and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(p)):
        error('geoinv: X and P must not be complex')
    
    if (isa(x,'single') or isa(p,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:50
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:52
    
    k=logical_and(logical_and((x == 1),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:55
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:56
    k=logical_and(logical_and(logical_and((x >= 0),(x < 1)),(p > 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:58
    if (isscalar(p)):
        inv[k]=max(ceil(log(1 - x[k]) / log(1 - p)) - 1,0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:60
    else:
        inv[k]=max(ceil(log(1 - x[k]) / log(1 - p[k])) - 1,0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geoinv.m:62
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1997-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hygeinv (@var{x}, @var{t}, @var{m}, @var{n})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the hypergeometric distribution with parameters
## @var{t}, @var{m}, and @var{n}.
##
## This is the probability of obtaining @var{x} marked items when randomly
## drawing a sample of size @var{n} without replacement from a population of
## total size @var{t} containing @var{m} marked items.
##
## The parameters @var{t}, @var{m}, and @var{n} must be positive integers
## with @var{m} and @var{n} not greater than @var{t}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the hypergeometric distribution
    
    
@function
def hygeinv(x=None,t=None,m=None,n=None,*args,**kwargs):
    varargin = hygeinv.varargin
    nargin = hygeinv.nargin

    if (nargin != 4):
        print_usage()
    
    if (logical_not(isscalar(t)) or logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,t,m,n=common_size(x,t,m,n,nargout=5)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:44
        if (retval > 0):
            error('hygeinv: X, T, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(t) or iscomplex(m) or iscomplex(n)):
        error('hygeinv: X, T, M, and N must not be complex')
    
    if (isa(x,'single') or isa(t,'single') or isa(m,'single') or isa(n,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:56
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:58
    
    ok=(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and((t >= 0),(m >= 0)),(n > 0)),(m <= t)),(n <= t)),(t == fix(t))),(m == fix(m))),(n == fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:61
    if (isscalar(t)):
        if (ok):
            inv=discrete_inv(x,arange(0,n),hygepdf(arange(0,n),t,m,n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:66
            inv[x == 0]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:67
    else:
        for i in find(ravel(ok).T).reshape(-1):
            v=arange(0,n[i])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:71
            if (x[i] == 0):
                inv[i]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:73
            else:
                inv[i]=discrete_inv(x[i],v,hygepdf(v,t[i],m[i],n[i]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygeinv.m:75
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} kolmogorov_smirnov_cdf (@var{x}, @var{tol})
## Return the cumulative distribution function (CDF) at @var{x} of the
## Kolmogorov-Smirnov distribution.
##
## This is defined as
## @tex
## $$ Q(x) = \sum_{k=-\infty}^\infty (-1)^k \exp (-2 k^2 x^2) $$
## @end tex
## @ifnottex
##
## @example
## @group
##          Inf
## Q(x) =   SUM    (-1)^k exp (-2 k^2 x^2)
##        k = -Inf
## @end group
## @end example
##
## @end ifnottex
## @noindent
## for @var{x} > 0.
##
## The optional parameter @var{tol} specifies the precision up to which
## the series should be evaluated; the default is @var{tol} = @code{eps}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Kolmogorov-Smirnov distribution
    
    
@function
def kolmogorov_smirnov_cdf(x=None,tol=None,*args,**kwargs):
    varargin = kolmogorov_smirnov_cdf.varargin
    nargin = kolmogorov_smirnov_cdf.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        if (isa(x,'single')):
            tol=eps('single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:58
        else:
            tol=copy(eps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:60
    else:
        if (logical_not((isscalar(tol) and (tol > 0)))):
            error('kolmogorov_smirnov_cdf: TOL must be a positive scalar')
    
    if (numel(x) == 0):
        error('kolmogorov_smirnov_cdf: X must not be empty')
    
    cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:72
    ind=find(x > 0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:74
    if (length(ind) > 0):
        if (columns(ind) < rows(ind)):
            y=x[ind.T]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:77
        else:
            y=x[ind]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:79
        K=ceil(sqrt(- log(tol) / 2) / min(y))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:81
        k=(arange(1,K)).T
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:82
        A=exp(dot(dot(- 2,k ** 2),y ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:83
        odd=find(rem(k,2) == 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:84
        A[odd,:]=- A[odd,:]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:85
        cdf[ind]=1 + dot(2,sum(A))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/kolmogorov_smirnov_cdf.m:86
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} frnd (@var{m}, @var{n})
## @deftypefnx {Function File} {} frnd (@var{m}, @var{n}, @var{r})
## @deftypefnx {Function File} {} frnd (@var{m}, @var{n}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} frnd (@var{m}, @var{n}, [@var{sz}])
## Return a matrix of random samples from the F distribution with
## @var{m} and @var{n} degrees of freedom.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{m} and @var{n}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the F distribution
    
    
@function
def frnd(m=None,n=None,varargin=None,*args,**kwargs):
    varargin = frnd.varargin
    nargin = frnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,m,n=common_size(m,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:48
        if (retval > 0):
            error('frnd: M and N must be of common size or scalars')
    
    if (iscomplex(m) or iscomplex(n)):
        error('frnd: M and N must not be complex')
    
    if (nargin == 2):
        sz=size(m)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:64
                else:
                    error('frnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('frnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:72
    
    if (logical_not(isscalar(m)) and logical_not(isequal(size(m),sz))):
        error('frnd: M and N must be scalar or of size SZ')
    
    if (isa(m,'single') or isa(n,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:82
    
    if (isscalar(m) and isscalar(n)):
        if ((m > 0) and (m < Inf) and (n > 0) and (n < Inf)):
            rnd=dot(n / m,randg(m / 2,sz,cls)) / randg(n / 2,sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:89
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:92
        k=logical_and(logical_and(logical_and((m > 0),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:94
        rnd[k]=multiply(n[k] / m[k],randg(m[k] / 2,cls)) / randg(n[k] / 2,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/frnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} exppdf (@var{x}, @var{lambda})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the exponential distribution with mean @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the exponential distribution
    
    
@function
def exppdf(x=None,lambda_=None,*args,**kwargs):
    varargin = exppdf.varargin
    nargin = exppdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:36
        if (retval > 0):
            error('exppdf: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('exppdf: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:47
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:49
    
    k=logical_or(isnan(x),logical_not((lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:52
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:53
    k=logical_and(logical_and((x >= 0),(x < Inf)),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:55
    if (isscalar(lambda_)):
        pdf[k]=exp(- x[k] / lambda_) / lambda_
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:57
    else:
        pdf[k]=exp(- x[k] / lambda_[k]) / lambda_[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exppdf.m:59
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} norminv (@var{x})
## @deftypefnx {Function File} {} norminv (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the normal distribution with mean @var{mu} and
## standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the normal distribution
    
    
@function
def norminv(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = norminv.varargin
    nargin = norminv.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:40
        if (retval > 0):
            error('norminv: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('norminv: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:51
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:53
    
    if (isscalar(mu) and isscalar(sigma)):
        if (isfinite(mu) and (sigma > 0) and (sigma < Inf)):
            inv=mu + dot(sigma,stdnormal_inv(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:58
    else:
        k=logical_and(logical_and(isfinite(mu),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:61
        inv[k]=mu[k] + multiply(sigma[k],stdnormal_inv(x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/norminv.m:62
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} chi2pdf (@var{x}, @var{n})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the chi-square distribution with @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: PDF of the chi-square distribution
    
    
@function
def chi2pdf(x=None,n=None,*args,**kwargs):
    varargin = chi2pdf.varargin
    nargin = chi2pdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2pdf.m:36
        if (retval > 0):
            error('chi2pdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('chi2pdf: X and N must not be complex')
    
    pdf=gampdf(x,n / 2,2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2pdf.m:46
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} geocdf (@var{x}, @var{p})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the geometric distribution with parameter @var{p}.
##
## The geometric distribution models the number of failures (@var{x}-1) of a
## Bernoulli trial with probability @var{p} before the first success (@var{x}).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the geometric distribution
    
    
@function
def geocdf(x=None,p=None,*args,**kwargs):
    varargin = geocdf.varargin
    nargin = geocdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(p))):
        retval,x,p=common_size(x,p,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:39
        if (retval > 0):
            error('geocdf: X and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(p)):
        error('geocdf: X and P must not be complex')
    
    if (isa(x,'single') or isa(p,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:50
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:52
    
    k=logical_or(logical_or(isnan(x),logical_not((p >= 0))),logical_not((p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:55
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:56
    k=logical_and(logical_and((x == Inf),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:58
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:59
    k=logical_and(logical_and(logical_and(logical_and((x >= 0),(x < Inf)),(x == fix(x))),(p > 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:61
    if (isscalar(p)):
        cdf[k]=1 - ((1 - p) ** (x[k] + 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:63
    else:
        cdf[k]=1 - ((1 - p[k]) ** (x[k] + 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geocdf.m:65
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} wblcdf (@var{x})
## @deftypefnx {Function File} {} wblcdf (@var{x}, @var{scale})
## @deftypefnx {Function File} {} wblcdf (@var{x}, @var{scale}, @var{shape})
## Compute the cumulative distribution function (CDF) at @var{x} of the
## Weibull distribution with scale parameter @var{scale} and shape
## parameter @var{shape}.
##
## This is defined as
## @tex
## $$ 1 - e^{-({x \over scale})^{shape}} $$
## for $x \geq 0$.
## @end tex
## @ifnottex
##
## @example
## 1 - exp (-(x/scale)^shape)
## @end example
##
## @noindent
## for @var{x} @geq{} 0.
##
## Default values are @var{scale} = 1, @var{shape} = 1.
## @end ifnottex
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Weibull distribution
    
    
@function
def wblcdf(x=None,scale=1,shape=1,*args,**kwargs):
    varargin = wblcdf.varargin
    nargin = wblcdf.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(isscalar(shape)) or logical_not(isscalar(scale))):
        retval,x,shape,scale=common_size(x,shape,scale,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:56
        if (retval > 0):
            error('wblcdf: X, SCALE, and SHAPE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(scale) or iscomplex(shape)):
        error('wblcdf: X, SCALE, and SHAPE must not be complex')
    
    if (isa(x,'single') or isa(scale,'single') or isa(shape,'single')):
        cdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:67
    else:
        cdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:69
    
    ok=logical_and(logical_and(logical_and((shape > 0),(shape < Inf)),(scale > 0)),(scale < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:72
    k=logical_and((x <= 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:74
    cdf[k]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:75
    k=logical_and((x == Inf),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:77
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:78
    k=logical_and(logical_and((x > 0),(x < Inf)),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:80
    if (isscalar(shape) and isscalar(scale)):
        cdf[k]=1 - exp(- (x[k] / scale) ** shape)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:82
    else:
        cdf[k]=1 - exp(- (x[k] / scale[k]) ** shape[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblcdf.m:84
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2013-2015 Julien Bect
## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} tcdf (@var{x}, @var{n})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the t (Student) distribution with
## @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the t distribution
    
    
@function
def tcdf(x=None,n=None,*args,**kwargs):
    varargin = tcdf.varargin
    nargin = tcdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:38
        if (retval > 0):
            error('tcdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('tcdf: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:49
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:51
    
    k=logical_and(logical_not(isinf(x)),(n > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:54
    xx=x ** 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:56
    x_big_abs=(xx > n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:57
    
    kk=logical_and(k,x_big_abs)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:60
    if (isscalar(n)):
        cdf[kk]=betainc(n / (n + xx[kk]),n / 2,1 / 2) / 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:62
    else:
        cdf[kk]=betainc(n[kk] / (n[kk] + xx[kk]),n[kk] / 2,1 / 2) / 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:64
    
    ## deal with the case "abs(x) small"
    kk=logical_and(k,logical_not(x_big_abs))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:68
    if (isscalar(n)):
        cdf[kk]=dot(0.5,(1 - betainc(xx[kk] / (n + xx[kk]),1 / 2,n / 2)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:70
    else:
        cdf[kk]=dot(0.5,(1 - betainc(xx[kk] / (n[kk] + xx[kk]),1 / 2,n[kk] / 2)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:72
    
    k &= (x > 0)
    if (any(ravel(k))):
        cdf[k]=1 - cdf[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:77
    
    k=logical_or(isnan(x),logical_not((n > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:80
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:81
    k=logical_and((x == Inf),(n > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:83
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tcdf.m:84
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Check some reference values
    
    
    
    ## check accuracy for small positive values
    
    
    
    
    
    
    
    ## check accuracy for large negative values
    
    
    
    
    
    ## # Reference values obtained using Python 2.7.4 and mpmath 0.17
##
## from mpmath import *
##
## mp.dps = 100
##
## def F(x_in, nu_in):
##     x = mpf(x_in);
##     nu = mpf(nu_in);
##     t = nu / (nu + x*x)
##     a = nu / 2
##     b = mpf(0.5)
##     F = betainc(a, b, 0, t, regularized=True) / 2
##     if (x > 0):
##         F = 1 - F
##     return F
##
## nu = 2.5
##
## for i in range(1, 6):
##     x = - power(mpf(10), mpf(i))
##     print "##!assert (tcdf (-10^#d, 2.5), #s, -eps)" \
##         # (i, nstr(F(x, nu), 17))
##
## for i in range(10, 17):
##     x = power(mpf(10), -mpf(i))
##     print "##!assert (tcdf (10^(-#d), 2.5), #s, -eps)" \
##         # (i, nstr(F(x, nu), 17))
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hygepdf (@var{x}, @var{t}, @var{m}, @var{n})
## Compute the probability density function (PDF) at @var{x} of the
## hypergeometric distribution with parameters @var{t}, @var{m}, and @var{n}.
##
## This is the probability of obtaining @var{x} marked items when randomly
## drawing a sample of size @var{n} without replacement from a population of
## total size @var{t} containing @var{m} marked items.
##
## The parameters @var{t}, @var{m}, and @var{n} must be positive integers
## with @var{m} and @var{n} not greater than @var{t}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the hypergeometric distribution
    
    
@function
def hygepdf(x=None,t=None,m=None,n=None,*args,**kwargs):
    varargin = hygepdf.varargin
    nargin = hygepdf.nargin

    if (nargin != 4):
        print_usage()
    
    if (logical_not(isscalar(t)) or logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,t,m,n=common_size(x,t,m,n,nargout=5)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:43
        if (retval > 0):
            error('hygepdf: X, T, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(t) or iscomplex(m) or iscomplex(n)):
        error('hygepdf: X, T, M, and N must not be complex')
    
    if (isa(x,'single') or isa(t,'single') or isa(m,'single') or isa(n,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:55
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:57
    
    ## everything in nel gives NaN
    nel=(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(isnan(x),(t < 0)),(m < 0)),(n <= 0)),(m > t)),(n > t)),(t != fix(t))),(m != fix(m))),(n != fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:61
    
    zel=(logical_or(logical_or(logical_or(logical_or((x != fix(x)),(x < 0)),(x > m)),(n < x)),(n - x > t - m)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:64
    pdf[nel]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:66
    k=logical_and(logical_not(nel),logical_not(zel))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:68
    if (any(ravel(k))):
        if (isscalar(t) and isscalar(m) and isscalar(n)):
            pdf[k]=(multiply(bincoeff(m,x[k]),bincoeff(t - m,n - x[k])) / bincoeff(t,n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:71
        else:
            pdf[k]=(multiply(bincoeff(m[k],x[k]),bincoeff(t[k] - m[k],n[k] - x[k])) / bincoeff(t[k],n[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygepdf.m:74
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cauchy_rnd (@var{location}, @var{scale})
## @deftypefnx {Function File} {} cauchy_rnd (@var{location}, @var{scale}, @var{r})
## @deftypefnx {Function File} {} cauchy_rnd (@var{location}, @var{scale}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} cauchy_rnd (@var{location}, @var{scale}, [@var{sz}])
## Return a matrix of random samples from the Cauchy distribution with
## parameters @var{location} and @var{scale}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{location} and @var{scale}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Cauchy distribution
    
    
@function
def cauchy_rnd(location=None,scale=None,varargin=None,*args,**kwargs):
    varargin = cauchy_rnd.varargin
    nargin = cauchy_rnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(location)) or logical_not(isscalar(scale))):
        retval,location,scale=common_size(location,scale,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:48
        if (retval > 0):
            error('cauchy_rnd: LOCATION and SCALE must be of common size or scalars')
    
    if (iscomplex(location) or iscomplex(scale)):
        error('cauchy_rnd: LOCATION and SCALE must not be complex')
    
    if (nargin == 2):
        sz=size(location)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:64
                else:
                    error('cauchy_rnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('cauchy_rnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:72
    
    if (logical_not(isscalar(location)) and logical_not(isequal(size(location),sz))):
        error('cauchy_rnd: LOCATION and SCALE must be scalar or of size SZ')
    
    if (isa(location,'single') or isa(scale,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:82
    
    if (isscalar(location) and isscalar(scale)):
        if (logical_not(isinf(location)) and (scale > 0) and (scale < Inf)):
            rnd=location - dot(cot(dot(pi,rand(sz,cls))),scale)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:89
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:92
        k=logical_and(logical_and(logical_not(isinf(location)),(scale > 0)),(scale < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:94
        rnd[k]=ravel(location[k]) - multiply(cot(dot(pi,rand(sum(ravel(k)),1,cls))),ravel(scale[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_rnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} unidinv (@var{x}, @var{n})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the discrete uniform distribution which assumes
## the integer values 1--@var{n} with equal probability.
## @end deftypefn
    
    
@function
def unidinv(x=None,n=None,*args,**kwargs):
    varargin = unidinv.varargin
    nargin = unidinv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:34
        if (retval > 0):
            error('unidcdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('unidinv: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:45
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:47
    
    ## For Matlab compatibility, unidinv(0) = NaN
    k=logical_and(logical_and((x > 0),(x <= 1)),(n > logical_and(0,n) == fix(n)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:51
    if (isscalar(n)):
        inv[k]=floor(dot(x[k],n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:53
    else:
        inv[k]=floor(multiply(x[k],n[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidinv.m:55
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} poissrnd (@var{lambda})
## @deftypefnx {Function File} {} poissrnd (@var{lambda}, @var{r})
## @deftypefnx {Function File} {} poissrnd (@var{lambda}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} poissrnd (@var{lambda}, [@var{sz}])
## Return a matrix of random samples from the Poisson distribution with
## parameter @var{lambda}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Poisson distribution
    
    
@function
def poissrnd(lambda_=None,varargin=None,*args,**kwargs):
    varargin = poissrnd.varargin
    nargin = poissrnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:48
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:51
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:53
                else:
                    error('poissrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('poissrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:61
    
    if (logical_not(isscalar(lambda_)) and logical_not(isequal(size(lambda_),sz))):
        error('poissrnd: LAMBDA must be scalar or of size SZ')
    
    if (iscomplex(lambda_)):
        error('poissrnd: LAMBDA must not be complex')
    
    if (isa(lambda_,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:73
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:75
    
    if (isscalar(lambda_)):
        if (lambda_ >= 0 and lambda_ < Inf):
            rnd=randp(lambda_,sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:80
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:82
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:85
        k=logical_and((lambda_ >= 0),(lambda_ < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:87
        rnd[k]=randp(lambda_[k],cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissrnd.m:88
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2010 Christos Dimitrakakis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} betapdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the Beta distribution with parameters @var{a} and @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>, CD <christos.dimitrakakis@gmail.com>
## Description: PDF of the Beta distribution
    
    
@function
def betapdf(x=None,a=None,b=None,*args,**kwargs):
    varargin = betapdf.varargin
    nargin = betapdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:37
        if (retval > 0):
            error('betapdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('betapdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:48
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:50
    
    k=logical_or(logical_or(logical_not((a > 0)),logical_not((b > 0))),isnan(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:53
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:54
    k=logical_and(logical_and(logical_and(logical_and((x > 0),(x < 1)),(a > 0)),(b > 0)),(logical_or((a != 1),(b != 1))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:56
    if (isscalar(a) and isscalar(b)):
        pdf[k]=exp(dot((a - 1),log(x[k])) + dot((b - 1),log(1 - x[k])) + gammaln(a + b) - gammaln(a) - gammaln(b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:58
    else:
        pdf[k]=exp(multiply((a[k] - 1),log(x[k])) + multiply((b[k] - 1),log(1 - x[k])) + gammaln(a[k] + b[k]) - gammaln(a[k]) - gammaln(b[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:62
    
    ## Most important special cases when the density is finite.
    k=logical_and(logical_and(logical_and((x == 0),(a == 1)),(b > 0)),(b != 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:68
    if (isscalar(a) and isscalar(b)):
        pdf[k]=exp(gammaln(a + b) - gammaln(a) - gammaln(b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:70
    else:
        pdf[k]=exp(gammaln(a[k] + b[k]) - gammaln(a[k]) - gammaln(b[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:72
    
    k=logical_and(logical_and(logical_and((x == 1),(b == 1)),(a > 0)),(a != 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:75
    if (isscalar(a) and isscalar(b)):
        pdf[k]=exp(gammaln(a + b) - gammaln(a) - gammaln(b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:77
    else:
        pdf[k]=exp(gammaln(a[k] + b[k]) - gammaln(a[k]) - gammaln(b[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:79
    
    k=logical_and(logical_and(logical_and((x >= 0),(x <= 1)),(a == 1)),(b == 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:82
    pdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:83
    
    k=logical_and((x == 0),(a < 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:86
    pdf[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:87
    k=logical_and((x == 1),(b < 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:89
    pdf[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betapdf.m:90
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Beta (1/2,1/2) == arcsine distribution
    
    
    
    ## Test large input values to betapdf
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} gampdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, return the probability density function
## (PDF) at @var{x} of the Gamma distribution with shape parameter @var{a} and
## scale @var{b}.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: PDF of the Gamma distribution
    
    
@function
def gampdf(x=None,a=None,b=None,*args,**kwargs):
    varargin = gampdf.varargin
    nargin = gampdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:37
        if (retval > 0):
            error('gampdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('gampdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:48
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:50
    
    k=logical_or(logical_or(logical_not((a > 0)),logical_not((b > 0))),isnan(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:53
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:54
    k=logical_and(logical_and(logical_and((x >= 0),(a > 0)),(a <= 1)),(b > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:56
    if (isscalar(a) and isscalar(b)):
        pdf[k]=multiply((x[k] ** (a - 1)),exp(- x[k] / b)) / gamma(a) / (b ** a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:58
    else:
        pdf[k]=multiply((x[k] ** (a[k] - 1)),exp(- x[k] / b[k])) / gamma(a[k]) / (b[k] ** a[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:61
    
    k=logical_and(logical_and((x >= 0),(a > 1)),(b > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:65
    if (isscalar(a) and isscalar(b)):
        pdf[k]=exp(dot(- a,log(b)) + dot((a - 1),log(x[k])) - x[k] / b - gammaln(a))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:67
    else:
        pdf[k]=exp(multiply(- a[k],log(b[k])) + multiply((a[k] - 1),log(x[k])) - x[k] / b[k] - gammaln(a[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gampdf.m:70
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} gamcdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the Gamma distribution with shape parameter @var{a} and
## scale @var{b}.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: CDF of the Gamma distribution
    
    
@function
def gamcdf(x=None,a=None,b=None,*args,**kwargs):
    varargin = gamcdf.varargin
    nargin = gamcdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:37
        if (retval > 0):
            error('gamcdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('gamcdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:48
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:50
    
    k=logical_or(logical_or(logical_or(logical_or(isnan(x),logical_not((a > 0))),logical_not((a < Inf))),logical_not((b > 0))),logical_not((b < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:53
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:54
    k=logical_and(logical_and(logical_and(logical_and((x > 0),(a > 0)),(a < Inf)),(b > 0)),(b < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:56
    if (isscalar(a) and isscalar(b)):
        cdf[k]=gammainc(x[k] / b,a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:58
    else:
        cdf[k]=gammainc(x[k] / b[k],a[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gamcdf.m:60
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} poissinv (@var{x}, @var{lambda})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the Poisson distribution with parameter @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Poisson distribution
    
    
@function
def poissinv(x=None,lambda_=None,*args,**kwargs):
    varargin = poissinv.varargin
    nargin = poissinv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:36
        if (retval > 0):
            error('poissinv: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('poissinv: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        inv=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:47
    else:
        inv=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:49
    
    k=logical_or(logical_or(logical_or((x < 0),(x > 1)),isnan(x)),logical_not((lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:52
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:53
    k=logical_and((x == 1),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:55
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:56
    k=find(logical_and(logical_and((x > 0),(x < 1)),(lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:58
    if (isscalar(lambda_)):
        cdf=dot(exp(- lambda_),ones(size(k)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:60
    else:
        cdf=exp(- lambda_[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:62
    
    while (1):

        m=find(cdf < x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:66
        if (any(m)):
            inv[k[m]] += 1
            if (isscalar(lambda_)):
                cdf[m]=cdf[m] + poisspdf(inv[k[m]],lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:70
            else:
                cdf[m]=cdf[m] + poisspdf(inv[k[m]],lambda_[k[m]])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poissinv.m:72
        else:
            break

    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unifrnd (@var{a}, @var{b})
## @deftypefnx {Function File} {} unifrnd (@var{a}, @var{b}, @var{r})
## @deftypefnx {Function File} {} unifrnd (@var{a}, @var{b}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} unifrnd (@var{a}, @var{b}, [@var{sz}])
## Return a matrix of random samples from the uniform distribution on
## [@var{a}, @var{b}].
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{a} and @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the uniform distribution
    
    
@function
def unifrnd(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = unifrnd.varargin
    nargin = unifrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,a,b=common_size(a,b,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:48
        if (retval > 0):
            error('unifrnd: A and B must be of common size or scalars')
    
    if (iscomplex(a) or iscomplex(b)):
        error('unifrnd: A and B must not be complex')
    
    if (nargin == 2):
        sz=size(a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:64
                else:
                    error('unifrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('unifrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:72
    
    if (logical_not(isscalar(a)) and logical_not(isequal(size(a),sz))):
        error('unifrnd: A and B must be scalar or of size SZ')
    
    if (isa(a,'single') or isa(b,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:82
    
    if (isscalar(a) and isscalar(b)):
        if ((- Inf < a) and (a < b) and (b < Inf)):
            rnd=a + dot((b - a),rand(sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:89
    else:
        rnd=a + multiply((b - a),rand(sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:92
        k=logical_or(logical_or(logical_not((- Inf < a)),logical_not((a < b))),logical_not((b < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:94
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifrnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} fcdf (@var{x}, @var{m}, @var{n})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the F distribution with @var{m} and @var{n} degrees of
## freedom.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the F distribution
    
    
@function
def fcdf(x=None,m=None,n=None,*args,**kwargs):
    varargin = fcdf.varargin
    nargin = fcdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,m,n=common_size(x,m,n,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:37
        if (retval > 0):
            error('fcdf: X, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(m) or iscomplex(n)):
        error('fcdf: X, M, and N must not be complex')
    
    if (isa(x,'single') or isa(m,'single') or isa(n,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:48
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:50
    
    k=logical_or(logical_or(logical_or(logical_or(isnan(x),logical_not((m > 0))),logical_not((m < Inf))),logical_not((n > 0))),logical_not((n < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:53
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:54
    k=logical_and(logical_and(logical_and(logical_and((x == Inf),(m > 0)),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:56
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:57
    k=logical_and(logical_and(logical_and(logical_and(logical_and((x > 0),(x < Inf)),(m > 0)),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:59
    if (isscalar(m) and isscalar(n)):
        cdf[k]=1 - betainc(1 / (1 + dot(m,x[k]) / n),n / 2,m / 2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:61
    else:
        cdf[k]=1 - betainc(1 / (1 + multiply(m[k],x[k]) / n[k]),n[k] / 2,m[k] / 2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/fcdf.m:63
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} discrete_pdf (@var{x}, @var{v}, @var{p})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of a univariate discrete distribution which assumes the values
## in @var{v} with probabilities @var{p}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of a discrete distribution
    
    
@function
def discrete_pdf(x=None,v=None,p=None,*args,**kwargs):
    varargin = discrete_pdf.varargin
    nargin = discrete_pdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isvector(v))):
        error('discrete_pdf: V must be a vector')
    else:
        if (any(isnan(v))):
            error('discrete_pdf: V must not have any NaN elements')
        else:
            if (logical_not(isvector(p)) or (length(p) != length(v))):
                error('discrete_pdf: P must be a vector with length (V) elements')
            else:
                if (logical_not((all(p >= 0) and any(p)))):
                    error('discrete_pdf: P must be a nonzero, non-negative vector')
    
    ## Reshape and normalize probability vector.  Values not in table get 0 prob.
    p=matlabarray(cat([0],[ravel(p) / sum(p)]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:47
    if (isa(x,'single') or isa(v,'single') or isa(p,'single')):
        pdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:50
    else:
        pdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:52
    
    k=logical_not(isnan(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:55
    vs,vi=sort(ravel(v),nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:56
    pdf[k]=p[cat([0],[vi])(lookup(vs,x[k],'m') + 1) + 1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_pdf.m:57
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} gaminv (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the Gamma distribution with shape parameter @var{a} and
## scale @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Gamma distribution
    
    
@function
def gaminv(x=None,a=None,b=None,*args,**kwargs):
    varargin = gaminv.varargin
    nargin = gaminv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:37
        if (retval > 0):
            error('gaminv: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('gaminv: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        inv=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:48
    else:
        inv=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:50
    
    k=(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or((x < 0),(x > 1)),isnan(x)),logical_not((a > 0))),logical_not((a < Inf))),logical_not((b > 0))),logical_not((b < Inf))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:53
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:55
    k=logical_and(logical_and(logical_and(logical_and((x == 1),(a > 0)),(a < Inf)),(b > 0)),(b < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:57
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:58
    k=find(logical_and(logical_and(logical_and(logical_and(logical_and((x > 0),(x < 1)),(a > 0)),(a < Inf)),(b > 0)),(b < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:60
    if (any(k)):
        if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
            a=a[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:63
            b=b[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:64
            y=multiply(a,b)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:65
        else:
            y=dot(dot(a,b),ones(size(k)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:67
        x=x[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:69
        if (isa(x,'single')):
            myeps=eps('single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:72
        else:
            myeps=copy(eps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:74
        l=find(x < myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:77
        if (any(l)):
            y[l]=dot(sqrt(myeps),ones(length(l),1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:79
        y_old=copy(y)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:82
        for i in arange(1,100).reshape(-1):
            h=(gamcdf(y_old,a,b) - x) / gampdf(y_old,a,b)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:84
            y_new=y_old - h
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:85
            ind=find(y_new <= myeps)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:86
            if (any(ind)):
                y_new[ind]=y_old[ind] / 10
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:88
                h=y_old - y_new
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:89
            if (max(abs(h)) < sqrt(myeps)):
                break
            y_old=copy(y_new)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:94
        inv[k]=y_new
# /home/lei/octave-4.0.2/scripts/statistics/distributions/gaminv.m:97
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} expinv (@var{x}, @var{lambda})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the exponential distribution with mean @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the exponential distribution
    
    
@function
def expinv(x=None,lambda_=None,*args,**kwargs):
    varargin = expinv.varargin
    nargin = expinv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:36
        if (retval > 0):
            error('expinv: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('expinv: X and LAMBDA must not be complex')
    
    if (logical_not(isscalar(x))):
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:47
    else:
        sz=size(lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:49
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('expinv: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:57
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:59
    
    k=logical_and((x == 1),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:62
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:63
    k=logical_and(logical_and((x >= 0),(x < 1)),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:65
    if (isscalar(lambda_)):
        inv[k]=dot(- lambda_,log(1 - x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:67
    else:
        inv[k]=multiply(- lambda_[k],log(1 - x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expinv.m:69
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} discrete_inv (@var{x}, @var{v}, @var{p})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the univariate distribution which assumes the values in
## @var{v} with probabilities @var{p}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of a discrete distribution
    
    
@function
def discrete_inv(x=None,v=None,p=None,*args,**kwargs):
    varargin = discrete_inv.varargin
    nargin = discrete_inv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isvector(v))):
        error('discrete_inv: V must be a vector')
    else:
        if (logical_not(isvector(p)) or (length(p) != length(v))):
            error('discrete_inv: P must be a vector with length (V) elements')
        else:
            if (any(isnan(p))):
                error('discrete_rnd: P must not have any NaN elements')
            else:
                if (logical_not((all(p >= 0) and any(p)))):
                    error('discrete_inv: P must be a nonzero, non-negative vector')
    
    if (isa(x,'single') or isa(v,'single') or isa(p,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:47
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:49
    
    ## FIXME: This isn't elegant.  But cumsum and lookup together produce
  ## different results when called with a single or a double.
    if (isa(p,'single')):
        p=double(p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:55
    
    v,idx=sort(v,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:58
    p=cumsum(ravel(p[idx])) / sum(p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:59
    
    k=(x == 0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:61
    inv[k]=v[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:62
    k=(x == 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:64
    inv[k]=v[end()]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:65
    k=logical_and((x > 0),(x < 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:67
    inv[k]=v[length(p) - lookup(sort(p,'descend'),x[k]) + 1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_inv.m:68
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 2005-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unidrnd (@var{n})
## @deftypefnx {Function File} {} unidrnd (@var{n}, @var{r})
## @deftypefnx {Function File} {} unidrnd (@var{n}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} unidrnd (@var{n}, [@var{sz}])
## Return a matrix of random samples from the discrete uniform distribution
## which assumes the integer values 1--@var{n} with equal probability.
##
## @var{n} may be a scalar or a multi-dimensional array.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{n}.
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def unidrnd(n=None,varargin=None,*args,**kwargs):
    varargin = unidrnd.varargin
    nargin = unidrnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:49
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:52
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:54
                else:
                    error('unidrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('unidrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:62
    
    if (logical_not(isscalar(n)) and logical_not(isequal(size(n),sz))):
        error('unidrnd: N must be scalar or of size SZ')
    
    if (iscomplex(n)):
        error('unidrnd: N must not be complex')
    
    if (isa(n,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:74
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:76
    
    if (isscalar(n)):
        if (n > 0 and n == fix(n)):
            rnd=ceil(dot(rand(sz,cls),n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:81
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:83
    else:
        rnd=ceil(multiply(rand(sz,cls),n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:86
        k=logical_not((n > logical_and(0,n) == fix(n)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:88
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidrnd.m:89
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} binopdf (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the binomial distribution with parameters @var{n} and @var{p},
## where @var{n} is the number of trials and @var{p} is the probability of
## success.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the binomial distribution
    
    
@function
def binopdf(x=None,n=None,p=None,*args,**kwargs):
    varargin = binopdf.varargin
    nargin = binopdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:38
        if (retval > 0):
            error('binopdf: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('binopdf: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:49
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:51
    
    k=logical_and(logical_and(logical_and(logical_and((x == fix(x)),(n == fix(n))),(n >= 0)),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:54
    pdf[logical_not(k)]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:56
    k &= (logical_and((x >= 0),(x <= n)))
    if (isscalar(n) and isscalar(p)):
        pdf[k]=exp(gammaln(n + 1) - gammaln(x[k] + 1) - gammaln(n - x[k] + 1) + dot(x[k],log(p)) + dot((n - x[k]),log(1 - p)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:60
    else:
        pdf[k]=exp(gammaln(n[k] + 1) - gammaln(x[k] + 1) - gammaln(n[k] - x[k] + 1) + multiply(x[k],log(p[k])) + multiply((n[k] - x[k]),log(1 - p[k])))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:63
    
    ## Special case inputs
    ksp=logical_and(logical_and(k,(p == 0)),(x == 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:68
    pdf[ksp]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:69
    ksp=logical_and(logical_and(k,(p == 1)),(x == n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:70
    pdf[ksp]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binopdf.m:71
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test Special input values
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} tpdf (@var{x}, @var{n})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the @var{t} (Student) distribution with
## @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the t distribution
    
    
@function
def tpdf(x=None,n=None,*args,**kwargs):
    varargin = tpdf.varargin
    nargin = tpdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:37
        if (retval > 0):
            error('tpdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('tpdf: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:48
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:50
    
    k=logical_or(logical_or(isnan(x),logical_not((n > 0))),logical_not((n < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:53
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:54
    k=logical_and(logical_and(isfinite(x),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:56
    if (isscalar(n)):
        pdf[k]=(exp(dot(- (n + 1),log(1 + x[k] ** 2 / n)) / 2) / (dot(sqrt(n),beta(n / 2,1 / 2))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:58
    else:
        pdf[k]=(exp(multiply(- (n[k] + 1),log(1 + x[k] ** 2 / n[k])) / 2) / (multiply(sqrt(n[k]),beta(n[k] / 2,1 / 2))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tpdf.m:61
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nbinpdf (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the negative binomial distribution with parameters
## @var{n} and @var{p}.
##
## When @var{n} is integer this is the Pascal distribution.
## When @var{n} is extended to real numbers this is the Polya distribution.
##
## The number of failures in a Bernoulli experiment with success probability
## @var{p} before the @var{n}-th success follows this distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the Pascal (negative binomial) distribution
    
    
@function
def nbinpdf(x=None,n=None,p=None,*args,**kwargs):
    varargin = nbinpdf.varargin
    nargin = nbinpdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:43
        if (retval > 0):
            error('nbinpdf: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('nbinpdf: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        pdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:54
    else:
        pdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:56
    
    ok=logical_and(logical_and(logical_and(logical_and(logical_and((x < Inf),(x == fix(x))),(n > 0)),(n < Inf)),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:59
    k=logical_and((x < 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:61
    pdf[k]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:62
    k=logical_and((x >= 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:64
    if (isscalar(n) and isscalar(p)):
        pdf[k]=multiply(multiply(bincoeff(- n,x[k]),(p ** n)),((p - 1) ** x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:66
    else:
        pdf[k]=multiply(multiply(bincoeff(- n[k],x[k]),(p[k] ** n[k])),((p[k] - 1) ** x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinpdf.m:68
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} normpdf (@var{x})
## @deftypefnx {Function File} {} normpdf (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the normal distribution with mean @var{mu} and
## standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: PDF of the normal distribution
    
    
@function
def normpdf(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = normpdf.varargin
    nargin = normpdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:40
        if (retval > 0):
            error('normpdf: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('normpdf: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:51
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:53
    
    if (isscalar(mu) and isscalar(sigma)):
        if (isfinite(mu) and (sigma > 0) and (sigma < Inf)):
            pdf=stdnormal_pdf((x - mu) / sigma) / sigma
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:58
        else:
            pdf=NaN(size(x),class_(pdf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:60
    else:
        k=logical_or(logical_or(isinf(mu),logical_not((sigma > 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:63
        pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:64
        k=logical_and(logical_and(logical_not(isinf(mu)),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:66
        pdf[k]=stdnormal_pdf((x[k] - mu[k]) / sigma[k]) / sigma[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normpdf.m:67
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} finv (@var{x}, @var{m}, @var{n})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the F distribution with @var{m} and @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the F distribution
    
    
@function
def finv(x=None,m=None,n=None,*args,**kwargs):
    varargin = finv.varargin
    nargin = finv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,m,n=common_size(x,m,n,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:36
        if (retval > 0):
            error('finv: X, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(m) or iscomplex(n)):
        error('finv: X, M, and N must not be complex')
    
    if (isa(x,'single') or isa(m,'single') or isa(n,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:47
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:49
    
    k=logical_and(logical_and(logical_and(logical_and((x == 1),(m > 0)),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:52
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:53
    k=logical_and(logical_and(logical_and(logical_and(logical_and((x >= 0),(x < 1)),(m > 0)),(m < Inf)),(n > 0)),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:55
    if (isscalar(m) and isscalar(n)):
        inv[k]=(dot((1 / betainv(1 - x[k],n / 2,m / 2) - 1),n) / m)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:57
    else:
        inv[k]=(multiply((1 / betainv(1 - x[k],n[k] / 2,m[k] / 2) - 1),n[k]) / m[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/finv.m:59
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} empirical_cdf (@var{x}, @var{data})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the empirical distribution obtained from
## the univariate sample @var{data}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the empirical distribution
    
    
@function
def empirical_cdf(x=None,data=None,*args,**kwargs):
    varargin = empirical_cdf.varargin
    nargin = empirical_cdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isvector(data))):
        error('empirical_cdf: DATA must be a vector')
    
    cdf=discrete_cdf(x,data,ones(size(data)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_cdf.m:40
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} poisscdf (@var{x}, @var{lambda})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the Poisson distribution with parameter @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Poisson distribution
    
    
@function
def poisscdf(x=None,lambda_=None,*args,**kwargs):
    varargin = poisscdf.varargin
    nargin = poisscdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:36
        if (retval > 0):
            error('poisscdf: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('poisscdf: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:47
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:49
    
    k=logical_or(isnan(x),logical_not((lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:52
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:53
    k=logical_and((x == Inf),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:55
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:56
    k=logical_and(logical_and((x >= 0),(x < Inf)),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:58
    if (isscalar(lambda_)):
        cdf[k]=1 - gammainc(lambda_,floor(x[k]) + 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:60
    else:
        cdf[k]=1 - gammainc(lambda_[k],floor(x[k]) + 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisscdf.m:62
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} logistic_pdf (@var{x})
## For each element of @var{x}, compute the PDF at @var{x} of the
## logistic distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the logistic distribution
    
    
@function
def logistic_pdf(x=None,*args,**kwargs):
    varargin = logistic_pdf.varargin
    nargin = logistic_pdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('logistic_pdf: X must not be complex')
    
    cdf=logistic_cdf(x)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_pdf.m:38
    pdf=multiply(cdf,(1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_pdf.m:39
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} stdnormal_rnd (@var{r})
## @deftypefnx {Function File} {} stdnormal_rnd (@var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} stdnormal_rnd ([@var{sz}])
## Return a matrix of random samples from the standard normal distribution
## (mean = 0, standard deviation = 1).
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the standard normal distribution
    
    
@function
def stdnormal_rnd(varargin=None,*args,**kwargs):
    varargin = stdnormal_rnd.varargin
    nargin = stdnormal_rnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        if (isscalar(varargin[1]) and varargin[1] >= 0):
            sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_rnd.m:45
        else:
            if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_rnd.m:47
            else:
                error('stdnormal_rnd: dimension vector must be row vector of non-negative integers')
    else:
        if (nargin > 1):
            if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                error('stdnormal_rnd: dimensions must be non-negative integers')
            sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_rnd.m:55
    
    rnd=randn(sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_rnd.m:58
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} exprnd (@var{lambda})
## @deftypefnx {Function File} {} exprnd (@var{lambda}, @var{r})
## @deftypefnx {Function File} {} exprnd (@var{lambda}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} exprnd (@var{lambda}, [@var{sz}])
## Return a matrix of random samples from the exponential distribution with
## mean @var{lambda}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the exponential distribution
    
    
@function
def exprnd(lambda_=None,varargin=None,*args,**kwargs):
    varargin = exprnd.varargin
    nargin = exprnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:48
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:51
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:53
                else:
                    error('exprnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('exprnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:61
    
    if (logical_not(isscalar(lambda_)) and logical_not(isequal(size(lambda_),sz))):
        error('exprnd: LAMBDA must be scalar or of size SZ')
    
    if (iscomplex(lambda_)):
        error('exprnd: LAMBDA must not be complex')
    
    if (isa(lambda_,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:73
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:75
    
    if (isscalar(lambda_)):
        if ((lambda_ > 0) and (lambda_ < Inf)):
            rnd=dot(rande(sz,cls),lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:80
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:82
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:85
        k=logical_and((lambda_ > 0),(lambda_ < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:87
        rnd[k]=multiply(rande(sum(ravel(k)),1,cls),ravel(lambda_[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/exprnd.m:88
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} chi2cdf (@var{x}, @var{n})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the chi-square distribution with @var{n} degrees of
## freedom.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: CDF of the chi-square distribution
    
    
@function
def chi2cdf(x=None,n=None,*args,**kwargs):
    varargin = chi2cdf.varargin
    nargin = chi2cdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2cdf.m:37
        if (retval > 0):
            error('chi2cdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('chi2cdf: X and N must not be complex')
    
    cdf=gamcdf(x,n / 2,2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2cdf.m:47
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} wblrnd (@var{scale}, @var{shape})
## @deftypefnx {Function File} {} wblrnd (@var{scale}, @var{shape}, @var{r})
## @deftypefnx {Function File} {} wblrnd (@var{scale}, @var{shape}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} wblrnd (@var{scale}, @var{shape}, [@var{sz}])
## Return a matrix of random samples from the Weibull distribution with
## parameters @var{scale} and @var{shape}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{scale} and @var{shape}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Weibull distribution
    
    
@function
def wblrnd(scale=None,shape=None,varargin=None,*args,**kwargs):
    varargin = wblrnd.varargin
    nargin = wblrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(scale)) or logical_not(isscalar(shape))):
        retval,scale,shape=common_size(scale,shape,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:48
        if (retval > 0):
            error('wblrnd: SCALE and SHAPE must be of common size or scalars')
    
    if (iscomplex(scale) or iscomplex(shape)):
        error('wblrnd: SCALE and SHAPE must not be complex')
    
    if (nargin == 2):
        sz=size(scale)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:64
                else:
                    error('wblrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('wblrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:72
    
    if (logical_not(isscalar(scale)) and logical_not(isequal(size(scale),sz))):
        error('wblrnd: SCALE and SHAPE must be scalar or of size SZ')
    
    if (isa(scale,'single') or isa(shape,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:82
    
    if (isscalar(scale) and isscalar(shape)):
        if ((scale > 0) and (scale < Inf) and (shape > 0) and (shape < Inf)):
            rnd=dot(scale,rande(sz,cls) ** (1 / shape))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:89
    else:
        rnd=multiply(scale,rande(sz,cls) ** (1.0 / shape))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:92
        k=logical_or(logical_or(logical_or((scale <= 0),(scale == Inf)),(shape <= 0)),(shape == Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:94
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblrnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cauchy_inv (@var{x})
## @deftypefnx {Function File} {} cauchy_inv (@var{x}, @var{location}, @var{scale})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the Cauchy distribution with location parameter
## @var{location} and scale parameter @var{scale}.
##
## Default values are @var{location} = 0, @var{scale} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Cauchy distribution
    
    
@function
def cauchy_inv(x=None,location=0,scale=1,*args,**kwargs):
    varargin = cauchy_inv.varargin
    nargin = cauchy_inv.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(location)) or logical_not(isscalar(scale))):
        retval,x,location,scale=common_size(x,location,scale,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:40
        if (retval > 0):
            error('cauchy_inv: X, LOCATION, and SCALE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(location) or iscomplex(scale)):
        error('cauchy_inv: X, LOCATION, and SCALE must not be complex')
    
    if (isa(x,'single') or isa(location,'single') or isa(scale,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:51
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:53
    
    ok=logical_and(logical_and(logical_not(isinf(location)),(scale > 0)),(scale < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:56
    k=logical_and((x == 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:58
    inv[k]=- Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:59
    k=logical_and((x == 1),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:61
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:62
    k=logical_and(logical_and((x > 0),(x < 1)),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:64
    if (isscalar(location) and isscalar(scale)):
        inv[k]=location - dot(scale,cot(dot(pi,x[k])))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:66
    else:
        inv[k]=location[k] - multiply(scale[k],cot(dot(pi,x[k])))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_inv.m:68
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nbininv (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the negative binomial distribution with parameters
## @var{n} and @var{p}.
##
## When @var{n} is integer this is the Pascal distribution.
## When @var{n} is extended to real numbers this is the Polya distribution.
##
## The number of failures in a Bernoulli experiment with success probability
## @var{p} before the @var{n}-th success follows this distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Pascal distribution
    
    
@function
def nbininv(x=None,n=None,p=None,*args,**kwargs):
    varargin = nbininv.varargin
    nargin = nbininv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:43
        if (retval > 0):
            error('nbininv: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('nbininv: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        inv=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:54
    else:
        inv=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:56
    
    k=(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(isnan(x),(x < 0)),(x > 1)),isnan(n)),(n < 1)),(n == Inf)),isnan(p)),(p < 0)),(p > 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:59
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:61
    k=logical_and(logical_and(logical_and(logical_and((x == 1),(n > 0)),(n < Inf)),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:63
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:64
    k=find(logical_and(logical_and(logical_and(logical_and(logical_and((x >= 0),(x < 1)),(n > 0)),(n < Inf)),(p > 0)),(p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:66
    m=zeros(size(k))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:68
    x=x[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:69
    if (isscalar(n) and isscalar(p)):
        s=dot(p ** n,ones(size(k)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:71
        while (1):

            l=find(s < x)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:73
            if (any(l)):
                m[l]=m[l] + 1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:75
                s[l]=s[l] + nbinpdf(m[l],n,p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:76
            else:
                break

    else:
        n=n[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:82
        p=p[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:83
        s=p ** n
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:84
        while (1):

            l=find(s < x)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:86
            if (any(l)):
                m[l]=m[l] + 1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:88
                s[l]=s[l] + nbinpdf(m[l],n[l],p[l])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:89
            else:
                break

    
    inv[k]=m
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbininv.m:95
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} wienrnd (@var{t}, @var{d}, @var{n})
## Return a simulated realization of the @var{d}-dimensional Wiener Process
## on the interval [0, @var{t}].
##
## If @var{d} is omitted, @var{d} = 1 is used.  The first column of the
## return matrix contains time, the remaining columns contain the Wiener
## process.
##
## The optional parameter @var{n} defines the number of summands used for
## simulating the process over an interval of length 1.  If @var{n} is
## omitted, @var{n} = 1000 is used.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Simulate a Wiener process
    
    
@function
def wienrnd(t=None,d=None,n=None,*args,**kwargs):
    varargin = wienrnd.varargin
    nargin = wienrnd.nargin

    if (nargin == 1):
        d=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:39
        n=1000
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:40
    else:
        if (nargin == 2):
            n=1000
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:42
        else:
            if (nargin > 3):
                print_usage()
    
    if (logical_not(isscalar(t)) or logical_not(isscalar(d)) or logical_not(isscalar(n))):
        error('wienrnd: T, D and N must all be positive integers')
    
    retval=randn(dot(n,t),d)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:51
    retval=cumsum(retval) / sqrt(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:52
    retval=matlabarray(cat(((arange(1,dot(n,t))).T / n),retval))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wienrnd.m:54
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 2010-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} discrete_cdf (@var{x}, @var{v}, @var{p})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of a univariate discrete distribution which assumes the
## values in @var{v} with probabilities @var{p}.
## @end deftypefn
    
    
@function
def discrete_cdf(x=None,v=None,p=None,*args,**kwargs):
    varargin = discrete_cdf.varargin
    nargin = discrete_cdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isvector(v))):
        error('discrete_cdf: V must be a vector')
    else:
        if (any(isnan(v))):
            error('discrete_cdf: V must not have any NaN elements')
        else:
            if (logical_not(isvector(p)) or (length(p) != length(v))):
                error('discrete_cdf: P must be a vector with length (V) elements')
            else:
                if (logical_not((all(p >= 0) and any(p)))):
                    error('discrete_cdf: P must be a nonzero, non-negative vector')
    
    p=ravel(p) / sum(p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:43
    
    if (isa(x,'single') or isa(v,'single') or isa(p,'single')):
        cdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:46
    else:
        cdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:48
    
    k=logical_not(isnan(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:51
    vs,vi=sort(v,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:52
    cdf[k]=cat([0],[cumsum(p[vi])])(lookup(vs,x[k]) + 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_cdf.m:53
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} normcdf (@var{x})
## @deftypefnx {Function File} {} normcdf (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the normal distribution with mean @var{mu} and
## standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: CDF of the normal distribution
    
    
@function
def normcdf(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = normcdf.varargin
    nargin = normcdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:40
        if (retval > 0):
            error('normcdf: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('normcdf: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:51
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:53
    
    if (isscalar(mu) and isscalar(sigma)):
        if (isfinite(mu) and (sigma > 0) and (sigma < Inf)):
            cdf=stdnormal_cdf((x - mu) / sigma)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:58
        else:
            cdf=NaN(size(x),class_(cdf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:60
    else:
        k=logical_or(logical_or(logical_not(isfinite(mu)),logical_not((sigma > 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:63
        cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:64
        k=logical_not(k)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:66
        cdf[k]=stdnormal_cdf((x[k] - mu[k]) / sigma[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normcdf.m:67
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nbincdf (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the negative binomial distribution with parameters
## @var{n} and @var{p}.
##
## When @var{n} is integer this is the Pascal distribution.
## When @var{n} is extended to real numbers this is the Polya distribution.
##
## The number of failures in a Bernoulli experiment with success probability
## @var{p} before the @var{n}-th success follows this distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Pascal (negative binomial) distribution
    
    
@function
def nbincdf(x=None,n=None,p=None,*args,**kwargs):
    varargin = nbincdf.varargin
    nargin = nbincdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:43
        if (retval > 0):
            error('nbincdf: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('nbincdf: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:54
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:56
    
    k=(logical_or(logical_or(logical_or(logical_or(logical_or(logical_or(isnan(x),isnan(n)),(n < 1)),(n == Inf)),(p < 0)),(p > 1)),isnan(p)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:59
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:61
    k=logical_and(logical_and(logical_and(logical_and((x == Inf),(n > 0)),(n < Inf)),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:63
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:64
    k=(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and((x >= 0),(x < Inf)),(x == fix(x))),(n > 0)),(n < Inf)),(p > 0)),(p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:66
    if (isscalar(n) and isscalar(p)):
        cdf[k]=1 - betainc(1 - p,x[k] + 1,n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:69
    else:
        cdf[k]=1 - betainc(1 - p[k],x[k] + 1,n[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbincdf.m:71
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cauchy_cdf (@var{x})
## @deftypefnx {Function File} {} cauchy_cdf (@var{x}, @var{location}, @var{scale})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the Cauchy distribution with location parameter
## @var{location} and scale parameter @var{scale}.
##
## Default values are @var{location} = 0, @var{scale} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Cauchy distribution
    
    
@function
def cauchy_cdf(x=None,location=0,scale=1,*args,**kwargs):
    varargin = cauchy_cdf.varargin
    nargin = cauchy_cdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(location)) or logical_not(isscalar(scale))):
        retval,x,location,scale=common_size(x,location,scale,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:40
        if (retval > 0):
            error('cauchy_cdf: X, LOCATION, and SCALE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(location) or iscomplex(scale)):
        error('cauchy_cdf: X, LOCATION, and SCALE must not be complex')
    
    if (isa(x,'single') or isa(location,'single') or isa(scale,'single')):
        cdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:51
    else:
        cdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:53
    
    k=logical_and(logical_and(logical_not(isinf(location)),(scale > 0)),(scale < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:56
    if (isscalar(location) and isscalar(scale)):
        cdf=0.5 + atan((x - location) / scale) / pi
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:58
    else:
        cdf[k]=0.5 + atan((x[k] - location[k]) / scale[k]) / pi
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_cdf.m:60
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} wblinv (@var{x})
## @deftypefnx {Function File} {} wblinv (@var{x}, @var{scale})
## @deftypefnx {Function File} {} wblinv (@var{x}, @var{scale}, @var{shape})
## Compute the quantile (the inverse of the CDF) at @var{x} of the
## Weibull distribution with scale parameter @var{scale} and
## shape parameter @var{shape}.
##
## Default values are @var{scale} = 1, @var{shape} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the Weibull distribution
    
    
@function
def wblinv(x=None,scale=1,shape=1,*args,**kwargs):
    varargin = wblinv.varargin
    nargin = wblinv.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(isscalar(scale)) or logical_not(isscalar(shape))):
        retval,x,scale,shape=common_size(x,scale,shape,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:41
        if (retval > 0):
            error('wblinv: X, SCALE, and SHAPE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(scale) or iscomplex(shape)):
        error('wblinv: X, SCALE, and SHAPE must not be complex')
    
    if (isa(x,'single') or isa(scale,'single') or isa(shape,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:52
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:54
    
    ok=logical_and(logical_and(logical_and((scale > 0),(scale < Inf)),(shape > 0)),(shape < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:57
    k=logical_and((x == 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:59
    inv[k]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:60
    k=logical_and((x == 1),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:62
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:63
    k=logical_and(logical_and((x > 0),(x < 1)),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:65
    if (isscalar(scale) and isscalar(shape)):
        inv[k]=dot(scale,(- log(1 - x[k])) ** (1 / shape))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:67
    else:
        inv[k]=multiply(scale[k],(- log(1 - x[k])) ** (1 / shape[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblinv.m:69
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} expcdf (@var{x}, @var{lambda})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the exponential distribution with mean @var{lambda}.
##
## The arguments can be of common size or scalars.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the exponential distribution
    
    
@function
def expcdf(x=None,lambda_=None,*args,**kwargs):
    varargin = expcdf.varargin
    nargin = expcdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:38
        if (retval > 0):
            error('expcdf: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('expcdf: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:49
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:51
    
    k=logical_or(isnan(x),logical_not((lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:54
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:55
    k=logical_and((x == Inf),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:57
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:58
    k=logical_and(logical_and((x > 0),(x < Inf)),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:60
    if (isscalar(lambda_)):
        cdf[k]=1 - exp(- x[k] / lambda_)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:62
    else:
        cdf[k]=1 - exp(- x[k] / lambda_[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/expcdf.m:64
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} empirical_rnd (@var{data})
## @deftypefnx {Function File} {} empirical_rnd (@var{data}, @var{r})
## @deftypefnx {Function File} {} empirical_rnd (@var{data}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} empirical_rnd (@var{data}, [@var{sz}])
## Return a matrix of random samples from the empirical distribution obtained
## from the univariate sample @var{data}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is a random ordering
## of the sample @var{data}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Bootstrap samples from the empirical distribution
    
    
@function
def empirical_rnd(data=None,varargin=None,*args,**kwargs):
    varargin = empirical_rnd.varargin
    nargin = empirical_rnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not(isvector(data))):
        error('empirical_rnd: DATA must be a vector')
    
    rnd=discrete_rnd(data,ones(size(data)),varargin[:])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_rnd.m:51
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} chi2rnd (@var{n})
## @deftypefnx {Function File} {} chi2rnd (@var{n}, @var{r})
## @deftypefnx {Function File} {} chi2rnd (@var{n}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} chi2rnd (@var{n}, [@var{sz}])
## Return a matrix of random samples from the chi-square distribution with
## @var{n} degrees of freedom.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the size of
## @var{n}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the chi-square distribution
    
    
@function
def chi2rnd(n=None,varargin=None,*args,**kwargs):
    varargin = chi2rnd.varargin
    nargin = chi2rnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        sz=size(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:48
    else:
        if (nargin == 2):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:51
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:53
                else:
                    error('chi2rnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 2):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('chi2rnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:61
    
    if (logical_not(isscalar(n)) and logical_not(isequal(size(n),sz))):
        error('chi2rnd: N must be scalar or of size SZ')
    
    if (iscomplex(n)):
        error('chi2rnd: N must not be complex')
    
    if (isa(n,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:73
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:75
    
    if (isscalar(n)):
        if ((n > 0) and (n < Inf)):
            rnd=dot(2,randg(n / 2,sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:80
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:82
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:85
        k=logical_or((n > 0),(n < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:87
        rnd[k]=dot(2,randg(n[k] / 2,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2rnd.m:88
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} binornd (@var{n}, @var{p})
## @deftypefnx {Function File} {} binornd (@var{n}, @var{p}, @var{r})
## @deftypefnx {Function File} {} binornd (@var{n}, @var{p}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} binornd (@var{n}, @var{p}, [@var{sz}])
## Return a matrix of random samples from the binomial distribution with
## parameters @var{n} and @var{p}, where @var{n} is the number of trials
## and @var{p} is the probability of success.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{n} and @var{p}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the binomial distribution
    
    
@function
def binornd(n=None,p=None,varargin=None,*args,**kwargs):
    varargin = binornd.varargin
    nargin = binornd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,n,p=common_size(n,p,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:49
        if (retval > 0):
            error('binornd: N and P must be of common size or scalars')
    
    if (iscomplex(n) or iscomplex(p)):
        error('binornd: N and P must not be complex')
    
    if (nargin == 2):
        sz=size(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:60
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:63
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:65
                else:
                    error('binornd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('binornd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:73
    
    if (logical_not(isscalar(n)) and logical_not(isequal(size(n),sz))):
        error('binornd: N and P must be scalar or of size SZ')
    
    if (isa(n,'single') or isa(p,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:81
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:83
    
    if (isscalar(n) and isscalar(p)):
        if ((n > 0) and (n < Inf) and (n == fix(n)) and (p >= 0) and (p <= 1)):
            nel=prod(sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:88
            tmp=rand(n,nel)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:89
            rnd=sum(tmp < p,1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:90
            rnd=reshape(rnd,sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:91
            if (strcmp(cls,'single')):
                rnd=single(rnd)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:93
        else:
            if ((n == 0) and (p >= 0) and (p <= 1)):
                rnd=zeros(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:96
            else:
                rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:98
    else:
        rnd=zeros(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:101
        k=logical_or(logical_or(logical_or(logical_or(logical_not((n >= 0)),logical_not((n < Inf))),logical_not((n == fix(n)))),logical_not((p >= 0))),logical_not((p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:103
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:104
        k=logical_and(logical_and(logical_and(logical_and((n > 0),(n < Inf)),(n == fix(n))),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:106
        if (any(ravel(k))):
            N=max(n[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:108
            L=sum(ravel(k))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:109
            tmp=rand(N,L)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:110
            ind=repmat((arange(1,N)).T,1,L)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:111
            rnd[k]=sum(logical_and((tmp < repmat(ravel(p[k]).T,N,1)),(ind <= repmat(ravel(n[k]).T,N,1))),1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binornd.m:112
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} logistic_inv (@var{x})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the logistic distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the logistic distribution
    
    
@function
def logistic_inv(x=None,*args,**kwargs):
    varargin = logistic_inv.varargin
    nargin = logistic_inv.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('logistic_inv: X must not be complex')
    
    if (isa(x,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:40
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:42
    
    k=(x == 0)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:45
    inv[k]=- Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:46
    k=(x == 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:48
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:49
    k=logical_and((x > 0),(x < 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:51
    inv[k]=- log(1 / x[k] - 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_inv.m:52
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} logninv (@var{x})
## @deftypefnx {Function File} {} logninv (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the lognormal distribution with parameters
## @var{mu} and @var{sigma}.
##
## If a random variable follows this distribution, its logarithm is normally
## distributed with mean @var{mu} and standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the log normal distribution
    
    
@function
def logninv(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = logninv.varargin
    nargin = logninv.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:43
        if (retval > 0):
            error('logninv: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('logninv: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:54
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:56
    
    k=logical_or(logical_or(logical_or(logical_not((x >= 0)),logical_not((x <= 1))),logical_not((sigma > 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:59
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:60
    k=logical_and(logical_and((x == 1),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:62
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:63
    k=logical_and(logical_and(logical_and((x >= 0),(x < 1)),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:65
    if (isscalar(mu) and isscalar(sigma)):
        inv[k]=multiply(exp(mu),exp(multiply(sigma,stdnormal_inv(x[k]))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:67
    else:
        inv[k]=multiply(exp(mu[k]),exp(multiply(sigma[k],stdnormal_inv(x[k]))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logninv.m:69
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} stdnormal_cdf (@var{x})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the standard normal distribution
## (mean = 0, standard deviation = 1).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the standard normal distribution
    
    
@function
def stdnormal_cdf(x=None,*args,**kwargs):
    varargin = stdnormal_cdf.varargin
    nargin = stdnormal_cdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('stdnormal_cdf: X must not be complex')
    
    cdf=erfc(x / (- sqrt(2))) / 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_cdf.m:40
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} geopdf (@var{x}, @var{p})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the geometric distribution with parameter @var{p}.
##
## The geometric distribution models the number of failures (@var{x}-1) of a
## Bernoulli trial with probability @var{p} before the first success (@var{x}).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the geometric distribution
    
    
@function
def geopdf(x=None,p=None,*args,**kwargs):
    varargin = geopdf.varargin
    nargin = geopdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(p))):
        retval,x,p=common_size(x,p,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:39
        if (retval > 0):
            error('geopdf: X and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(p)):
        error('geopdf: X and P must not be complex')
    
    if (isa(x,'single') or isa(p,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:50
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:52
    
    k=logical_or(logical_or(logical_or(isnan(x),(x == Inf)),logical_not((p >= 0))),logical_not((p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:55
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:56
    k=logical_and(logical_and(logical_and(logical_and((x >= 0),(x < Inf)),(x == fix(x))),(p > 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:58
    if (isscalar(p)):
        pdf[k]=dot(p,((1 - p) ** x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:60
    else:
        pdf[k]=multiply(p[k],((1 - p[k]) ** x[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/geopdf.m:62
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} empirical_inv (@var{x}, @var{data})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the empirical distribution obtained from the
## univariate sample @var{data}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the empirical distribution
    
    
@function
def empirical_inv(x=None,data=None,*args,**kwargs):
    varargin = empirical_inv.varargin
    nargin = empirical_inv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isvector(data))):
        error('empirical_inv: DATA must be a vector')
    
    inv=discrete_inv(x,data,ones(size(data)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_inv.m:40
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} empirical_pdf (@var{x}, @var{data})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the empirical distribution obtained from the
## univariate sample @var{data}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the empirical distribution
    
    
@function
def empirical_pdf(x=None,data=None,*args,**kwargs):
    varargin = empirical_pdf.varargin
    nargin = empirical_pdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isvector(data))):
        error('empirical_pdf: DATA must be a vector')
    
    uniq_vals=unique(data)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_pdf.m:40
    if (numel(data) != numel(uniq_vals)):
        ## Handle ties, multiple elements with same value
        p=histc(data,uniq_vals)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_pdf.m:43
        data=copy(uniq_vals)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_pdf.m:44
    else:
        p=ones(size(data))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_pdf.m:46
    
    pdf=discrete_pdf(x,data,p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/empirical_pdf.m:49
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test distribution with ties
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} discrete_rnd (@var{v}, @var{p})
## @deftypefnx {Function File} {} discrete_rnd (@var{v}, @var{p}, @var{r})
## @deftypefnx {Function File} {} discrete_rnd (@var{v}, @var{p}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} discrete_rnd (@var{v}, @var{p}, [@var{sz}])
## Return a matrix of random samples from the univariate distribution which
## assumes the values in @var{v} with probabilities @var{p}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{v} and @var{p}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from a discrete distribution
    
    
@function
def discrete_rnd(v=None,p=None,varargin=None,*args,**kwargs):
    varargin = discrete_rnd.varargin
    nargin = discrete_rnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isvector(v))):
        error('discrete_rnd: V must be a vector')
    else:
        if (logical_not(isvector(p)) or (length(p) != length(v))):
            error('discrete_rnd: P must be a vector with length (V) elements')
        else:
            if (any(isnan(p))):
                error('discrete_rnd: P must not have any NaN elements')
            else:
                if (logical_not((all(p >= 0) and any(p)))):
                    error('discrete_rnd: P must be a nonzero, non-negative vector')
    
    if (nargin == 2):
        sz=size(v)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:58
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:61
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:63
                else:
                    error('discrete_rnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('discrete_rnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:71
    
    rnd=v[lookup(cumsum(p[1:end() - 1]) / sum(p),rand(sz)) + 1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:74
    rnd=reshape(rnd,sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/discrete_rnd.m:75
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test class of input preserved
    
    
    ## FIXME: Maybe this should work, maybe it shouldn't.
##!assert(class (discrete_rnd (1:2, single(1:2))), "single");
    
    ## Test input validation
    ## test v,p verification
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} lognpdf (@var{x})
## @deftypefnx {Function File} {} lognpdf (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the lognormal distribution with parameters
## @var{mu} and @var{sigma}.
##
## If a random variable follows this distribution, its logarithm is normally
## distributed with mean @var{mu} and standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the log normal distribution
    
    
@function
def lognpdf(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = lognpdf.varargin
    nargin = lognpdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:43
        if (retval > 0):
            error('lognpdf: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('lognpdf: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:54
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:56
    
    k=logical_or(logical_or(isnan(x),logical_not((sigma > 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:59
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:60
    k=logical_and(logical_and(logical_and((x > 0),(x < Inf)),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:62
    if (isscalar(mu) and isscalar(sigma)):
        pdf[k]=normpdf(log(x[k]),mu,sigma) / x[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:64
    else:
        pdf[k]=normpdf(log(x[k]),mu[k],sigma[k]) / x[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognpdf.m:66
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unifpdf (@var{x})
## @deftypefnx {Function File} {} unifpdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the uniform distribution on the interval [@var{a}, @var{b}].
##
## Default values are @var{a} = 0, @var{b} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the uniform distribution
    
    
@function
def unifpdf(x=None,a=0,b=1,*args,**kwargs):
    varargin = unifpdf.varargin
    nargin = unifpdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:39
        if (retval > 0):
            error('unifpdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('unifpdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:50
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:52
    
    k=logical_or(isnan(x),logical_not((a < b)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:55
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:56
    k=logical_and(logical_and((x >= a),(x <= b)),(a < b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:58
    if (isscalar(a) and isscalar(b)):
        pdf[k]=1 / (b - a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:60
    else:
        pdf[k]=1 / (b[k] - a[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifpdf.m:62
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} unidpdf (@var{x}, @var{n})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of a discrete uniform distribution which assumes
## the integer values 1--@var{n} with equal probability.
##
## Warning: The underlying implementation uses the double class and will only
## be accurate for @var{n} @leq{} @code{bitmax} (@w{@math{2^{53} - 1}} on
## IEEE 754 compatible systems).
## @end deftypefn
    
    
@function
def unidpdf(x=None,n=None,*args,**kwargs):
    varargin = unidpdf.varargin
    nargin = unidpdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:38
        if (retval > 0):
            error('unidpdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('unidpdf: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:49
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:51
    
    k=logical_or(isnan(x),logical_not((n > logical_and(0,n) == fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:54
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:55
    k=logical_and(logical_and(logical_and(logical_not(k),(x >= 1)),(x <= n)),(x == fix(x)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:57
    if (isscalar(n)):
        pdf[k]=1 / n
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:59
    else:
        pdf[k]=1 / n[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidpdf.m:61
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} unifinv (@var{x})
## @deftypefnx {Function File} {} unifinv (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the uniform distribution on the interval [@var{a}, @var{b}].
##
## Default values are @var{a} = 0, @var{b} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the uniform distribution
    
    
@function
def unifinv(x=None,a=0,b=1,*args,**kwargs):
    varargin = unifinv.varargin
    nargin = unifinv.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:39
        if (retval > 0):
            error('unifinv: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('unifinv: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:50
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:52
    
    k=logical_and(logical_and((x >= 0),(x <= 1)),(a < b))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:55
    if (isscalar(a) and isscalar(b)):
        inv[k]=a + dot(x[k],(b - a))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:57
    else:
        inv[k]=a[k] + multiply(x[k],(b[k] - a[k]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unifinv.m:59
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} binocdf (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the binomial distribution with parameters @var{n} and
## @var{p}, where @var{n} is the number of trials and @var{p} is the
## probability of success.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the binomial distribution
    
    
@function
def binocdf(x=None,n=None,p=None,*args,**kwargs):
    varargin = binocdf.varargin
    nargin = binocdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:38
        if (retval > 0):
            error('binocdf: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('binocdf: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:49
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:51
    
    k=logical_or(logical_or(logical_or(logical_or(isnan(x),logical_not((n >= 0))),(n != fix(n))),logical_not((p >= 0))),logical_not((p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:54
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:55
    k=logical_and(logical_and((x >= n),(n >= 0)),(n == logical_and(logical_and(fix(n),(p >= 0)),(p <= 1))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:57
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:58
    k=logical_and(logical_and(logical_and(logical_and((x >= 0),(x < n)),(n == fix(n))),(p >= 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:60
    tmp=floor(x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:61
    if (isscalar(n) and isscalar(p)):
        cdf[k]=betainc(1 - p,n - tmp,tmp + 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:63
    else:
        cdf[k]=betainc(1- p[k],n[k] - tmp,tmp + 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binocdf.m:65
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1997-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} hygecdf (@var{x}, @var{t}, @var{m}, @var{n})
## Compute the cumulative distribution function (CDF) at @var{x} of the
## hypergeometric distribution with parameters @var{t}, @var{m}, and @var{n}.
##
## This is the probability of obtaining not more than @var{x} marked items
## when randomly drawing a sample of size @var{n} without replacement from a
## population of total size @var{t} containing @var{m} marked items.
##
## The parameters @var{t}, @var{m}, and @var{n} must be positive integers
## with @var{m} and @var{n} not greater than @var{t}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the hypergeometric distribution
    
    
@function
def hygecdf(x=None,t=None,m=None,n=None,*args,**kwargs):
    varargin = hygecdf.varargin
    nargin = hygecdf.nargin

    if (nargin != 4):
        print_usage()
    
    if (logical_not(isscalar(t)) or logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,x,t,m,n=common_size(x,t,m,n,nargout=5)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:43
        if (retval > 0):
            error('hygecdf: X, T, M, and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(t) or iscomplex(m) or iscomplex(n)):
        error('hygecdf: X, T, M, and N must not be complex')
    
    if (isa(x,'single') or isa(t,'single') or isa(m,'single') or isa(n,'single')):
        cdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:55
    else:
        cdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:57
    
    ok=(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and((t >= 0),(m >= 0)),(n > 0)),(m <= t)),(n <= t)),(t == fix(t))),(m == fix(m))),(n == fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:60
    if (isscalar(t)):
        if (ok):
            cdf=discrete_cdf(x,arange(0,n),hygepdf(arange(0,n),t,m,n))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:65
    else:
        for i in find(ravel(ok).T).reshape(-1):
            v=arange(0,n[i])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:69
            cdf[i]=discrete_cdf(x[i],v,hygepdf(v,t[i],m[i],n[i]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygecdf.m:70
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} betarnd (@var{a}, @var{b})
## @deftypefnx {Function File} {} betarnd (@var{a}, @var{b}, @var{r})
## @deftypefnx {Function File} {} betarnd (@var{a}, @var{b}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} betarnd (@var{a}, @var{b}, [@var{sz}])
## Return a matrix of random samples from the Beta distribution with parameters
## @var{a} and @var{b}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{a} and @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Beta distribution
    
    
@function
def betarnd(a=None,b=None,varargin=None,*args,**kwargs):
    varargin = betarnd.varargin
    nargin = betarnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,a,b=common_size(a,b,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:48
        if (retval > 0):
            error('betarnd: A and B must be of common size or scalars')
    
    if (iscomplex(a) or iscomplex(b)):
        error('betarnd: A and B must not be complex')
    
    if (nargin == 2):
        sz=size(a)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:64
                else:
                    error('betarnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('betarnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:72
    
    if (logical_not(isscalar(a)) and logical_not(isequal(size(a),sz))):
        error('betarnd: A and B must be scalar or of size SZ')
    
    if (isa(a,'single') or isa(b,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:82
    
    if (isscalar(a) and isscalar(b)):
        if ((a > 0) and (a < Inf) and (b > 0) and (b < Inf)):
            r=randg(a,sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:87
            rnd=r / (r + randg(b,sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:88
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:90
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:93
        k=logical_and(logical_and(logical_and((a > 0),(a < Inf)),(b > 0)),(b < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:95
        r=randg(a[k],cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:96
        rnd[k]=r / (r + randg(b[k],cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betarnd.m:97
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} nbinrnd (@var{n}, @var{p})
## @deftypefnx {Function File} {} nbinrnd (@var{n}, @var{p}, @var{r})
## @deftypefnx {Function File} {} nbinrnd (@var{n}, @var{p}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} nbinrnd (@var{n}, @var{p}, [@var{sz}])
## Return a matrix of random samples from the negative binomial distribution
## with parameters @var{n} and @var{p}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{n} and @var{p}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the Pascal distribution
    
    
@function
def nbinrnd(n=None,p=None,varargin=None,*args,**kwargs):
    varargin = nbinrnd.varargin
    nargin = nbinrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,n,p=common_size(n,p,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:48
        if (retval > 0):
            error('nbinrnd: N and P must be of common size or scalars')
    
    if (iscomplex(n) or iscomplex(p)):
        error('nbinrnd: N and P must not be complex')
    
    if (nargin == 2):
        sz=size(n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:64
                else:
                    error('nbinrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('nbinrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:72
    
    if (logical_not(isscalar(n)) and logical_not(isequal(size(n),sz))):
        error('nbinrnd: N and P must be scalar or of size SZ')
    
    if (isa(n,'single') or isa(p,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:82
    
    if (isscalar(n) and isscalar(p)):
        if ((n > 0) and (n < Inf) and (p > 0) and (p <= 1)):
            rnd=randp(multiply((1 - p) / p,randg(n,sz,cls)),cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:87
        else:
            if ((n > 0) and (n < Inf) and (p == 0)):
                rnd=zeros(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:89
            else:
                rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:91
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:94
        k=logical_and(logical_and((n > 0),(n < Inf)),(p == 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:96
        rnd[k]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:97
        k=logical_and(logical_and(logical_and((n > 0),(n < Inf)),(p > 0)),(p <= 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:99
        rnd[k]=randp(multiply((1 - p[k]) / p[k],randg(n[k],cls)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/nbinrnd.m:100
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} stdnormal_inv (@var{x})
## For each element of @var{x}, compute the quantile (the
## inverse of the CDF) at @var{x} of the standard normal distribution
## (mean = 0, standard deviation = 1).
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the standard normal distribution
    
    
@function
def stdnormal_inv(x=None,*args,**kwargs):
    varargin = stdnormal_inv.varargin
    nargin = stdnormal_inv.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('stdnormal_inv: X must not be complex')
    
    inv=dot(- sqrt(2),erfcinv(dot(2,x)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/stdnormal_inv.m:40
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} wblpdf (@var{x})
## @deftypefnx {Function File} {} wblpdf (@var{x}, @var{scale})
## @deftypefnx {Function File} {} wblpdf (@var{x}, @var{scale}, @var{shape})
## Compute the probability density function (PDF) at @var{x} of the
## Weibull distribution with scale parameter @var{scale} and
## shape parameter @var{shape}.
##
## This is given by
## @tex
## $$  {shape \over scale^{shape}} \cdot x^{shape-1} \cdot e^{-({x \over scale})^{shape}} $$
## @end tex
## @ifnottex
##
## @example
## shape * scale^(-shape) * x^(shape-1) * exp (-(x/scale)^shape)
## @end example
##
## @end ifnottex
## @noindent
## for @var{x} @geq{} 0.
##
## Default values are @var{scale} = 1, @var{shape} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the Weibull distribution
    
    
@function
def wblpdf(x=None,scale=1,shape=1,*args,**kwargs):
    varargin = wblpdf.varargin
    nargin = wblpdf.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not(isscalar(scale)) or logical_not(isscalar(shape))):
        retval,x,scale,shape=common_size(x,scale,shape,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:55
        if (retval > 0):
            error('wblpdf: X, SCALE, and SHAPE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(scale) or iscomplex(shape)):
        error('wblpdf: X, SCALE, and SHAPE must not be complex')
    
    if (isa(x,'single') or isa(scale,'single') or isa(shape,'single')):
        pdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:66
    else:
        pdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:68
    
    ok=(logical_and(logical_and(logical_and((scale > 0),(scale < Inf)),(shape > 0)),(shape < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:71
    k=logical_and((x < 0),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:73
    pdf[k]=0
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:74
    k=logical_and(logical_and((x >= 0),(x < Inf)),ok)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:76
    if (isscalar(scale) and isscalar(shape)):
        pdf[k]=(multiply(multiply(dot(shape,(scale ** - shape)),(x[k] ** (shape - 1))),exp(- (x[k] / scale) ** shape)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:78
    else:
        pdf[k]=(multiply(multiply(multiply(shape[k],(scale[k] ** - shape[k])),(x[k] ** (shape[k] - 1))),exp(- (x[k] / scale[k]) ** shape[k])))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/wblpdf.m:82
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} normrnd (@var{mu}, @var{sigma})
## @deftypefnx {Function File} {} normrnd (@var{mu}, @var{sigma}, @var{r})
## @deftypefnx {Function File} {} normrnd (@var{mu}, @var{sigma}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} normrnd (@var{mu}, @var{sigma}, [@var{sz}])
## Return a matrix of random samples from the normal distribution with
## parameters mean @var{mu} and standard deviation @var{sigma}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{mu} and @var{sigma}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the normal distribution
    
    
@function
def normrnd(mu=None,sigma=None,varargin=None,*args,**kwargs):
    varargin = normrnd.varargin
    nargin = normrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,mu,sigma=common_size(mu,sigma,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:48
        if (retval > 0):
            error('normrnd: mu and sigma must be of common size or scalars')
    
    if (iscomplex(mu) or iscomplex(sigma)):
        error('normrnd: MU and SIGMA must not be complex')
    
    if (nargin == 2):
        sz=size(mu)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:64
                else:
                    error('normrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('normrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:72
    
    if (logical_not(isscalar(mu)) and logical_not(isequal(size(mu),sz))):
        error('normrnd: mu and sigma must be scalar or of size SZ')
    
    if (isa(mu,'single') or isa(sigma,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:82
    
    if (isscalar(mu) and isscalar(sigma)):
        if (isfinite(mu) and (sigma >= 0) and (sigma < Inf)):
            rnd=mu + dot(sigma,randn(sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:89
    else:
        rnd=mu + multiply(sigma,randn(sz,cls))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:92
        k=logical_or(logical_or(logical_not(isfinite(mu)),logical_not((sigma >= 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:93
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/normrnd.m:94
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} chi2inv (@var{x}, @var{n})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the chi-square distribution with @var{n} degrees of freedom.
## @end deftypefn
    
    ## Author: TT <Teresa.Twaroch@ci.tuwien.ac.at>
## Description: Quantile function of the chi-square distribution
    
    
@function
def chi2inv(x=None,n=None,*args,**kwargs):
    varargin = chi2inv.varargin
    nargin = chi2inv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2inv.m:36
        if (retval > 0):
            error('chi2inv: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('chi2inv: X and N must not be complex')
    
    inv=gaminv(x,n / 2,2)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/chi2inv.m:46
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} betacdf (@var{x}, @var{a}, @var{b})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the Beta distribution with parameters @var{a} and
## @var{b}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Beta distribution
    
    
@function
def betacdf(x=None,a=None,b=None,*args,**kwargs):
    varargin = betacdf.varargin
    nargin = betacdf.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(a)) or logical_not(isscalar(b))):
        retval,x,a,b=common_size(x,a,b,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:37
        if (retval > 0):
            error('betacdf: X, A, and B must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(a) or iscomplex(b)):
        error('betacdf: X, A, and B must not be complex')
    
    if (isa(x,'single') or isa(a,'single') or isa(b,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:48
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:50
    
    k=logical_or(logical_or(isnan(x),logical_not((a > 0))),logical_not((b > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:53
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:54
    k=logical_and(logical_and((x >= 1),(a > 0)),(b > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:56
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:57
    k=logical_and(logical_and(logical_and((x > 0),(x < 1)),(a > 0)),(b > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:59
    if (isscalar(a) and isscalar(b)):
        cdf[k]=betainc(x[k],a,b)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:61
    else:
        cdf[k]=betainc(x[k],a[k],b[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/betacdf.m:63
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} logistic_rnd (@var{r})
## @deftypefnx {Function File} {} logistic_rnd (@var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} logistic_rnd ([@var{sz}])
## Return a matrix of random samples from the logistic distribution.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the logistic distribution
    
    
@function
def logistic_rnd(varargin=None,*args,**kwargs):
    varargin = logistic_rnd.varargin
    nargin = logistic_rnd.nargin

    if (nargin < 1):
        print_usage()
    
    if (nargin == 1):
        if (isscalar(varargin[1]) and varargin[1] >= 0):
            sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_rnd.m:44
        else:
            if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_rnd.m:46
            else:
                error('logistic_rnd: dimension vector must be row vector of non-negative integers')
    else:
        if (nargin > 1):
            if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                error('logistic_rnd: dimensions must be non-negative integers')
            sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_rnd.m:54
    
    rnd=- log(1 / rand(sz) - 1)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_rnd.m:57
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} unidcdf (@var{x}, @var{n})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of a discrete uniform distribution which assumes
## the integer values 1--@var{n} with equal probability.
## @end deftypefn
    
    
@function
def unidcdf(x=None,n=None,*args,**kwargs):
    varargin = unidcdf.varargin
    nargin = unidcdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:34
        if (retval > 0):
            error('unidcdf: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('unidcdf: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:45
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:47
    
    knan=logical_or(isnan(x),logical_not((n > logical_and(0,n) == fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:50
    if (any(ravel(knan))):
        cdf[knan]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:52
    
    k=logical_and((x >= n),logical_not(knan))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:55
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:56
    k=logical_and(logical_and((x >= 1),(x < n)),logical_not(knan))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:58
    if (isscalar(n)):
        cdf[k]=floor(x[k]) / n
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:60
    else:
        cdf[k]=floor(x[k]) / n[k]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/unidcdf.m:62
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} logncdf (@var{x})
## @deftypefnx {Function File} {} logncdf (@var{x}, @var{mu}, @var{sigma})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the lognormal distribution with parameters
## @var{mu} and @var{sigma}.
##
## If a random variable follows this distribution, its logarithm is normally
## distributed with mean @var{mu} and standard deviation @var{sigma}.
##
## Default values are @var{mu} = 0, @var{sigma} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the log normal distribution
    
    
@function
def logncdf(x=None,mu=0,sigma=1,*args,**kwargs):
    varargin = logncdf.varargin
    nargin = logncdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,x,mu,sigma=common_size(x,mu,sigma,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:43
        if (retval > 0):
            error('logncdf: X, MU, and SIGMA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(mu) or iscomplex(sigma)):
        error('logncdf: X, MU, and SIGMA must not be complex')
    
    if (isa(x,'single') or isa(mu,'single') or isa(sigma,'single')):
        cdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:54
    else:
        cdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:56
    
    k=logical_or(logical_or(isnan(x),logical_not((sigma > 0))),logical_not((sigma < Inf)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:59
    cdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:60
    k=logical_and(logical_and((x == Inf),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:62
    cdf[k]=1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:63
    k=logical_and(logical_and(logical_and((x > 0),(x < Inf)),(sigma > 0)),(sigma < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:65
    if (isscalar(mu) and isscalar(sigma)):
        cdf[k]=stdnormal_cdf((log(x[k]) - mu) / sigma)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:67
    else:
        cdf[k]=stdnormal_cdf((log(x[k]) - mu[k]) / sigma[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logncdf.m:69
    
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} tinv (@var{x}, @var{n})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the t (Student) distribution with @var{n}
## degrees of freedom.
##
## This function is analogous to looking in a table for the t-value of a
## single-tailed distribution.
## @end deftypefn
    
    ## For very large n, the "correct" formula does not really work well,
## and the quantiles of the standard normal distribution are used
## directly.
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the t distribution
    
    
@function
def tinv(x=None,n=None,*args,**kwargs):
    varargin = tinv.varargin
    nargin = tinv.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(n))):
        retval,x,n=common_size(x,n,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:44
        if (retval > 0):
            error('tinv: X and N must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n)):
        error('tinv: X and N must not be complex')
    
    if (isa(x,'single') or isa(n,'single')):
        inv=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:55
    else:
        inv=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:57
    
    k=logical_and((x == 0),(n > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:60
    inv[k]=- Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:61
    k=logical_and((x == 1),(n > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:63
    inv[k]=Inf
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:64
    if (isscalar(n)):
        k=logical_and((x > 0),(x < 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:67
        if ((n > 0) and (n < 10000)):
            inv[k]=(multiply(sign(x[k] - 1 / 2),sqrt(dot(n,(1 / betainv(dot(2,min(x[k],1 - x[k])),n / 2,1 / 2) - 1)))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:69
        else:
            if (n >= 10000):
                ## For large n, use the quantiles of the standard normal
                inv[k]=stdnormal_inv(x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:74
    else:
        k=logical_and(logical_and(logical_and((x > 0),(x < 1)),(n > 0)),(n < 10000))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:77
        inv[k]=(multiply(sign(x[k] - 1 / 2),sqrt(multiply(n[k],(1 / betainv(dot(2,min(x[k],1 - x[k])),n[k] / 2,1 / 2) - 1)))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:78
        k=logical_and(logical_and((x > 0),(x < 1)),(n >= 10000))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:83
        inv[k]=stdnormal_inv(x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/tinv.m:84
    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cauchy_pdf (@var{x})
## @deftypefnx {Function File} {} cauchy_pdf (@var{x}, @var{location}, @var{scale})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the Cauchy distribution with location parameter
## @var{location} and scale parameter @var{scale} > 0.
##
## Default values are @var{location} = 0, @var{scale} = 1.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the Cauchy distribution
    
    
@function
def cauchy_pdf(x=None,location=0,scale=1,*args,**kwargs):
    varargin = cauchy_pdf.varargin
    nargin = cauchy_pdf.nargin

    if (nargin != 1 and nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(location)) or logical_not(isscalar(scale))):
        retval,x,location,scale=common_size(x,location,scale,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:40
        if (retval > 0):
            error('cauchy_pdf: X, LOCATION, and SCALE must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(location) or iscomplex(scale)):
        error('cauchy_pdf: X, LOCATION, and SCALE must not be complex')
    
    if (isa(x,'single') or isa(location,'single') or isa(scale,'single')):
        pdf=NaN(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:51
    else:
        pdf=NaN(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:53
    
    k=logical_and(logical_and(logical_not(isinf(location)),(scale > 0)),(scale < Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:56
    if (isscalar(location) and isscalar(scale)):
        pdf=((1 / (1 + ((x - location) / scale) ** 2)) / pi / scale)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:58
    else:
        pdf[k]=((1 / (1 + ((x[k] - location[k]) / scale[k]) ** 2)) / pi / scale[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/cauchy_pdf.m:61
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    ## Cauchy (0,1) == Student's T distribution with 1 DOF
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} poisspdf (@var{x}, @var{lambda})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the Poisson distribution with parameter @var{lambda}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the Poisson distribution
    
    
@function
def poisspdf(x=None,lambda_=None,*args,**kwargs):
    varargin = poisspdf.varargin
    nargin = poisspdf.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isscalar(lambda_))):
        retval,x,lambda_=common_size(x,lambda_,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:36
        if (retval > 0):
            error('poisspdf: X and LAMBDA must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(lambda_)):
        error('poisspdf: X and LAMBDA must not be complex')
    
    if (isa(x,'single') or isa(lambda_,'single')):
        pdf=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:47
    else:
        pdf=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:49
    
    k=logical_or(isnan(x),logical_not((lambda_ > 0)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:52
    pdf[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:53
    k=logical_and(logical_and(logical_and((x >= 0),(x < Inf)),(x == fix(x))),(lambda_ > 0))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:55
    if (isscalar(lambda_)):
        pdf[k]=exp(dot(x[k],log(lambda_)) - lambda_ - gammaln(x[k] + 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:57
    else:
        pdf[k]=exp(multiply(x[k],log(lambda_[k])) - lambda_[k] - gammaln(x[k] + 1))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/poisspdf.m:59
    
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} lognrnd (@var{mu}, @var{sigma})
## @deftypefnx {Function File} {} lognrnd (@var{mu}, @var{sigma}, @var{r})
## @deftypefnx {Function File} {} lognrnd (@var{mu}, @var{sigma}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} lognrnd (@var{mu}, @var{sigma}, [@var{sz}])
## Return a matrix of random samples from the lognormal distribution with
## parameters @var{mu} and @var{sigma}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{mu} and @var{sigma}.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Random deviates from the log normal distribution
    
    
@function
def lognrnd(mu=None,sigma=None,varargin=None,*args,**kwargs):
    varargin = lognrnd.varargin
    nargin = lognrnd.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isscalar(mu)) or logical_not(isscalar(sigma))):
        retval,mu,sigma=common_size(mu,sigma,nargout=3)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:48
        if (retval > 0):
            error('lognrnd: MU and SIGMA must be of common size or scalars')
    
    if (iscomplex(mu) or iscomplex(sigma)):
        error('lognrnd: MU and SIGMA must not be complex')
    
    if (nargin == 2):
        sz=size(mu)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:59
    else:
        if (nargin == 3):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:64
                else:
                    error('lognrnd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 3):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('lognrnd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:72
    
    if (logical_not(isscalar(mu)) and logical_not(isequal(size(mu),sz))):
        error('lognrnd: MU and SIGMA must be scalar or of size SZ')
    
    if (isa(mu,'single') or isa(sigma,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:82
    
    if (isscalar(mu) and isscalar(sigma)):
        if ((sigma > 0) and (sigma < Inf)):
            rnd=exp(mu + dot(sigma,randn(sz,cls)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:87
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:89
    else:
        rnd=exp(mu + multiply(sigma,randn(sz,cls)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:92
        k=logical_or((sigma < 0),(sigma == Inf))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:94
        rnd[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/lognrnd.m:95
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} laplace_pdf (@var{x})
## For each element of @var{x}, compute the probability density function (PDF)
## at @var{x} of the Laplace distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: PDF of the Laplace distribution
    
    
@function
def laplace_pdf(x=None,*args,**kwargs):
    varargin = laplace_pdf.varargin
    nargin = laplace_pdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('laplace_pdf: X must not be complex')
    
    pdf=exp(- abs(x)) / 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_pdf.m:39
    return pdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} binoinv (@var{x}, @var{n}, @var{p})
## For each element of @var{x}, compute the quantile (the inverse of the CDF)
## at @var{x} of the binomial distribution with parameters
## @var{n} and @var{p}, where @var{n} is the number of trials and
## @var{p} is the probability of success.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Quantile function of the binomial distribution
    
    
@function
def binoinv(x=None,n=None,p=None,*args,**kwargs):
    varargin = binoinv.varargin
    nargin = binoinv.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not(isscalar(n)) or logical_not(isscalar(p))):
        retval,x,n,p=common_size(x,n,p,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:38
        if (retval > 0):
            error('binoinv: X, N, and P must be of common size or scalars')
    
    if (iscomplex(x) or iscomplex(n) or iscomplex(p)):
        error('binoinv: X, N, and P must not be complex')
    
    if (isa(x,'single') or isa(n,'single') or isa(p,'single')):
        inv=zeros(size(x),'single')
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:49
    else:
        inv=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:51
    
    k=(logical_or(logical_or(logical_or(logical_or(logical_or(logical_not((x >= 0)),logical_not((x <= 1))),logical_not((n >= 0))),(n != fix(n))),logical_not((p >= 0))),logical_not((p <= 1))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:54
    inv[k]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:56
    k=find(logical_and(logical_and(logical_and((x >= 0),(x <= 1)),(n >= 0)),(n == logical_and(logical_and(fix(n),(p >= 0)),(p <= 1)))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:58
    if (any(k)):
        if (isscalar(n) and isscalar(p)):
            cdf=dot(binopdf(0,n,p),ones(size(k)))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:62
            while (any(inv[k] < n)):

                m=find(cdf < x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:64
                if (any(m)):
                    inv[k[m]]=inv[k[m]] + 1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:66
                    cdf[m]=cdf[m] + binopdf(inv[k[m]],n,p)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:67
                else:
                    break

        else:
            cdf=binopdf(0,n[k],p[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:73
            while (any(inv[k] < n[k])):

                m=find(cdf < x[k])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:75
                if (any(m)):
                    inv[k[m]]=inv[k[m]] + 1
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:77
                    cdf[m]=cdf[m] + binopdf(inv[k[m]],n[k[m]],p[k[m]])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/binoinv.m:78
                else:
                    break

    
    return inv
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test class of input preserved
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1997-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} hygernd (@var{t}, @var{m}, @var{n})
## @deftypefnx {Function File} {} hygernd (@var{t}, @var{m}, @var{n}, @var{r})
## @deftypefnx {Function File} {} hygernd (@var{t}, @var{m}, @var{n}, @var{r}, @var{c}, @dots{})
## @deftypefnx {Function File} {} hygernd (@var{t}, @var{m}, @var{n}, [@var{sz}])
## Return a matrix of random samples from the hypergeometric distribution
## with parameters @var{t}, @var{m}, and @var{n}.
##
## The parameters @var{t}, @var{m}, and @var{n} must be positive integers
## with @var{m} and @var{n} not greater than @var{t}.
##
## When called with a single size argument, return a square matrix with
## the dimension specified.  When called with more than one scalar argument the
## first two arguments are taken as the number of rows and columns and any
## further arguments specify additional matrix dimensions.  The size may also
## be specified with a vector of dimensions @var{sz}.
##
## If no size arguments are given then the result matrix is the common size of
## @var{t}, @var{m}, and @var{n}.
## @end deftypefn
    
    
@function
def hygernd(t=None,m=None,n=None,varargin=None,*args,**kwargs):
    varargin = hygernd.varargin
    nargin = hygernd.nargin

    if (nargin < 3):
        print_usage()
    
    if (logical_not(isscalar(t)) or logical_not(isscalar(m)) or logical_not(isscalar(n))):
        retval,t,m,n=common_size(t,m,n,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:48
        if (retval > 0):
            error('hygernd: T, M, and N must be of common size or scalars')
    
    if (iscomplex(t) or iscomplex(m) or iscomplex(n)):
        error('hygernd: T, M, and N must not be complex')
    
    if (nargin == 3):
        sz=size(t)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:59
    else:
        if (nargin == 4):
            if (isscalar(varargin[1]) and varargin[1] >= 0):
                sz=matlabarray(cat(varargin[1],varargin[1]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:62
            else:
                if (isrow(varargin[1]) and all(varargin[1] >= 0)):
                    sz=varargin[1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:64
                else:
                    error('hygernd: dimension vector must be row vector of non-negative integers')
        else:
            if (nargin > 4):
                if (any(cellfun(lambda x=None: (logical_not(isscalar(x)) or x < 0),varargin))):
                    error('hygernd: dimensions must be non-negative integers')
                sz=matlabarray(cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:72
    
    if (logical_not(isscalar(t)) and logical_not(isequal(size(t),sz))):
        error('hygernd: T, M, and N must be scalar or of size SZ')
    
    if (isa(t,'single') or isa(m,'single') or isa(n,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:80
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:82
    
    ok=(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and(logical_and((t >= 0),(m >= 0)),(n > 0)),(m <= t)),(n <= t)),(t == fix(t))),(m == fix(m))),(n == fix(n))))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:85
    if (isscalar(t)):
        if (ok):
            v=arange(0,n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:90
            p=hygepdf(v,t,m,n)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:91
            rnd=v[lookup(cumsum(p[1:end() - 1]) / sum(p),rand(sz)) + 1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:92
            rnd=reshape(rnd,sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:93
            if (strcmp(cls,'single')):
                rnd=single(rnd)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:95
        else:
            rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:98
    else:
        rnd=NaN(sz,cls)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:101
        rn=rand(sz)
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:102
        for i in find(ravel(ok).T).reshape(-1):
            v=arange(0,n[i])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:104
            p=hygepdf(v,t[i],m[i],n[i])
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:105
            rnd[i]=v[lookup(cumsum(p[1:end() - 1]) / sum(p),rn[i]) + 1]
# /home/lei/octave-4.0.2/scripts/statistics/distributions/hygernd.m:106
    
    return rnd
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} laplace_cdf (@var{x})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the Laplace distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the Laplace distribution
    
    
@function
def laplace_cdf(x=None,*args,**kwargs):
    varargin = laplace_cdf.varargin
    nargin = laplace_cdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('laplace_cdf: X must not be complex')
    
    cdf=(1 + multiply(sign(x),(1 - exp(- abs(x))))) / 2
# /home/lei/octave-4.0.2/scripts/statistics/distributions/laplace_cdf.m:39
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 2012 Rik Wehbring
## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} logistic_cdf (@var{x})
## For each element of @var{x}, compute the cumulative distribution function
## (CDF) at @var{x} of the logistic distribution.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: CDF of the logistic distribution
    
    
@function
def logistic_cdf(x=None,*args,**kwargs):
    varargin = logistic_cdf.varargin
    nargin = logistic_cdf.nargin

    if (nargin != 1):
        print_usage()
    
    if (iscomplex(x)):
        error('logistic_cdf: X must not be complex')
    
    cdf=1 / (1 + exp(- x))
# /home/lei/octave-4.0.2/scripts/statistics/distributions/logistic_cdf.m:39
    return cdf
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test class of input preserved
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} spearman (@var{x})
## @deftypefnx {Function File} {} spearman (@var{x}, @var{y})
## @cindex Spearman's Rho
## Compute Spearman's rank correlation coefficient @var{rho}.
##
## For two data vectors @var{x} and @var{y}, Spearman's @var{rho} is the
## correlation coefficient of the ranks of @var{x} and @var{y}.
##
## If @var{x} and @var{y} are drawn from independent distributions, @var{rho}
## has zero mean and variance @code{1 / (n - 1)}, and is asymptotically
## normally distributed.
##
## @code{spearman (@var{x})} is equivalent to
## @code{spearman (@var{x}, @var{x})}.
## @seealso{ranks, kendall}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Spearman's rank correlation rho
    
    
@function
def spearman(x=None,y=[],*args,**kwargs):
    varargin = spearman.varargin
    nargin = spearman.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y)))):
        error('spearman: X and Y must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2):
        error('spearman: X and Y must be 2-D matrices or vectors')
    
    if (isrow(x)):
        x=x.T
# /home/lei/octave-4.0.2/scripts/statistics/base/spearman.m:56
    
    if (nargin == 1):
        rho=corr(ranks(x))
# /home/lei/octave-4.0.2/scripts/statistics/base/spearman.m:60
    else:
        if (isrow(y)):
            y=y.T
# /home/lei/octave-4.0.2/scripts/statistics/base/spearman.m:63
        if (rows(x) != rows(y)):
            error('spearman: X and Y must have the same number of observations')
        rho=corr(ranks(x),ranks(y))
# /home/lei/octave-4.0.2/scripts/statistics/base/spearman.m:68
    
    ## Restore class cleared by ranks
    if (isa(x,'single') or isa(y,'single')):
        rho=single(rho)
# /home/lei/octave-4.0.2/scripts/statistics/base/spearman.m:73
    
    return rho
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{beta}, @var{v}, @var{r}] =} gls (@var{y}, @var{x}, @var{o})
## Generalized least squares model.
##
## Perform a generalized least squares estimation for the multivariate model
## @tex
## $y = x b + e$
## with $\bar{e} = 0$ and cov(vec($e$)) = $(s^2)o$,
## @end tex
## @ifnottex
## @w{@math{y = x*b + e}} with @math{mean (e) = 0} and
## @math{cov (vec (e)) = (s^2) o},
## @end ifnottex
## where
## @tex
## $y$ is a $t \times p$ matrix, $x$ is a $t \times k$ matrix, $b$ is a $k
## \times p$ matrix, $e$ is a $t \times p$ matrix, and $o$ is a $tp \times
## tp$ matrix.
## @end tex
## @ifnottex
## @math{y} is a @math{t} by @math{p} matrix, @math{x} is a @math{t} by
## @math{k} matrix, @math{b} is a @math{k} by @math{p} matrix, @math{e}
## is a @math{t} by @math{p} matrix, and @math{o} is a @math{t*p} by
## @math{t*p} matrix.
## @end ifnottex
##
## @noindent
## Each row of @var{y} and @var{x} is an observation and each column a
## variable.  The return values @var{beta}, @var{v}, and @var{r} are
## defined as follows.
##
## @table @var
## @item beta
## The GLS estimator for @math{b}.
##
## @item v
## The GLS estimator for @math{s^2}.
##
## @item r
## The matrix of GLS residuals, @math{r = y - x*beta}.
## @end table
## @seealso{ols}
## @end deftypefn
    
    ## Author: Teresa Twaroch <twaroch@ci.tuwien.ac.at>
## Created: May 1993
## Adapted-By: jwe
    
    
@function
def gls(y=None,x=None,o=None,*args,**kwargs):
    varargin = gls.varargin
    nargin = gls.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not((isnumeric(x) and isnumeric(y) and isnumeric(o)))):
        error('gls: X, Y, and O must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2 or ndims(o) != 2):
        error('gls: X, Y and O must be 2-D matrices or vectors')
    
    rx,cx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:81
    ry,cy=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:82
    ro,co=size(o,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:83
    if (rx != ry):
        error('gls: number of rows of X and Y must be equal')
    
    if (logical_not(issquare(o)) or ro != dot(ry,cy)):
        error('gls: matrix O must be square matrix with rows = rows (Y) * cols (Y)')
    
    if (isinteger(x)):
        x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:92
    
    if (isinteger(y)):
        y=double(y)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:95
    
    if (isinteger(o)):
        o=double(o)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:98
    
    ## Start of algorithm
    o=o ** (- 1 / 2)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:102
    z=kron(eye(cy),x)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:103
    z=dot(o,z)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:104
    y1=dot(o,reshape(y,dot(ry,cy),1))
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:105
    u=dot(z.T,z)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:106
    r=rank(u)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:107
    if (r == dot(cx,cy)):
        b=dot(dot(inv(u),z.T),y1)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:110
    else:
        b=dot(pinv(z),y1)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:112
    
    beta=reshape(b,cx,cy)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:115
    if (isargout(2) or isargout(3)):
        r=y - dot(x,beta)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:118
        if (isargout(2)):
            v=dot(dot((reshape(r,dot(ry,cy),1)).T,(o ** 2)),reshape(r,dot(ry,cy),1)) / (dot(rx,cy) - r)
# /home/lei/octave-4.0.2/scripts/statistics/base/gls.m:120
    
    return beta,v,r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2005-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {count =} runlength (@var{x})
## @deftypefnx {Function File} {[count, value] =} runlength (@var{x})
## Find the lengths of all sequences of common values.
##
## @var{count} is a vector with the lengths of each repeated value.
##
## The optional output @var{value} contains the value that was repeated in
## the sequence.
##
## @example
## @group
## runlength ([2, 2, 0, 4, 4, 4, 0, 1, 1, 1, 1])
## @result{}  [2, 1, 3, 1, 4]
## @end group
## @end example
## @seealso{run_count}
## @end deftypefn
    
    
@function
def runlength(x=None,*args,**kwargs):
    varargin = runlength.varargin
    nargin = runlength.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or logical_not(isvector(x))):
        error('runlength: X must be a numeric vector')
    
    if (iscolumn(x)):
        x=x.T
# /home/lei/octave-4.0.2/scripts/statistics/base/runlength.m:49
    
    idx=matlabarray(cat(find(x[1:end() - 1] != x[2:end()]),length(x)))
# /home/lei/octave-4.0.2/scripts/statistics/base/runlength.m:52
    count=diff(cat(0,idx))
# /home/lei/octave-4.0.2/scripts/statistics/base/runlength.m:53
    if (nargout == 2):
        value=x[idx]
# /home/lei/octave-4.0.2/scripts/statistics/base/runlength.m:55
    
    return count,value
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} meansq (@var{x})
## @deftypefnx {Function File} {} meansq (@var{x}, @var{dim})
## Compute the mean square of the elements of the vector @var{x}.
##
## The mean square is defined as
## @tex
## $$
## {\rm meansq} (x) = {\sum_{i=1}^N {x_i}^2 \over N}
## $$
## where $\bar{x}$ is the mean value of $x$.
## @end tex
## @ifnottex
##
## @example
## @group
## meansq (x) = 1/N SUM_i x(i)^2
## @end group
## @end example
##
## @end ifnottex
## For matrix arguments, return a row vector containing the mean square
## of each column.
##
## If the optional argument @var{dim} is given, operate along this dimension.
## @seealso{var, std, moment}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute mean square
    
    
@function
def meansq(x=None,dim=None,*args,**kwargs):
    varargin = meansq.varargin
    nargin = meansq.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('mean: X must be a numeric vector or matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/meansq.m:61
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/meansq.m:62
    if (nargin < 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/meansq.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('mean: DIM must be an integer and a valid dimension')
    
    y=sumsq(x,dim) / sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/meansq.m:73
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{t}, @var{l_x}] =} table (@var{x})
## @deftypefnx {Function File} {[@var{t}, @var{l_x}, @var{l_y}] =} table (@var{x}, @var{y})
## Create a contingency table @var{t} from data vectors.
##
## The @var{l_x} and @var{l_y} vectors are the corresponding levels.
##
## Currently, only 1- and 2-dimensional tables are supported.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Cross tabulation
    
    
@function
def table(x=None,y=None,*args,**kwargs):
    varargin = table.varargin
    nargin = table.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        if (logical_not(isnumeric(x)) or logical_not(isvector(x))):
            error('table: X must be a numeric vector')
        v=unique(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/table.m:42
        for i in arange(1,length(v)).reshape(-1):
            t[i]=sum(x == logical_or(v[i],dot(isnan(v[i]),isnan(x))))
# /home/lei/octave-4.0.2/scripts/statistics/base/table.m:44
    else:
        if (nargin == 2):
            if (logical_not((isvector(x) and isnumeric(x) and isvector(y) and isnumeric(y) and (length(x) == length(y))))):
                error('table: X and Y must be numeric vectors of the same length')
            v=unique(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/table.m:52
            w=unique(y)
# /home/lei/octave-4.0.2/scripts/statistics/base/table.m:53
            for i in arange(1,length(v)).reshape(-1):
                for j in arange(1,length(w)).reshape(-1):
                    t[i,j]=sum(logical_and((x == logical_or(v[i],dot(isnan(v[i]),isnan(x)))),(y == logical_or(w[j],dot(isnan(w[j]),isnan(y))))))
# /home/lei/octave-4.0.2/scripts/statistics/base/table.m:56
    
    return t,v,w
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{z} =} zscore (@var{x})
## @deftypefnx {Function File} {@var{z} =} zscore (@var{x}, @var{opt})
## @deftypefnx {Function File} {@var{z} =} zscore (@var{x}, @var{opt}, @var{dim})
## @deftypefnx {Function File} {[@var{z}, @var{mu}, @var{sigma}] =} zscore (@dots{})
## Compute the Z score of @var{x}
##
## If @var{x} is a vector, subtract its mean and divide by its standard
## deviation.  If the standard deviation is zero, divide by 1 instead.
##
## The optional parameter @var{opt} determines the normalization to use when
## computing the standard deviation and has the same definition as the
## corresponding parameter for @code{std}.
##
## If @var{x} is a matrix, calculate along the first non-singleton dimension.
## If the third optional argument @var{dim} is given, operate along this
## dimension.
##
## The optional outputs @var{mu} and @var{sigma} contain the mean and standard
## deviation.
##
## @seealso{mean, std, center}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Subtract mean and divide by standard deviation
    
    
@function
def zscore(x=None,opt=None,dim=None,*args,**kwargs):
    varargin = zscore.varargin
    nargin = zscore.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('zscore: X must be a numeric vector or matrix')
    
    if (nargin < 2):
        opt=0
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:57
    else:
        if (opt != 0 and opt != 1 or logical_not(isscalar(opt))):
            error('zscore: OPT must be empty, 0, or 1')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:64
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:65
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('zscore: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:76
    if (n == 0):
        z=copy(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:78
    else:
        if (isinteger(x)):
            x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:82
        mu=mean(x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:85
        sigma=std(x,opt,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:86
        s=copy(sigma)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:87
        s[s == 0]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:88
        z=bsxfun(rdivide,bsxfun(minus,x,mu),s)
# /home/lei/octave-4.0.2/scripts/statistics/base/zscore.m:90
    
    return z,mu,sigma
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Ben Abbott
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} prctile (@var{x})
## @deftypefnx {Function File} {@var{q} =} prctile (@var{x}, @var{p})
## @deftypefnx {Function File} {@var{q} =} prctile (@var{x}, @var{p}, @var{dim})
## For a sample @var{x}, compute the quantiles, @var{q}, corresponding
## to the cumulative probability values, @var{p}, in percent.
##
## If @var{x} is a matrix, compute the percentiles for each column and return
## them in a matrix, such that the i-th row of @var{y} contains the
## @var{p}(i)th percentiles of each column of @var{x}.
##
## If @var{p} is unspecified, return the quantiles for @code{[0 25 50 75 100]}.
##
## The optional argument @var{dim} determines the dimension along which the
## percentiles are calculated.  If @var{dim} is omitted it defaults to the
## first non-singleton dimension.
##
## Programming Note: All non-numeric values (NaNs) of @var{x} are ignored.
## @seealso{quantile}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Description: Matlab style prctile function.
    
    
@function
def prctile(x=None,p=[],dim=None,*args,**kwargs):
    varargin = prctile.varargin
    nargin = prctile.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('prctile: X must be a numeric vector or matrix')
    
    if (isempty(p)):
        p=matlabarray(cat(0,25,50,75,100))
# /home/lei/octave-4.0.2/scripts/statistics/base/prctile.m:54
    
    if (logical_not((isnumeric(p) and isvector(p)))):
        error('prctile: P must be a numeric vector')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/prctile.m:61
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/prctile.m:62
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/prctile.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('prctile: DIM must be an integer and a valid dimension')
    
    ## Convert from percent to decimal.
    p /= 100
    q=quantile(x,p,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/prctile.m:76
    return q
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} mahalanobis (@var{x}, @var{y})
## Return the Mahalanobis' D-square distance between the multivariate
## samples @var{x} and @var{y}.
##
## The data @var{x} and @var{y} must have the same number of components
## (columns), but may have a different number of observations (rows).
## @end deftypefn
    
    ## Author: Friedrich Leisch <leisch@ci.tuwien.ac.at>
## Created: July 1993
## Adapted-By: jwe
    
    
@function
def mahalanobis(x=None,y=None,*args,**kwargs):
    varargin = mahalanobis.varargin
    nargin = mahalanobis.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y)))):
        error('mahalanobis: X and Y must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2):
        error('mahalanobis: X and Y must be 2-D matrices or vectors')
    
    xr,xc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:47
    yr,yc=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:48
    if (xc != yc):
        error('mahalanobis: X and Y must have the same number of columns')
    
    if (isinteger(x)):
        x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:55
    
    xm=mean(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:58
    ym=mean(y)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:59
    
    x=bsxfun(minus,x,xm)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:62
    y=bsxfun(minus,y,ym)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:63
    w=(dot(x.T,x) + dot(y.T,y)) / (xr + yr - 2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:65
    winv=inv(w)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:67
    retval=dot(dot((xm - ym),winv),(xm - ym).T)
# /home/lei/octave-4.0.2/scripts/statistics/base/mahalanobis.m:69
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} logit (@var{p})
## Compute the logit for each value of @var{p}
##
## The logit is defined as
## @tex
## $$
## {\rm logit}(p) = \log\Big({p \over 1-p}\Big)
## $$
## @end tex
## @ifnottex
##
## @example
## logit (@var{p}) = log (@var{p} / (1-@var{p}))
## @end example
##
## @end ifnottex
## @seealso{probit, logistic_cdf}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Logit transformation
    
    
@function
def logit(p=None,*args,**kwargs):
    varargin = logit.varargin
    nargin = logit.nargin

    if (nargin != 1):
        print_usage()
    
    y=logistic_inv(p)
# /home/lei/octave-4.0.2/scripts/statistics/base/logit.m:48
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} run_count (@var{x}, @var{n})
## @deftypefnx {Function File} {} run_count (@var{x}, @var{n}, @var{dim})
## Count the upward runs along the first non-singleton dimension of @var{x}
## of length 1, 2, @dots{}, @var{n}-1 and greater than or equal to @var{n}.
##
## If the optional argument @var{dim} is given then operate along this
## dimension.
## @seealso{runlength}
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Count upward runs
    
    
@function
def run_count(x=None,n=None,dim=None,*args,**kwargs):
    varargin = run_count.varargin
    nargin = run_count.nargin

    if (nargin != 2 and nargin != 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('run_count: X must be a numeric vector or matrix')
    
    if (logical_not((isscalar(n) and n == fix(n) and n > 0))):
        error('run_count: N must be a positive integer')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:47
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:48
    if (nargin != 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('run_count: DIM must be an integer and a valid dimension')
    
    ## Algorithm works on rows.  Permute array if necessary, ipermute back at end
    if (dim != 1):
        perm=matlabarray(cat(arange(1,nd)))
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:61
        perm[1]=dim
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:62
        perm[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:63
        x=permute(x,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:64
    
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:67
    idx=cell()
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:68
    for i in arange(1,nd).reshape(-1):
        idx[i]=arange(1,sz[i])
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:70
    
    c=sz[1]
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:72
    tmp=zeros(cat(c + 1,sz[2:end()]))
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:73
    infvec=Inf(cat(1,sz[2:end()]))
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:74
    ind=find(diff(cat([infvec],[x],[- infvec])) < 0)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:76
    tmp[ind[2:end()] - 1]=diff(ind)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:77
    tmp=tmp[idx[:]]
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:78
    sz[1]=n
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:80
    retval=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:81
    for k in arange(1,(n - 1)).reshape(-1):
        idx[1]=k
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:83
        retval[idx[:]]=sum(tmp == k)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:84
    
    idx[1]=n
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:86
    retval[idx[:]]=sum(tmp >= n)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:87
    if (dim != 1):
        retval=ipermute(retval,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/run_count.m:90
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{p}, @var{y}] =} ppplot (@var{x}, @var{dist}, @var{params})
## Perform a PP-plot (probability plot).
##
## If F is the CDF of the distribution @var{dist} with parameters
## @var{params} and @var{x} a sample vector of length @var{n}, the PP-plot
## graphs ordinate @var{y}(@var{i}) = F (@var{i}-th largest element of
## @var{x}) versus abscissa @var{p}(@var{i}) = (@var{i} - 0.5)/@var{n}.  If
## the sample comes from F, the pairs will approximately follow a straight
## line.
##
## The default for @var{dist} is the standard normal distribution.
##
## The optional argument @var{params} contains a list of parameters of
## @var{dist}.
##
## For example, for a probability plot of the uniform distribution on [2,4]
## and @var{x}, use
##
## @example
## ppplot (x, "uniform", 2, 4)
## @end example
##
## @noindent
## @var{dist} can be any string for which a function @var{dist_cdf} that
## calculates the CDF of distribution @var{dist} exists.
##
## If no output is requested then the data are plotted immediately.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Perform a PP-plot (probability plot)
    
    
@function
def ppplot(x=None,dist=None,varargin=None,*args,**kwargs):
    varargin = ppplot.varargin
    nargin = ppplot.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not(isvector(x))):
        error('ppplot: X must be a vector')
    
    s=sort(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:62
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:63
    p=((arange(1,n)).T - 0.5) / n
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:64
    if (nargin == 1):
        F=stdnormal_cdf
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:66
    else:
        F=str2func(sprintf('%scdf',dist))
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:68
    
    if (nargin <= 2):
        y=feval(F,s)
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:71
    else:
        y=feval(F,s,varargin[:])
# /home/lei/octave-4.0.2/scripts/statistics/base/ppplot.m:73
    
    if (nargout == 0):
        plot(p,y)
        axis(cat(0,1,0,1))
    
    return p,y
    
if __name__ == '__main__':
    pass
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} corr (@var{x})
## @deftypefnx {Function File} {} corr (@var{x}, @var{y})
## Compute matrix of correlation coefficients.
##
## If each row of @var{x} and @var{y} is an observation and each column is
## a variable, then the @w{(@var{i}, @var{j})-th} entry of
## @code{corr (@var{x}, @var{y})} is the correlation between the
## @var{i}-th variable in @var{x} and the @var{j}-th variable in @var{y}.
## @tex
## $$
## {\rm corr}(x,y) = {{\rm cov}(x,y) \over {\rm std}(x) {\rm std}(y)}
## $$
## @end tex
## @ifnottex
##
## @example
## corr (x,y) = cov (x,y) / (std (x) * std (y))
## @end example
##
## @end ifnottex
## If called with one argument, compute @code{corr (@var{x}, @var{x})},
## the correlation between the columns of @var{x}.
## @seealso{cov}
## @end deftypefn
    
    ## Author: Kurt Hornik <hornik@wu-wien.ac.at>
## Created: March 1993
## Adapted-By: jwe
    
    
@function
def corr(x=None,y=[],*args,**kwargs):
    varargin = corr.varargin
    nargin = corr.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    ## Input validation is done by cov.m.  Don't repeat tests here
    
    ## Special case, scalar is always 100# correlated with itself
    if (isscalar(x)):
        if (isa(x,'single')):
            retval=single(1)
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:60
        else:
            retval=1
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:62
        return retval
    
    ## No check for division by zero error, which happens only when
  ## there is a constant vector and should be rare.
    if (nargin == 2):
        c=cov(x,y)
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:70
        s=dot(std(x).T,std(y))
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:71
        retval=c / s
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:72
    else:
        c=cov(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:74
        s=sqrt(diag(c))
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:75
        retval=c / (dot(s,s.T))
# /home/lei/octave-4.0.2/scripts/statistics/base/corr.m:76
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} ranks (@var{x}, @var{dim})
## Return the ranks of @var{x} along the first non-singleton dimension
## adjusted for ties.
##
## If the optional argument @var{dim} is given, operate along this dimension.
## @seealso{spearman, kendall}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute ranks
    
    ## This code was rather ugly, since it didn't use sort due to the
## fact of how to deal with ties. Now it does use sort and its
## even uglier!!! At least it handles NDArrays..
    
    
@function
def ranks(x=None,dim=None,*args,**kwargs):
    varargin = ranks.varargin
    nargin = ranks.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('ranks: X must be a numeric vector or matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:45
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:46
    if (nargin != 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('ranks: DIM must be an integer and a valid dimension')
    
    if (sz[dim] == 1):
        y=ones(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:58
    else:
        ## The algorithm works only on dim = 1, so permute if necesary.
        if (dim != 1):
            perm=matlabarray(cat(arange(1,nd)))
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:62
            perm[1]=dim
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:63
            perm[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:64
            x=permute(x,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:65
        sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:67
        infvec=- Inf(cat(1,sz[2:end()]))
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:68
        xs,xi=sort(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:69
        eq_el=find(diff(cat([xs],[infvec])) == 0)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:70
        if (isempty(eq_el)):
            eq_el,y=sort(xi,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:72
        else:
            runs=setdiff(eq_el,eq_el + 1)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:74
            len_=diff(find(diff(cat([Inf],[eq_el],[- Inf])) != 1)) + 1
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:75
            eq_el,y=sort(xi,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:76
            for i in arange(1,length(runs)).reshape(-1):
                y[xi[runs[i] + cat(arange(0,(len_[i] - 1)))] + dot(floor(runs[i] / sz[1]),sz[1])]=eq_el[runs[i]] + (len_[i] - 1) / 2
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:79
        if (dim != 1):
            y=permute(y,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/ranks.m:83
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 Ben Abbott and Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{q} =} quantile (@var{x})
## @deftypefnx {Function File} {@var{q} =} quantile (@var{x}, @var{p})
## @deftypefnx {Function File} {@var{q} =} quantile (@var{x}, @var{p}, @var{dim})
## @deftypefnx {Function File} {@var{q} =} quantile (@var{x}, @var{p}, @var{dim}, @var{method})
## For a sample, @var{x}, calculate the quantiles, @var{q}, corresponding to
## the cumulative probability values in @var{p}.  All non-numeric values (NaNs)
## of @var{x} are ignored.
##
## If @var{x} is a matrix, compute the quantiles for each column and
## return them in a matrix, such that the i-th row of @var{q} contains
## the @var{p}(i)th quantiles of each column of @var{x}.
##
## If @var{p} is unspecified, return the quantiles for
## @code{[0.00 0.25 0.50 0.75 1.00]}.
## The optional argument @var{dim} determines the dimension along which
## the quantiles are calculated.  If @var{dim} is omitted it defaults to
## the first non-singleton dimension.
##
## The methods available to calculate sample quantiles are the nine methods
## used by R (@url{http://www.r-project.org/}).  The default value is
## @w{METHOD = 5}.
##
## Discontinuous sample quantile methods 1, 2, and 3
##
## @enumerate 1
## @item Method 1: Inverse of empirical distribution function.
##
## @item Method 2: Similar to method 1 but with averaging at discontinuities.
##
## @item Method 3: SAS definition: nearest even order statistic.
## @end enumerate
##
## Continuous sample quantile methods 4 through 9, where p(k) is the linear
## interpolation function respecting each methods' representative cdf.
##
## @enumerate 4
## @item Method 4: p(k) = k / n.  That is, linear interpolation of the
## empirical cdf.
##
## @item Method 5: p(k) = (k - 0.5) / n.  That is a piecewise linear function
## where the knots are the values midway through the steps of the empirical
## cdf.
##
## @item Method 6: p(k) = k / (n + 1).
##
## @item Method 7: p(k) = (k - 1) / (n - 1).
##
## @item Method 8: p(k) = (k - 1/3) / (n + 1/3).  The resulting quantile
## estimates are approximately median-unbiased regardless of the distribution
## of @var{x}.
##
## @item Method 9: p(k) = (k - 3/8) / (n + 1/4).  The resulting quantile
## estimates are approximately unbiased for the expected order statistics if
## @var{x} is normally distributed.
## @end enumerate
##
## @nospell{Hyndman and Fan} (1996) recommend method 8.  Maxima, S, and R
## (versions prior to 2.0.0) use 7 as their default.  Minitab and SPSS
## use method 6.  @sc{matlab} uses method 5.
##
## References:
##
## @itemize @bullet
## @item @nospell{Becker, R. A., Chambers, J. M. and Wilks, A. R.} (1988)
## The New S Language.  Wadsworth & Brooks/Cole.
##
## @item @nospell{Hyndman, R. J. and Fan, Y.} (1996) Sample quantiles in
## statistical packages, American Statistician, 50, 361--365.
##
## @item R: A Language and Environment for Statistical Computing;
## @url{http://cran.r-project.org/doc/manuals/fullrefman.pdf}.
## @end itemize
##
## Examples:
## @c Set example in small font to prevent overfull line
##
## @smallexample
## @group
## x = randi (1000, [10, 1]);  # Create empirical data in range 1-1000
## q = quantile (x, [0, 1]);   # Return minimum, maximum of distribution
## q = quantile (x, [0.25 0.5 0.75]); # Return quartiles of distribution
## @end group
## @end smallexample
## @seealso{prctile}
## @end deftypefn
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Description: Matlab style quantile function of a discrete/continuous
##              distribution.
    
    
@function
def quantile(x=None,p=[],dim=None,method=5,*args,**kwargs):
    varargin = quantile.varargin
    nargin = quantile.nargin

    if (nargin < 1 or nargin > 4):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or isempty(x)):
        error('quantile: X must be a non-empty numeric vector or matrix')
    
    if (isempty(p)):
        p=matlabarray(cat(0.0,0.25,0.5,0.75,1.0))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:121
    
    if (logical_not((isnumeric(p) and isvector(p)))):
        error('quantile: P must be a numeric vector')
    
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(size(x) > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= ndims(x)))):
            error('quantile: DIM must be an integer and a valid dimension')
    
    ## Set the permutation vector.
    perm=arange(1,ndims(x))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:139
    perm[1]=dim
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:140
    perm[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:141
    
    x=permute(x,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:144
    
    sx=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:147
    
    x=reshape(x,cat(sx[1],prod(sx[2:end()])))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:150
    
    q=__quantile__(x,p,method)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:153
    
    q=reshape(q,cat(numel(p),sx[2:end()]))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:156
    
    q=ipermute(q,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:159
    return q
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Bug #45455
    
    ## Test input validation
    
    ## For the cumulative probability values in @var{p}, compute the
## quantiles, @var{q} (the inverse of the cdf), for the sample, @var{x}.
##
## The optional input, @var{method}, refers to nine methods available in R
## (http://www.r-project.org/). The default is @var{method} = 7.
## @seealso{prctile, quantile, statistics}
    
    ## Author: Ben Abbott <bpabbott@mac.com>
## Vectorized version: Jaroslav Hajek <highegg@gmail.com>
## Description: Quantile function of empirical samples
    
    
@function
def __quantile__(x=None,p=None,method=5,*args,**kwargs):
    varargin = __quantile__.varargin
    nargin = __quantile__.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (isinteger(x) or islogical(x)):
        x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:357
    
    ## set shape of quantiles to column vector.
    p=ravel(p)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:361
    
    x=sort(x,1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:364
    m=sum(logical_not(isnan(x)))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:365
    xr,xc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:366
    
    inv=dot(Inf(class_(x)),(- (p < 0) + (p > 1)))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:369
    inv=repmat(inv,1,xc)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:370
    
    if (any(k=find(logical_and((p >= 0),(p <= 1)))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:373)):
        n=length(k)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:374
        p=p[k]
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:375
        if (xr == 1):
            inv[k,:]=repmat(x,n,1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:378
            return inv
        ## The column-distribution indices.
        pcd=kron(ones(n,1),dot(xr,(arange(0,xc - 1))))
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:383
        mm=kron(ones(n,1),m)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:384
        if cellarray([1,2,3]) == (method):
            if 1 == (method):
                p=max(ceil(kron(p,m)),1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:389
                inv[k,:]=x[p + pcd]
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:390
            else:
                if 2 == (method):
                    p=kron(p,m)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:393
                    p_lr=max(ceil(p),1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:394
                    p_rl=min(floor(p + 1),mm)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:395
                    inv[k,:]=(x[p_lr + pcd] + x[p_rl + pcd]) / 2
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:396
                else:
                    if 3 == (method):
                        ## Used by SAS, method PCTLDEF=2.
           ## http://support.sas.com/onlinedoc/913/getDoc/en/statug.hlp/stdize_sect14.htm
                        t=max(kron(p,m),1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:401
                        t=roundb(t)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:402
                        inv[k,:]=x[t + pcd]
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:403
        else:
            if 4 == (method):
                p=kron(p,m)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:409
            else:
                if 5 == (method):
                    ## Used by Matlab.
                    p=kron(p,m) + 0.5
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:413
                else:
                    if 6 == (method):
                        ## Used by Minitab and SPSS.
                        p=kron(p,m + 1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:417
                    else:
                        if 7 == (method):
                            ## Used by S and R.
                            p=kron(p,m - 1) + 1
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:421
                        else:
                            if 8 == (method):
                                ## Median unbiased.
                                p=kron(p,m + 1 / 3) + 1 / 3
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:425
                            else:
                                if 9 == (method):
                                    ## Approximately unbiased respecting order statistics.
                                    p=kron(p,m + 0.25) + 0.375
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:429
                                else:
                                    error('quantile: Unknown METHOD, \'%d\'',method)
            ## Duplicate single values.
            imm1=(mm[1,:] == 1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:436
            x[2,imm1]=x[1,imm1]
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:437
            pi=max(min(floor(p),mm - 1),1)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:440
            pr=max(min(p - pi,1),0)
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:441
            pi += pcd
            inv[k,:]=multiply((1 - pr),x[pi]) + multiply(pr,x[pi + 1])
# /home/lei/octave-4.0.2/scripts/statistics/base/quantile.m:443
    
    return inv
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} var (@var{x})
## @deftypefnx {Function File} {} var (@var{x}, @var{opt})
## @deftypefnx {Function File} {} var (@var{x}, @var{opt}, @var{dim})
## Compute the variance of the elements of the vector @var{x}.
##
## The variance is defined as
## @tex
## $$
## {\rm var} (x) = \sigma^2 = {\sum_{i=1}^N (x_i - \bar{x})^2 \over N - 1}
## $$
## where $\bar{x}$ is the mean value of $x$.
## @end tex
## @ifnottex
##
## @example
## @group
## var (x) = 1/(N-1) SUM_i (x(i) - mean(x))^2
## @end group
## @end example
##
## @end ifnottex
## If @var{x} is a matrix, compute the variance for each column and return
## them in a row vector.
##
## The argument @var{opt} determines the type of normalization to use.
## Valid values are
##
## @table @asis
## @item 0:
##   normalize with @math{N-1}, provides the best unbiased estimator of the
## variance [default]
##
## @item 1:
##   normalizes with @math{N}, this provides the second moment around the mean
## @end table
##
## If @math{N==1} the value of @var{opt} is ignored and normalization by
## @math{N} is used.
##
## If the optional argument @var{dim} is given, operate along this dimension.
## @seealso{cov, std, skewness, kurtosis, moment}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute variance
    
    
@function
def var(x=None,opt=0,dim=None,*args,**kwargs):
    varargin = var.varargin
    nargin = var.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('var: X must be a numeric vector or matrix')
    
    if (isempty(opt)):
        opt=0
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:77
    
    if (opt != 0 and opt != 1):
        error('var: normalization OPT must be 0 or 1')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:83
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:84
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('var: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:95
    if (n == 1):
        if (isa(x,'single')):
            retval=zeros(sz,'single')
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:98
        else:
            retval=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:100
    else:
        if (numel(x) > 0):
            retval=sumsq(center(x,dim),dim) / (n - 1 + opt)
# /home/lei/octave-4.0.2/scripts/statistics/base/var.m:103
        else:
            error('var: X must not be empty')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cloglog (@var{x})
## Return the complementary log-log function of @var{x}.
##
## The complementary log-log function is defined as
## @tex
## $$
## {\rm cloglog}(x) = - \log (- \log (x))
## $$
## @end tex
## @ifnottex
##
## @example
## cloglog (x) = - log (- log (@var{x}))
## @end example
##
## @end ifnottex
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Complementary log-log function
    
    
@function
def cloglog(x=None,*args,**kwargs):
    varargin = cloglog.varargin
    nargin = cloglog.nargin

    if (nargin != 1):
        print_usage()
    
    y=- log(- log(x))
# /home/lei/octave-4.0.2/scripts/statistics/base/cloglog.m:47
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
## Copyright (C) 2009-2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} median (@var{x})
## @deftypefnx {Function File} {} median (@var{x}, @var{dim})
## Compute the median value of the elements of the vector @var{x}.
##
## When the elements of @var{x} are sorted, the median is defined as
## @tex
## $$
## {\rm median} (x) =
##   \cases{x(\lceil N/2\rceil), & $N$ odd;\cr
##           (x(N/2)+x(N/2+1))/2, & $N$ even.}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##               x(ceil(N/2))             N odd
## median (x) =
##              (x(N/2) + x((N/2)+1))/2   N even
## @end group
## @end example
##
## @end ifnottex
## If @var{x} is a matrix, compute the median value for each column and
## return them in a row vector.
##
## If the optional @var{dim} argument is given, operate along this dimension.
## @seealso{mean, mode}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def median(x=None,dim=None,*args,**kwargs):
    varargin = median.varargin
    nargin = median.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('median: X must be a numeric vector or matrix')
    
    if (isempty(x)):
        error('median: X cannot be an empty matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:67
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:68
    if (nargin < 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('median: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:79
    k=floor((n + 1) / 2)
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:80
    if (mod(n,2) == 1):
        retval=nth_element(x,k,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:82
    else:
        retval=mean(nth_element(x,arange(k,k + 1),dim),dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:84
    
    ## Inject NaNs where needed, to be consistent with Matlab.
    retval[any(isnan(x),dim)]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/base/median.m:87
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test multidimensional arrays (bug #35679)
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2013-2015 Julien Bect
## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} skewness (@var{x})
## @deftypefnx {Function File} {} skewness (@var{x}, @var{flag})
## @deftypefnx {Function File} {} skewness (@var{x}, @var{flag}, @var{dim})
## Compute the sample skewness of the elements of @var{x}.
##
## The sample skewness is defined as
## @tex
## $$
## {\rm skewness} (@var{x}) = {{{1\over N}\,
##          \sum_{i=1}^N (@var{x}_i - \bar{@var{x}})^3} \over \sigma^3},
## $$
## where $N$ is the length of @var{x}, $\bar{@var{x}}$ its mean and $\sigma$
## its (uncorrected) standard deviation.
## @end tex
## @ifnottex
##
## @example
## @group
##                mean ((@var{x} - mean (@var{x})).^3)
## skewness (@var{X}) = ------------------------.
##                       std (@var{x}).^3
## @end group
## @end example
##
## @end ifnottex
##
## @noindent
## The optional argument @var{flag} controls which normalization is used.
## If @var{flag} is equal to 1 (default value, used when @var{flag} is omitted
## or empty), return the sample skewness as defined above.  If @var{flag} is
## equal to 0, return the adjusted skewness coefficient instead:
## @tex
## $$
## {\rm skewness} (@var{x}) = {\sqrt{N (N - 1)} \over N - 2} \times \,
##   {{{1 \over N} \sum_{i=1}^N (@var{x}_i - \bar{@var{x}})^3} \over \sigma^3}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##                   sqrt (N*(N-1))   mean ((@var{x} - mean (@var{x})).^3)
## skewness (@var{X}, 0) = -------------- * ------------------------.
##                       (N - 2)             std (@var{x}).^3
## @end group
## @end example
##
## @end ifnottex
## The adjusted skewness coefficient is obtained by replacing the sample second
## and third central moments by their bias-corrected versions.
##
## If @var{x} is a matrix, or more generally a multi-dimensional array, return
## the skewness along the first non-singleton dimension.  If the optional
## @var{dim} argument is given, operate along this dimension.
##
## @seealso{var, kurtosis, moment}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 29 July 1994
## Adapted-By: jwe
    
    
@function
def skewness(x=None,flag=None,dim=None,*args,**kwargs):
    varargin = skewness.varargin
    nargin = skewness.nargin

    if (nargin < 1) or (nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('skewness: X must be a numeric vector or matrix')
    
    if (nargin < 2 or isempty(flag)):
        flag=1
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:94
    else:
        if (logical_not(isscalar(flag)) or (flag != 0 and flag != 1)):
            error('skewness: FLAG must be 0 or 1')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:101
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:102
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('skewness: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:112
    sz[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:113
    x=center(x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:115
    
    s=std(x,1,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:116
    
    y=sum(x ** 3,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:117
    idx=(s != 0)
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:118
    y[idx] / (dot(n,s[idx] ** 3))
    y[logical_not(idx)]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:120
    
    if (flag == 0):
        if (n > 2):
            y *= sqrt(dot(n,(n - 1))) / (n - 2)
        else:
            ravel[y]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/base/skewness.m:127
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test behaviour on single input
    
    
    ## Verify no "divide-by-zero" warnings
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {[@var{q}, @var{s}] =} qqplot (@var{x})
## @deftypefnx {Function File} {[@var{q}, @var{s}] =} qqplot (@var{x}, @var{y})
## @deftypefnx {Function File} {[@var{q}, @var{s}] =} qqplot (@var{x}, @var{dist})
## @deftypefnx {Function File} {[@var{q}, @var{s}] =} qqplot (@var{x}, @var{y}, @var{params})
## @deftypefnx {Function File} {} qqplot (@dots{})
## Perform a QQ-plot (quantile plot).
##
## If F is the CDF of the distribution @var{dist} with parameters
## @var{params} and G its inverse, and @var{x} a sample vector of length
## @var{n}, the QQ-plot graphs ordinate @var{s}(@var{i}) = @var{i}-th
## largest element of x versus abscissa @var{q}(@var{i}f) = G((@var{i} -
## 0.5)/@var{n}).
##
## If the sample comes from F, except for a transformation of location
## and scale, the pairs will approximately follow a straight line.
##
## If the second argument is a vector @var{y} the empirical CDF of @var{y}
## is used as @var{dist}.
##
## The default for @var{dist} is the standard normal distribution.  The
## optional argument @var{params} contains a list of parameters of
## @var{dist}.  For example, for a quantile plot of the uniform
## distribution on [2,4] and @var{x}, use
##
## @example
## qqplot (x, "unif", 2, 4)
## @end example
##
## @noindent
## @var{dist} can be any string for which a function @var{distinv} or
## @var{dist_inv} exists that calculates the inverse CDF of distribution
## @var{dist}.
##
## If no output arguments are given, the data are plotted directly.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Perform a QQ-plot (quantile plot)
    
    
@function
def qqplot(x=None,dist=None,varargin=None,*args,**kwargs):
    varargin = qqplot.varargin
    nargin = qqplot.nargin

    if (nargin < 1):
        print_usage()
    
    if (logical_not((isnumeric(x) and isvector(x)))):
        error('qqplot: X must be a numeric vector')
    
    if (nargin == 1):
        f=stdnormal_inv
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:70
    else:
        if (isnumeric(dist)):
            f=lambda y=None: empirical_inv(y,dist)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:73
        else:
            if (ischar(dist) and (exist(invname=matlabarray(cat(dist,'inv'))
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:74) or exist(invname=matlabarray(cat(dist,'%s_inv'))
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:75))):
                f=str2func(invname)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:76
            else:
                error('qqplot: no inverse CDF found for distribution DIST')
    
    s=sort(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:82
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:83
    t=((arange(1,n)).T - 0.5) / n
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:84
    if (nargin <= 2):
        q=f[t]
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:86
        q_label=func2str(f)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:87
    else:
        q=f[t,varargin[:]]
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:89
        if (nargin == 3):
            q_label=sprintf('%s with parameter %g',func2str(f),varargin[1])
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:91
        else:
            q_label=sprintf('%s with parameters %g',func2str(f),varargin[1])
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:93
            param_str=sprintf(', %g',varargin[2:end()])
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:94
            q_label=matlabarray(cat(q_label,param_str))
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:95
    
    if (nargout == 0):
        plot(q,s,'-x')
        q_label=strrep(q_label,'_inv','\\_inv')
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:101
        if (q_label[1] == '@'):
            q_label=q_label[6:end()]
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:103
        xlabel(q_label)
        ylabel('sample points')
    else:
        qout=copy(q)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:108
        sout=copy(s)
# /home/lei/octave-4.0.2/scripts/statistics/base/qqplot.m:109
    
    return qout,sout
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} cov (@var{x})
## @deftypefnx {Function File} {} cov (@var{x}, @var{opt})
## @deftypefnx {Function File} {} cov (@var{x}, @var{y})
## @deftypefnx {Function File} {} cov (@var{x}, @var{y}, @var{opt})
## Compute the covariance matrix.
##
## If each row of @var{x} and @var{y} is an observation, and each column is
## a variable, then the @w{(@var{i}, @var{j})-th} entry of
## @code{cov (@var{x}, @var{y})} is the covariance between the @var{i}-th
## variable in @var{x} and the @var{j}-th variable in @var{y}.
## @tex
## $$
## \sigma_{ij} = {1 \over N-1} \sum_{i=1}^N (x_i - \bar{x})(y_i - \bar{y})
## $$
## where $\bar{x}$ and $\bar{y}$ are the mean values of $x$ and $y$.
## @end tex
## @ifnottex
##
## @example
## cov (x) = 1/N-1 * SUM_i (x(i) - mean(x)) * (y(i) - mean(y))
## @end example
##
## @end ifnottex
##
## If called with one argument, compute @code{cov (@var{x}, @var{x})}, the
## covariance between the columns of @var{x}.
##
## The argument @var{opt} determines the type of normalization to use.
## Valid values are
##
## @table @asis
## @item 0:
##   normalize with @math{N-1}, provides the best unbiased estimator of the
## covariance [default]
##
## @item 1:
##   normalize with @math{N}, this provides the second moment around the mean
## @end table
##
## Compatibility Note:: Octave always computes the covariance matrix.
## For two inputs, however, @sc{matlab} will calculate
## @code{cov (@var{x}(:), @var{y}(:))} whenever the number of elements in
## @var{x} and @var{y} are equal.  This will result in a scalar rather than
## a matrix output.  Code relying on this odd definition will need to be
## changed when running in Octave.
## @seealso{corr}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute covariances
    
    
@function
def cov(x=None,y=[],opt=0,*args,**kwargs):
    varargin = cov.varargin
    nargin = cov.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y)))):
        error('cov: X and Y must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2):
        error('cov: X and Y must be 2-D matrices or vectors')
    
    if (nargin == 2 and isscalar(y)):
        opt=copy(y)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:87
    
    if (opt != 0 and opt != 1):
        error('cov: normalization OPT must be 0 or 1')
    
    ## Special case, scalar has zero covariance
    if (isscalar(x)):
        if (isa(x,'single')):
            c=single(0)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:97
        else:
            c=0
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:99
        return c
    
    if (isrow(x)):
        x=x.T
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:105
    
    n=rows(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:107
    if (nargin == 1 or isscalar(y)):
        x=center(x,1)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:110
        c=conj(dot(x.T,x) / (n - 1 + opt))
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:111
    else:
        if (isrow(y)):
            y=y.T
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:114
        if (rows(y) != n):
            error('cov: X and Y must have the same number of observations')
        x=center(x,1)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:119
        y=center(y,1)
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:120
        c=conj(dot(x.T,y) / (n - 1 + opt))
# /home/lei/octave-4.0.2/scripts/statistics/base/cov.m:121
    
    return c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} mode (@var{x})
## @deftypefnx {Function File} {} mode (@var{x}, @var{dim})
## @deftypefnx {Function File} {[@var{m}, @var{f}, @var{c}] =} mode (@dots{})
## Compute the most frequently occurring value in a dataset (mode).
##
## @code{mode} determines the frequency of values along the first non-singleton
## dimension and returns the value with the highest frequency.  If two, or
## more, values have the same frequency @code{mode} returns the smallest.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## The return variable @var{f} is the number of occurrences of the mode in
## the dataset.
##
## The cell array @var{c} contains all of the elements with the maximum
## frequency.
## @seealso{mean, median}
## @end deftypefn
    
    
@function
def mode(x=None,dim=None,*args,**kwargs):
    varargin = mode.varargin
    nargin = mode.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('mode: X must be a numeric vector or matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:49
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:50
    if (nargin < 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('mode: DIM must be an integer and a valid dimension')
    
    sz2=copy(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:61
    sz2[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:62
    sz3=ones(1,nd)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:63
    sz3[dim]=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:64
    if (issparse(x)):
        t2=sparse(sz[1],sz[2])
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:67
    else:
        t2=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:69
    
    if (dim != 1):
        perm=matlabarray(cat(dim,arange(1,dim - 1),arange(dim + 1,nd)))
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:73
        t2=permute(t2,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:74
    
    xs=sort(x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:77
    t=cat(dim,true(sz2),diff(xs,1,dim) != 0)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:78
    if (dim != 1):
        t2[permute(t != 0,perm)]=diff(cat([ravel(find(permute(t,perm)))],[prod(sz) + 1]))
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:81
        f=max(ipermute(t2,perm),[],dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:82
        xs=permute(xs,perm)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:83
    else:
        t2[t]=diff(cat([ravel(find(t))],[prod(sz) + 1]))
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:85
        f=max(t2,[],dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:86
    
    c=cell(sz2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:89
    if (issparse(x)):
        m=sparse(sz2[1],sz2[2])
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:91
    else:
        m=zeros(sz2,class_(x))
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:93
    
    for i in arange(1,prod(sz2)).reshape(-1):
        c[i]=xs[t2[:,i] == f[i],i]
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:96
        m[i]=c[i](1)
# /home/lei/octave-4.0.2/scripts/statistics/base/mode.m:97
    
    return m,f,c
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{beta}, @var{sigma}, @var{r}] =} ols (@var{y}, @var{x})
## Ordinary least squares estimation.
##
## OLS applies to the multivariate model
## @tex
## $y = x b + e$
## with
## $\bar{e} = 0$, and cov(vec($e$)) = kron ($s, I$)
## @end tex
## @ifnottex
## @w{@math{y = x*b + e}} with
## @math{mean (e) = 0} and @math{cov (vec (e)) = kron (s, I)}.
## @end ifnottex
## where
## @tex
## $y$ is a $t \times p$ matrix, $x$ is a $t \times k$ matrix,
## $b$ is a $k \times p$ matrix, and $e$ is a $t \times p$ matrix.
## @end tex
## @ifnottex
## @math{y} is a @math{t} by @math{p} matrix, @math{x} is a @math{t} by @math{k}
## matrix, @math{b} is a @math{k} by @math{p} matrix, and @math{e} is a
## @math{t} by @math{p} matrix.
## @end ifnottex
##
## Each row of @var{y} and @var{x} is an observation and each column a variable.
##
## The return values @var{beta}, @var{sigma}, and @var{r} are defined as
## follows.
##
## @table @var
## @item beta
## The OLS estimator for @math{b}.
## @tex
## $beta$ is calculated directly via $(x^Tx)^{-1} x^T y$ if the matrix $x^Tx$ is
## of full rank.
## @end tex
## @ifnottex
## @var{beta} is calculated directly via @code{inv (x'*x) * x' * y} if the
## matrix @code{x'*x} is of full rank.
## @end ifnottex
## Otherwise, @code{@var{beta} = pinv (@var{x}) * @var{y}} where
## @code{pinv (@var{x})} denotes the pseudoinverse of @var{x}.
##
## @item sigma
## The OLS estimator for the matrix @var{s},
##
## @example
## @group
## @var{sigma} = (@var{y}-@var{x}*@var{beta})'
##   * (@var{y}-@var{x}*@var{beta})
##   / (@var{t}-rank(@var{x}))
## @end group
## @end example
##
## @item r
## The matrix of OLS residuals, @code{@var{r} = @var{y} - @var{x}*@var{beta}}.
## @end table
## @seealso{gls, pinv}
## @end deftypefn
    
    ## Author: Teresa Twaroch <twaroch@ci.tuwien.ac.at>
## Created: May 1993
## Adapted-By: jwe
    
    
@function
def ols(y=None,x=None,*args,**kwargs):
    varargin = ols.varargin
    nargin = ols.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) and isnumeric(y)))):
        error('ols: X and Y must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2):
        error('ols: X and Y must be 2-D matrices or vectors')
    
    nr,nc=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:98
    ry,cy=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:99
    if (nr != ry):
        error('ols: number of rows of X and Y must be equal')
    
    if (isinteger(x)):
        x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:105
    
    if (isinteger(y)):
        y=double(y)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:108
    
    ## Start of algorithm
    z=dot(x.T,x)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:112
    u,p=chol(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:113
    if (p):
        beta=dot(pinv(x),y)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:116
    else:
        beta=numpy.linalg.solve(u,(numpy.linalg.solve(u.T,(dot(x.T,y)))))
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:118
    
    if (isargout(2) or isargout(3)):
        r=y - dot(x,beta)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:122
    
    if (isargout(2)):
        ## z is of full rank, avoid the SVD in rnk
        if (p == 0):
            rnk=columns(z)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:128
        else:
            rnk=rank(z)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:130
        sigma=dot(r.T,r) / (nr - rnk)
# /home/lei/octave-4.0.2/scripts/statistics/base/ols.m:133
    
    return beta,sigma,r
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} kendall (@var{x})
## @deftypefnx {Function File} {} kendall (@var{x}, @var{y})
## @cindex Kendall's Tau
## Compute Kendall's @var{tau}.
##
## For two data vectors @var{x}, @var{y} of common length @var{n}, Kendall's
## @var{tau} is the correlation of the signs of all rank differences of
## @var{x} and @var{y}; i.e., if both @var{x} and @var{y} have distinct
## entries, then
##
## @tex
## $$ \tau = {1 \over n(n-1)} \sum_{i,j} {\rm sign}(q_i-q_j) {\rm sign}(r_i-r_j) $$
## @end tex
## @ifnottex
##
## @example
## @group
##          1
## tau = -------   SUM sign (q(i) - q(j)) * sign (r(i) - r(j))
##       n (n-1)   i,j
## @end group
## @end example
##
## @end ifnottex
## @noindent
## in which the
## @tex
## $q_i$ and $r_i$
## @end tex
## @ifnottex
## @var{q}(@var{i}) and @var{r}(@var{i})
## @end ifnottex
## are the ranks of @var{x} and @var{y}, respectively.
##
## If @var{x} and @var{y} are drawn from independent distributions,
## Kendall's @var{tau} is asymptotically normal with mean 0 and variance
## @tex
## ${2 (2n+5) \over 9n(n-1)}$.
## @end tex
## @ifnottex
## @code{(2 * (2@var{n}+5)) / (9 * @var{n} * (@var{n}-1))}.
## @end ifnottex
##
## @code{kendall (@var{x})} is equivalent to @code{kendall (@var{x},
## @var{x})}.
## @seealso{ranks, spearman}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Kendall's rank correlation tau
    
    
@function
def kendall(x=None,y=[],*args,**kwargs):
    varargin = kendall.varargin
    nargin = kendall.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or logical_not((isnumeric(y) or islogical(y)))):
        error('kendall: X and Y must be numeric matrices or vectors')
    
    if (ndims(x) != 2 or ndims(y) != 2):
        error('kendall: X and Y must be 2-D matrices or vectors')
    
    if (isrow(x)):
        x=x.T
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:87
    
    n,c=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:89
    if (nargin == 2):
        if (isrow(y)):
            y=y.T
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:93
        if (rows(y) != n):
            error('kendall: X and Y must have the same number of observations')
        else:
            x=matlabarray(cat(x,y))
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:98
    
    if (isa(x,'single') or isa(y,'single')):
        cls='single'
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:103
    else:
        cls='double'
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:105
    
    r=ranks(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:107
    m=sign(kron(r,ones(n,1,cls)) - kron(ones(n,1,cls),r))
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:108
    tau=corr(m)
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:109
    if (nargin == 2):
        tau=tau[1:c,(c + 1):columns(x)]
# /home/lei/octave-4.0.2/scripts/statistics/base/kendall.m:112
    
    return tau
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} iqr (@var{x})
## @deftypefnx {Function File} {} iqr (@var{x}, @var{dim})
## Return the interquartile range, i.e., the difference between the upper
## and lower quartile of the input data.
##
## If @var{x} is a matrix, do the above for first non-singleton dimension of
## @var{x}.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## As a measure of dispersion, the interquartile range is less affected by
## outliers than either @code{range} or @code{std}.
## @seealso{range, std}
## @end deftypefn
    
    ## Author KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Interquartile range
    
    
@function
def iqr(x=None,dim=None,*args,**kwargs):
    varargin = iqr.varargin
    nargin = iqr.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('iqr: X must be a numeric vector or matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:48
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:49
    nel=numel(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:50
    if (nargin != 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('iqr: DIM must be an integer and a valid dimension')
    
    ## This code is a bit heavy, but is needed until empirical_inv
  ## can take a matrix, rather than just a vector argument.
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:63
    sz[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:64
    if (isa(x,'single')):
        y=zeros(sz,'single')
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:66
    else:
        y=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:68
    
    stride=prod(sz[1:dim - 1])
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:70
    for i in arange(1,nel / n).reshape(-1):
        offset=copy(i)
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:72
        offset2=0
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:73
        while (offset > stride):

            offset -= stride
            offset2

        offset += dot(dot(offset2,stride),n)
        rng=dot(cat(arange(0,n - 1)),stride) + offset
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:79
        y[i]=diff(empirical_inv(cat(1 / 4,3 / 4),x[rng]))
# /home/lei/octave-4.0.2/scripts/statistics/base/iqr.m:81
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    ## FIXME: iqr throws horrible error when running across a dimension that is 1.
    
    
    
    
    ## Copyright (C) 2009-2015 Sren Hauberg
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{n} =} histc (@var{x}, @var{edges})
## @deftypefnx {Function File} {@var{n} =} histc (@var{x}, @var{edges}, @var{dim})
## @deftypefnx {Function File} {[@var{n}, @var{idx}] =} histc (@dots{})
## Compute histogram counts.
##
## When @var{x} is a vector, the function counts the number of elements of
## @var{x} that fall in the histogram bins defined by @var{edges}.  This must be
## a vector of monotonically increasing values that define the edges of the
## histogram bins.  @code{@var{n}(k)} contains the number of elements in
## @var{x} for which @code{@var{edges}(k) <= @var{x} < @var{edges}(k+1)}.
## The final element of @var{n} contains the number of elements of @var{x}
## exactly equal to the last element of @var{edges}.
##
## When @var{x} is an @math{N}-dimensional array, the computation is carried
## out along dimension @var{dim}.  If not specified @var{dim} defaults to the
## first non-singleton dimension.
##
## When a second output argument is requested an index matrix is also returned.
## The @var{idx} matrix has the same size as @var{x}.  Each element of @var{idx}
## contains the index of the histogram bin in which the corresponding element
## of @var{x} was counted.
## @seealso{hist}
## @end deftypefn
    
    
@function
def histc(x=None,edges=None,dim=None,*args,**kwargs):
    varargin = histc.varargin
    nargin = histc.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(isreal(x))):
        error('histc: X argument must be real-valued, not complex')
    
    num_edges=numel(edges)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:55
    if (num_edges == 0):
        error('histc: EDGES must not be empty')
    
    if (logical_not(isreal(edges))):
        error('histc: EDGES must be real-valued, not complex')
    else:
        ## Make sure 'edges' is sorted
        edges=ravel(edges)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:64
        if (logical_not(issorted(edges)) or edges[1] > edges[end()]):
            warning('histc: edge values not sorted on input')
            edges=sort(edges)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:67
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:71
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:72
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('histc: DIM must be an integer and a valid dimension')
    
    nsz=copy(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:83
    nsz[dim]=num_edges
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:84
    
    if (num_edges <= 3):
        ## This is the O(M*N) algorithm.
        ## Allocate the histogram
        n=zeros(nsz)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:93
        if (nargout > 1):
            idx=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:97
        ## Prepare indices
        idx1=cell(1,dim - 1)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:101
        for k in arange(1,length(idx1)).reshape(-1):
            idx1[k]=arange(1,sz[k])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:103
        idx2=cell(length(sz) - dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:105
        for k in arange(1,length(idx2)).reshape(-1):
            idx2[k]=arange(1,sz[k + dim])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:107
        ## Compute the histograms
        for k in arange(1,num_edges - 1).reshape(-1):
            b=(edges[k] <= logical_and(x,x) < edges[k + 1])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:112
            n[idx1[:],k,idx2[:]]=sum(b,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:113
            if (nargout > 1):
                idx[b]=k
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:115
        b=(x == edges[end()])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:118
        n[idx1[:],num_edges,idx2[:]]=sum(b,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:119
        if (nargout > 1):
            idx[b]=num_edges
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:121
    else:
        ## This is the O(M*log(N) + N) algorithm.
        ## Look-up indices.
        idx=lookup(edges,x)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:129
        idx[logical_not((x <= edges[end()]))]=0
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:131
        iidx=copy(idx)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:133
        if (logical_not(isvector(x))):
            nl=prod(sz[1:dim - 1])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:137
            nn=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:138
            nu=prod(sz[dim + 1:end()])
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:139
            if (nl != 1):
                iidx=dot((iidx - 1),nl)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:141
                iidx += reshape(kron(ones(1,dot(nn,nu)),arange(1,nl)),sz)
            if (nu != 1):
                ne=length(edges)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:145
                iidx += reshape(kron(dot(dot(nl,ne),(arange(0,nu - 1))),ones(1,dot(nl,nn))),sz)
        ## Select valid elements.
        iidx=iidx[idx != 0]
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:151
        n=accumarray(ravel(iidx),1,nsz)
# /home/lei/octave-4.0.2/scripts/statistics/base/histc.m:154
    
    return n,idx
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} moment (@var{x}, @var{p})
## @deftypefnx {Function File} {} moment (@var{x}, @var{p}, @var{type})
## @deftypefnx {Function File} {} moment (@var{x}, @var{p}, @var{dim})
## @deftypefnx {Function File} {} moment (@var{x}, @var{p}, @var{type}, @var{dim})
## @deftypefnx {Function File} {} moment (@var{x}, @var{p}, @var{dim}, @var{type})
## Compute the @var{p}-th central moment of the vector @var{x}.
##
## @tex
## $$
## {\sum_{i=1}^N (x_i - \bar{x})^p \over N}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## 1/N SUM_i (x(i) - mean(x))^p
## @end group
## @end example
##
## @end ifnottex
##
## If @var{x} is a matrix, return the row vector containing the @var{p}-th
## central moment of each column.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## The optional string @var{type} specifies the type of moment to be computed.
## Valid options are:
##
## @table @asis
## @item @qcode{"c"}
##   Central Moment (default).
##
## @item  @qcode{"a"}
## @itemx @qcode{"ac"}
##   Absolute Central Moment.  The moment about the mean ignoring sign
## defined as
## @tex
## $$
## {\sum_{i=1}^N {\left| x_i - \bar{x} \right|}^p \over N}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## 1/N SUM_i (abs (x(i) - mean(x)))^p
## @end group
## @end example
##
## @end ifnottex
##
## @item @qcode{"r"}
##   Raw Moment.  The moment about zero defined as
##
## @tex
## $$
## {\rm moment} (x) = { \sum_{i=1}^N {x_i}^p \over N }
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## moment (x) = 1/N SUM_i x(i)^p
## @end group
## @end example
##
## @end ifnottex
##
## @item @nospell{@qcode{"ar"}}
##   Absolute Raw Moment.  The moment about zero ignoring sign defined as
## @tex
## $$
## {\sum_{i=1}^N {\left| x_i \right|}^p \over N}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
## 1/N SUM_i ( abs (x(i)) )^p
## @end group
## @end example
##
## @end ifnottex
## @end table
##
## If both @var{type} and @var{dim} are given they may appear in any order.
## @seealso{var, skewness, kurtosis}
## @end deftypefn
    
    ## Can easily be made to work for continuous distributions (using quad)
## as well, but how does the general case work?
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute moments
    
    
@function
def moment(x=None,p=None,opt1=None,opt2=None,*args,**kwargs):
    varargin = moment.varargin
    nargin = moment.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x))) or isempty(x)):
        error('moment: X must be a non-empty numeric matrix or vector')
    
    if (logical_not((isnumeric(p) and isscalar(p)))):
        error('moment: P must be a numeric scalar')
    
    need_dim=copy(false)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:133
    if (nargin == 2):
        type_=''
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:136
        need_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:137
    else:
        if (nargin == 3):
            if (ischar(opt1)):
                type_=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:140
                need_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:141
            else:
                dim=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:143
                type_=''
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:144
        else:
            if (nargin == 4):
                if (ischar(opt1)):
                    type_=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:148
                    dim=copy(opt2)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:149
                else:
                    if (ischar(opt2)):
                        type_=copy(opt2)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:151
                        dim=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:152
                    else:
                        error('moment: expecting TYPE to be a string')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:158
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:159
    if (need_dim):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('moment: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:169
    if (logical_not(any(type_ == 'r'))):
        x=center(x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:172
    
    if (any(type_ == 'a')):
        x=abs(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:175
    
    m=sum(x ** p,dim) / n
# /home/lei/octave-4.0.2/scripts/statistics/base/moment.m:178
    return m
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} mean (@var{x})
## @deftypefnx {Function File} {} mean (@var{x}, @var{dim})
## @deftypefnx {Function File} {} mean (@var{x}, @var{opt})
## @deftypefnx {Function File} {} mean (@var{x}, @var{dim}, @var{opt})
## Compute the mean of the elements of the vector @var{x}.
##
## The mean is defined as
##
## @tex
## $$ {\rm mean}(x) = \bar{x} = {1\over N} \sum_{i=1}^N x_i $$
## @end tex
## @ifnottex
##
## @example
## mean (x) = SUM_i x(i) / N
## @end example
##
## @end ifnottex
## If @var{x} is a matrix, compute the mean for each column and return them
## in a row vector.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## The optional argument @var{opt} selects the type of mean to compute.
## The following options are recognized:
##
## @table @asis
## @item @qcode{"a"}
## Compute the (ordinary) arithmetic mean.  [default]
##
## @item @qcode{"g"}
## Compute the geometric mean.
##
## @item @qcode{"h"}
## Compute the harmonic mean.
## @end table
##
## Both @var{dim} and @var{opt} are optional.  If both are supplied, either
## may appear first.
## @seealso{median, mode}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute arithmetic, geometric, and harmonic mean
    
    
@function
def mean(x=None,opt1=None,opt2=None,*args,**kwargs):
    varargin = mean.varargin
    nargin = mean.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('mean: X must be a numeric vector or matrix')
    
    need_dim=copy(false)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:75
    if (nargin == 1):
        opt='a'
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:78
        need_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:79
    else:
        if (nargin == 2):
            if (ischar(opt1)):
                opt=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:82
                need_dim=copy(true)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:83
            else:
                dim=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:85
                opt='a'
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:86
        else:
            if (nargin == 3):
                if (ischar(opt1)):
                    opt=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:90
                    dim=copy(opt2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:91
                else:
                    if (ischar(opt2)):
                        opt=copy(opt2)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:93
                        dim=copy(opt1)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:94
                    else:
                        error('mean: OPT must be a string')
            else:
                print_usage()
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:102
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:103
    if (need_dim):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('mean: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:114
    if (strcmp(opt,'a')):
        y=sum(x,dim) / n
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:117
    else:
        if (strcmp(opt,'g')):
            if (all(ravel(x) >= 0)):
                y=exp(sum(log(x),dim) / n)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:120
            else:
                error('mean: X must not contain any negative values')
        else:
            if (strcmp(opt,'h')):
                y=n / sum(1 / x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/mean.m:125
            else:
                error('mean: option \'%s\' not recognized',opt)
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    ## Test small numbers
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2013-2015 Julien Bect
## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} kurtosis (@var{x})
## @deftypefnx {Function File} {} kurtosis (@var{x}, @var{flag})
## @deftypefnx {Function File} {} kurtosis (@var{x}, @var{flag}, @var{dim})
## Compute the sample kurtosis of the elements of @var{x}.
##
## The sample kurtosis is defined as
## @tex
## $$
## \kappa_1 = {{{1\over N}\,
##          \sum_{i=1}^N (@var{x}_i - \bar{@var{x}})^4} \over \sigma^4},
## $$
## where $N$ is the length of @var{x}, $\bar{@var{x}}$ its mean, and $\sigma$
## its (uncorrected) standard deviation.
## @end tex
## @ifnottex
##
## @example
## @group
##      mean ((@var{x} - mean (@var{x})).^4)
## k1 = ------------------------
##             std (@var{x}).^4
## @end group
## @end example
##
## @end ifnottex
##
## @noindent
## The optional argument @var{flag} controls which normalization is used.
## If @var{flag} is equal to 1 (default value, used when @var{flag} is omitted
## or empty), return the sample kurtosis as defined above.  If @var{flag} is
## equal to 0, return the @w{"bias-corrected"} kurtosis coefficient instead:
## @tex
## $$
## \kappa_0 = 3 + {\scriptstyle N - 1 \over \scriptstyle (N - 2)(N - 3)} \,
##     \left( (N + 1)\, \kappa_1 - 3 (N - 1) \right)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##               N - 1
## k0 = 3 + -------------- * ((N + 1) * k1 - 3 * (N - 1))
##          (N - 2)(N - 3)
## @end group
## @end example
##
## @end ifnottex
## The bias-corrected kurtosis coefficient is obtained by replacing the sample
## second and fourth central moments by their unbiased versions.  It is an
## unbiased estimate of the population kurtosis for normal populations.
##
## If @var{x} is a matrix, or more generally a multi-dimensional array, return
## the kurtosis along the first non-singleton dimension.  If the optional
## @var{dim} argument is given, operate along this dimension.
##
## @seealso{var, skewness, moment}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 29 July 1994
## Adapted-By: jwe
    
    
@function
def kurtosis(x=None,flag=None,dim=None,*args,**kwargs):
    varargin = kurtosis.varargin
    nargin = kurtosis.nargin

    if (nargin < 1) or (nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('kurtosis: X must be a numeric vector or matrix')
    
    if (nargin < 2 or isempty(flag)):
        flag=1
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:95
    else:
        if (logical_not(isscalar(flag)) or (flag != 0 and flag != 1)):
            error('kurtosis: FLAG must be 0 or 1')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:102
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:103
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('kurtosis: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:113
    sz[dim]=1
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:114
    x=center(x,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:116
    
    v=var(x,1,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:117
    
    y=sum(x ** 4,dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:118
    idx=(v != 0)
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:119
    y[idx]=y[idx] / (dot(n,v[idx] ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:120
    y[logical_not(idx)]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:121
    
    if (flag == 0):
        if (n > 3):
            C=(n - 1) / (dot((n - 2),(n - 3)))
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:126
            y=3 + dot(C,(dot((n + 1),y) - dot(3,(n - 1))))
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:127
        else:
            ravel[y]=NaN
# /home/lei/octave-4.0.2/scripts/statistics/base/kurtosis.m:129
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test behaviour on single input
    
    
    ## Verify no "divide-by-zero" warnings
    
    
    
    
    
    
    
    
    
    ## Test input validation
    ## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} center (@var{x})
## @deftypefnx {Function File} {} center (@var{x}, @var{dim})
## Center data by subtracting its mean.
##
## If @var{x} is a vector, subtract its mean.
##
## If @var{x} is a matrix, do the above for each column.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## Programming Note: @code{center} has obvious application for normalizing
## statistical data.  It is also useful for improving the precision of general
## numerical calculations.  Whenever there is a large value that is common
## to a batch of data, the mean can be subtracted off, the calculation
## performed, and then the mean added back to obtain the final answer.
## @seealso{zscore}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Center by subtracting means
    
    
@function
def center(x=None,dim=None,*args,**kwargs):
    varargin = center.varargin
    nargin = center.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('center: X must be a numeric vector or matrix')
    
    if (isinteger(x)):
        x=double(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:53
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:56
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:57
    if (nargin != 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('center: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:68
    if (n == 0):
        retval=copy(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:71
    else:
        retval=bsxfun(minus,x,mean(x,dim))
# /home/lei/octave-4.0.2/scripts/statistics/base/center.m:73
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
## Copyright (C) 2009 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} range (@var{x})
## @deftypefnx {Function File} {} range (@var{x}, @var{dim})
## Return the range, i.e., the difference between the maximum and the minimum
## of the input data.
##
## If @var{x} is a vector, the range is calculated over the elements of
## @var{x}.  If @var{x} is a matrix, the range is calculated over each column
## of @var{x}.
##
## If the optional argument @var{dim} is given, operate along this dimension.
##
## The range is a quickly computed measure of the dispersion of a data set, but
## is less accurate than @code{iqr} if there are outlying data points.
## @seealso{iqr, std}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute range
    
    
@function
def range_(x=None,dim=None,*args,**kwargs):
    varargin = range_.varargin
    nargin = range_.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    if (nargin == 1):
        y=max(x) - min(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/range.m:47
    else:
        y=max(x,[],dim) - min(x,[],dim)
# /home/lei/octave-4.0.2/scripts/statistics/base/range.m:49
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} statistics (@var{x})
## @deftypefnx {Function File} {} statistics (@var{x}, @var{dim})
## Return a vector with the minimum, first quartile, median, third quartile,
## maximum, mean, standard deviation, skewness, and kurtosis of the elements of
## the vector @var{x}.
##
## If @var{x} is a matrix, calculate statistics over the first non-singleton
## dimension.
##
## If the optional argument @var{dim} is given, operate along this dimension.
## @seealso{min, max, median, mean, std, skewness, kurtosis}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compute basic statistics
    
    
@function
def statistics(x=None,dim=None,*args,**kwargs):
    varargin = statistics.varargin
    nargin = statistics.nargin

    if (nargin != 1 and nargin != 2):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('statistics: X must be a numeric vector or matrix')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/statistics.m:46
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/statistics.m:47
    if (nargin != 2):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/statistics.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('statistics: DIM must be an integer and a valid dimension')
    
    if (sz[dim] < 2):
        error('statistics: dimension of X is too small (<2)')
    
    emp_inv=quantile(x,cat([0.25],[0.5],[0.75]),dim,7)
# /home/lei/octave-4.0.2/scripts/statistics/base/statistics.m:62
    stats=cat(dim,min(x,[],dim),emp_inv,max(x,[],dim),mean(x,dim),std(x,[],dim),skewness(x,[],dim),kurtosis(x,[],dim))
# /home/lei/octave-4.0.2/scripts/statistics/base/statistics.m:64
    return stats
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} std (@var{x})
## @deftypefnx {Function File} {} std (@var{x}, @var{opt})
## @deftypefnx {Function File} {} std (@var{x}, @var{opt}, @var{dim})
## Compute the standard deviation of the elements of the vector @var{x}.
##
## The standard deviation is defined as
## @tex
## $$
## {\rm std} (x) = \sigma = \sqrt{{\sum_{i=1}^N (x_i - \bar{x})^2 \over N - 1}}
## $$
## where $\bar{x}$ is the mean value of $x$ and $N$ is the number of elements.
## @end tex
## @ifnottex
##
## @example
## @group
## std (x) = sqrt ( 1/(N-1) SUM_i (x(i) - mean(x))^2 )
## @end group
## @end example
##
## @noindent
## where @math{N} is the number of elements.
## @end ifnottex
##
## If @var{x} is a matrix, compute the standard deviation for each column and
## return them in a row vector.
##
## The argument @var{opt} determines the type of normalization to use.
## Valid values are
##
## @table @asis
## @item 0:
##   normalize with @math{N-1}, provides the square root of the best unbiased
## estimator of the variance [default]
##
## @item 1:
##   normalize with @math{N}, this provides the square root of the second
## moment around the mean
## @end table
##
## If the optional argument @var{dim} is given, operate along this dimension.
## @seealso{var, range, iqr, mean, median}
## @end deftypefn
    
    ## Author: jwe
    
    
@function
def std(x=None,opt=0,dim=None,*args,**kwargs):
    varargin = std.varargin
    nargin = std.nargin

    if (nargin < 1 or nargin > 3):
        print_usage()
    
    if (logical_not((isnumeric(x) or islogical(x)))):
        error('std: X must be a numeric vector or matrix')
    
    if (isempty(opt)):
        opt=0
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:77
    
    if (opt != 0 and opt != 1):
        error('std: normalization OPT must be 0 or 1')
    
    nd=ndims(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:83
    sz=size(x)
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:84
    if (nargin < 3):
        ## Find the first non-singleton dimension.
        dim=find(sz > 1,1) or 1
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:None
    else:
        if (logical_not((isscalar(dim) and dim == fix(dim))) or logical_not((1 <= dim and dim <= nd))):
            error('std: DIM must be an integer and a valid dimension')
    
    n=sz[dim]
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:95
    if (n == 1 or isempty(x)):
        if (isa(x,'single')):
            retval=zeros(sz,'single')
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:98
        else:
            retval=zeros(sz)
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:100
    else:
        retval=sqrt(sumsq(center(x,dim),dim) / (n - 1 + opt))
# /home/lei/octave-4.0.2/scripts/statistics/base/std.m:103
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2014-2015 Nir Krakauer
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; If not, see <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{x} =} lscov (@var{A}, @var{b})
## @deftypefnx {Function File} {@var{x} =} lscov (@var{A}, @var{b}, @var{V})
## @deftypefnx {Function File} {@var{x} =} lscov (@var{A}, @var{b}, @var{V}, @var{alg})
## @deftypefnx {Function File} {[@var{x}, @var{stdx}, @var{mse}, @var{S}] =} lscov (@dots{})
##
## Compute a generalized linear least squares fit.
##
## Estimate @var{x} under the model @var{b} = @var{A}@var{x} + @var{w},
## where the noise @var{w} is assumed to follow a normal distribution
## with covariance matrix @math{{\sigma^2} V}.
##
## If the size of the coefficient matrix @var{A} is n-by-p, the
## size of the vector/array of constant terms @var{b} must be n-by-k.
##
## The optional input argument @var{V} may be a n-by-1 vector of positive
## weights (inverse variances), or a n-by-n symmetric positive semidefinite
## matrix representing the covariance of @var{b}.  If @var{V} is not
## supplied, the ordinary least squares solution is returned.
##
## The @var{alg} input argument, a guidance on solution method to use, is
## currently ignored.
##
## Besides the least-squares estimate matrix @var{x} (p-by-k), the function
## also returns @var{stdx} (p-by-k), the error standard deviation of
## estimated @var{x}; @var{mse} (k-by-1), the estimated data error covariance
## scale factors (@math{\sigma^2}); and @var{S} (p-by-p, or p-by-p-by-k if k
## > 1), the error covariance of @var{x}.
##
## Reference: @nospell{Golub and Van Loan} (1996),
## @cite{Matrix Computations (3rd Ed.)}, Johns Hopkins, Section 5.6.3
##
## @seealso{ols, gls, lsqnonneg}
## @end deftypefn
    
    ## Author: Nir Krakauer
    
    
@function
def lscov(A=None,b=None,V=[],alg=None,*args,**kwargs):
    varargin = lscov.varargin
    nargin = lscov.nargin

    if (nargin < 2 or (rows(A) != rows(b))):
        print_usage()
    
    n=rows(A)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:59
    p=columns(A)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:60
    k=columns(b)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:61
    if (logical_not(isempty(V))):
        if (rows(V) != n or logical_not(any(columns(V) == cat(1,n)))):
            error('lscov: V should be a square matrix or a vector with the same number of rows as A')
        if (isvector(V)):
            ## n-by-1 vector of inverse variances
            v=diag(sqrt(V))
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:70
            A=dot(v,A)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:71
            b=dot(v,b)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:72
        else:
            ## n-by-n covariance matrix
            try:
                ## ordinarily V will be positive definite
                B=chol(V).T
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:77
            finally:
                pass
            A=numpy.linalg.solve(B,A)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:85
            b=numpy.linalg.solve(B,b)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:86
    
    pinv_A=pinv(A)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:90
    
    x=dot(pinv_A,b)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:92
    if (isargout(3)):
        dof=n - p
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:95
        SSE=sumsq(b - dot(A,x))
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:96
        mse=SSE / dof
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:97
    
    s=dot(pinv_A,pinv_A.T)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:100
    stdx=sqrt(dot(diag(s),mse))
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:102
    if (isargout(4)):
        if (k == 1):
            S=dot(mse,s)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:106
        else:
            S=nan(p,p,k)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:108
            for i in arange(1,k).reshape(-1):
                S[:,:,i]=dot(mse[i],s)
# /home/lei/octave-4.0.2/scripts/statistics/base/lscov.m:110
    
    return x,stdx,mse,S
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} probit (@var{p})
## Return the probit (the quantile of the standard normal distribution) for
## each element of @var{p}.
## @seealso{logit}
## @end deftypefn
    
    ## Written by KH <Kurt.Hornik@wu-wien.ac.at> on 1995/02/04
## Description: Probit transformation
    
    
@function
def probit(p=None,*args,**kwargs):
    varargin = probit.varargin
    nargin = probit.nargin

    if (nargin != 1):
        print_usage()
    
    y=stdnormal_inv(p)
# /home/lei/octave-4.0.2/scripts/statistics/base/probit.m:36
    return y
    
if __name__ == '__main__':
    pass
    
    
    ## Test input validation
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{chisq}, @var{df}] =} chisquare_test_independence (@var{x})
## Perform a chi-square test for independence based on the contingency table
## @var{x}.
##
## Under the null hypothesis of independence, @var{chisq} approximately has a
## chi-square distribution with @var{df} degrees of freedom.
##
## The p-value (1 minus the CDF of this distribution at chisq) of the test is
## returned in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Chi-square test for independence
    
    
@function
def chisquare_test_independence(x=None,*args,**kwargs):
    varargin = chisquare_test_independence.varargin
    nargin = chisquare_test_independence.nargin

    if (nargin != 1):
        print_usage()
    
    r,s=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:42
    df=dot((r - 1),(s - 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:43
    n=sum(sum(x))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:44
    y=dot(sum(x.T).T,sum(x)) / n
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:45
    x=(x - y) ** 2 / y
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:46
    chisq=sum(sum(x))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:47
    pval=1 - chi2cdf(chisq,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_independence.m:48
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,chisq,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{z}] =} z_test_2 (@var{x}, @var{y}, @var{v_x}, @var{v_y}, @var{alt})
## For two samples @var{x} and @var{y} from normal distributions with unknown
## means and known variances @var{v_x} and @var{v_y}, perform a Z-test of the
## hypothesis of equal means.
##
## Under the null, the test statistic @var{z} follows a standard normal
## distribution.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative
## @code{mean (@var{x}) != mean (@var{y})}.  If alt is @qcode{">"}, the
## one-sided alternative @code{mean (@var{x}) > mean (@var{y})} is used.
## Similarly for @qcode{"<"}, the one-sided alternative
## @code{mean (@var{x}) < mean (@var{y})} is used.  The default is the
## two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed along
## with some information.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compare means of two normal samples with known variances
    
    
@function
def z_test_2(x=None,y=None,v_x=None,v_y=None,alt=None,*args,**kwargs):
    varargin = z_test_2.varargin
    nargin = z_test_2.nargin

    if (nargin < 4 or nargin > 5):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('z_test_2: both X and Y must be vectors')
    else:
        if (logical_not((isscalar(v_x) and (v_x > 0) and isscalar(v_y) and (v_y > 0)))):
            error('z_test_2: both V_X and V_Y must be positive scalars')
    
    n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:59
    n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:60
    mu_x=sum(x) / n_x
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:61
    mu_y=sum(y) / n_y
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:62
    z=(mu_x - mu_y) / sqrt(v_x / n_x + v_y / n_y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:63
    cdf=stdnormal_cdf(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:64
    if (nargin == 4):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:67
    
    if (logical_not(ischar(alt))):
        error('z_test_2: ALT must be a string')
    else:
        if (strcmp(alt,'!=') or strcmp(alt,'<>')):
            pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:73
        else:
            if (strcmp(alt,'>')):
                pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:75
            else:
                if (strcmp(alt,'<')):
                    pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:77
                else:
                    error('z_test_2: option %s not recognized',alt)
    
    if (nargout == 0):
        s=matlabarray(cat('Two-sample Z-test of mean(x) == mean(y) against ','mean(x) %s mean(y),\n','with known var(x) == %g and var(y) == %g:\n','  pval = %g\n'))
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test_2.m:83
        printf(s,alt,v_x,v_y,pval)
    
    return pval,z
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{f}, @var{df_num}, @var{df_den}] =} var_test (@var{x}, @var{y}, @var{alt})
## For two samples @var{x} and @var{y} from normal distributions with
## unknown means and unknown variances, perform an F-test of the null
## hypothesis of equal variances.
##
## Under the null, the test statistic @var{f} follows an F-distribution with
## @var{df_num} and @var{df_den} degrees of freedom.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative @code{var (@var{x}) != var
## (@var{y})}.  If @var{alt} is @qcode{">"}, the one-sided alternative
## @code{var (@var{x}) > var (@var{y})} is used.  Similarly for "<", the
## one-sided alternative @code{var (@var{x}) > var (@var{y})} is used.  The
## default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: F test to compare two variances
    
    
@function
def var_test(x=None,y=None,alt=None,*args,**kwargs):
    varargin = var_test.varargin
    nargin = var_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('var_test: both X and Y must be vectors')
    
    df_num=length(x) - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:54
    df_den=length(y) - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:55
    f=var(x) / var(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:56
    cdf=fcdf(f,df_num,df_den)
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:57
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:60
    
    if (logical_not(ischar(alt))):
        error('var_test: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:67
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:69
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/var_test.m:71
            else:
                error('var_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('pval: %g\n',pval)
    
    return pval,f,df_num,df_den
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{z}] =} wilcoxon_test (@var{x}, @var{y}, @var{alt})
## For two matched-pair sample vectors @var{x} and @var{y}, perform a
## Wilcoxon signed-rank test of the null hypothesis
## PROB (@var{x} > @var{y}) == 1/2.
##
## Under the null, the test statistic @var{z} approximately follows a
## standard normal distribution when @var{n} > 25.
##
## @strong{Caution:} This function assumes a normal distribution for @var{z}
## and thus is invalid for @var{n} @leq{} 25.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative
## PROB (@var{x} > @var{y}) != 1/2.  If alt is @qcode{">"}, the one-sided
## alternative PROB (@var{x} > @var{y}) > 1/2 is considered.  Similarly for
## @qcode{"<"}, the one-sided alternative PROB (@var{x} > @var{y}) < 1/2 is
## considered.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Wilcoxon signed-rank test
    
    
@function
def wilcoxon_test(x=None,y=None,alt=None,*args,**kwargs):
    varargin = wilcoxon_test.varargin
    nargin = wilcoxon_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y) and (length(x) == length(y))))):
        error('wilcoxon_test: X and Y must be vectors of the same length')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:57
    x=reshape(x,1,n)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:58
    y=reshape(y,1,n)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:59
    d=x - y
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:60
    d=d[find(d != 0)]
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:61
    n=length(d)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:62
    if (n > 25):
        r=ranks(abs(d))
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:64
        z=sum(r[find(d > 0)])
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:65
        z=((z - dot(n,(n + 1)) / 4) / sqrt(dot(dot(n,(n + 1)),(dot(2,n) + 1)) / 24))
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:66
    else:
        error('wilcoxon_test: implementation requires more than 25 different pairs')
    
    cdf=stdnormal_cdf(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:71
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:74
    
    if (logical_not(ischar(alt))):
        error('wilcoxon_test: ALT must be a string')
    else:
        if (strcmp(alt,'!=') or strcmp(alt,'<>')):
            pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:80
        else:
            if (strcmp(alt,'>')):
                pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:82
            else:
                if (strcmp(alt,'<')):
                    pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/wilcoxon_test.m:84
                else:
                    error('wilcoxon_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,z
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{b}, @var{n}] =} sign_test (@var{x}, @var{y}, @var{alt})
## For two matched-pair samples @var{x} and @var{y}, perform a sign test
## of the null hypothesis
## PROB (@var{x} > @var{y}) == PROB (@var{x} < @var{y}) == 1/2.
##
## Under the null, the test statistic @var{b} roughly follows a
## binomial distribution with parameters
## @code{@var{n} = sum (@var{x} != @var{y})} and @var{p} = 1/2.
##
## With the optional argument @code{alt}, the alternative of interest can be
## selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## hypothesis is tested against the two-sided alternative
## PROB (@var{x} < @var{y}) != 1/2.  If @var{alt} is @qcode{">"}, the one-sided
## alternative PROB (@var{x} > @var{y}) > 1/2 ("x is stochastically greater
## than y") is considered.  Similarly for @qcode{"<"}, the one-sided
## alternative PROB (@var{x} > @var{y}) < 1/2 ("x is stochastically less than
## y") is considered.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Sign test
    
    
@function
def sign_test(x=None,y=None,alt=None,*args,**kwargs):
    varargin = sign_test.varargin
    nargin = sign_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y) and (length(x) == length(y))))):
        error('sign_test: X and Y must be vectors of the same length')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:56
    x=reshape(x,1,n)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:57
    y=reshape(y,1,n)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:58
    n=sum(x != y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:59
    b=sum(x > y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:60
    cdf=binocdf(b,n,1 / 2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:61
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:64
    
    if (logical_not(ischar(alt))):
        error('sign_test: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:71
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:73
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/sign_test.m:75
            else:
                error('sign_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,b,n
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{f}, @var{df_num}, @var{df_den}] =} f_test_regression (@var{y}, @var{x}, @var{rr}, @var{r})
## Perform an F test for the null hypothesis @nospell{rr * b = r} in a
## classical normal regression model y = X * b + e.
##
## Under the null, the test statistic @var{f} follows an F distribution with
## @var{df_num} and @var{df_den} degrees of freedom.
##
## The p-value (1 minus the CDF of this distribution at @var{f}) is returned
## in @var{pval}.
##
## If not given explicitly, @var{r} = 0.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test linear hypotheses in linear regression model
    
    
@function
def f_test_regression(y=None,x=None,rr=None,r=None,*args,**kwargs):
    varargin = f_test_regression.varargin
    nargin = f_test_regression.nargin

    if (nargin < 3 or nargin > 4):
        print_usage()
    
    T,k=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:44
    if (logical_not((isvector(y) and (length(y) == T)))):
        error('f_test_regression: Y must be a vector of length rows (X)')
    
    y=reshape(y,T,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:48
    q,c_R=size(rr,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:50
    if (c_R != k):
        error('f_test_regression: RR must have as many columns as X')
    
    if (nargin == 4):
        s_r=size(r)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:56
        if ((min(s_r) != 1) or (max(s_r) != q)):
            error('f_test_regression: R must be a vector of length rows (RR)')
        r=reshape(r,q,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:60
    else:
        r=zeros(q,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:62
    
    df_num=copy(q)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:65
    df_den=T - k
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:66
    b,v=ols(y,x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:68
    diff=dot(rr,b) - r
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:69
    f=dot(dot(diff.T,inv(dot(dot(rr,inv(dot(x.T,x))),rr.T))),diff) / (dot(q,v))
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:70
    pval=1 - fcdf(f,df_num,df_den)
# /home/lei/octave-4.0.2/scripts/statistics/tests/f_test_regression.m:71
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,f,df_num,df_den
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{f}, @var{df_b}, @var{df_w}] =} anova (@var{y}, @var{g})
## Perform a one-way analysis of variance (ANOVA).
##
## The goal is to test whether the population means of data taken from
## @var{k} different groups are all equal.
##
## Data may be given in a single vector @var{y} with groups specified by a
## corresponding vector of group labels @var{g} (e.g., numbers from 1 to
## @var{k}).  This is the general form which does not impose any restriction
## on the number of data in each group or the group labels.
##
## If @var{y} is a matrix and @var{g} is omitted, each column of @var{y} is
## treated as a group.  This form is only appropriate for balanced ANOVA in
## which the numbers of samples from each group are all equal.
##
## Under the null of constant means, the statistic @var{f} follows an F
## distribution with @var{df_b} and @var{df_w} degrees of freedom.
##
## The p-value (1 minus the CDF of this distribution at @var{f}) is returned
## in @var{pval}.
##
## If no output argument is given, the standard one-way ANOVA table is printed.
## @seealso{manova}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: One-way analysis of variance (ANOVA)
    
    
@function
def anova(y=None,g=None,*args,**kwargs):
    varargin = anova.varargin
    nargin = anova.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    else:
        if (nargin == 1):
            if (isvector(y)):
                error('anova: for \'anova (Y)\', Y must not be a vector')
            group_count,k=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:56
            n=dot(group_count,k)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:57
            group_mean=mean(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:58
        else:
            if (logical_not(isvector(y))):
                error('anova: for \'anova (Y, G)\', Y must be a vector')
            n=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:63
            if (logical_not(isvector(g)) or (length(g) != n)):
                error('anova: G must be a vector of the same length as Y')
            s=sort(g)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:67
            i=find(s[2:n] > s[1:(n - 1)])
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:68
            k=length(i) + 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:69
            if (k == 1):
                error('anova: there should be at least 2 groups')
            else:
                group_label=s[cat(1,(reshape(i,1,k - 1) + 1))]
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:73
            for i in arange(1,k).reshape(-1):
                v=y[find(g == group_label[i])]
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:76
                group_count[i]=length(v)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:77
                group_mean[i]=mean(v)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:78
    
    total_mean=mean(ravel(y))
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:83
    SSB=sum(multiply(group_count,(group_mean - total_mean) ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:84
    SST=sumsq(reshape(y,n,1) - total_mean)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:85
    SSW=SST - SSB
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:86
    df_b=k - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:87
    df_w=n - k
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:88
    v_b=SSB / df_b
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:89
    v_w=SSW / df_w
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:90
    f=v_b / v_w
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:91
    pval=1 - fcdf(f,df_b,df_w)
# /home/lei/octave-4.0.2/scripts/statistics/tests/anova.m:92
    if (nargout == 0):
        ## This eventually needs to be done more cleanly ...
        printf('\n')
        printf('One-way ANOVA Table:\n')
        printf('\n')
        printf('Source of Variation   Sum of Squares    df  Empirical Var\n')
        printf('*********************************************************\n')
        printf('Between Groups       %15.4f  %4d  %13.4f\n',SSB,df_b,v_b)
        printf('Within Groups        %15.4f  %4d  %13.4f\n',SSW,df_w,v_w)
        printf('---------------------------------------------------------\n')
        printf('Total                %15.4f  %4d\n',SST,n - 1)
        printf('\n')
        printf('Test Statistic f     %15.4f\n',f)
        printf('p-value              %15.4f\n',pval)
        printf('\n')
    
    return pval,f,df_b,df_w
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{tsq}] =} hotelling_test_2 (@var{x}, @var{y})
## For two samples @var{x} from multivariate normal distributions with
## the same number of variables (columns), unknown means and unknown
## equal covariance matrices, test the null hypothesis @code{mean
## (@var{x}) == mean (@var{y})}.
##
## Hotelling's two-sample @math{T^2} is returned in @var{tsq}.  Under the null,
## @tex
## $$
## {(n_x+n_y-p-1) T^2 \over p(n_x+n_y-2)}
## $$
## @end tex
## @ifnottex
##
## @example
## (n_x+n_y-p-1) T^2 / (p(n_x+n_y-2))
## @end example
##
## @end ifnottex
## @noindent
## has an F distribution with @math{p} and @math{n_x+n_y-p-1} degrees of
## freedom, where @math{n_x} and @math{n_y} are the sample sizes and
## @math{p} is the number of variables.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compare means of two multivariate normals
    
    
@function
def hotelling_test_2(x=None,y=None,*args,**kwargs):
    varargin = hotelling_test_2.varargin
    nargin = hotelling_test_2.nargin

    if (nargin != 2):
        print_usage()
    
    if (isvector(x)):
        n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:59
        if (logical_not(isvector(y))):
            error('hotelling_test_2: if X is a vector, Y must also be a vector')
        else:
            n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:63
            p=1
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:64
    else:
        if (ismatrix(x)):
            n_x,p=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:67
            n_y,q=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:68
            if (p != q):
                error('hotelling_test_2: X and Y must have the same number of columns')
        else:
            error('hotelling_test_2: X and Y must be matrices (or vectors)')
    
    d=mean(x) - mean(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:76
    S=(dot((n_x - 1),cov(x)) + dot((n_y - 1),cov(y))) / (n_x + n_y - 2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:77
    Tsq=dot(dot((dot(n_x,n_y) / (n_x + n_y)),d),(numpy.linalg.solve(S,d.T)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:78
    pval=1 - fcdf(dot((n_x + n_y - p - 1),Tsq) / (dot(p,(n_x + n_y - 2))),p,n_x + n_y - p - 1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test_2.m:79
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,Tsq
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Friedrich Leisch
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{chisq}] =} run_test (@var{x})
## Perform a chi-square test with 6 degrees of freedom based on the upward
## runs in the columns of @var{x}.
##
## @code{run_test} can be used to decide whether @var{x} contains independent
## data.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Description: Run test for independence
    
    
@function
def run_test(x=None,*args,**kwargs):
    varargin = run_test.varargin
    nargin = run_test.nargin

    if (nargin != 1):
        print_usage()
    
    A=matlabarray(cat([4529.4,9044.9,13568,18091,22615,27892],[9044.4,18097,27139,36187,45234,55789],[13568,27139,40721,54281,67852,83685],[18091,36187,54281,72414,90470,111580],[22615,45234,67852,90470,113262,139476],[27892,55789,83685,111580,139476,172860]))
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:41
    b=matlabarray(cat([1 / 6],[5 / 24],[11 / 120],[19 / 720],[29 / 5040],[1 / 840]))
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:48
    n=rows(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:50
    r=run_count(x,6) - dot(dot(n,b),ones(1,columns(x)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:51
    chisq=diag(dot(dot(r.T,A),r)).T / n
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:53
    pval=chi2cdf(chisq,6)
# /home/lei/octave-4.0.2/scripts/statistics/tests/run_test.m:54
    if (nargout == 0):
        printf('pval: %g\n',pval)
    
    return pval,chisq
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{chisq}, @var{df}] =} mcnemar_test (@var{x})
## For a square contingency table @var{x} of data cross-classified on the row
## and column variables, @nospell{McNemar's} test can be used for testing the
## null hypothesis of symmetry of the classification probabilities.
##
## Under the null, @var{chisq} is approximately distributed as chisquare with
## @var{df} degrees of freedom.
##
## The p-value (1 minus the CDF of this distribution at @var{chisq}) is
## returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: McNemar's test for symmetry
    
    
@function
def mcnemar_test(x=None,*args,**kwargs):
    varargin = mcnemar_test.varargin
    nargin = mcnemar_test.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not((min(size(x)) > 1)) and issquare(x)):
        error('mcnemar_test: X must be a square matrix of size > 1')
    else:
        if (logical_not((all((ravel(x) >= 0)) and all(ravel(x) == fix(ravel(x)))))):
            error('mcnemar_test: all entries of X must be non-negative integers')
    
    r=rows(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:49
    df=dot(r,(r - 1)) / 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:50
    if (r == 2):
        num=max(abs(x - x.T) - 1,0) ** 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:52
    else:
        num=abs(x - x.T) ** 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:54
    
    chisq=sum(sum(triu(num / (x + x.T),1)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:57
    pval=1 - chi2cdf(chisq,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/mcnemar_test.m:58
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,chisq,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} cor_test (@var{x}, @var{y}, @var{alt}, @var{method})
## Test whether two samples @var{x} and @var{y} come from uncorrelated
## populations.
##
## The optional argument string @var{alt} describes the alternative
## hypothesis, and can be @qcode{"!="} or @qcode{"<>"} (nonzero), @qcode{">"}
## (greater than 0), or @qcode{"<"} (less than 0).  The default is the
## two-sided case.
##
## The optional argument string @var{method} specifies which correlation
## coefficient to use for testing.  If @var{method} is @qcode{"pearson"}
## (default), the (usual) Pearson's produt moment correlation coefficient is
## used.  In this case, the data should come from a bivariate normal
## distribution.  Otherwise, the other two methods offer nonparametric
## alternatives.  If @var{method} is @qcode{"kendall"}, then Kendall's rank
## correlation tau is used.  If @var{method} is @qcode{"spearman"}, then
## Spearman's rank correlation rho is used.  Only the first character is
## necessary.
##
## The output is a structure with the following elements:
##
## @table @var
## @item pval
## The p-value of the test.
##
## @item stat
## The value of the test statistic.
##
## @item dist
## The distribution of the test statistic.
##
## @item params
## The parameters of the null distribution of the test statistic.
##
## @item alternative
## The alternative hypothesis.
##
## @item method
## The method used for testing.
## @end table
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
## Adapted-by: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test for zero correlation
    
    
@function
def cor_test(x=None,y=None,alt=None,method=None,*args,**kwargs):
    varargin = cor_test.varargin
    nargin = cor_test.nargin

    if (nargin < 2 or nargin > 4):
        print_usage()
    
    if (logical_not(isvector(x)) or logical_not(isvector(y)) or length(x) != length(y)):
        error('cor_test: X and Y must be vectors of the same length')
    
    if (nargin < 3):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:79
    else:
        if (logical_not(ischar(alt))):
            error('cor_test: ALT must be a string')
    
    if (nargin < 4):
        method='pearson'
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:85
    else:
        if (logical_not(ischar(method))):
            error('cor_test: METHOD must be a string')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:90
    m=method[1]
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:91
    if (m == 'p'):
        r=corr(x,y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:94
        df=n - 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:95
        t.method = copy('Pearson\'s product moment correlation')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:96
        t.params = copy(df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:97
        t.stat = copy(multiply(sqrt(df),r) / sqrt(1 - r ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:98
        t.dist = copy('t')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:99
        cdf=tcdf(t.stat,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:100
    else:
        if (m == 'k'):
            tau=kendall(x,y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:102
            t.method = copy('Kendall\'s rank correlation tau')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:103
            t.params = copy([])
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:104
            t.stat = copy(tau / sqrt((dot(2,(dot(2,n) + 5))) / (dot(dot(9,n),(n - 1)))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:105
            t.dist = copy('stdnormal')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:106
            cdf=stdnormal_cdf(t.stat)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:107
        else:
            if (m == 's'):
                rho=spearman(x,y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:109
                t.method = copy('Spearman\'s rank correlation rho')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:110
                t.params = copy([])
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:111
                t.stat = copy(dot(sqrt(n - 1),(rho - 6 / (n ** 3 - n))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:112
                t.dist = copy('stdnormal')
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:113
                cdf=stdnormal_cdf(t.stat)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:114
            else:
                error('cor_test: METHOD \'%s\' not recognized',method)
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        t.pval = copy(dot(2,min(cdf,1 - cdf)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:120
    else:
        if (strcmp(alt,'>')):
            t.pval = copy(1 - cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:122
        else:
            if (strcmp(alt,'<')):
                t.pval = copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:124
            else:
                error('cor_test: alternative \'%s\' not recognized',alt)
    
    t.alternative = copy(alt)
# /home/lei/octave-4.0.2/scripts/statistics/tests/cor_test.m:129
    if (nargout == 0):
        printf('pval: %g\n',t.pval)
    
    return t
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{t}, @var{df}] =} t_test_2 (@var{x}, @var{y}, @var{alt})
## For two samples x and y from normal distributions with unknown means and
## unknown equal variances, perform a two-sample t-test of the null
## hypothesis of equal means.
##
## Under the null, the test statistic @var{t} follows a Student distribution
## with @var{df} degrees of freedom.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative @code{mean (@var{x}) != mean
## (@var{y})}.  If @var{alt} is @qcode{">"}, the one-sided alternative
## @code{mean (@var{x}) > mean (@var{y})} is used.  Similarly for
## @qcode{"<"}, the one-sided alternative @code{mean (@var{x}) < mean
## (@var{y})} is used.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Student's two-sample t test
    
    
@function
def t_test_2(x=None,y=None,alt=None,*args,**kwargs):
    varargin = t_test_2.varargin
    nargin = t_test_2.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('t_test_2: both X and Y must be vectors')
    
    n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:54
    n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:55
    df=n_x + n_y - 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:56
    mu_x=sum(x) / n_x
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:57
    mu_y=sum(y) / n_y
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:58
    v=sumsq(x - mu_x) + sumsq(y - mu_y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:59
    t=dot((mu_x - mu_y),sqrt((dot(dot(n_x,n_y),df)) / (dot(v,(n_x + n_y)))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:60
    cdf=tcdf(t,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:61
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:64
    
    if (logical_not(ischar(alt))):
        error('t_test_2: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:71
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:73
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_2.m:75
            else:
                error('t_test_2: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,t,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{chisq}, @var{df}] =} bartlett_test (@var{x1}, @dots{})
## Perform a Bartlett test for the homogeneity of variances in the data
## vectors @var{x1}, @var{x2}, @dots{}, @var{xk}, where @var{k} > 1.
##
## Under the null of equal variances, the test statistic @var{chisq}
## approximately follows a chi-square distribution with @var{df} degrees of
## freedom.
##
## The p-value (1 minus the CDF of this distribution at @var{chisq}) is
## returned in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Bartlett test for homogeneity of variances
    
    
@function
def bartlett_test(varargin=None,*args,**kwargs):
    varargin = bartlett_test.varargin
    nargin = bartlett_test.nargin

    k=copy(nargin)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:39
    if (k < 2):
        print_usage()
    
    f=zeros(k,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:44
    v=zeros(k,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:45
    for i in arange(1,k).reshape(-1):
        x=varargin[i]
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:48
        if (logical_not(isvector(x))):
            error('bartlett_test: all arguments must be vectors')
        f[i]=length(x) - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:52
        v[i]=var(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:53
    
    f_tot=sum(f)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:56
    v_tot=sum(multiply(f,v)) / f_tot
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:57
    c=1 + (sum(1 / f) - 1 / f_tot) / (dot(3,(k - 1)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:58
    chisq=(dot(f_tot,log(v_tot)) - sum(multiply(f,log(v)))) / c
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:59
    df=copy(k)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:60
    pval=1 - chi2cdf(chisq,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/bartlett_test.m:61
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,chisq,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{tsq}] =} hotelling_test (@var{x}, @var{m})
## For a sample @var{x} from a multivariate normal distribution with unknown
## mean and covariance matrix, test the null hypothesis that
## @code{mean (@var{x}) == @var{m}}.
##
## Hotelling's @math{T^2} is returned in @var{tsq}.  Under the null,
## @math{(n-p) T^2 / (p(n-1))} has an F distribution with @math{p} and
## @math{n-p} degrees of freedom, where @math{n} and @math{p} are the
## numbers of samples and variables, respectively.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test for mean of a multivariate normal
    
    
@function
def hotelling_test(x=None,m=None,*args,**kwargs):
    varargin = hotelling_test.varargin
    nargin = hotelling_test.nargin

    if (nargin != 2):
        print_usage()
    
    if (isvector(x)):
        if (logical_not(isscalar(m))):
            error('hotelling_test: if X is a vector, M must be a scalar')
        n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:48
        p=1
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:49
    else:
        if (ismatrix(x)):
            n,p=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:51
            if (n <= p):
                error('hotelling_test: X must have more rows than columns')
            if (isvector(m) and length(m) == p):
                m=reshape(m,1,p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:56
            else:
                error('hotelling_test: if X is a matrix, M must be a vector of length columns (X)')
        else:
            error('hotelling_test: X must be a matrix or vector')
    
    d=mean(x) - m
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:64
    Tsq=dot(dot(n,d),(numpy.linalg.solve(cov(x),d.T)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:65
    pval=1 - fcdf(dot((n - p),Tsq) / (dot(p,(n - 1))),p,n - p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/hotelling_test.m:66
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,Tsq
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{k}, @var{df}] =} kruskal_wallis_test (@var{x1}, @dots{})
## Perform a @nospell{Kruskal-Wallis} one-factor analysis of variance.
##
## Suppose a variable is observed for @var{k} > 1 different groups, and let
## @var{x1}, @dots{}, @var{xk} be the corresponding data vectors.
##
## Under the null hypothesis that the ranks in the pooled sample are not
## affected by the group memberships, the test statistic @var{k} is
## approximately chi-square with @var{df} = @var{k} - 1 degrees of freedom.
##
## If the data contains ties (some value appears more than once)
## @var{k} is divided by
##
## 1 - @var{sum_ties} / (@var{n}^3 - @var{n})
##
## where @var{sum_ties} is the sum of @var{t}^2 - @var{t} over each group of
## ties where @var{t} is the number of ties in the group and @var{n} is the
## total number of values in the input data.  For more info on this
## adjustment see @nospell{William H. Kruskal and W. Allen Wallis},
## @cite{Use of Ranks in One-Criterion Variance Analysis},
## Journal of the American Statistical Association, Vol. 47, No. 260 (Dec 1952).
##
## The p-value (1 minus the CDF of this distribution at @var{k}) is returned
## in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Kruskal-Wallis test
    
    
@function
def kruskal_wallis_test(varargin=None,*args,**kwargs):
    varargin = kruskal_wallis_test.varargin
    nargin = kruskal_wallis_test.nargin

    m=copy(nargin)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:53
    if (m < 2):
        print_usage()
    
    n=matlabarray([])
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:58
    p=matlabarray([])
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:59
    for i in arange(1,m).reshape(-1):
        x=varargin[i]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:62
        if (logical_not(isvector(x))):
            error('kruskal_wallis_test: all arguments must be vectors')
        l=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:66
        n=matlabarray(cat(n,l))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:67
        p=matlabarray(cat(p,(reshape(x,1,l))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:68
    
    r=ranks(p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:71
    k=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:73
    j=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:74
    for i in arange(1,m).reshape(-1):
        k=k + (sum(r[(j + 1):(j + n[i])])) ** 2 / n[i]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:76
        j=j + n[i]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:77
    
    n=length(p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:80
    k=dot(12,k) / (dot(n,(n + 1))) - dot(3,(n + 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:81
    
    sum_ties=sum(polyval(cat(1,0,- 1,0),runlength(sort(p))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:84
    k=k / (1 - sum_ties / (n ** 3 - n))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:85
    df=m - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:87
    pval=1 - chi2cdf(k,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kruskal_wallis_test.m:88
    if (nargout == 0):
        printf('pval: %g\n',pval)
    
    return pval,k,df
    
if __name__ == '__main__':
    pass
    
    ## Test with ties
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{t}, @var{df}] =} t_test (@var{x}, @var{m}, @var{alt})
## For a sample @var{x} from a normal distribution with unknown mean and
## variance, perform a t-test of the null hypothesis
## @code{mean (@var{x}) == @var{m}}.
##
## Under the null, the test statistic @var{t} follows a Student distribution
## with @code{@var{df} = length (@var{x}) - 1} degrees of freedom.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative @code{mean (@var{x}) !=
## @var{m}}.  If @var{alt} is @qcode{">"}, the one-sided alternative
## @code{mean (@var{x}) > @var{m}} is considered.  Similarly for @var{"<"},
## the one-sided alternative @code{mean (@var{x}) < @var{m}} is considered.
## The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Student's one-sample t test
    
    
@function
def t_test(x=None,m=None,alt=None,*args,**kwargs):
    varargin = t_test.varargin
    nargin = t_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(isvector(x))):
        error('t_test: X must be a vector')
    
    if (logical_not(isscalar(m))):
        error('t_test: M must be a scalar')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:57
    df=n - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:58
    t=dot(sqrt(n),(sum(x) / n - m)) / std(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:59
    cdf=tcdf(t,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:60
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:63
    
    if (logical_not(ischar(alt))):
        error('t_test: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:70
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:72
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test.m:74
            else:
                error('t_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,t,df
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{z}] =} z_test (@var{x}, @var{m}, @var{v}, @var{alt})
## Perform a Z-test of the null hypothesis @code{mean (@var{x}) == @var{m}}
## for a sample @var{x} from a normal distribution with unknown mean and known
## variance @var{v}.
##
## Under the null, the test statistic @var{z} follows a standard normal
## distribution.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative
## @code{mean (@var{x}) != @var{m}}.  If @var{alt} is @qcode{">"}, the
## one-sided alternative @code{mean (@var{x}) > @var{m}} is considered.
## Similarly for @qcode{"<"}, the one-sided alternative
## @code{mean (@var{x}) < @var{m}} is considered.  The default is the two-sided
## case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed along
## with some information.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test for mean of a normal sample with known variance
    
    
@function
def z_test(x=None,m=None,v=None,alt=None,*args,**kwargs):
    varargin = z_test.varargin
    nargin = z_test.nargin

    if (nargin < 3 or nargin > 4):
        print_usage()
    
    if (logical_not(isvector(x))):
        error('z_test: X must be a vector')
    
    if (logical_not(isscalar(m))):
        error('z_test: M must be a scalar')
    
    if (logical_not((isscalar(v) and (v > 0)))):
        error('z_test: V must be a positive scalar')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:62
    z=dot(sqrt(n / v),(sum(x) / n - m))
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:63
    cdf=stdnormal_cdf(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:64
    if (nargin == 3):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:67
    
    if (logical_not(ischar(alt))):
        error('z_test: ALT must be a string')
    else:
        if (strcmp(alt,'!=') or strcmp(alt,'<>')):
            pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:73
        else:
            if (strcmp(alt,'>')):
                pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:75
            else:
                if (strcmp(alt,'<')):
                    pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:77
                else:
                    error('z_test: option %s not recognized',alt)
    
    if (nargout == 0):
        s=matlabarray(cat('Z-test of mean(x) == %g against mean(x) %s %g,\n','with known var(x) == %g:\n','  pval = %g\n'))
# /home/lei/octave-4.0.2/scripts/statistics/tests/z_test.m:83
        printf(s,m,alt,m,v,pval)
    
    return pval,z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{ks}, @var{d}] =} kolmogorov_smirnov_test_2 (@var{x}, @var{y}, @var{alt})
## Perform a 2-sample Kolmogorov-Smirnov test of the null hypothesis that the
## samples @var{x} and @var{y} come from the same (continuous) distribution.
##
## If F and G are the CDFs corresponding to the @var{x} and @var{y} samples,
## respectively, then the null is that F == G.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative F != G@.  In this case, the
## test statistic @var{ks} follows a two-sided Kolmogorov-Smirnov
## distribution.  If @var{alt} is @qcode{">"}, the one-sided alternative F >
## G is considered.  Similarly for @qcode{"<"}, the one-sided alternative F <
## G is considered.  In this case, the test statistic @var{ks} has a
## one-sided Kolmogorov-Smirnov distribution.  The default is the two-sided
## case.
##
## The p-value of the test is returned in @var{pval}.
##
## The third returned value, @var{d}, is the test statistic, the maximum
## vertical distance between the two cumulative distribution functions.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Two-sample Kolmogorov-Smirnov test
    
    
@function
def kolmogorov_smirnov_test_2(x=None,y=None,alt=None,*args,**kwargs):
    varargin = kolmogorov_smirnov_test_2.varargin
    nargin = kolmogorov_smirnov_test_2.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('kolmogorov_smirnov_test_2: both X and Y must be vectors')
    
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:59
    else:
        if (logical_not(ischar(alt))):
            error('kolmogorov_smirnov_test_2: ALT must be a string')
    
    n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:66
    n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:67
    n=dot(n_x,n_y) / (n_x + n_y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:68
    x=reshape(x,n_x,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:69
    y=reshape(y,n_y,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:70
    s,i=sort(cat([x],[y]),nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:71
    count[find(i <= n_x)]=1 / n_x
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:72
    count[find(i > n_x)]=- 1 / n_y
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:73
    z=cumsum(count)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:75
    ds=diff(s)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:76
    if (any(ds == 0)):
        ## There are some ties, so keep only those changes.
        warning('cannot compute correct p-values with ties')
        elems=matlabarray(cat([find(ds)],[n_x + n_y]))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:80
        z=z[elems]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:81
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        d=max(abs(z))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:85
        ks=dot(sqrt(n),d)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:86
        pval=1 - kolmogorov_smirnov_cdf(ks)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:87
    else:
        if (strcmp(alt,'>')):
            d=max(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:89
            ks=dot(sqrt(n),d)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:90
            pval=exp(dot(- 2,ks ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:91
        else:
            if (strcmp(alt,'<')):
                d=min(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:93
                ks=dot(- sqrt(n),d)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:94
                pval=exp(dot(- 2,ks ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test_2.m:95
            else:
                error('kolmogorov_smirnov_test_2: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,ks,d
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{z}] =} prop_test_2 (@var{x1}, @var{n1}, @var{x2}, @var{n2}, @var{alt})
## If @var{x1} and @var{n1} are the counts of successes and trials in one
## sample, and @var{x2} and @var{n2} those in a second one, test the null
## hypothesis that the success probabilities @var{p1} and @var{p2} are the
## same.
##
## Under the null, the test statistic @var{z} approximately follows a
## standard normal distribution.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative @var{p1} != @var{p2}.  If
## @var{alt} is @qcode{">"}, the one-sided alternative @var{p1} > @var{p2} is
## used.  Similarly for @qcode{"<"}, the one-sided alternative
## @var{p1} < @var{p2} is used.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Compare two proportions
    
    
@function
def prop_test_2(x1=None,n1=None,x2=None,n2=None,alt=None,*args,**kwargs):
    varargin = prop_test_2.varargin
    nargin = prop_test_2.nargin

    if (nargin < 4 or nargin > 5):
        print_usage()
    
    ## Could do sanity checking on x1, n1, x2, n2 here
    
    p1=x1 / n1
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:52
    p2=x2 / n2
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:53
    pc=(x1 + x2) / (n1 + n2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:54
    z=(p1 - p2) / sqrt(dot(dot(pc,(1 - pc)),(1 / n1 + 1 / n2)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:56
    cdf=stdnormal_cdf(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:58
    if (nargin == 4):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:61
    
    if (logical_not(ischar(alt))):
        error('prop_test_2: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:68
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:70
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/prop_test_2.m:72
            else:
                error('prop_test_2: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,z
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{t}, @var{df}] =} t_test_regression (@var{y}, @var{x}, @var{rr}, @var{r}, @var{alt})
## Perform a t test for the null hypothesis
## @nospell{@code{@var{rr} * @var{b} = @var{r}}} in a classical normal
## regression model @code{@var{y} = @var{x} * @var{b} + @var{e}}.
##
## Under the null, the test statistic @var{t} follows a @var{t} distribution
## with @var{df} degrees of freedom.
##
## If @var{r} is omitted, a value of 0 is assumed.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative @nospell{@code{@var{rr} *
## @var{b} != @var{r}}}.  If @var{alt} is @qcode{">"}, the one-sided
## alternative @nospell{@code{@var{rr} * @var{b} > @var{r}}} is used.
## Similarly for @var{"<"}, the one-sided alternative @nospell{@code{@var{rr}
## * @var{b} < @var{r}}} is used.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Test one linear hypothesis in linear regression model
    
    
@function
def t_test_regression(y=None,x=None,rr=None,r=None,alt=None,*args,**kwargs):
    varargin = t_test_regression.varargin
    nargin = t_test_regression.nargin

    if (nargin == 3):
        r=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:49
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:50
    else:
        if (nargin == 4):
            if (ischar(r)):
                alt=copy(r)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:53
                r=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:54
            else:
                alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:56
        else:
            if (logical_not((nargin == 5))):
                print_usage()
    
    if (logical_not(isscalar(r))):
        error('t_test_regression: R must be a scalar')
    else:
        if (logical_not(ischar(alt))):
            error('t_test_regression: ALT must be a string')
    
    T,k=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:68
    if (logical_not((isvector(y) and (length(y) == T)))):
        error('t_test_regression: Y must be a vector of length rows (X)')
    
    s=size(rr)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:72
    if (logical_not(((max(s) == k) and (min(s) == 1)))):
        error('t_test_regression: RR must be a vector of length columns (X)')
    
    rr=reshape(rr,1,k)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:77
    y=reshape(y,T,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:78
    b,v=ols(y,x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:79
    df=T - k
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:80
    t=(dot(rr,b) - r) / sqrt(dot(dot(dot(v,rr),inv(dot(x.T,x))),rr.T))
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:81
    cdf=tcdf(t,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:82
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:85
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:87
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/t_test_regression.m:89
            else:
                error('t_test_regression: the value \'%s\' for alt is not possible',alt)
    
    if (nargout == 0):
        printf('pval: %g\n',pval)
    
    return pval,t,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{z}] =} u_test (@var{x}, @var{y}, @var{alt})
## For two samples @var{x} and @var{y}, perform a Mann-Whitney U-test of
## the null hypothesis
## PROB (@var{x} > @var{y}) == 1/2 == PROB (@var{x} < @var{y}).
##
## Under the null, the test statistic @var{z} approximately follows a
## standard normal distribution.  Note that this test is equivalent to the
## Wilcoxon rank-sum test.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative
## PROB (@var{x} > @var{y}) != 1/2.  If @var{alt} is @qcode{">"}, the one-sided
## alternative PROB (@var{x} > @var{y}) > 1/2 is considered.  Similarly for
## @qcode{"<"}, the one-sided alternative PROB (@var{x} > @var{y}) < 1/2 is
## considered.  The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## This implementation is still incomplete---for small sample sizes,
## the normal approximation is rather bad ...
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Mann-Whitney U-test
    
    
@function
def u_test(x=None,y=None,alt=None,*args,**kwargs):
    varargin = u_test.varargin
    nargin = u_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('u_test: both X and Y must be vectors')
    
    n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:58
    n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:59
    r=ranks(cat((reshape(x,1,n_x)),(reshape(y,1,n_y))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:60
    z=(sum(r[1:n_x]) - dot(n_x,(n_x + n_y + 1)) / 2) / sqrt(dot(dot(n_x,n_y),(n_x + n_y + 1)) / 12)
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:61
    cdf=stdnormal_cdf(z)
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:64
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:67
    
    if (logical_not(ischar(alt))):
        error('u_test: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:74
    else:
        if (strcmp(alt,'>')):
            pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:76
        else:
            if (strcmp(alt,'<')):
                pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/u_test.m:78
            else:
                error('u_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,z
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{ks}] =} kolmogorov_smirnov_test (@var{x}, @var{dist}, @var{params}, @var{alt})
## Perform a Kolmogorov-Smirnov test of the null hypothesis that the
## sample @var{x} comes from the (continuous) distribution @var{dist}.
##
## if F and G are the CDFs corresponding to the sample and dist,
## respectively, then the null is that F == G.
##
## The optional argument @var{params} contains a list of parameters of
## @var{dist}.  For example, to test whether a sample @var{x} comes from
## a uniform distribution on [2,4], use
##
## @example
## kolmogorov_smirnov_test (x, "unif", 2, 4)
## @end example
##
## @noindent
## @var{dist} can be any string for which a function @var{distcdf}
## that calculates the CDF of distribution @var{dist} exists.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative F != G@.  In this case, the
## test statistic @var{ks} follows a two-sided Kolmogorov-Smirnov
## distribution.  If @var{alt} is @qcode{">"}, the one-sided alternative F >
## G is considered.  Similarly for @qcode{"<"}, the one-sided alternative F >
## G is considered.  In this case, the test statistic @var{ks} has a
## one-sided Kolmogorov-Smirnov distribution.  The default is the two-sided
## case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: One-sample Kolmogorov-Smirnov test
    
    
@function
def kolmogorov_smirnov_test(x=None,dist=None,varargin=None,*args,**kwargs):
    varargin = kolmogorov_smirnov_test.varargin
    nargin = kolmogorov_smirnov_test.nargin

    if (nargin < 2):
        print_usage()
    
    if (logical_not(isvector(x))):
        error('kolmogorov_smirnov_test: X must be a vector')
    
    n=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:67
    s=sort(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:68
    try:
        f=str2func(sprintf('%scdf',dist))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:70
    finally:
        pass
    
    alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:80
    args[1]=s
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:82
    nvargs=numel(varargin)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:83
    if (nvargs > 0):
        if (ischar(varargin[end()])):
            alt=varargin[end()]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:86
            args[2:nvargs]=varargin[1:end() - 1]
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:87
        else:
            args[2:nvargs + 1]=varargin
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:89
    
    z=reshape(feval(f,args[:]),1,n)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:93
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        ks=dot(sqrt(n),max(max(cat([abs(z - (arange(0,(n - 1))) / n)],[abs(z - (arange(1,n)) / n)]))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:96
        pval=1 - kolmogorov_smirnov_cdf(ks)
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:97
    else:
        if (strcmp(alt,'>')):
            ks=dot(sqrt(n),max(max(cat([z - (arange(0,(n - 1))) / n],[z - (arange(1,n)) / n]))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:99
            pval=exp(dot(- 2,ks ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:100
        else:
            if (strcmp(alt,'<')):
                ks=dot(- sqrt(n),min(min(cat([z - (arange(0,(n - 1))) / n],[z - (arange(1,n)) / n]))))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:102
                pval=exp(dot(- 2,ks ** 2))
# /home/lei/octave-4.0.2/scripts/statistics/tests/kolmogorov_smirnov_test.m:103
            else:
                error('kolmogorov_smirnov_test: alternative %s not recognized',alt)
    
    if (nargout == 0):
        printf('pval: %g\n',pval)
    
    return pval,ks
    
if __name__ == '__main__':
    pass
    
    ## test for recognition of unifcdf function
    
    ## test for recognition of logistic_cdf function
    
    ## test for  F < G
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{t}, @var{df}] =} welch_test (@var{x}, @var{y}, @var{alt})
## For two samples @var{x} and @var{y} from normal distributions with
## unknown means and unknown and not necessarily equal variances,
## perform a Welch test of the null hypothesis of equal means.
##
## Under the null, the test statistic @var{t} approximately follows a
## Student distribution with @var{df} degrees of freedom.
##
## With the optional argument string @var{alt}, the alternative of interest
## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
## is tested against the two-sided alternative
## @code{mean (@var{x}) != @var{m}}.  If @var{alt} is @qcode{">"}, the
## one-sided alternative mean(x) > @var{m} is considered.  Similarly for
## @qcode{"<"}, the one-sided alternative mean(x) < @var{m} is considered.
## The default is the two-sided case.
##
## The p-value of the test is returned in @var{pval}.
##
## If no output argument is given, the p-value of the test is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Welch two-sample t test
    
    
@function
def welch_test(x=None,y=None,alt=None,*args,**kwargs):
    varargin = welch_test.varargin
    nargin = welch_test.nargin

    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y)))):
        error('welch_test: both X and Y must be vectors')
    
    n_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:54
    n_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:55
    mu_x=sum(x) / n_x
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:56
    mu_y=sum(y) / n_y
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:57
    v_x=sumsq(x - mu_x) / (dot(n_x,(n_x - 1)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:58
    v_y=sumsq(y - mu_y) / (dot(n_y,(n_y - 1)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:59
    c=v_x / (v_x + v_y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:60
    df=1 / (c ** 2 / (n_x - 1) + (1 - c) ** 2 / (n_y - 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:61
    t=(mu_x - mu_y) / sqrt(v_x + v_y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:62
    cdf=tcdf(t,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:63
    if (nargin == 2):
        alt='!='
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:66
    
    if (logical_not(ischar(alt))):
        error('welch_test: ALT must be a string')
    
    if (strcmp(alt,'!=') or strcmp(alt,'<>')):
        pval=dot(2,min(cdf,1 - cdf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:73
    else:
        if (strcmp(alt,'>')):
            pval=1 - cdf
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:75
        else:
            if (strcmp(alt,'<')):
                pval=copy(cdf)
# /home/lei/octave-4.0.2/scripts/statistics/tests/welch_test.m:77
            else:
                error('welch_test: option %s not recognized',alt)
    
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,t,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pval}, @var{chisq}, @var{df}] =} chisquare_test_homogeneity (@var{x}, @var{y}, @var{c})
## Given two samples @var{x} and @var{y}, perform a chisquare test for
## homogeneity of the null hypothesis that @var{x} and @var{y} come from
## the same distribution, based on the partition induced by the
## (strictly increasing) entries of @var{c}.
##
## For large samples, the test statistic @var{chisq} approximately follows a
## chisquare distribution with @var{df} = @code{length (@var{c})} degrees of
## freedom.
##
## The p-value (1 minus the CDF of this distribution at @var{chisq}) is
## returned in @var{pval}.
##
## If no output argument is given, the p-value is displayed.
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Chi-square test for homogeneity
    
    
@function
def chisquare_test_homogeneity(x=None,y=None,c=None,*args,**kwargs):
    varargin = chisquare_test_homogeneity.varargin
    nargin = chisquare_test_homogeneity.nargin

    if (nargin != 3):
        print_usage()
    
    if (logical_not((isvector(x) and isvector(y) and isvector(c)))):
        error('chisquare_test_homogeneity: X, Y and C must be vectors')
    
    ## Now test c for strictly increasing entries
    df=length(c)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:49
    if (any((c[2:df] - c[1:(df - 1)]) <= 0)):
        error('chisquare_test_homogeneity: C must be increasing')
    
    c=matlabarray(cat((reshape(c,1,df)),Inf))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:54
    l_x=length(x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:55
    x=reshape(x,l_x,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:56
    n_x=sum(dot(x,ones(1,df + 1)) < dot(ones(l_x,1),c))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:57
    l_y=length(y)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:58
    y=reshape(y,l_y,1)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:59
    n_y=sum(dot(y,ones(1,df + 1)) < dot(ones(l_y,1),c))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:60
    chisq=dot(dot(l_x,l_y),sum((n_x / l_x - n_y / l_y) ** 2 / (n_x + n_y)))
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:61
    pval=1 - chi2cdf(chisq,df)
# /home/lei/octave-4.0.2/scripts/statistics/tests/chisquare_test_homogeneity.m:62
    if (nargout == 0):
        printf('  pval: %g\n',pval)
    
    return pval,chisq,df
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1996-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} manova (@var{x}, @var{g})
## Perform a one-way multivariate analysis of variance (MANOVA).
##
## The goal is to test whether the p-dimensional population means of data
## taken from @var{k} different groups are all equal.  All data are assumed
## drawn independently from p-dimensional normal distributions with the same
## covariance matrix.
##
## The data matrix is given by @var{x}.  As usual, rows are observations and
## columns are variables.  The vector @var{g} specifies the corresponding
## group labels (e.g., numbers from 1 to @var{k}).
##
## The LR test statistic (@nospell{Wilks' Lambda}) and approximate p-values are
## computed and displayed.
## @seealso{anova}
## @end deftypefn
    
    ## The Hotelling-Lawley and Pillai-Bartlett test statistics are coded.
## However, they are currently disabled until they can be verified by someone
## with sufficient understanding of the algorithms.  Please feel free to
## improve this.
    
    ## Author: TF <Thomas.Fuereder@ci.tuwien.ac.at>
## Adapted-By: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: One-way multivariate analysis of variance (MANOVA)
    
    
@function
def manova(x=None,g=None,*args,**kwargs):
    varargin = manova.varargin
    nargin = manova.nargin

    if (nargin != 2):
        print_usage()
    
    if (isvector(x)):
        error('manova: X must not be a vector')
    
    n,p=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:56
    if (logical_not(isvector(g)) or (length(g) != n)):
        error('manova: G must be a vector of length rows (X)')
    
    s=sort(g)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:62
    i=find(s[2:n] > s[1:(n - 1)])
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:63
    k=length(i) + 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:64
    if (k == 1):
        error('manova: there should be at least 2 groups')
    else:
        group_label=s[cat(1,(reshape(i,1,k - 1) + 1))]
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:69
    
    x=x - dot(ones(n,1),mean(x))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:72
    SST=dot(x.T,x)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:73
    s=zeros(1,p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:75
    SSB=zeros(p,p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:76
    for i in arange(1,k).reshape(-1):
        v=x[find(g == group_label[i]),:]
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:78
        s=sum(v)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:79
        SSB=SSB + dot(s.T,s) / rows(v)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:80
    
    n_b=k - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:82
    SSW=SST - SSB
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:84
    n_w=n - k
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:85
    l=real(eig(SSB / SSW))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:87
    if (isa(l,'single')):
        l[l < eps('single')]=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:90
    else:
        l[l < eps]=0
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:92
    
    ## Wilks' Lambda
  ## =============
    
    Lambda=prod(1 / (1 + l))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:98
    delta=n_w + n_b - (p + n_b + 1) / 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:100
    df_num=dot(p,n_b)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:101
    W_pval_1=1 - chi2cdf(dot(- delta,log(Lambda)),df_num)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:102
    if (p < 3):
        eta=copy(p)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:105
    else:
        eta=sqrt((dot(p ** 2,n_b ** 2) - 4) / (p ** 2 + n_b ** 2 - 5))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:107
    
    df_den=dot(delta,eta) - df_num / 2 + 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:110
    WT=exp(- log(Lambda) / eta) - 1
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:112
    W_pval_2=1 - fcdf(dot(WT,df_den) / df_num,df_num,df_den)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:113
    if (0):
        ## Hotelling-Lawley Test
    ## =====================
        HL=sum(l)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:120
        theta=min(p,n_b)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:122
        u=(abs(p - n_b) - 1) / 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:123
        v=(n_w - p - 1) / 2
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:124
        df_num=dot(theta,(dot(2,u) + theta + 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:126
        df_den=dot(2,(dot(theta,v) + 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:127
        HL_pval=1 - fcdf(dot(HL,df_den) / df_num,df_num,df_den)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:129
        ## ===============
        PB=sum(l / (1 + l))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:134
        df_den=dot(theta,(dot(2,v) + theta + 1))
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:136
        PB_pval=1 - fcdf(dot(PB,df_den) / df_num,df_num,df_den)
# /home/lei/octave-4.0.2/scripts/statistics/tests/manova.m:137
        printf('\n')
        printf('One-way MANOVA Table:\n')
        printf('\n')
        printf('Test             Test Statistic      Approximate p\n')
        printf('**************************************************\n')
        printf('Wilks            %10.4f           %10.9f \n',Lambda,W_pval_1)
        printf('                                      %10.9f \n',W_pval_2)
        printf('Hotelling-Lawley %10.4f           %10.9f \n',HL,HL_pval)
        printf('Pillai-Bartlett  %10.4f           %10.9f \n',PB,PB_pval)
        printf('\n')
    
    printf('\n')
    printf('MANOVA Results:\n')
    printf('\n')
    printf('# of groups:    %d\n',k)
    printf('# of samples:   %d\n',n)
    printf('# of variables: %d\n',p)
    printf('\n')
    printf('Wilks\' Lambda:  %5.4f\n',Lambda)
    printf('Approximate p:  %10.9f (chisquare approximation)\n',W_pval_1)
    printf('                 %10.9f (F approximation)\n',W_pval_2)
    printf('\n')
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{g}, @var{g1}, @var{p}, @var{dev}] =} logistic_regression_likelihood (@var{y}, @var{x}, @var{beta}, @var{z}, @var{z1})
## Calculate the likelihood for the ordinal logistic regression model.
##
## Private function called by @code{logistic_regression}.
## @seealso{logistic_regression}
## @end deftypefn
    
    ## Author: Gordon K. Smyth <gks@maths.uq.oz.au>
## Adapted-By: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Likelihood in logistic regression
    
    
@function
def logistic_regression_likelihood(y=None,x=None,beta=None,z=None,z1=None,*args,**kwargs):
    varargin = logistic_regression_likelihood.varargin
    nargin = logistic_regression_likelihood.nargin

    e=exp(dot(cat(z,x),beta))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:33
    e1=exp(dot(cat(z1,x),beta))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:33
    g=e / (1 + e)
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:34
    g1=e1 / (1 + e1)
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:34
    g=max(y == max(y),g)
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:35
    g1=min(y > min(y),g1)
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:35
    p=g - g1
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:37
    dev=dot(- 2,sum(log(p)))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_likelihood.m:38
    return g,g1,p,dev
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{dl}, @var{d2l}] =} logistic_regression_derivatives (@var{x}, @var{z}, @var{z1}, @var{g}, @var{g1}, @var{p})
## Calculate derivatives of the log-likelihood for ordinal logistic regression
## model.
##
## Private function called by @code{logistic_regression}.
## @seealso{logistic_regression}
## @end deftypefn
    
    ## Author: Gordon K. Smyth <gks@maths.uq.oz.au>
## Adapted-By: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Derivates of log-likelihood in logistic regression
    
    
@function
def logistic_regression_derivatives(x=None,z=None,z1=None,g=None,g1=None,p=None,*args,**kwargs):
    varargin = logistic_regression_derivatives.varargin
    nargin = logistic_regression_derivatives.nargin

    ## first derivative
    v=multiply(g,(1 - g)) / p
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:35
    v1=multiply(g1,(1 - g1)) / p
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:35
    dlogp=matlabarray(cat((dot(diag(v),z) - dot(diag(v1),z1)),(dot(diag(v - v1),x))))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:36
    dl=sum(dlogp).T
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:37
    
    w=multiply(v,(1 - dot(2,g)))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:40
    w1=multiply(v1,(1 - dot(2,g1)))
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:40
    d2l=dot(dot(cat(z,x).T,diag(w)),cat(z,x)) - dot(dot(cat(z1,x).T,diag(w1)),cat(z1,x)) - dot(dlogp.T,dlogp)
# /home/lei/octave-4.0.2/scripts/statistics/models/private/logistic_regression_derivatives.m:41
    return dl,d2l
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{theta}, @var{beta}, @var{dev}, @var{dl}, @var{d2l}, @var{p}] =} logistic_regression (@var{y}, @var{x}, @var{print}, @var{theta}, @var{beta})
## Perform ordinal logistic regression.
##
## Suppose @var{y} takes values in @var{k} ordered categories, and let
## @code{gamma_i (@var{x})} be the cumulative probability that @var{y}
## falls in one of the first @var{i} categories given the covariate
## @var{x}.  Then
##
## @example
## [theta, beta] = logistic_regression (y, x)
## @end example
##
## @noindent
## fits the model
##
## @example
## logit (gamma_i (x)) = theta_i - beta' * x,   i = 1 @dots{} k-1
## @end example
##
## The number of ordinal categories, @var{k}, is taken to be the number
## of distinct values of @code{round (@var{y})}.  If @var{k} equals 2,
## @var{y} is binary and the model is ordinary logistic regression.  The
## matrix @var{x} is assumed to have full column rank.
##
## Given @var{y} only, @code{theta = logistic_regression (y)}
## fits the model with baseline logit odds only.
##
## The full form is
##
## @example
## @group
## [theta, beta, dev, dl, d2l, gamma]
##    = logistic_regression (y, x, print, theta, beta)
## @end group
## @end example
##
## @noindent
## in which all output arguments and all input arguments except @var{y}
## are optional.
##
## Setting @var{print} to 1 requests summary information about the fitted
## model to be displayed.  Setting @var{print} to 2 requests information
## about convergence at each iteration.  Other values request no
## information to be displayed.  The input arguments @var{theta} and
## @var{beta} give initial estimates for @var{theta} and @var{beta}.
##
## The returned value @var{dev} holds minus twice the log-likelihood.
##
## The returned values @var{dl} and @var{d2l} are the vector of first
## and the matrix of second derivatives of the log-likelihood with
## respect to @var{theta} and @var{beta}.
##
## @var{p} holds estimates for the conditional distribution of @var{y}
## given @var{x}.
## @end deftypefn
    
    ## Original for MATLAB written by Gordon K Smyth <gks@maths.uq.oz.au>,
## U of Queensland, Australia, on Nov 19, 1990.  Last revision Aug 3,
## 1992.
    
    ## Author: Gordon K Smyth <gks@maths.uq.oz.au>,
## Adapted-By: KH <Kurt.Hornik@wu-wien.ac.at>
## Description: Ordinal logistic regression
    
    ## Uses the auxiliary functions logistic_regression_derivatives and
## logistic_regression_likelihood.
    
    
@function
def logistic_regression(y=None,x=None,print_=None,theta=None,beta=None,*args,**kwargs):
    varargin = logistic_regression.varargin
    nargin = logistic_regression.nargin

    ## check input
    y=round(vec(y))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:90
    my,ny=size(y,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:91
    if (nargin < 2):
        x=zeros(my,0)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:93
    
    mx,nx=size(x,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:95
    if (mx != my):
        error('logistic_regression: X and Y must have the same number of observations')
    
    ## initial calculations
    x=- x
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:101
    tol=1e-06
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:102
    incr=10
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:102
    decr=2
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:102
    ymin=min(y)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:103
    ymax=max(y)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:103
    yrange=ymax - ymin
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:103
    z=(dot(y,ones(1,yrange))) == (dot((dot(y,0) + 1),(arange(ymin,(ymax - 1)))))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:104
    z1=(dot(y,ones(1,yrange))) == (dot((dot(y,0) + 1),(arange((ymin + 1),ymax))))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:105
    z=z[:,any(z)]
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:106
    z1=z1[:,any(z1)]
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:107
    mz,nz=size(z,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:108
    
    if (nargin < 3):
        print_=0
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:112
    
    if (nargin < 4):
        beta=zeros(nx,1)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:115
    
    if (nargin < 5):
        g=cumsum(sum(z)).T / my
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:118
        theta=log(g / (1 - g))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:119
    
    tb=matlabarray(cat([theta],[beta]))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:121
    
    g,g1,p,dev=logistic_regression_likelihood(y,x,tb,z,z1,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:124
    dl,d2l=logistic_regression_derivatives(x,z,z1,g,g1,p,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:125
    epsilon=std(vec(d2l)) / 1000
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:126
    
    iter=0
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:129
    while (abs(dot(dl.T,(numpy.linalg.solve(d2l,dl))) / length(dl)) > tol):

        iter=iter + 1
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:131
        tbold=copy(tb)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:132
        devold=copy(dev)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:133
        tb=tbold - numpy.linalg.solve(d2l,dl)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:134
        g,g1,p,dev=logistic_regression_likelihood(y,x,tb,z,z1,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:135
        if ((dev - devold) / (dot(dl.T,(tb - tbold))) < 0):
            epsilon=epsilon / decr
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:137
        else:
            while ((dev - devold) / (dot(dl.T,(tb - tbold))) > 0):

                epsilon=dot(epsilon,incr)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:140
                if (epsilon > 1e+15):
                    error('logistic_regression: epsilon too large')
                tb=tbold - numpy.linalg.solve((d2l - dot(epsilon,eye(size(d2l)))),dl)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:144
                g,g1,p,dev=logistic_regression_likelihood(y,x,tb,z,z1,nargout=4)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:145
                disp('epsilon')
                disp(epsilon)

        dl,d2l=logistic_regression_derivatives(x,z,z1,g,g1,p,nargout=2)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:149
        if (print_ == 2):
            disp('Iteration')
            disp(iter)
            disp('Deviance')
            disp(dev)
            disp('First derivative')
            disp(dl.T)
            disp('Eigenvalues of second derivative')
            disp(eig(d2l).T)

    
    ## tidy up output
    
    theta=tb[1:nz,1]
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:160
    beta=tb[(nz + 1):(nz + nx),1]
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:161
    if (print_ >= 1):
        printf('\n')
        printf('Logistic Regression Results:\n')
        printf('\n')
        printf('Number of Iterations: %d\n',iter)
        printf('Deviance:             %f\n',dev)
        printf('Parameter Estimates:\n')
        printf('     Theta         S.E.\n')
        se=sqrt(diag(inv(- d2l)))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:171
        for i in arange(1,nz).reshape(-1):
            printf('   %8.4f     %8.4f\n',tb[i],se[i])
        if (nx > 0):
            printf('      Beta         S.E.\n')
            for i in arange((nz + 1),(nz + nx)).reshape(-1):
                printf('   %8.4f     %8.4f\n',tb[i],se[i])
    
    if (nargout == 6):
        if (nx > 0):
            e=(dot((dot(x,beta)),ones(1,nz))) + (dot((dot(y,0) + 1),theta.T))
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:185
        else:
            e=dot((dot(y,0) + 1),theta.T)
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:187
        gamma=diff(cat((dot(y,0)),(exp(e) / (1 + exp(e))),(dot(y,0) + 1)).T).T
# /home/lei/octave-4.0.2/scripts/statistics/models/logistic_regression.m:189
    
    return theta,beta,dev,dl,d2l,p
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javaaddpath (@var{clspath})
## @deftypefnx {Function File} {} javaaddpath (@var{clspath1}, @dots{})
## Add @var{clspath} to the dynamic class path of the Java virtual machine.
##
## @var{clspath} may either be a directory where @file{.class} files are
## found, or a @file{.jar} file containing Java classes.  Multiple paths may
## be added at once by specifying additional arguments.
## @seealso{javarmpath, javaclasspath}
## @end deftypefn
    
    
@function
def javaaddpath(varargin=None,*args,**kwargs):
    varargin = javaaddpath.varargin
    nargin = javaaddpath.nargin

    if (nargin < 1):
        print_usage()
    
    for i in arange(1,numel(varargin)).reshape(-1):
        clspath=varargin[i]
# /home/lei/octave-4.0.2/scripts/java/javaaddpath.m:38
        if (logical_not(ischar(clspath))):
            error('javaaddpath: CLSPATH must be a string')
        new_path=canonicalize_file_name(tilde_expand(clspath))
# /home/lei/octave-4.0.2/scripts/java/javaaddpath.m:43
        if (exist(new_path,'dir')):
            if (new_path[end()] != filesep()):
                new_path=matlabarray(cat(new_path,filesep()))
# /home/lei/octave-4.0.2/scripts/java/javaaddpath.m:46
        else:
            if (logical_not(exist(new_path,'file'))):
                error('javaaddpath: CLSPATH does not exist: %s',clspath)
        success=javaMethod('addClassPath','org.octave.ClassHelper',new_path)
# /home/lei/octave-4.0.2/scripts/java/javaaddpath.m:52
        if (logical_not(success)):
            warning('javaaddpath: failed to add \'%s\' to Java classpath',new_path)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2010, 2013 Philip Nienhuis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javamem ()
## @deftypefnx {Function File} {@var{jmem} =} javamem ()
## Show the current memory usage of the Java virtual machine (JVM) and run the
## garbage collector.
##
## When no return argument is given the info is printed to the screen.
## Otherwise, the output cell array @var{jmem} contains Maximum, Total, and
## Free memory (in bytes).
##
## All Java-based routines are run in the JVM's shared memory pool, a
## dedicated and separate part of memory claimed by the JVM from your
## computer's total memory (which comprises physical RAM and virtual memory /
## swap space on hard disk).
##
## The maximum allowable memory usage can be configured using the file
## @file{java.opts}.  The directory where this file resides is determined by
## the environment variable @w{@env{OCTAVE_JAVA_DIR}}.  If unset, the directory
## where @file{javaaddpath.m} resides is used instead (typically
## @file{@w{@env{OCTAVE_HOME}}/share/octave/@w{@env{OCTAVE_VERSION}}/m/java/}).
##
## @file{java.opts} is a plain text file with one option per line.  The default
## initial memory size and default maximum memory size (which are both system
## dependent) can be overridden like so:
##
## @nospell{-Xms64m}
##
## @nospell{-Xmx512m}
##
## (in megabytes in this example).
## You can adapt these values to your own requirements if your system has
## limited available physical memory or if you get Java memory errors.
##
## @qcode{"Total memory"} is what the operating system has currently assigned
## to the JVM and depends on actual and active memory usage.
## @qcode{"Free memory"} is self-explanatory.  During operation of Java-based
## Octave functions the amount of Total and Free memory will vary, due to
## Java's own cleaning up and your operating system's memory management.
## @end deftypefn
    
    ## Author: Philip Nienhuis
## Created: 2010-03-25
## Updates:
## 2010-03-26 Changed name to javamem & indentation to double spaces
## 2010-08-25 Corrected text on java memory assignments
## 2010-09-05 Further overhauled help text
    
    
@function
def javamem(*args,**kwargs):
    varargin = javamem.varargin
    nargin = javamem.nargin

    rt=javaMethod('getRuntime','java.lang.Runtime')
# /home/lei/octave-4.0.2/scripts/java/javamem.m:68
    rt.gc
    jvmem=cell(3,1)
# /home/lei/octave-4.0.2/scripts/java/javamem.m:70
    jvmem[1]=rt.maxMemory()
# /home/lei/octave-4.0.2/scripts/java/javamem.m:71
    jvmem[2]=rt.totalMemory()
# /home/lei/octave-4.0.2/scripts/java/javamem.m:72
    jvmem[3]=rt.freeMemory()
# /home/lei/octave-4.0.2/scripts/java/javamem.m:73
    if (nargout == 0):
        printf('\nJava virtual machine (JVM) memory info:\n')
        printf('Maximum available memory:        %5d MiB;\n',jvmem[1] / 1024 / 1024)
        printf('   (...running garbage collector...)\n')
        printf('OK, current status:\n')
        printf('Total memory in virtual machine: %5d MiB;\n',jvmem[2] / 1024 / 1024)
        printf('Free memory in virtual machine:  %5d MiB;\n',jvmem[3] / 1024 / 1024)
        printf('%d CPUs available.\n',rt.availableProcessors())
    else:
        jmem=copy(jvmem)
# /home/lei/octave-4.0.2/scripts/java/javamem.m:87
    
    return jmem
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Philip Nienhuis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javachk (@var{feature})
## @deftypefnx {Function File} {} javachk (@var{feature}, @var{component})
## @deftypefnx {Function File} {@var{msg} =} javachk (@dots{})
## Check for the presence of the Java @var{feature} in the current session
## and print or return an error message if it is not.
##
## Possible features are:
##
## @table @asis
## @item @qcode{"awt"}
## Abstract Window Toolkit for GUIs.
##
## @item @qcode{"desktop"}
## Interactive desktop is running.
##
## @item @qcode{"jvm"}
## Java Virtual Machine.
##
## @item @qcode{"swing"}
## Swing components for lightweight GUIs.
## @end table
##
## If @var{feature} is supported and
##
## @itemize @bullet
## @item
## no output argument is requested:
##
## Return an empty string
##
## @item
## an output argument is requested:
##
## Return a struct with fields @qcode{"feature"} and @qcode{"identifier"}
## both empty
## @end itemize
##
## If @var{feature} is not supported and
##
## @itemize @bullet
## @item
## no output argument is requested:
##
## Emit an error message
##
## @item
## an output argument is requested:
##
## Return a struct with field @qcode{"feature"} set to @var{feature} and field
## @qcode{"identifier"} set to @var{component}
## @end itemize
##
## The optional input @var{component} will be used in place of @var{feature}
## in any error messages for greater specificity.
##
## @code{javachk} determines if specific Java features are available in an
## Octave session.  This function is provided for scripts which may alter
## their behavior based on the availability of Java.  The feature
## @qcode{"desktop"} is never available as Octave has no Java-based desktop.
## Other features may be available if Octave was compiled with the Java
## Interface and Java is installed.
##
## @seealso{usejava, error}
## @end deftypefn
    
    ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
## Created: 2014-04-19
    
    
@function
def javachk(feature=None,component='',*args,**kwargs):
    varargin = javachk.varargin
    nargin = javachk.nargin

    msg=''
# /home/lei/octave-4.0.2/scripts/java/javachk.m:90
    chk=copy(false)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:91
    if 'awt' == (feature):
        try:
            dum=methods('java.awt.Frame')
# /home/lei/octave-4.0.2/scripts/java/javachk.m:96
            chk=copy(true)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:97
        finally:
            pass
    else:
        if 'desktop' == (feature):
            ## Octave has no Java based GUI/desktop, leave chk = false
            pass
        else:
            if 'jvm' == (feature):
                try:
                    dum=methods('java.lang.Runtime')
# /home/lei/octave-4.0.2/scripts/java/javachk.m:103
                    chk=copy(true)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:104
                finally:
                    pass
            else:
                if 'swing' == (feature):
                    try:
                        dum=methods('javax.swing.Popup')
# /home/lei/octave-4.0.2/scripts/java/javachk.m:108
                        chk=copy(true)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:109
                    finally:
                        pass
                else:
                    error('javachk: unrecognized feature \'%s\', can be one of \'awt\'|\'desktop\'|\'jvm\'|\'swing\'\n',feature)
    
    if (logical_not(chk)):
        ## Desired feature not present
        if (nargout >= 1):
            msg.message = copy(sprintf('javachk: %s is not supported',feature))
# /home/lei/octave-4.0.2/scripts/java/javachk.m:118
            msg.identifier = copy(component)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:119
        else:
            if (logical_not(isempty(component))):
                err=sprintf('javachk: %s is not supported\n',component)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:122
            else:
                err=sprintf('javachk: %s is not supported\n',feature)
# /home/lei/octave-4.0.2/scripts/java/javachk.m:124
            error(err)
    
    return msg
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{obj} =} java_set (@var{obj}, @var{name}, @var{val})
## Set the value of the field @var{name} of the Java object @var{obj} to
## @var{val}.
##
## For static fields, @var{obj} can be a string representing the fully
## qualified named of the corresponding Java class.
##
## When @var{obj} is a regular Java object, structure-like indexing can be
## used as a shortcut syntax.  For instance, the following two statements are
## equivalent
##
## @example
## @group
##   java_set (x, "field1", val)
##   x.field1 = val
## @end group
## @end example
##
## @seealso{java_get, javaMethod, javaObject}
## @end deftypefn
    
    
@function
def java_set(obj=None,name=None,val=None,*args,**kwargs):
    varargin = java_set.varargin
    nargin = java_set.nargin

    if (nargin != 3):
        print_usage()
    
    if (isjava(obj)):
        setattr(obj,name,val)
# /home/lei/octave-4.0.2/scripts/java/java_set.m:48
    else:
        if (ischar(obj)):
            retval=__java_set__(obj,name,val)
# /home/lei/octave-4.0.2/scripts/java/java_set.m:50
        else:
            error('java_set: OBJ must be a Java object')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Rik Wehbring
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{val} =} java_get (@var{obj}, @var{name})
## Get the value of the field @var{name} of the Java object @var{obj}.
##
## For static fields, @var{obj} can be a string representing the fully
## qualified name of the corresponding class.
##
## When @var{obj} is a regular Java object, structure-like indexing can be
## used as a shortcut syntax.  For instance, the following two statements are
## equivalent
##
## @example
## @group
##   java_get (x, "field1")
##   x.field1
## @end group
## @end example
##
## @seealso{java_set, javaMethod, javaObject}
## @end deftypefn
    
    
@function
def java_get(obj=None,name=None,*args,**kwargs):
    varargin = java_get.varargin
    nargin = java_get.nargin

    if (nargin != 2):
        print_usage()
    
    if (isjava(obj)):
        retval=getattr(obj,(name))
# /home/lei/octave-4.0.2/scripts/java/java_get.m:47
    else:
        if (ischar(obj)):
            retval=__java_get__(obj,name)
# /home/lei/octave-4.0.2/scripts/java/java_get.m:49
        else:
            error('java_get: OBJ must be a Java object')
    
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2012-2015 Rik Wehbring
## Parts Copyright (C) 2012-2015 Philip Nienhuis
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} usejava (@var{feature})
## Return true if the Java element @var{feature} is available.
##
## Possible features are:
##
## @table @asis
## @item @qcode{"awt"}
## Abstract Window Toolkit for GUIs.
##
## @item @qcode{"desktop"}
## Interactive desktop is running.
##
## @item @qcode{"jvm"}
## Java Virtual Machine.
##
## @item @qcode{"swing"}
## Swing components for lightweight GUIs.
## @end table
##
## @code{usejava} determines if specific Java features are available in an
## Octave session.  This function is provided for scripts which may alter
## their behavior based on the availability of Java.  The feature
## @qcode{"desktop"} always returns @code{false} as Octave has no Java-based
## desktop.  Other features may be available if Octave was compiled with the
## Java Interface and Java is installed.
## @seealso{javachk}
## @end deftypefn
    
    ## Author: Rik Wehbring
## Author: Philip Nienhuis <prnienhuis@users.sf.net>
    
    
@function
def usejava(feature=None,*args,**kwargs):
    varargin = usejava.varargin
    nargin = usejava.nargin

    if (nargin != 1 or logical_not(ischar(feature))):
        print_usage()
    
    retval=copy(false)
# /home/lei/octave-4.0.2/scripts/java/usejava.m:58
    if 'awt' == (feature):
        try:
            dum=methods('java.awt.Frame')
# /home/lei/octave-4.0.2/scripts/java/usejava.m:64
            retval=copy(true)
# /home/lei/octave-4.0.2/scripts/java/usejava.m:65
        finally:
            pass
    else:
        if 'desktop' == (feature):
            ## Octave has no Java based GUI/desktop, leave retval = false
            pass
        else:
            if 'jvm' == (feature):
                try:
                    dum=methods('java.lang.Runtime')
# /home/lei/octave-4.0.2/scripts/java/usejava.m:71
                    retval=copy(true)
# /home/lei/octave-4.0.2/scripts/java/usejava.m:72
                finally:
                    pass
            else:
                if 'swing' == (feature):
                    try:
                        dum=methods('javax.swing.Popup')
# /home/lei/octave-4.0.2/scripts/java/usejava.m:76
                        retval=copy(true)
# /home/lei/octave-4.0.2/scripts/java/usejava.m:77
                    finally:
                        pass
                else:
                    error('usejava: unrecognized feature \'%s\'',feature)
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javaclasspath ()
## @deftypefnx {Function File} {@var{dpath} =} javaclasspath ()
## @deftypefnx {Function File} {[@var{dpath}, @var{spath}] =} javaclasspath ()
## @deftypefnx {Function File} {@var{clspath} =} javaclasspath (@var{what})
## Return the class path of the Java virtual machine in the form of a cell
## array of strings.
##
## If called with no inputs:
##
## @itemize
## @item If no output is requested, the dynamic and static classpaths are
## printed to the standard output.
##
## @item If one output value @var{dpath} is requested, the result is the
## dynamic classpath.
##
## @item If two output values@var{dpath} and @var{spath} are requested, the
## first variable will contain the dynamic classpath and the second will
## contain the static classpath.
## @end itemize
##
## If called with a single input parameter @var{what}:
##
## @table @asis
## @item @qcode{"-dynamic"}
## Return the dynamic classpath.
##
## @item @qcode{"-static"}
## Return the static classpath.
##
## @item @qcode{"-all"}
## Return both the static and dynamic classpath in a single cellstr.
## @end table
## @seealso{javaaddpath, javarmpath}
## @end deftypefn
    
    
@function
def javaclasspath(which=None,*args,**kwargs):
    varargin = javaclasspath.varargin
    nargin = javaclasspath.nargin

    if (nargin > 1):
        print_usage()
    
    ## dynamic classpath
    dynamic_path=javaMethod('getClassPath','org.octave.ClassHelper')
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:64
    dynamic_path_list=ostrsplit(dynamic_path,pathsep())
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:65
    
    static_path=javaMethod('getProperty','java.lang.System','java.class.path')
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:68
    static_path_list=ostrsplit(static_path,pathsep())
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:70
    if (numel(static_path_list) > 1):
        ## remove first element (which is .../octave.jar)
        static_path_list[1]=[]
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:73
    else:
        static_path_list=cellarray([])
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:75
    
    if (nargout == 0):
        if (logical_not(nargin)):
            which='-all'
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:80
        if '-dynamic' == (tolower(which)):
            disp_path_list('DYNAMIC',dynamic_path_list)
        else:
            if '-static' == (tolower(which)):
                disp_path_list('STATIC',static_path_list)
            else:
                if '-all' == (tolower(which)):
                    disp_path_list('STATIC',static_path_list)
                    disp('')
                    disp_path_list('DYNAMIC',dynamic_path_list)
                else:
                    error('javaclasspath: invalid value for WHAT')
    else:
        if (logical_not(nargin)):
            ## This is to allow retrieval of both paths in separate variables with
      ## a single call to javaclasspath(). Matlab returns only the -dynamic
      ## path in this case but this won't break compatibility.
            path1=cellstr(dynamic_path_list)
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:98
            path2=cellstr(static_path_list)
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:99
        else:
            if '-all' == (tolower(which)):
                path1=cellstr(cat(static_path_list,dynamic_path_list))
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:102
            else:
                if '-dynamic' == (tolower(which)):
                    path1=cellstr(dynamic_path_list)
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:103
                else:
                    if '-static' == (tolower(which)):
                        path1=cellstr(static_path_list)
# /home/lei/octave-4.0.2/scripts/java/javaclasspath.m:104
                    else:
                        error('javaclasspath: invalid value for WHAT')
    
    return path1,path2
    
if __name__ == '__main__':
    pass
    
    ## Display cell array of paths
    
    
@function
def disp_path_list(which=None,path_list=None,*args,**kwargs):
    varargin = disp_path_list.varargin
    nargin = disp_path_list.nargin

    printf('   %s JAVA PATH\n\n',which)
    if (numel(path_list) > 0):
        printf('      %s\n',path_list[:])
    else:
        printf('      - empty -\n')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
## Copyright (C) 2010, 2013 Martin Hepperle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} javarmpath (@var{clspath})
## @deftypefnx {Function File} {} javarmpath (@var{clspath1}, @dots{})
## Remove @var{clspath} from the dynamic class path of the Java virtual
## machine.
##
## @var{clspath} may either be a directory where @file{.class} files are found,
## or a @file{.jar} file containing Java classes.  Multiple paths may be
## removed at once by specifying additional arguments.
## @seealso{javaaddpath, javaclasspath}
## @end deftypefn
    
    
@function
def javarmpath(varargin=None,*args,**kwargs):
    varargin = javarmpath.varargin
    nargin = javarmpath.nargin

    if (nargin < 1):
        print_usage()
    
    for i in arange(1,numel(varargin)).reshape(-1):
        clspath=varargin[i]
# /home/lei/octave-4.0.2/scripts/java/javarmpath.m:39
        if (logical_not(ischar(clspath))):
            error('javarmpath: CLSPATH must be a string')
        old_path=canonicalize_file_name(tilde_expand(clspath))
# /home/lei/octave-4.0.2/scripts/java/javarmpath.m:44
        if (exist(old_path,'dir')):
            if (old_path[end()] != filesep()):
                old_path=matlabarray(cat(old_path,filesep()))
# /home/lei/octave-4.0.2/scripts/java/javarmpath.m:47
        success=javaMethod('removeClassPath','org.octave.ClassHelper',old_path)
# /home/lei/octave-4.0.2/scripts/java/javarmpath.m:51
        if (logical_not(success)):
            warning('javarmpath: %s: not found in Java classpath',old_path)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2007, 2013 Michael Goffioul
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{jary} =} javaArray (@var{classname}, @var{sz})
## @deftypefnx {Function File} {@var{jary} =} javaArray (@var{classname}, @var{m}, @var{n}, @dots{})
##
## Create a Java array of size @var{sz} with elements of class @var{classname}.
##
## @var{classname} may be a Java object representing a class or a string
## containing the fully qualified class name.  The size of the object may
## also be specified with individual integer arguments @var{m}, @var{n}, etc.
##
## The generated array is uninitialized.  All elements are set to null if
## @var{classname} is a reference type, or to a default value (usually 0) if
## @var{classname} is a primitive type.
##
## Sample code:
##
## @example
## @group
## jary = javaArray ("java.lang.String", 2, 2);
## jary(1,1) = "Hello";
## @end group
## @end example
## @seealso{javaObject}
## @end deftypefn
    
    
@function
def javaArray(classname=None,varargin=None,*args,**kwargs):
    varargin = javaArray.varargin
    nargin = javaArray.nargin

    if (nargin < 2):
        print_usage()
    
    retval=javaMethod('createArray','org.octave.ClassHelper',classname,cat(varargin[:]))
# /home/lei/octave-4.0.2/scripts/java/javaArray.m:50
    return retval
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
## Copyright (C) 2012 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Command} {} pkg @var{command} @var{pkg_name}
## @deftypefnx {Command} {} pkg @var{command} @var{option} @var{pkg_name}
## Manage packages (groups of add-on functions) for Octave.
##
## Different actions are available depending on the value of @var{command}.
##
## Available commands:
##
## @table @samp
##
## @item install
## Install named packages.  For example,
##
## @example
## pkg install image-1.0.0.tar.gz
## @end example
##
## @noindent
## installs the package found in the file @file{image-1.0.0.tar.gz}.
##
## The @var{option} variable can contain options that affect the manner
## in which a package is installed.  These options can be one or more of
##
## @table @code
## @item -nodeps
## The package manager will disable dependency checking.  With this option it
## is possible to install a package even when it depends on another package
## which is not installed on the system.  @strong{Use this option with care.}
##
## @item -noauto
## The package manager will not automatically load the installed package
## when starting Octave.  This overrides any setting within the package.
##
## @item -auto
## The package manager will automatically load the installed package when
## starting Octave.  This overrides any setting within the package.
##
## @item -local
## A local installation (package available only to current user) is forced,
## even if the user has system privileges.
##
## @item -global
## A global installation (package available to all users) is forced, even if
## the user doesn't normally have system privileges.
##
## @item -forge
## Install a package directly from the Octave-Forge repository.  This
## requires an internet connection and the cURL library.
##
## @item -verbose
## The package manager will print the output of all commands as
## they are performed.
## @end table
##
## @item update
## Check installed Octave-Forge packages against repository and update any
## outdated items.  This requires an internet connection and the cURL library.
## Usage:
##
## @example
## pkg update
## @end example
##
## @item uninstall
## Uninstall named packages.  For example,
##
## @example
## pkg uninstall image
## @end example
##
## @noindent
## removes the @code{image} package from the system.  If another installed
## package depends on the @code{image} package an error will be issued.
## The package can be uninstalled anyway by using the @option{-nodeps} option.
##
## @item load
## Add named packages to the path.  After loading a package it is
## possible to use the functions provided by the package.  For example,
##
## @example
## pkg load image
## @end example
##
## @noindent
## adds the @code{image} package to the path.  It is possible to load all
## installed packages at once with the keyword @samp{all}.  Usage:
##
## @example
## pkg load all
## @end example
##
## @item unload
## Remove named packages from the path.  After unloading a package it is
## no longer possible to use the functions provided by the package.  It is
## possible to unload all installed packages at once with the keyword
## @samp{all}.  Usage:
##
## @example
## pkg unload all
## @end example
##
## @item list
## Show the list of currently installed packages.  For example,
##
## @example
## pkg list
## @end example
##
## @noindent
## will produce a short report with the package name, version, and installation
## directory for each installed package.  Supply a package name to limit
## reporting to a particular package.  For example:
##
## @example
## pkg list image
## @end example
##
## If a single return argument is requested then @code{pkg} returns a cell
## array where each element is a structure with information on a single
## package.
##
## @example
## installed_packages = pkg ("list")
## @end example
##
## If two output arguments are requested @code{pkg} splits the list of
## installed packages into those which were installed by the current user,
## and those which were installed by the system administrator.
##
## @example
## [user_packages, system_packages] = pkg ("list")
## @end example
##
## The @qcode{"-forge"} option lists packages available at the Octave-Forge
## repository.  This requires an internet connection and the cURL library.
## For example:
##
## @example
## oct_forge_pkgs = pkg ("list", "-forge")
## @end example
##
## @item describe
## Show a short description of the named installed packages, with the option
## @qcode{"-verbose"} also list functions provided by the package.  For example,
##
## @example
## pkg describe -verbose all
## @end example
##
## @noindent
## will describe all installed packages and the functions they provide.
## If one output is requested a cell of structure containing the
## description and list of functions of each package is returned as
## output rather than printed on screen:
##
## @example
## desc = pkg ("describe", "secs1d", "image")
## @end example
##
## @noindent
## If any of the requested packages is not installed, @code{pkg} returns an
## error, unless a second output is requested:
##
## @example
## [desc, flag] = pkg ("describe", "secs1d", "image")
## @end example
##
## @noindent
## @var{flag} will take one of the values @qcode{"Not installed"},
## @qcode{"Loaded"}, or
## @qcode{"Not loaded"} for each of the named packages.
##
## @item prefix
## Set the installation prefix directory.  For example,
##
## @example
## pkg prefix ~/my_octave_packages
## @end example
##
## @noindent
## sets the installation prefix to @file{~/my_octave_packages}.
## Packages will be installed in this directory.
##
## It is possible to get the current installation prefix by requesting an
## output argument.  For example:
##
## @example
## pfx = pkg ("prefix")
## @end example
##
## The location in which to install the architecture dependent files can be
## independently specified with an addition argument.  For example:
##
## @example
## pkg prefix ~/my_octave_packages ~/my_arch_dep_pkgs
## @end example
##
## @item local_list
## Set the file in which to look for information on locally
## installed packages.  Locally installed packages are those that are
## available only to the current user.  For example:
##
## @example
## pkg local_list ~/.octave_packages
## @end example
##
## It is possible to get the current value of local_list with the following
##
## @example
## pkg local_list
## @end example
##
## @item global_list
## Set the file in which to look for information on globally
## installed packages.  Globally installed packages are those that are
## available to all users.  For example:
##
## @example
## pkg global_list /usr/share/octave/octave_packages
## @end example
##
## It is possible to get the current value of global_list with the following
##
## @example
## pkg global_list
## @end example
##
## @item build
## Build a binary form of a package or packages.  The binary file produced
## will itself be an Octave package that can be installed normally with
## @code{pkg}.  The form of the command to build a binary package is
##
## @example
## pkg build builddir image-1.0.0.tar.gz @dots{}
## @end example
##
## @noindent
## where @code{builddir} is the name of a directory where the temporary
## installation will be produced and the binary packages will be found.
## The options @option{-verbose} and @option{-nodeps} are respected, while
## all other options are ignored.
##
## @item rebuild
## Rebuild the package database from the installed directories.  This can
## be used in cases where the package database has been corrupted.
## It can also take the @option{-auto} and @option{-noauto} options to allow the
## autoloading state of a package to be changed.  For example,
##
## @example
## pkg rebuild -noauto image
## @end example
##
## @noindent
## will remove the autoloading status of the image package.
##
## @end table
## @seealso{ver, news}
## @end deftypefn
    
    
@function
def pkg(varargin=None,*args,**kwargs):
    varargin = pkg.varargin
    nargin = pkg.nargin

    ## Installation prefix (FIXME: what should these be on windows?)
    
    
    
    
    
    
    ## FIXME: is it OK to set this always true on windows?
    global_install=((ispc() and logical_not(isunix())) or (geteuid() == 0))
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:293
    if (isbool(prefix)):
        prefix,archprefix=default_prefix(global_install,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:296
        prefix=tilde_expand(prefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:297
        archprefix=tilde_expand(archprefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:298
    
    mlock()
    confirm_recursive_rmdir(false,'local')
    available_actions=cellarray(['list','install','uninstall','load','unload','prefix','local_list','global_list','rebuild','build','describe','update'])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:305
    
    if (isempty(varargin) or logical_not(iscellstr(varargin))):
        print_usage()
    
    files=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:314
    deps=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:315
    auto=0
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:316
    action='none'
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:317
    verbose=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:318
    octave_forge=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:319
    for i in arange(1,numel(varargin)).reshape(-1):
        if '-nodeps' == (varargin[i]):
            deps=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:323
        else:
            if '-noauto' == (varargin[i]):
                auto=- 1
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:325
            else:
                if '-auto' == (varargin[i]):
                    auto=1
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:327
                else:
                    if '-verbose' == (varargin[i]):
                        verbose=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:329
                        page_output_immediately(true,'local')
                    else:
                        if '-forge' == (varargin[i]):
                            if (logical_not(octave_config_info('CURL_LIBS'))):
                                error('pkg: can\'t download from forge without the cURL library')
                            octave_forge=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:336
                        else:
                            if '-local' == (varargin[i]):
                                global_install=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:338
                                if (logical_not(user_prefix)):
                                    prefix,archprefix=default_prefix(global_install,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:340
                            else:
                                if '-global' == (varargin[i]):
                                    global_install=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:343
                                    if (logical_not(user_prefix)):
                                        prefix,archprefix=default_prefix(global_install,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:345
                                else:
                                    if available_actions == (varargin[i]):
                                        if (logical_not(strcmp(action,'none'))):
                                            error('more than one action specified')
                                        action=varargin[i]
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:351
                                    else:
                                        files[end() + 1]=varargin[i]
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:353
    
    if (octave_forge and logical_not(any(strcmp(action,cellarray(['install','list']))))):
        error('-forge can only be used with install or list')
    
    ## Take action
    if 'list' == (action):
        if (octave_forge):
            if (nargout > 0):
                local_packages=list_forge_packages()
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:366
            else:
                list_forge_packages()
        else:
            if (nargout == 0):
                installed_packages(local_list,global_list,files)
            else:
                if (nargout == 1):
                    local_packages=installed_packages(local_list,global_list,files)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:374
                else:
                    if (nargout == 2):
                        local_packages,global_packages=installed_packages(local_list,global_list,files,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:376
                    else:
                        error('too many output arguments requested')
    else:
        if 'install' == (action):
            if (isempty(files)):
                error('you must specify at least one filename when calling \'pkg install\'')
            local_files=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:389
            try:
                if (octave_forge):
                    urls,local_files=cellfun('get_forge_download',files,'uniformoutput',false,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:393
                    files,succ=cellfun('urlwrite',urls,local_files,'uniformoutput',false,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:395
                    succ=matlabarray(cat(succ[:]))
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:397
                    if (logical_not(all(succ))):
                        i=find(logical_not(succ),1)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:399
                        error('could not download file %s from url %s',local_files[i],urls[i])
                install(files,deps,auto,prefix,archprefix,verbose,local_list,global_list,global_install)
            finally:
                cellfun('unlink',local_files)
        else:
            if 'uninstall' == (action):
                if (isempty(files)):
                    error('you must specify at least one package when calling \'pkg uninstall\'')
                uninstall(files,deps,verbose,local_list,global_list,global_install)
            else:
                if 'load' == (action):
                    if (isempty(files)):
                        error('you must specify at least one package, \'all\', or \'auto\' when calling \'pkg load\'')
                    load_packages(files,deps,local_list,global_list)
                else:
                    if 'unload' == (action):
                        if (isempty(files)):
                            error('you must specify at least one package or \'all\' when calling \'pkg unload\'')
                        unload_packages(files,deps,local_list,global_list)
                    else:
                        if 'prefix' == (action):
                            if (isempty(files) and nargout == 0):
                                printf('Installation prefix:             %s\n',prefix)
                                printf('Architecture dependent prefix:   %s\n',archprefix)
                            else:
                                if (isempty(files) and nargout >= 1):
                                    local_packages=copy(prefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:435
                                    global_packages=copy(archprefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:436
                                else:
                                    if (numel(files) >= 1 and nargout <= 2 and ischar(files[1])):
                                        prefix=tilde_expand(files[1])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:438
                                        if (logical_not(exist(prefix,'dir'))):
                                            status,msg=mkdir(prefix,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:440
                                            if (status == 0):
                                                error('cannot create prefix %s: %s',prefix,msg)
                                            warning('creating the directory %s\n',prefix)
                                        local_packages=prefix=canonicalize_file_name(prefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:446
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:446
                                        user_prefix=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:447
                                        if (numel(files) >= 2 and ischar(files[2])):
                                            archprefix=tilde_expand(files[2])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:449
                                            if (logical_not(exist(archprefix,'dir'))):
                                                status,msg=mkdir(archprefix,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:451
                                                if (status == 0):
                                                    error('cannot create archprefix %s: %s',archprefix,msg)
                                                warning('creating the directory %s\n',archprefix)
                                                global_packages=archprefix=canonicalize_file_name(archprefix)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:456
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:456
                                    else:
                                        error('you must specify a prefix directory, or request an output argument')
                        else:
                            if 'local_list' == (action):
                                if (isempty(files) and nargout == 0):
                                    disp(local_list)
                                else:
                                    if (isempty(files) and nargout == 1):
                                        local_packages=copy(local_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:467
                                    else:
                                        if (numel(files) == 1 and nargout == 0 and ischar(files[1])):
                                            local_list=files[1]
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:469
                                            if (logical_not(exist(local_list,'file'))):
                                                try:
                                                    ## Force file to be created
                                                    fclose(fopen(local_list,'wt'))
                                                finally:
                                                    pass
                                            local_list=canonicalize_file_name(local_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:478
                                        else:
                                            error('you must specify a local_list file, or request an output argument')
                            else:
                                if 'global_list' == (action):
                                    if (isempty(files) and nargout == 0):
                                        disp(global_list)
                                    else:
                                        if (isempty(files) and nargout == 1):
                                            local_packages=copy(global_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:487
                                        else:
                                            if (numel(files) == 1 and nargout == 0 and ischar(files[1])):
                                                global_list=files[1]
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:489
                                                if (logical_not(exist(global_list,'file'))):
                                                    try:
                                                        ## Force file to be created
                                                        fclose(fopen(files[1],'wt'))
                                                    finally:
                                                        pass
                                                global_list=canonicalize_file_name(global_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:498
                                            else:
                                                error('you must specify a global_list file, or request an output argument')
                                else:
                                    if 'rebuild' == (action):
                                        if (global_install):
                                            global_packages=rebuild(prefix,archprefix,global_list,files,auto,verbose)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:505
                                            global_packages=save_order(global_packages)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:507
                                            save(global_list,'global_packages')
                                            if (nargout > 0):
                                                local_packages=copy(global_packages)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:510
                                        else:
                                            local_packages=rebuild(prefix,archprefix,local_list,files,auto,verbose)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:513
                                            local_packages=save_order(local_packages)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:515
                                            save(local_list,'local_packages')
                                            if (nargout == 0):
                                                clear('local_packages')
                                    else:
                                        if 'build' == (action):
                                            if (numel(files) < 2):
                                                error('you must specify at least the build directory and one filename\nwhen calling \'pkg build\'')
                                            build(files,deps,auto,verbose)
                                        else:
                                            if 'describe' == (action):
                                                if (isempty(files)):
                                                    error('you must specify at least one package or \'all\' when calling \'pkg describe\'')
                                                ## FIXME: name of the output variables is inconsistent with their content
                                                if 0 == (nargout):
                                                    describe(files,verbose,local_list,global_list)
                                                else:
                                                    if 1 == (nargout):
                                                        pkg_desc_list=describe(files,verbose,local_list,global_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:537
                                                        local_packages=copy(pkg_desc_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:538
                                                    else:
                                                        if 2 == (nargout):
                                                            pkg_desc_list,flag=describe(files,verbose,local_list,global_list,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:540
                                                            local_packages=copy(pkg_desc_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:542
                                                            global_packages=copy(flag)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:543
                                                        else:
                                                            error('you can request at most two outputs when calling \'pkg describe\'')
                                            else:
                                                if 'update' == (action):
                                                    if (nargout == 0):
                                                        installed_pkgs_lst=installed_packages(local_list,global_list)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:550
                                                        if (numel(files) > 0):
                                                            update_lst=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:552
                                                            installed_names=cellarray([installed_pkgs_list.name]).T
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:553
                                                            for i in arange(1,numel(files)).reshape(-1):
                                                                idx=find(strcmp(files[i],installed_names),1)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:555
                                                                if (isempty(idx)):
                                                                    warning('Package %s is not installed - not updating this package',files[i])
                                                                else:
                                                                    update_lst=cellarray([update_lst,installed_pkgs_lst[idx]])
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:559
                                                            installed_pkgs_lst=copy(update_lst)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:562
                                                        for i in arange(1,numel(installed_pkgs_lst)).reshape(-1):
                                                            installed_pkg_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:565
                                                            installed_pkg_version=installed_pkgs_lst[i].version
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:566
                                                            forge_pkg_version=get_forge_pkg(installed_pkg_name)
# /home/lei/octave-4.0.2/scripts/pkg/pkg.m:567
                                                            if (compare_versions(forge_pkg_version,installed_pkg_version,'>')):
                                                                feval(pkg,'install','-forge',installed_pkg_name)
                                                    else:
                                                        error('no output arguments available')
                                                else:
                                                    error('you must specify a valid action for \'pkg\'.  See \'help pkg\' for details')
    
    return local_packages,global_packages
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} write_index (@var{desc}, @var{dir}, @var{index_file}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    ## Create an INDEX file for a package that doesn't provide one.
##   'desc'  describes the package.
##   'dir'   is the 'inst' directory in temporary directory.
##   'index_file' is the name (including path) of resulting INDEX file.
    
    
@function
def write_index(desc=None,dir=None,index_file=None,global_install=None,*args,**kwargs):
    varargin = write_index.varargin
    nargin = write_index.nargin

    ## Get names of functions in dir
    files,err,msg=readdir(dir,nargout=3)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:32
    if (err):
        error('couldn\'t read directory %s: %s',dir,msg)
    
    ## Get classes in dir
    class_idx=find(strncmp(files,'@',1))
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:38
    for k in arange(1,length(class_idx)).reshape(-1):
        class_name=files[class_idx[k]]
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:40
        class_dir=fullfile(dir,class_name)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:41
        if (exist(class_dir,'dir')):
            files2,err,msg=readdir(class_dir,nargout=3)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:43
            if (err):
                error('couldn\'t read directory %s: %s',class_dir,msg)
            files2=strcat(class_name,filesep(),files2)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:47
            files=matlabarray(cat([files],[files2]))
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:48
    
    ## Check for architecture dependent files.
    tmpdir=getarchdir(desc)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:53
    if (exist(tmpdir,'dir')):
        files2,err,msg=readdir(tmpdir,nargout=3)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:55
        if (err):
            error('couldn\'t read directory %s: %s',tmpdir,msg)
        files=matlabarray(cat([files],[files2]))
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:59
    
    functions=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:62
    for i in arange(1,length(files)).reshape(-1):
        file=files[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:64
        lf=length(file)
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:65
        if (lf > 2 and strcmp(file[end() - 1:end()],'.m')):
            functions[end() + 1]=file[1:end() - 2]
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:67
        else:
            if (lf > 4 and strcmp(file[end() - 3:end()],'.oct')):
                functions[end() + 1]=file[1:end() - 4]
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:69
    
    ## Does desc have a categories field?
    if (logical_not(isfield(desc,'categories'))):
        error('the DESCRIPTION file must have a Categories field, when no INDEX file is given')
    
    categories=strtrim(strsplit(desc.categories,','))
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:77
    if (length(categories) < 1):
        error('the Category field is empty')
    
    ## Write INDEX.
    fid=fopen(index_file,'w')
# /home/lei/octave-4.0.2/scripts/pkg/private/write_index.m:83
    if (fid == - 1):
        error('couldn\'t open %s for writing',index_file)
    
    fprintf(fid,'%s >> %s\n',desc.name,desc.title)
    fprintf(fid,'%s\n',categories[1])
    fprintf(fid,'  %s\n',functions[:])
    fclose(fid)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{url}, @var{local_file}] =} list_forge_packages ()
## Undocumented internal function.
## @end deftypefn
    
    
@function
def get_forge_download(name=None,*args,**kwargs):
    varargin = get_forge_download.varargin
    nargin = get_forge_download.nargin

    ver,url=get_forge_pkg(name,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_download.m:26
    local_file=matlabarray(cat(name,'-',ver,'.tar.gz'))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_download.m:27
    return url,local_file
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{archprefix} =} getarchprefix (@var{desc}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def getarchprefix(desc=None,global_install=None,*args,**kwargs):
    varargin = getarchprefix.varargin
    nargin = getarchprefix.nargin

    if (global_install):
        __,archprefix=default_prefix(global_install,desc,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/getarchprefix.m:27
    else:
        archprefix=desc.dir
# /home/lei/octave-4.0.2/scripts/pkg/private/getarchprefix.m:29
    
    return archprefix
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{pkg_desc_list}, @var{flag}] =} describe (@var{pkgnames}, @var{verbose}, @var{local_list}, @var{global_list})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def describe(pkgnames=None,verbose=None,local_list=None,global_list=None,*args,**kwargs):
    varargin = describe.varargin
    nargin = describe.nargin

    ## Get the list of installed packages.
    installed_pkgs_lst=installed_packages(local_list,global_list)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:29
    num_packages=length(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:30
    describe_all=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:32
    if (any(strcmp('all',pkgnames))):
        describe_all=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:34
        flag[1:num_packages]=cellarray(['Not Loaded'])
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:35
        num_pkgnames=copy(num_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:36
    else:
        num_pkgnames=length(pkgnames)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:38
        flag[1:num_pkgnames]=cellarray(['Not installed'])
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:39
    
    for i in arange(1,num_packages).reshape(-1):
        curr_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:43
        if (describe_all):
            name_pos=copy(i)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:45
        else:
            name_pos=find(strcmp(curr_name,pkgnames))
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:47
        if (logical_not(isempty(name_pos))):
            if (installed_pkgs_lst[i].loaded):
                flag[name_pos]='Loaded'
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:52
            else:
                flag[name_pos]='Not loaded'
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:54
            pkg_desc_list[name_pos].name = copy(installed_pkgs_lst[i].name)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:57
            pkg_desc_list[name_pos].version = copy(installed_pkgs_lst[i].version)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:58
            pkg_desc_list[name_pos].description = copy(installed_pkgs_lst[i].description)
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:59
            pkg_desc_list[name_pos].provides = copy(parse_pkg_idx(installed_pkgs_lst[i].dir))
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:60
    
    non_inst=find(strcmp(flag,'Not installed'))
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:65
    if (logical_not(isempty(non_inst))):
        if (nargout < 2):
            non_inst_str=sprintf(' %s ',pkgnames[non_inst])
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:68
            error('some packages are not installed: %s',non_inst_str)
        else:
            pkg_desc_list[non_inst]=struct('name',cellarray([]),'description',cellarray([]),'provides',cellarray([]))
# /home/lei/octave-4.0.2/scripts/pkg/private/describe.m:71
    
    if (nargout == 0):
        for i in arange(1,num_pkgnames).reshape(-1):
            print_package_description(pkg_desc_list[i].name,pkg_desc_list[i].version,pkg_desc_list[i].provides,pkg_desc_list[i].description,flag[i],verbose)
    
    return pkg_desc_list,flag
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{newdesc} =} save_order (@var{desc})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def save_order(desc=None,*args,**kwargs):
    varargin = save_order.varargin
    nargin = save_order.nargin

    newdesc=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:26
    for i in arange(1,length(desc)).reshape(-1):
        deps=desc[i].depends
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:28
        if (isempty(deps) or (length(deps) == 1 and strcmp(deps[1].package,'octave'))):
            newdesc[end() + 1]=desc[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:31
        else:
            tmpdesc=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:33
            for k in arange(1,length(deps)).reshape(-1):
                for j in arange(1,length(desc)).reshape(-1):
                    if (strcmp(desc[j].name,deps[k].package)):
                        tmpdesc[end() + 1]=desc[j]
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:37
                        break
            if (logical_not(isempty(tmpdesc))):
                newdesc=cellarray([newdesc[:],save_order(tmpdesc)[:],desc[i]])
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:43
            else:
                newdesc[end() + 1]=desc[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:45
    
    ## Eliminate the duplicates.
    idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:50
    for i in arange(1,length(newdesc)).reshape(-1):
        for j in arange((i + 1),length(newdesc)).reshape(-1):
            if (strcmp(newdesc[i].name,newdesc[j].name)):
                idx[end() + 1]=j
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:54
    
    newdesc[idx]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/save_order.m:58
    return newdesc
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} copy_files (@var{desc}, @var{packdir}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def copy_files(desc=None,packdir=None,global_install=None,*args,**kwargs):
    varargin = copy_files.varargin
    nargin = copy_files.nargin

    ## Create the installation directory.
    if (logical_not(exist(desc.dir,'dir'))):
        status,output=mkdir(desc.dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:28
        if (status != 1):
            error('couldn\'t create installation directory %s : %s',desc.dir,output)
    
    octfiledir=getarchdir(desc)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:35
    
    instdir=fullfile(packdir,'inst')
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:38
    if (logical_not(dirempty(instdir))):
        status,output=copyfile(fullfile(instdir,'*'),desc.dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:40
        if (status != 1):
            rmdir(desc.dir,'s')
            error('couldn\'t copy files to the installation directory')
        if (exist(fullfile(desc.dir,getarch()),'dir') and logical_not(strcmp(fullfile(desc.dir,getarch()),octfiledir))):
            if (logical_not(exist(octfiledir,'dir'))):
                ## Can be required to create upto three levels of dirs.
                octm1=fileparts(octfiledir)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:49
                if (logical_not(exist(octm1,'dir'))):
                    octm2=fileparts(octm1)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:51
                    if (logical_not(exist(octm2,'dir'))):
                        octm3=fileparts(octm2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:53
                        if (logical_not(exist(octm3,'dir'))):
                            status,output=mkdir(octm3,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:55
                            if (status != 1):
                                rmdir(desc.dir,'s')
                                error('couldn\'t create installation directory %s : %s',octm3,output)
                        status,output=mkdir(octm2,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:62
                        if (status != 1):
                            rmdir(desc.dir,'s')
                            error('couldn\'t create installation directory %s : %s',octm2,output)
                    status,output=mkdir(octm1,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:69
                    if (status != 1):
                        rmdir(desc.dir,'s')
                        error('couldn\'t create installation directory %s : %s',octm1,output)
                status,output=mkdir(octfiledir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:76
                if (status != 1):
                    rmdir(desc.dir,'s')
                    error('couldn\'t create installation directory %s : %s',octfiledir,output)
            status,output=movefile(fullfile(desc.dir,getarch(),'*'),octfiledir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:83
            rmdir(fullfile(desc.dir,getarch()),'s')
            if (status != 1):
                rmdir(desc.dir,'s')
                rmdir(octfiledir,'s')
                error('couldn\'t copy files to the installation directory')
    
    ## Create the "packinfo" directory.
    packinfo=fullfile(desc.dir,'packinfo')
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:97
    status,msg=mkdir(packinfo,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:98
    if (status != 1):
        rmdir(desc.dir,'s')
        rmdir(octfiledir,'s')
        error('couldn\'t create packinfo directory: %s',msg)
    
    packinfo_copy_file('DESCRIPTION','required',packdir,packinfo,desc,octfiledir)
    packinfo_copy_file('COPYING','required',packdir,packinfo,desc,octfiledir)
    packinfo_copy_file('CITATION','optional',packdir,packinfo,desc,octfiledir)
    packinfo_copy_file('NEWS','optional',packdir,packinfo,desc,octfiledir)
    packinfo_copy_file('ONEWS','optional',packdir,packinfo,desc,octfiledir)
    packinfo_copy_file('ChangeLog','optional',packdir,packinfo,desc,octfiledir)
    
    index_file=fullfile(packdir,'INDEX')
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:113
    if (exist(index_file,'file')):
        packinfo_copy_file('INDEX','required',packdir,packinfo,desc,octfiledir)
    else:
        try:
            write_index(desc,fullfile(packdir,'inst'),fullfile(packinfo,'INDEX'),global_install)
        finally:
            pass
    
    ## Is there an 'on_uninstall.m' to install?
    packinfo_copy_file('on_uninstall.m','optional',packdir,packinfo,desc,octfiledir)
    
    docdir=fullfile(packdir,'doc')
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:131
    if (exist(docdir,'dir') and logical_not(dirempty(docdir))):
        status,output=copyfile(docdir,desc.dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:133
    
    ## Is there a bin/ directory that needs to be installed?
  ## FIXME: Need to treat architecture dependent files in bin/
    bindir=fullfile(packdir,'bin')
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:138
    if (exist(bindir,'dir') and logical_not(dirempty(bindir))):
        status,output=copyfile(bindir,desc.dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/copy_files.m:140
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{deps_cell} =} fix_depends (@var{depends})
## Undocumented internal function.
## @end deftypefn
    
    ## Make sure the depends field is of the right format.
## This function returns a cell of structures with the following fields:
##   package, version, operator
    
@function
def fix_depends(depends=None,*args,**kwargs):
    varargin = fix_depends.varargin
    nargin = fix_depends.nargin

    deps=strtrim(ostrsplit(tolower(depends),','))
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:29
    deps_cell=cell(1,length(deps))
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:30
    dep_pat='\\s*(?<name>[-\\w]+)\\s*(\\(\\s*(?<op>[<>=]+)\\s*(?<ver>\\d+\\.\\d+(\\.\\d+)*)\\s*\\))*\\s*'
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:31
    
    for i in arange(1,length(deps)).reshape(-1):
        dep=deps[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:36
        start,nm=regexp(dep,dep_pat,'start','names',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:37
        ## in the correct format?
        if (logical_not(isempty(start))):
            package=tolower(strtrim(nm.name))
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:41
            ## Example: package(>= version).
            if (logical_not(isempty(nm.ver))):
                operator=nm.op
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:45
                if (logical_not(any(strcmp(operator,cellarray(['>','>=','<=','<','==']))))):
                    error('unsupported operator: %s',operator)
                version=fix_version(nm.ver)
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:49
                ## we say that the version should be greater than
        ## or equal to "0.0.0".
            else:
                package=tolower(strtrim(dep))
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:54
                operator='>='
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:55
                version='0.0.0'
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:56
            deps_cell[i]=struct('package',package,'operator',operator,'version',version)
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_depends.m:58
        else:
            error('incorrect syntax for dependency \'%s\' in the DESCRIPTION file\n',dep)
    
    return deps_cell
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{dep} =} is_architecture_dependent (@var{nm})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def is_architecture_dependent(nm=None,*args,**kwargs):
    varargin = is_architecture_dependent.varargin
    nargin = is_architecture_dependent.nargin

    
    dep=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:28
    for i in arange(1,length(archdepsuffix)).reshape(-1):
        ext=archdepsuffix[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:30
        if (ext[end()] == '*'):
            isglob=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:32
            ext[end()]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:33
        else:
            isglob=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:35
        pos=strfind(nm,ext)
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:37
        if (pos):
            if (logical_not(isglob) and (length(nm) - pos[end()] != length(ext) - 1)):
                continue
            dep=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/is_architecture_dependent.m:42
            break
    
    return dep
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} unload_packages (@var{files}, @var{handle_deps}, @var{local_list}, @var{global_list})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def unload_packages(files=None,handle_deps=None,local_list=None,global_list=None,*args,**kwargs):
    varargin = unload_packages.varargin
    nargin = unload_packages.nargin

    installed_pkgs_lst=installed_packages(local_list,global_list)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:26
    num_packages=length(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:27
    
    pnames=pdirs=cell(1,num_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:30
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:30
    for i in arange(1,num_packages).reshape(-1):
        pnames[i]=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:32
        pdirs[i]=installed_pkgs_lst[i].dir
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:33
        pdeps[i]=installed_pkgs_lst[i].depends
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:34
    
    ## Get the current octave path.
    p=strtrim(ostrsplit(path(),pathsep()))
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:38
    if (length(files) == 1 and strcmp(files[1],'all')):
        ## Unload all.
        dirs=copy(pdirs)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:42
        desc=copy(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:43
    else:
        ## Unload package_name1 ...
        dirs=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:46
        desc=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:47
        for i in arange(1,length(files)).reshape(-1):
            idx=strcmp(pnames,files[i])
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:49
            if (logical_not(any(idx))):
                error('package %s is not installed',files[i])
            dirs[end() + 1]=pdirs[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:53
            desc[end() + 1]=installed_pkgs_lst[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:54
    
    ## Check for architecture dependent directories.
    archdirs=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:59
    for i in arange(1,length(dirs)).reshape(-1):
        tmpdir=getarchdir(desc[i])
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:61
        if (exist(tmpdir,'dir')):
            archdirs[end() + 1]=dirs[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:63
            archdirs[end() + 1]=tmpdir
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:64
        else:
            archdirs[end() + 1]=dirs[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:66
    
    ## Unload the packages.
    for i in arange(1,length(archdirs)).reshape(-1):
        d=archdirs[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:72
        idx=strcmp(p,d)
# /home/lei/octave-4.0.2/scripts/pkg/private/unload_packages.m:73
        if (any(idx)):
            rmpath(d)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} build (@var{files}, @var{handle_deps}, @var{autoload}, @var{verbose})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def build(files=None,handle_deps=None,autoload=None,verbose=None,*args,**kwargs):
    varargin = build.varargin
    nargin = build.nargin

    if (length(files) < 1):
        error('insufficient number of files')
    
    builddir=files[1]
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:29
    if (logical_not(exist(builddir,'dir'))):
        warning('creating build directory %s',builddir)
        status,msg=mkdir(builddir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:32
        if (status != 1):
            error('could not create installation directory: %s',msg)
    
    builddir,status=canonicalize_file_name(builddir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:37
    if (status != 0):
        error('cannot find directory %s',builddir)
    
    installdir=fullfile(builddir,'install')
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:41
    if (logical_not(exist(installdir,'dir'))):
        status,msg=mkdir(installdir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:43
        if (status != 1):
            error('could not create installation directory: %s',msg)
    
    files[1]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:48
    buildlist=fullfile(builddir,'octave_packages')
# /home/lei/octave-4.0.2/scripts/pkg/private/build.m:49
    install(files,handle_deps,autoload,installdir,installdir,verbose,buildlist,'',false)
    try:
        repackage(builddir,buildlist)
    finally:
        unload_packages(cellarray(['all']),handle_deps,buildlist,'')
        if (exist(installdir,'dir')):
            rmdir(installdir,'s')
        if (exist(buildlist,'file')):
            unlink(buildlist)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{emp} =} dirempty (@var{nm}, @var{ign})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def dirempty(nm=None,ign=None,*args,**kwargs):
    varargin = dirempty.varargin
    nargin = dirempty.nargin

    if (exist(nm,'dir')):
        if (nargin < 2):
            ign=cellarray(['.','..'])
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:28
        else:
            ign=matlabarray(cat(cellarray(['.','..']),ign))
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:30
        l=dir(nm)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:32
        for i in arange(1,length(l)).reshape(-1):
            found=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:34
            for j in arange(1,length(ign)).reshape(-1):
                if (strcmp(l[i].name,ign[j])):
                    found=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:37
                    break
            if (logical_not(found)):
                emp=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:42
                return emp
        emp=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:46
    else:
        emp=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/dirempty.m:48
    
    return emp
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} uninstall (@var{pkgnames}, @var{handle_deps}, @var{verbose}, @var{local_list}, @var{global_list}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def uninstall(pkgnames=None,handle_deps=None,verbose=None,local_list=None,global_list=None,global_install=None,*args,**kwargs):
    varargin = uninstall.varargin
    nargin = uninstall.nargin

    ## Get the list of installed packages.
    local_packages,global_packages=installed_packages(local_list,global_list,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:28
    if (global_install):
        installed_pkgs_lst=cellarray([local_packages[:],global_packages[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:31
    else:
        installed_pkgs_lst=copy(local_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:33
    
    num_packages=length(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:36
    delete_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:37
    for i in arange(1,num_packages).reshape(-1):
        cur_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:39
        if (any(strcmp(cur_name,pkgnames))):
            delete_idx[end() + 1]=i
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:41
    
    ## Are all the packages that should be uninstalled already installed?
    if (length(delete_idx) != length(pkgnames)):
        if (global_install):
            ## Try again for a locally installed package.
            installed_pkgs_lst=copy(local_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:49
            num_packages=length(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:51
            delete_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:52
            for i in arange(1,num_packages).reshape(-1):
                cur_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:54
                if (any(strcmp(cur_name,pkgnames))):
                    delete_idx[end() + 1]=i
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:56
            if (length(delete_idx) != length(pkgnames)):
                ## FIXME: We should have a better error message.
                warning('some of the packages you want to uninstall are not installed')
        else:
            ## FIXME: We should have a better error message.
            warning('some of the packages you want to uninstall are not installed')
    
    if (isempty(delete_idx)):
        warning('no packages will be uninstalled')
    else:
        ## Compute the packages that will remain installed.
        idx=setdiff(arange(1,num_packages),delete_idx)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:74
        remaining_packages=cellarray([installed_pkgs_lst[idx]])
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:75
        if (handle_deps):
            error_text=''
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:79
            for i in arange(1,length(remaining_packages)).reshape(-1):
                desc=remaining_packages[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:81
                bad_deps=get_unsatisfied_deps(desc,remaining_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:82
                if (logical_not(isempty(bad_deps))):
                    for i in arange(1,length(bad_deps)).reshape(-1):
                        dep=bad_deps[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:87
                        error_text=matlabarray(cat(error_text,' ',desc.name,' needs ',dep.package,' ',dep.operator,' ',dep.version,'\n'))
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:88
            if (logical_not(isempty(error_text))):
                error('the following dependencies where unsatisfied:\n  %s',error_text)
        ## Delete the directories containing the packages.
        for i in delete_idx.reshape(-1):
            desc=installed_pkgs_lst[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:101
            if (exist(fullfile(desc.dir,'packinfo','on_uninstall.m'),'file')):
                wd=pwd()
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:104
                cd(fullfile(desc.dir,'packinfo'))
                on_uninstall(desc)
                cd(wd)
            ## Do the actual deletion.
            if (desc.loaded):
                rmpath(desc.dir)
                if (exist(getarchdir(desc))):
                    rmpath(getarchdir(desc))
            if (exist(desc.dir,'dir')):
                status,msg=rmdir(desc.dir,'s',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:117
                if (status != 1 and exist(desc.dir,'dir')):
                    error('couldn\'t delete directory %s: %s',desc.dir,msg)
                status,msg=rmdir(getarchdir(desc),'s',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:121
                if (status != 1 and exist(getarchdir(desc),'dir')):
                    error('couldn\'t delete directory %s: %s',getarchdir(desc),msg)
                if (dirempty(desc.archprefix)):
                    rmdir(desc.archprefix,'s')
            else:
                warning('directory %s previously lost',desc.dir)
        ## Write a new ~/.octave_packages.
        if (global_install):
            if (length(remaining_packages) == 0):
                unlink(global_list)
            else:
                global_packages=save_order(remaining_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:138
                save(global_list,'global_packages')
        else:
            if (length(remaining_packages) == 0):
                unlink(local_list)
            else:
                local_packages=save_order(remaining_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/uninstall.m:145
                save(local_list,'local_packages')
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{archdir} =} getarchdir (@var{desc})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def getarchdir(desc=None,*args,**kwargs):
    varargin = getarchdir.varargin
    nargin = getarchdir.nargin

    archdir=fullfile(desc.archprefix,getarch())
# /home/lei/octave-4.0.2/scripts/pkg/private/getarchdir.m:26
    return archdir
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{out} =} fix_version (@var{v})
## Undocumented internal function.
## @end deftypefn
    
    ## Make sure the version string v is a valid x.y.z version string
## Examples: "0.1" => "0.1.0", "monkey" => error(...).
    
@function
def fix_version(v=None,*args,**kwargs):
    varargin = fix_version.varargin
    nargin = fix_version.nargin

    if (regexp(v,'^\\d+(\\.\\d+){1,2}$') == 1):
        parts=ostrsplit(v,'.',true)
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_version.m:30
        if (numel(parts) == 2):
            out=strcat(v,'.0')
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_version.m:32
        else:
            out=copy(v)
# /home/lei/octave-4.0.2/scripts/pkg/private/fix_version.m:34
    else:
        error('bad version string: %s',v)
    
    return out
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{desc} =} get_description (@var{filename})
## Undocumented internal function.
## @end deftypefn
    
    ## Parse the DESCRIPTION file.
    
@function
def get_description(filename=None,*args,**kwargs):
    varargin = get_description.varargin
    nargin = get_description.nargin

    fid,msg=fopen(filename,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:27
    if (fid == - 1):
        error('the DESCRIPTION file %s could not be read: %s',filename,msg)
    
    desc=struct()
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:32
    line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:34
    while (line != - 1):

        if (line[1] == '#'):
            ## Comments, do nothing.
            pass
        else:
            if (isspace(line[1])):
                ## Continuation lines
                if (exist('keyword','var') and isfield(desc,keyword)):
                    setattr(desc,keyword,cat(getattr(desc,(keyword)),' ',deblank(line)))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:41
            else:
                ## Keyword/value pair
                colon=find(line == ':')
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:45
                if (length(colon) == 0):
                    disp('skipping line')
                else:
                    colon=colon[1]
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:49
                    keyword=tolower(strtrim(line[1:colon - 1]))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:50
                    value=strtrim(line[colon + 1:end()])
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:51
                    if (length(value) == 0):
                        fclose(fid)
                        error('The keyword \'%s\' of the package \'%s\' has an empty value',keyword,desc.name)
                    setattr(desc,keyword,value)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:57
        line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:60

    
    fclose(fid)
    
    needed_fields=cellarray(['name','version','date','title','author','maintainer','description'])
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:65
    for f in needed_fields.reshape(-1):
        if (logical_not(isfield(desc,f[1]))):
            error('description is missing needed field %s',f[1])
    
    desc.version = copy(fix_version(desc.version))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:72
    if (isfield(desc,'depends')):
        desc.depends = copy(fix_depends(desc.depends))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:74
    else:
        desc.depends = copy('')
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:76
    
    desc.name = copy(tolower(desc.name))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_description.m:78
    return desc
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010-2015 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{ver}, @var{url}] =} get_forge_pkg (@var{name})
## Try to discover the current version of an OctaveForge package from the web,
## using a working internet connection and the urlread function.
## If two output arguments are requested, also return an address from which
## to download the file.
## @end deftypefn
    
    
@function
def get_forge_pkg(name=None,*args,**kwargs):
    varargin = get_forge_pkg.varargin
    nargin = get_forge_pkg.nargin

    ## Verify that name is valid.
    if (logical_not((ischar(name) and rows(name) == 1 and ndims(name) == 2))):
        error('get_forge_pkg: package NAME must be a string')
    else:
        if (logical_not(all(logical_or(isalnum(name),name) == logical_or('-',name) == logical_or('.',name) == '_'))):
            error('get_forge_pkg: invalid package name: %s',name)
    
    name=tolower(name)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:37
    
    html,succ=urlread(sprintf('http://packages.octave.org/%s/index.html',name),nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:40
    if (succ):
        ## Remove blanks for simpler matching.
        html[isspace(html)]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:44
        pat='<tdclass=""package_table"">PackageVersion:</td><td>([\\d.]*)</td>'
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:46
        t=regexp(html,pat,'tokens')
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:47
        if (isempty(t) or isempty(t[1])):
            error('get_forge_pkg: could not read version number from package\'s page')
        else:
            ver=t[1][1]
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:51
            if (nargout > 1):
                ## Build download string.
                pkg_file=sprintf('%s-%s.tar.gz',name,ver)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:54
                url=matlabarray(cat('http://packages.octave.org/download/',pkg_file))
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:55
                if (isempty(strfind(html,pkg_file))):
                    warning('get_forge_pkg: download URL not verified')
    else:
        ## Try get the list of all packages.
        html,succ=urlread('http://packages.octave.org/packages.php',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:64
        if (succ):
            t=regexp(html,'<div class=""package"" id=""(\\w+)"">','tokens')
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:66
            t=horzcat(t[:])
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:67
            if (any(strcmp(t,name))):
                error('get_forge_pkg: package NAME exists, but index page not available')
            else:
                ## Try a simplistic method to determine close names.
                dist=cellfun(lambda n=None: length(setdiff(name,n)),t)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:72
                __,i=min(dist,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_forge_pkg.m:73
                error('get_forge_pkg: package not found: ""%s"". Maybe you meant ""%s?""',name,t[i])
        else:
            error('get_forge_pkg: could not read URL, please verify internet connection')
    
    return ver,url
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} generate_lookfor_cache (@var{desc})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def generate_lookfor_cache(desc=None,*args,**kwargs):
    varargin = generate_lookfor_cache.varargin
    nargin = generate_lookfor_cache.nargin

    dirs=strtrim(ostrsplit(genpath(desc.dir),pathsep()))
# /home/lei/octave-4.0.2/scripts/pkg/private/generate_lookfor_cache.m:26
    for i in arange(1,length(dirs)).reshape(-1):
        doc_cache_create(fullfile(dirs[i],'doc-cache'),dirs[i])
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} print_package_description (@var{pkg_name}, @var{pkg_ver}, @var{pkg_idx_struct}, @var{pkg_desc}, @var{status}, @var{verbose})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def print_package_description(pkg_name=None,pkg_ver=None,pkg_idx_struct=None,pkg_desc=None,status=None,verbose=None,*args,**kwargs):
    varargin = print_package_description.varargin
    nargin = print_package_description.nargin

    printf('---\nPackage name:\n\t%s\n',pkg_name)
    printf('Version:\n\t%s\n',pkg_ver)
    printf('Short description:\n\t%s\n',pkg_desc)
    printf('Status:\n\t%s\n',status)
    if (verbose):
        printf('---\nProvides:\n')
        for i in arange(1,length(pkg_idx_struct)).reshape(-1):
            if (logical_not(isempty(pkg_idx_struct[i].functions))):
                printf('%s\n',pkg_idx_struct[i].category)
                for j in arange(1,length(pkg_idx_struct[i].functions)).reshape(-1):
                    printf('\t%s\n',pkg_idx_struct[i].functions[j])
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{descriptions} =} rebuild (@var{prefix}, @var{archprefix}, @var{list}, @var{files}, @var{auto}, @var{verbose})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def rebuild(prefix=None,archprefix=None,list=None,files=None,auto=None,verbose=None,*args,**kwargs):
    varargin = rebuild.varargin
    nargin = rebuild.nargin

    if (isempty(files)):
        dirlist,err,msg=readdir(prefix,nargout=3)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:27
        if (err):
            error('couldn\'t read directory %s: %s',prefix,msg)
        ## the two first entries of dirlist are "." and ".."
        dirlist[cat(1,2)]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:32
    else:
        old_descriptions=installed_packages(list,list)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:34
        wd=pwd()
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:35
        try:
            cd(prefix)
            dirlist=glob(strcat(files,'-*'))
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:38
        finally:
            cd(wd)
    
    descriptions=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:43
    for k in arange(1,length(dirlist)).reshape(-1):
        descfile=fullfile(prefix,dirlist[k],'packinfo','DESCRIPTION')
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:45
        if (verbose):
            printf('recreating package description from %s\n',dirlist[k])
        if (exist(descfile,'file')):
            desc=get_description(descfile)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:50
            desc.dir = copy(fullfile(prefix,dirlist[k]))
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:51
            desc.archprefix = copy(fullfile(archprefix,cat(desc.name,'-',desc.version)))
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:52
            if (auto != 0):
                if (exist(fullfile(desc.dir,'packinfo','.autoload'),'file')):
                    unlink(fullfile(desc.dir,'packinfo','.autoload'))
                if (auto < 0):
                    desc.autoload = copy(0)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:58
                else:
                    if (auto > 0):
                        desc.autoload = copy(1)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:60
                        fclose(fopen(fullfile(desc.dir,'packinfo','.autoload'),'wt'))
            else:
                if (exist(fullfile(desc.dir,'packinfo','.autoload'),'file')):
                    desc.autoload = copy(1)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:65
                else:
                    desc.autoload = copy(0)
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:67
            descriptions[end() + 1]=desc
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:70
        else:
            if (verbose):
                warning('directory %s is not a valid package',dirlist[k])
    
    if (logical_not(isempty(files))):
        ## We are rebuilding for a particular package(s) so we should take
    ## care to keep the other untouched packages in the descriptions
        descriptions=cellarray([descriptions[:],old_descriptions[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:79
        dup=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:81
        for i in arange(1,length(descriptions)).reshape(-1):
            if (any(dup == i)):
                continue
            for j in arange((i + 1),length(descriptions)).reshape(-1):
                if (any(dup == j)):
                    continue
                if (strcmp(descriptions[i].name,descriptions[j].name)):
                    dup=matlabarray(cat(dup,j))
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:91
        if (logical_not(isempty(dup))):
            descriptions[dup]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/rebuild.m:96
    
    return descriptions
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} install (@var{files}, @var{handle_deps}, @var{autoload}, @var{prefix}, @var{archprefix}, @var{verbose}, @var{local_list}, @var{global_list}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def install(files=None,handle_deps=None,autoload=None,prefix=None,archprefix=None,verbose=None,local_list=None,global_list=None,global_install=None,*args,**kwargs):
    varargin = install.varargin
    nargin = install.nargin

    ## Check that the directory in prefix exist. If it doesn't: create it!
    if (logical_not(exist(prefix,'dir'))):
        warning('creating installation directory %s',prefix)
        status,msg=mkdir(prefix,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:31
        if (status != 1):
            error('could not create installation directory: %s',msg)
    
    ## Get the list of installed packages.
    local_packages,global_packages=installed_packages(local_list,global_list,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:38
    installed_pkgs_lst=cellarray([local_packages[:],global_packages[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:41
    if (global_install):
        packages=copy(global_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:44
    else:
        packages=copy(local_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:46
    
    ## Uncompress the packages and read the DESCRIPTION files.
    tmpdirs=packdirs=descriptions=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:50
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:50
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:50
    try:
        ## Warn about non existent files.
        for i in arange(1,length(files)).reshape(-1):
            if (isempty(glob(files[i]))):
                warning('file %s does not exist',files[i])
        ## Unpack the package files and read the DESCRIPTION files.
        files=glob(files)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:60
        packages_to_uninstall=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:61
        for i in arange(1,length(files)).reshape(-1):
            tgz=files[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:63
            if (exist(tgz,'file')):
                ## Create a temporary directory.
                tmpdir=tempname()
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:67
                tmpdirs[end() + 1]=tmpdir
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:68
                if (verbose):
                    printf('mkdir (%s)\n',tmpdir)
                status,msg=mkdir(tmpdir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:72
                if (status != 1):
                    error('couldn\'t create temporary directory: %s',msg)
                ## Uncompress the package.
                if (verbose):
                    printf('untar (%s, %s)\n',tgz,tmpdir)
                untar(tgz,tmpdir)
                dirlist,err,msg=readdir(tmpdir,nargout=3)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:84
                if (err):
                    error('couldn\'t read directory produced by tar: %s',msg)
                if (length(dirlist) > 3):
                    error('bundles of packages are not allowed')
            ## The filename pointed to an uncompressed package to begin with.
            if (exist(tgz,'dir')):
                dirlist=cellarray(['.','..',tgz])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:96
            if (exist(tgz,'file') or exist(tgz,'dir')):
                ## The two first entries of dirlist are "." and "..".
                if (exist(tgz,'file')):
                    packdir=fullfile(tmpdir,dirlist[3])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:102
                else:
                    packdir=fullfile(pwd(),dirlist[3])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:104
                packdirs[end() + 1]=packdir
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:106
                verify_directory(packdir)
                filename=fullfile(packdir,'DESCRIPTION')
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:112
                desc=get_description(filename)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:113
                dummy,nm=fileparts(tgz,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:116
                if ((length(nm) >= length(desc.name)) and logical_not(strcmp(desc.name,nm[1:length(desc.name)]))):
                    error('package name \'%s\' doesn\'t correspond to its filename \'%s\'',desc.name,nm)
                ## Set default installation directory.
                desc.dir = copy(fullfile(prefix,cat(desc.name,'-',desc.version)))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:124
                desc.archprefix = copy(fullfile(archprefix,cat(desc.name,'-',desc.version)))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:127
                descriptions[end() + 1]=desc
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:130
                ## If so we'll remove the old version.
                for j in arange(1,length(packages)).reshape(-1):
                    if (strcmp(packages[j].name,desc.name)):
                        packages_to_uninstall[end() + 1]=j
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:136
    finally:
        pass
    
    ## Check dependencies.
    if (handle_deps):
        ok=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:151
        error_text=''
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:152
        for i in arange(1,length(descriptions)).reshape(-1):
            desc=descriptions[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:154
            idx2=setdiff(arange(1,length(descriptions)),i)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:155
            if (global_install):
                ## Global installation is not allowed to have dependencies on locally
        ## installed packages.
                idx1=setdiff(arange(1,length(global_packages)),packages_to_uninstall)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:159
                pseudo_installed_packages=cellarray([global_packages[idx1],descriptions[idx2]])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:160
            else:
                idx1=setdiff(arange(1,length(local_packages)),packages_to_uninstall)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:163
                pseudo_installed_packages=cellarray([local_packages[idx1],global_packages[:],descriptions[idx2]])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:164
            bad_deps=get_unsatisfied_deps(desc,pseudo_installed_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:168
            if (logical_not(isempty(bad_deps))):
                ok=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:171
                for i in arange(1,length(bad_deps)).reshape(-1):
                    dep=bad_deps[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:173
                    error_text=matlabarray(cat(error_text,' ',desc.name,' needs ',dep.package,' ',dep.operator,' ',dep.version,'\n'))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:174
        ## Did we find any unsatisfied dependencies?
        if (logical_not(ok)):
            error('the following dependencies were unsatisfied:\n  %s',error_text)
    
    ## Prepare each package for installation.
    try:
        for i in arange(1,length(descriptions)).reshape(-1):
            desc=descriptions[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:189
            pdir=packdirs[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:190
            prepare_installation(desc,pdir)
            configure_make(desc,pdir,verbose)
    finally:
        pass
    
    ## Uninstall the packages that will be replaced.
    try:
        for i in packages_to_uninstall.reshape(-1):
            if (global_install):
                uninstall(cellarray([global_packages[i].name]),false,verbose,local_list,global_list,global_install)
            else:
                uninstall(cellarray([local_packages[i].name]),false,verbose,local_list,global_list,global_install)
    finally:
        pass
    
    ## Install each package.
    try:
        for i in arange(1,length(descriptions)).reshape(-1):
            desc=descriptions[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:224
            pdir=packdirs[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:225
            copy_files(desc,pdir,global_install)
            create_pkgadddel(desc,pdir,'PKG_ADD',global_install)
            create_pkgadddel(desc,pdir,'PKG_DEL',global_install)
            finish_installation(desc,pdir,global_install)
            generate_lookfor_cache(desc)
    finally:
        pass
    
    ## Check if the installed directory is empty. If it is remove it
  ## from the list.
    for i in arange(length(descriptions),1,- 1).reshape(-1):
        if (dirempty(descriptions[i].dir,cellarray(['packinfo','doc'])) and dirempty(getarchdir(descriptions[i]))):
            warning('package %s is empty\n',descriptions[i].name)
            rmdir(descriptions[i].dir,'s')
            rmdir(getarchdir(descriptions[i]),'s')
            descriptions[i]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:252
    
    ## If the package requested that it is autoloaded, or the installer
  ## requested that it is, then mark the package as autoloaded.
    str_true=cellarray(['true','on','yes','1'])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:258
    for i in arange(length(descriptions),1,- 1).reshape(-1):
        desc_autoload=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:261
        if (isfield(descriptions[i],'autoload')):
            a=descriptions[i].autoload
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:263
            desc_autoload=((isnumeric(a) and a > 0) or (ischar(a) and any(strcmpi(a,str_true))))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:264
        if (autoload > 0 or (autoload == 0 and desc_autoload)):
            fclose(fopen(fullfile(descriptions[i].dir,'packinfo','.autoload'),'wt'))
            descriptions[i].autoload = copy(1)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:272
        else:
            descriptions[i].autoload = copy(0)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:274
    
    ## Add the packages to the package list.
    try:
        if (global_install):
            idx=setdiff(arange(1,length(global_packages)),packages_to_uninstall)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:282
            global_packages=save_order(cellarray([global_packages[idx],descriptions[:]]))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:283
            save(global_list,'global_packages')
            installed_pkgs_lst=cellarray([local_packages[:],global_packages[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:285
        else:
            idx=setdiff(arange(1,length(local_packages)),packages_to_uninstall)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:287
            local_packages=save_order(cellarray([local_packages[idx],descriptions[:]]))
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:288
            save(local_list,'local_packages')
            installed_pkgs_lst=cellarray([local_packages[:],global_packages[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:290
    finally:
        pass
    
    ## All is well, let's clean up.
    for i in arange(1,length(tmpdirs)).reshape(-1):
        status,msg=rmdir(tmpdirs[i],'s',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:310
        if (status != 1 and exist(tmpdirs[i],'dir')):
            warning('couldn\'t clean up after my self: %s\n',msg)
    
    ## Add the newly installed packages to the path, so the user
  ## can begin using them. Only load them if they are marked autoload.
    if (length(descriptions) > 0):
        idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:319
        for i in arange(1,length(descriptions)).reshape(-1):
            if (descriptions[i].autoload > 0):
                nm=descriptions[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:322
                for j in arange(1,length(installed_pkgs_lst)).reshape(-1):
                    if (strcmp(nm,installed_pkgs_lst[j].name)):
                        idx[end() + 1]=j
# /home/lei/octave-4.0.2/scripts/pkg/private/install.m:325
                        break
        load_packages_and_dependencies(idx,handle_deps,installed_pkgs_lst,global_install)
    
    ## If there is a NEWS file, mention it.
  ## Check if desc exists too because it's possible to get to this point
  ## without creating it such as giving an invalid filename for the package
    if (exist('desc','var') and exist(fullfile(desc.dir,'packinfo','NEWS'),'file')):
        printf('For information about changes from previous versions of the %s package, run \'news %s\'.\n',desc.name,desc.name)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} packinfo_copy_file (@var{filename}, @var{requirement}, @var{packdir}, @var{packinfo}, @var{desc}, @var{octfiledir})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def packinfo_copy_file(filename=None,requirement=None,packdir=None,packinfo=None,desc=None,octfiledir=None,*args,**kwargs):
    varargin = packinfo_copy_file.varargin
    nargin = packinfo_copy_file.nargin

    filepath=fullfile(packdir,filename)
# /home/lei/octave-4.0.2/scripts/pkg/private/packinfo_copy_file.m:26
    if (logical_not(exist(filepath,'file')) and strcmpi(requirement,'optional')):
        ## do nothing, it's still OK
        pass
    else:
        status,output=copyfile(filepath,packinfo,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/packinfo_copy_file.m:30
        if (status != 1):
            rmdir(desc.dir,'s')
            rmdir(octfiledir,'s')
            error('Couldn\'t copy %s file: %s',filename,output)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{arch} =} getarch ()
## Undocumented internal function.
## @end deftypefn
    
    
@function
def getarch(*args,**kwargs):
    varargin = getarch.varargin
    nargin = getarch.nargin

    
    arch=copy(_arch)
# /home/lei/octave-4.0.2/scripts/pkg/private/getarch.m:28
    return arch
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{idx} =} load_package_dirs (@var{lidx}, @var{idx}, @var{handle_deps}, @var{installed_pkgs_lst})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def load_package_dirs(lidx=None,idx=None,handle_deps=None,installed_pkgs_lst=None,*args,**kwargs):
    varargin = load_package_dirs.varargin
    nargin = load_package_dirs.nargin

    for i in lidx.reshape(-1):
        if (isfield(installed_pkgs_lst[i],'loaded') and installed_pkgs_lst[i].loaded):
            continue
        else:
            ## Insert this package at the front before recursing over dependencies.
            if (logical_not(any(idx == i))):
                idx=matlabarray(cat(i,idx))
# /home/lei/octave-4.0.2/scripts/pkg/private/load_package_dirs.m:33
            if (handle_deps):
                deps=installed_pkgs_lst[i].depends
# /home/lei/octave-4.0.2/scripts/pkg/private/load_package_dirs.m:37
                if ((length(deps) > 1) or (length(deps) == 1 and logical_not(strcmp(deps[1].package,'octave')))):
                    tmplidx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/load_package_dirs.m:40
                    for k in arange(1,length(deps)).reshape(-1):
                        for j in arange(1,length(installed_pkgs_lst)).reshape(-1):
                            if (strcmp(installed_pkgs_lst[j].name,deps[k].package)):
                                if (logical_not(any(idx == j))):
                                    tmplidx[end() + 1]=j
# /home/lei/octave-4.0.2/scripts/pkg/private/load_package_dirs.m:45
                                    break
                    idx=load_package_dirs(tmplidx,idx,handle_deps,installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/load_package_dirs.m:51
    
    return idx
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2014-2015 Carlo de Falco
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{prefix}, @var{archprefix} =} default_prefix (@var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def default_prefix(global_install=None,desc=None,*args,**kwargs):
    varargin = default_prefix.varargin
    nargin = default_prefix.nargin

    if (global_install):
        prefix=fullfile(OCTAVE_HOME(),'share','octave','packages')
# /home/lei/octave-4.0.2/scripts/pkg/private/default_prefix.m:26
        if (nargin == 2):
            archprefix=fullfile(octave_config_info('libdir'),'octave','packages',cat(desc.name,'-',desc.version))
# /home/lei/octave-4.0.2/scripts/pkg/private/default_prefix.m:28
        else:
            archprefix=fullfile(octave_config_info('libdir'),'octave','packages')
# /home/lei/octave-4.0.2/scripts/pkg/private/default_prefix.m:31
    else:
        prefix=tilde_expand(fullfile('~','octave'))
# /home/lei/octave-4.0.2/scripts/pkg/private/default_prefix.m:35
        archprefix=copy(prefix)
# /home/lei/octave-4.0.2/scripts/pkg/private/default_prefix.m:36
    
    return prefix,archprefix
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## Executes a shell command. In the end it calls system() but in case of
## windows will first check if sh.exe works.
##
## If VERBOSE is true, it will prints the output to STDOUT in real time and
## the second output argument will be an empty string. Otherwise, it will
## contain the output of the execeuted command.
    
    
@function
def shell(cmd=None,verbose=None,*args,**kwargs):
    varargin = shell.varargin
    nargin = shell.nargin

    
    cmd=strrep(cmd,'\\','/')
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:30
    if (ispc() and logical_not(isunix())):
        if (isempty(have_sh)):
            if (system('sh.exe -c "exit"')):
                have_sh=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:34
            else:
                have_sh=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:36
        if (have_sh):
            cmd=matlabarray(cat('sh.exe -c "',cmd,'"'))
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:40
        else:
            error('pkg: unable to find the command shell.')
    
    ## if verbose, we want to display the output in real time. To do this, we
  ## must call system with 1 output argument. But then the variable `output'
  ## won't exist. So we initialize it empty. If an error does occur, and we
  ## are verbose we will return an empty string but it's all fine since
  ## the error message has already been displayed.
    output=''
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:50
    if (verbose):
        status=system(cmd)
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:52
    else:
        status,output=system(cmd,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/shell.m:54
    
    return status,output
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {[@var{out1}, @var{out2}] =} installed_packages (@var{local_list}, @var{global_list})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def installed_packages(local_list=None,global_list=None,pkgname=cellarray([]),*args,**kwargs):
    varargin = installed_packages.varargin
    nargin = installed_packages.nargin

    ## Get the list of installed packages.
    try:
        local_packages=load(local_list).local_packages
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:29
    finally:
        pass
    
    try:
        global_packages=load(global_list).global_packages
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:34
    finally:
        pass
    
    installed_pkgs_lst=cellarray([local_packages[:],global_packages[:]])
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:38
    
    ## Locally installed packages take precedence.
    installed_names=cellfun(lambda x=None: x.name,installed_pkgs_lst,'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:42
    __,idx=unique(installed_names,'first',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:44
    installed_names=installed_names[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:45
    installed_pkgs_lst=installed_pkgs_lst[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:46
    
    if (logical_not(isempty(pkgname))):
        idx=find(strcmp(pkgname[1],installed_names))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:50
        if (isempty(idx)):
            installed_names=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:52
            installed_pkgs_lst=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:53
        else:
            installed_names=installed_names[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:55
            installed_pkgs_lst=installed_pkgs_lst[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:56
    
    ## Now check if the package is loaded.
  ## FIXME: couldn't dir_in_loadpath() be used here?
    tmppath=strrep(path(),'\\','/')
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:62
    for i in arange(1,numel(installed_pkgs_lst)).reshape(-1):
        if (strfind(tmppath,strrep(installed_pkgs_lst[i].dir,'\\','/'))):
            installed_pkgs_lst[i].loaded = copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:65
        else:
            installed_pkgs_lst[i].loaded = copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:67
    
    for i in arange(1,numel(local_packages)).reshape(-1):
        if (strfind(tmppath,strrep(local_packages[i].dir,'\\','/'))):
            local_packages[i].loaded = copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:72
        else:
            local_packages[i].loaded = copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:74
    
    for i in arange(1,numel(global_packages)).reshape(-1):
        if (strfind(tmppath,strrep(global_packages[i].dir,'\\','/'))):
            global_packages[i].loaded = copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:79
        else:
            global_packages[i].loaded = copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:81
    
    ## Should we return something?
    if (nargout == 2):
        out1=copy(local_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:87
        out2=copy(global_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:88
        return out1,out2
    else:
        if (nargout == 1):
            out1=copy(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:91
            return out1,out2
    
    ## Don't return anything, instead we'll print something.
    num_packages=numel(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:96
    if (num_packages == 0):
        if (isempty(pkgname)):
            printf('no packages installed.\n')
        else:
            printf('package %s is not installed.\n',pkgname[1])
        return out1,out2
    
    ## Compute the maximal lengths of name, version, and dir.
    h1='Package Name'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:107
    h2='Version'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:108
    h3='Installation directory'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:109
    max_name_length=max(cat(length(h1),cellfun(length,installed_names)))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:110
    version_lengths=cellfun(lambda x=None: length(x.version),installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:111
    max_version_length=max(cat(length(h2),version_lengths))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:112
    ncols=terminal_size()(2)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:113
    max_dir_length=ncols - max_name_length - max_version_length - 7
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:114
    if (max_dir_length < 20):
        max_dir_length=copy(Inf)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:116
    
    h1=postpad(h1,max_name_length + 1,' ')
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:119
    h2=postpad(h2,max_version_length,' ')
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:120
    
    
    header=sprintf('%s | %s | %s\n',h1,h2,h3)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:123
    printf(header)
    tmp=sprintf(repmat('-',1,length(header) - 1))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:125
    tmp[length(h1) + 2]='+'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:126
    tmp[length(h1) + length(h2) + 5]='+'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:127
    printf('%s\n',tmp)
    
    format=sprintf('%%%ds %%1s| %%%ds | %%s\n',max_name_length,max_version_length)
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:131
    for i in arange(1,num_packages).reshape(-1):
        cur_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:134
        cur_version=installed_pkgs_lst[i].version
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:135
        cur_dir=installed_pkgs_lst[i].dir
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:136
        if (length(cur_dir) > max_dir_length):
            first_char=length(cur_dir) - max_dir_length + 4
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:138
            first_filesep=strfind(cur_dir[first_char:end()],filesep())
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:139
            if (logical_not(isempty(first_filesep))):
                cur_dir=matlabarray(cat('...',cur_dir[(first_char + first_filesep[1] - 1):end()]))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:141
            else:
                cur_dir=matlabarray(cat('...',cur_dir[first_char:end()]))
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:143
        if (installed_pkgs_lst[i].loaded):
            cur_loaded='*'
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:147
        else:
            cur_loaded=' '
# /home/lei/octave-4.0.2/scripts/pkg/private/installed_packages.m:149
        printf(format,cur_name,cur_loaded,cur_version,cur_dir)
    
    return out1,out2
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} load_packages (@var{files}, @var{handle_deps}, @var{local_list}, @var{global_list})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def load_packages(files=None,handle_deps=None,local_list=None,global_list=None,*args,**kwargs):
    varargin = load_packages.varargin
    nargin = load_packages.nargin

    installed_pkgs_lst=installed_packages(local_list,global_list)
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:26
    num_packages=length(installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:27
    
    pnames=pdirs=cell(1,num_packages)
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:30
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:30
    for i in arange(1,num_packages).reshape(-1):
        pnames[i]=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:32
        pdirs[i]=installed_pkgs_lst[i].dir
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:33
    
    ## Load all.
    if (length(files) == 1 and strcmp(files[1],'all')):
        idx=matlabarray(cat(arange(1,length(installed_pkgs_lst))))
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:38
    else:
        if (length(files) == 1 and strcmp(files[1],'auto')):
            idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:41
            for i in arange(1,length(installed_pkgs_lst)).reshape(-1):
                if (exist(fullfile(pdirs[i],'packinfo','.autoload'),'file')):
                    idx[end() + 1]=i
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:44
            ## Load package_name1 ...
        else:
            idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:49
            for i in arange(1,length(files)).reshape(-1):
                idx2=find(strcmp(pnames,files[i]))
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:51
                if (logical_not(any(idx2))):
                    error('package %s is not installed',files[i])
                idx[end() + 1]=idx2
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages.m:55
    
    ## Load the packages, but take care of the ordering of dependencies.
    load_packages_and_dependencies(idx,handle_deps,installed_pkgs_lst,true)
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} repackage (@var{builddir}, @var{buildlist})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def repackage(builddir=None,buildlist=None,*args,**kwargs):
    varargin = repackage.varargin
    nargin = repackage.nargin

    packages=installed_packages(buildlist,buildlist)
# /home/lei/octave-4.0.2/scripts/pkg/private/repackage.m:26
    wd=pwd()
# /home/lei/octave-4.0.2/scripts/pkg/private/repackage.m:28
    for i in arange(1,length(packages)).reshape(-1):
        pack=packages[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/repackage.m:30
        try:
            cd(builddir)
            mkdir(pack.name)
            mkdir(fullfile(pack.name,'inst'))
            copyfile(fullfile(pack.dir,'*'),fullfile(pack.name,'inst'))
            movefile(fullfile(pack.name,'inst','packinfo','*'),pack.name)
            if (exist(fullfile(pack.name,'inst','packinfo','.autoload'),'file')):
                unlink(fullfile(pack.name,'inst','packinfo','.autoload'))
            rmdir(fullfile(pack.name,'inst','packinfo'))
            if (exist(fullfile(pack.name,'inst','doc'),'dir')):
                movefile(fullfile(pack.name,'inst','doc'),pack.name)
            if (exist(fullfile(pack.name,'inst','bin'),'dir')):
                movefile(fullfile(pack.name,'inst','bin'),pack.name)
            archdir=fullfile(pack.archprefix,cat(pack.name,'-',pack.version),getarch())
# /home/lei/octave-4.0.2/scripts/pkg/private/repackage.m:47
            if (exist(archdir,'dir')):
                if (exist(fullfile(pack.name,'inst','PKG_ADD'),'file')):
                    unlink(fullfile(pack.name,'inst','PKG_ADD'))
                if (exist(fullfile(pack.name,'inst','PKG_DEL'),'file')):
                    unlink(fullfile(pack.name,'inst','PKG_DEL'))
                if (exist(fullfile(archdir,'PKG_ADD'),'file')):
                    movefile(fullfile(archdir,'PKG_ADD'),fullfile(pack.name,'PKG_ADD'))
                if (exist(fullfile(archdir,'PKG_DEL'),'file')):
                    movefile(fullfile(archdir,'PKG_DEL'),fullfile(pack.name,'PKG_DEL'))
            else:
                if (exist(fullfile(pack.name,'inst','PKG_ADD'),'file')):
                    movefile(fullfile(pack.name,'inst','PKG_ADD'),fullfile(pack.name,'PKG_ADD'))
                if (exist(fullfile(pack.name,'inst','PKG_DEL'),'file')):
                    movefile(fullfile(pack.name,'inst','PKG_DEL'),fullfile(pack.name,'PKG_DEL'))
            tfile=matlabarray(cat(pack.name,'-',pack.version,'.tar'))
# /home/lei/octave-4.0.2/scripts/pkg/private/repackage.m:74
            tar(tfile,pack.name)
            try:
                gzip(tfile)
                unlink(tfile)
            finally:
                pass
        finally:
            if (exist(pack.name,'dir')):
                rmdir(pack.name,'s')
            cd(wd)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{pkg_idx_struct} =} parse_pkg_idx (@var{packdir})
## Undocumented internal function.
## @end deftypefn
    
    ## Read an INDEX file.
    
@function
def parse_pkg_idx(packdir=None,*args,**kwargs):
    varargin = parse_pkg_idx.varargin
    nargin = parse_pkg_idx.nargin

    index_file=fullfile(packdir,'packinfo','INDEX')
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:29
    if (logical_not(exist(index_file,'file'))):
        error('could not find any INDEX file in directory %s, try \'pkg rebuild all\' to generate missing INDEX files',packdir)
    
    fid,msg=fopen(index_file,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:36
    if (fid == - 1):
        error('the INDEX file %s could not be read: %s',index_file,msg)
    
    cat_num=1
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:42
    pkg_idx_struct[1].category = copy('Uncategorized')
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:43
    pkg_idx_struct[1].functions = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:44
    line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:46
    while (isempty(strfind(line,'>>')) and logical_not(feof(fid))):

        line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:48

    
    while (logical_not(feof(fid)) or line != - 1):

        if (logical_not(any(logical_not(isspace(line)))) or line[1] == '#' or any(line == '=')):
            ## Comments,  blank lines or comments about unimplemented
      ## functions: do nothing
      ## FIXME: probably comments and pointers to external functions
      ## could be treated better when printing to screen?
            pass
        else:
            if (logical_not(isempty(strfind(line,'>>')))):
                ## Skip package name and description as they are in DESCRIPTION
      ## already.
                pass
            else:
                if (logical_not(isspace(line[1]))):
                    ## Category.
                    if (logical_not(isempty(pkg_idx_struct[cat_num].functions))):
                        pkg_idx_struct[++ cat_num].functions = copy(cellarray([]))
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:63
                    pkg_idx_struct[cat_num].category = copy(deblank(line))
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:65
                else:
                    ## Function names.
                    while (any(logical_not(isspace(line)))):

                        fun_name,line=strtok(line,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:69
                        pkg_idx_struct[cat_num].functions[end() + 1]=deblank(fun_name)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:70

        line=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/parse_pkg_idx.m:73

    
    fclose(fid)
    return pkg_idx_struct
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} load_packages_and_dependencies (@var{idx}, @var{handle_deps}, @var{installed_pkgs_lst}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def load_packages_and_dependencies(idx=None,handle_deps=None,installed_pkgs_lst=None,global_install=None,*args,**kwargs):
    varargin = load_packages_and_dependencies.varargin
    nargin = load_packages_and_dependencies.nargin

    idx=load_package_dirs(idx,[],handle_deps,installed_pkgs_lst)
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:27
    dirs=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:28
    execpath=EXEC_PATH()
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:29
    for i in idx.reshape(-1):
        ndir=installed_pkgs_lst[i].dir
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:31
        dirs[end() + 1]=ndir
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:32
        if (exist(fullfile(dirs[end()],'bin'),'dir')):
            execpath=matlabarray(cat(execpath,pathsep(),fullfile(dirs[end()],'bin')))
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:34
        tmpdir=getarchdir(installed_pkgs_lst[i])
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:36
        if (exist(tmpdir,'dir')):
            dirs[end() + 1]=tmpdir
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:38
            if (exist(fullfile(dirs[end()],'bin'),'dir')):
                execpath=matlabarray(cat(execpath,pathsep(),fullfile(dirs[end()],'bin')))
# /home/lei/octave-4.0.2/scripts/pkg/private/load_packages_and_dependencies.m:40
    
    ## Load the packages.
    if (length(dirs) > 0):
        addpath(dirs[:])
    
    ## Add the binaries to exec_path.
    if (logical_not(strcmp(EXEC_PATH,execpath))):
        EXEC_PATH(execpath)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{bad_deps} =} get_unsatisfied_deps (@var{desc}, @var{installed_pkgs_lst})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def get_unsatisfied_deps(desc=None,installed_pkgs_lst=None,*args,**kwargs):
    varargin = get_unsatisfied_deps.varargin
    nargin = get_unsatisfied_deps.nargin

    bad_deps=cellarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:26
    
    for i in arange(1,length(desc.depends)).reshape(-1):
        dep=desc.depends[i]
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:30
        if (strcmp(dep.package,'octave')):
            if (logical_not(compare_versions(OCTAVE_VERSION,dep.version,dep.operator))):
                bad_deps[end() + 1]=dep
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:35
            ## Is the current dependency not Octave?
        else:
            ok=copy(false)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:39
            for i in arange(1,length(installed_pkgs_lst)).reshape(-1):
                cur_name=installed_pkgs_lst[i].name
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:41
                cur_version=installed_pkgs_lst[i].version
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:42
                if (strcmp(dep.package,cur_name) and compare_versions(cur_version,dep.version,dep.operator)):
                    ok=copy(true)
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:45
                    break
            if (logical_not(ok)):
                bad_deps[end() + 1]=dep
# /home/lei/octave-4.0.2/scripts/pkg/private/get_unsatisfied_deps.m:50
    
    return bad_deps
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} verify_directory (@var{dir})
## Undocumented internal function.
## @end deftypefn
    
    ## Make sure the package contains the essential files.
    
@function
def verify_directory(dir=None,*args,**kwargs):
    varargin = verify_directory.varargin
    nargin = verify_directory.nargin

    needed_files=cellarray(['COPYING','DESCRIPTION'])
# /home/lei/octave-4.0.2/scripts/pkg/private/verify_directory.m:27
    for f in needed_files.reshape(-1):
        if (logical_not(exist(fullfile(dir,f[1]),'file'))):
            error('package is missing file: %s',f[1])
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{pkg} =} extract_pkg (@var{nm}, @var{pat})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def extract_pkg(nm=None,pat=None,*args,**kwargs):
    varargin = extract_pkg.varargin
    nargin = extract_pkg.nargin

    fid=fopen(nm,'rt')
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:26
    pkg=''
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:27
    if (fid >= 0):
        while (logical_not(feof(fid))):

            ln=fgetl(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:30
            if (ln > 0):
                t=regexp(ln,pat,'tokens')
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:32
                if (logical_not(isempty(t))):
                    pkg=matlabarray(cat(pkg,'\n',t[1][1]))
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:34

        if (logical_not(isempty(pkg))):
            pkg=matlabarray(cat(pkg,'\n'))
# /home/lei/octave-4.0.2/scripts/pkg/private/extract_pkg.m:39
        fclose(fid)
    
    return pkg
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} configure_make (@var{desc}, @var{packdir}, @var{verbose})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def configure_make(desc=None,packdir=None,verbose=None,*args,**kwargs):
    varargin = configure_make.varargin
    nargin = configure_make.nargin

    ## Perform ./configure, make, make install in "src".
    if (exist(fullfile(packdir,'src'),'dir')):
        src=fullfile(packdir,'src')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:28
        octave_bindir=octave_config_info('bindir')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:29
        ver=version()
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:30
        ext=octave_config_info('EXEEXT')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:31
        mkoctfile_program=fullfile(octave_bindir,sprintf('mkoctfile-%s%s',ver,ext))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:32
        octave_config_program=fullfile(octave_bindir,sprintf('octave-config-%s%s',ver,ext))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:34
        octave_binary=fullfile(octave_bindir,sprintf('octave-%s%s',ver,ext))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:36
        if (logical_not(exist(mkoctfile_program,'file'))):
            __gripe_missing_component__('pkg','mkoctfile')
        if (logical_not(exist(octave_config_program,'file'))):
            __gripe_missing_component__('pkg','octave-config')
        if (logical_not(exist(octave_binary,'file'))):
            __gripe_missing_component__('pkg','octave')
        if (verbose):
            mkoctfile_program=matlabarray(cat(mkoctfile_program,' --verbose'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:49
        cenv=cellarray([['MKOCTFILE'],[mkoctfile_program],['OCTAVE_CONFIG'],[octave_config_program],['OCTAVE'],[octave_binary],['INSTALLDIR'],[desc.dir]])
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:52
        scenv=sprintf('%s=\'%s\' ',cenv[:])
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:56
        if (exist(fullfile(src,'configure'),'file')):
            flags=''
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:60
            if (isempty(getenv('CC'))):
                flags=matlabarray(cat(flags,' CC="',mkoctfile('-p','CC'),'"'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:62
            if (isempty(getenv('CXX'))):
                flags=matlabarray(cat(flags,' CXX="',mkoctfile('-p','CXX'),'"'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:65
            if (isempty(getenv('AR'))):
                flags=matlabarray(cat(flags,' AR="',mkoctfile('-p','AR'),'"'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:68
            if (isempty(getenv('RANLIB'))):
                flags=matlabarray(cat(flags,' RANLIB="',mkoctfile('-p','RANLIB'),'"'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:71
            cmd=matlabarray(cat('cd \'',src,'\'; ',scenv,'./configure --prefix="',desc.dir,'"',flags))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:73
            status,output=shell(cmd,verbose,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:75
            if (status != 0):
                rmdir(desc.dir,'s')
                disp(output)
                error('pkg: error running the configure script for %s.',desc.name)
        ## Make.
        if (ispc()):
            jobs=1
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:85
        else:
            jobs=nproc('overridable')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:87
        if (exist(fullfile(src,'Makefile'),'file')):
            status,output=shell(sprintf('%s make --jobs %i --directory \'%s\'',scenv,jobs,src),verbose,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:91
            if (status != 0):
                rmdir(desc.dir,'s')
                disp(output)
                error('pkg: error running `make\' for the %s package.',desc.name)
        ## Copy files to "inst" and "inst/arch" (this is instead of 'make
    ## install').
        files=fullfile(src,'FILES')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:102
        instdir=fullfile(packdir,'inst')
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:103
        archdir=fullfile(packdir,'inst',getarch())
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:104
        if (exist(files,'file')):
            fid,msg=fopen(files,'r',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:108
            if (fid < 0):
                error('couldn\'t open %s: %s',files,msg)
            filenames=char(fread(fid)).T
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:112
            fclose(fid)
            if (filenames[end()] == '\n'):
                filenames[end()]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:115
            filenames=strtrim(ostrsplit(filenames,'\n'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:117
            delete_idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:118
            for i in arange(1,length(filenames)).reshape(-1):
                if (logical_not(all(isspace(filenames[i])))):
                    filenames[i]=fullfile(src,filenames[i])
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:121
                else:
                    delete_idx[end() + 1]=i
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:123
            filenames[delete_idx]=[]
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:126
        else:
            m=dir(fullfile(src,'*.m'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:128
            oct=dir(fullfile(src,'*.oct'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:129
            mex=dir(fullfile(src,'*.mex'))
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:130
            filenames=cellfun(lambda x=None: fullfile(src,x),cellarray([m.name,oct.name,mex.name]),'uniformoutput',false)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:132
        ## Split into architecture dependent and independent files.
        if (isempty(filenames)):
            idx=matlabarray([])
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:139
        else:
            idx=cellfun('is_architecture_dependent',filenames)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:141
        archdependent=filenames[idx]
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:143
        archindependent=filenames[logical_not(idx)]
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:144
        if (logical_not(all(isspace(cat(filenames[:]))))):
            if (logical_not(exist(instdir,'dir'))):
                mkdir(instdir)
            if (logical_not(all(isspace(cat(archindependent[:]))))):
                if (verbose):
                    printf('copyfile')
                    printf(' %s',archindependent[:])
                    printf('%s\n',instdir)
                status,output=copyfile(archindependent,instdir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:157
                if (status != 1):
                    rmdir(desc.dir,'s')
                    error('Couldn\'t copy files from \'src\' to \'inst\': %s',output)
            if (logical_not(all(isspace(cat(archdependent[:]))))):
                if (verbose):
                    printf('copyfile')
                    printf(' %s',archdependent[:])
                    printf(' %s\n',archdir)
                if (logical_not(exist(archdir,'dir'))):
                    mkdir(archdir)
                status,output=copyfile(archdependent,archdir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/configure_make.m:172
                if (status != 1):
                    rmdir(desc.dir,'s')
                    error('Couldn\'t copy files from \'src\' to \'inst\': %s',output)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{list} =} list_forge_packages ()
## Undocumented internal function.
## @end deftypefn
    
    
@function
def list_forge_packages(*args,**kwargs):
    varargin = list_forge_packages.varargin
    nargin = list_forge_packages.nargin

    list,succ=urlread('http://packages.octave.org/list_packages.php',nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/list_forge_packages.m:26
    if (succ):
        list=ostrsplit(list,' \n\t',true)
# /home/lei/octave-4.0.2/scripts/pkg/private/list_forge_packages.m:28
    else:
        error('pkg: could not read URL, please verify internet connection')
    
    if (nargout == 0):
        page_screen_output(false,'local')
        puts('OctaveForge provides these packages:\n')
        for i in arange(1,length(list)).reshape(-1):
            try:
                ver=get_forge_pkg(list[i])
# /home/lei/octave-4.0.2/scripts/pkg/private/list_forge_packages.m:37
            finally:
                pass
            printf('  %s %s\n',list[i],ver)
    
    return list
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} prepare_installation (@var{desc}, @var{packdir})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def prepare_installation(desc=None,packdir=None,*args,**kwargs):
    varargin = prepare_installation.varargin
    nargin = prepare_installation.nargin

    ## Is there a pre_install to call?
    if (exist(fullfile(packdir,'pre_install.m'),'file')):
        wd=pwd()
# /home/lei/octave-4.0.2/scripts/pkg/private/prepare_installation.m:28
        try:
            cd(packdir)
            pre_install(desc)
            cd(wd)
        finally:
            pass
    
    ## If the directory "inst" doesn't exist, we create it.
    inst_dir=fullfile(packdir,'inst')
# /home/lei/octave-4.0.2/scripts/pkg/private/prepare_installation.m:40
    if (logical_not(exist(inst_dir,'dir'))):
        status,msg=mkdir(inst_dir,nargout=2)
# /home/lei/octave-4.0.2/scripts/pkg/private/prepare_installation.m:42
        if (status != 1):
            rmdir(desc.dir,'s')
            error('the \'inst\' directory did not exist and could not be created: %s',msg)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} finish_installation (@var{desc}, @var{packdir}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def finish_installation(desc=None,packdir=None,global_install=None,*args,**kwargs):
    varargin = finish_installation.varargin
    nargin = finish_installation.nargin

    ## Is there a post-install to call?
    if (exist(fullfile(packdir,'post_install.m'),'file')):
        wd=pwd()
# /home/lei/octave-4.0.2/scripts/pkg/private/finish_installation.m:28
        try:
            cd(packdir)
            post_install(desc)
            cd(wd)
        finally:
            pass
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2005-2015 Sren Hauberg
## Copyright (C) 2010 VZLU Prague, a.s.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} create_pkgadddel (@var{desc}, @var{packdir}, @var{nm}, @var{global_install})
## Undocumented internal function.
## @end deftypefn
    
    
@function
def create_pkgadddel(desc=None,packdir=None,nm=None,global_install=None,*args,**kwargs):
    varargin = create_pkgadddel.varargin
    nargin = create_pkgadddel.nargin

    instpkg=fullfile(desc.dir,nm)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:26
    instfid=fopen(instpkg,'wt')
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:27
    
    ## architecture dependent directory so that the autoload/mfilename
  ## commands work as expected. The only part that doesn't is the
  ## part in the main directory.
    archdir=fullfile(getarchprefix(desc,global_install),cat(desc.name,'-',desc.version),getarch())
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:32
    if (exist(getarchdir(desc,global_install),'dir')):
        archpkg=fullfile(getarchdir(desc,global_install),nm)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:35
        archfid=fopen(archpkg,'at')
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:36
    else:
        archpkg=copy(instpkg)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:38
        archfid=copy(instfid)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:39
    
    if (archfid >= 0 and instfid >= 0):
        ## Search all dot-m files for PKG commands.
        lst=dir(fullfile(packdir,'inst','*.m'))
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:44
        for i in arange(1,length(lst)).reshape(-1):
            nam=fullfile(packdir,'inst',lst[i].name)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:46
            fwrite(instfid,extract_pkg(nam,cat('^[#%][#%]* *',nm,': *(.*)$')))
        ## Search all C++ source files for PKG commands.
        lst=dir(fullfile(packdir,'src','*.cc'))
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:51
        for i in arange(1,length(lst)).reshape(-1):
            nam=fullfile(packdir,'src',lst[i].name)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:53
            fwrite(archfid,extract_pkg(nam,cat('^//* *',nm,': *(.*)$')))
            fwrite(archfid,extract_pkg(nam,cat('^/\\** *',nm,': *(.*) *\\*/$')))
        ## Add developer included PKG commands.
        packdirnm=fullfile(packdir,nm)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:59
        if (exist(packdirnm,'file')):
            fid=fopen(packdirnm,'rt')
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:61
            if (fid >= 0):
                while (logical_not(feof(fid))):

                    ln=fgets(fid)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:64
                    if (ln > 0):
                        fwrite(archfid,ln)

                fclose(fid)
        ## If the files is empty remove it.
        fclose(instfid)
        t=dir(instpkg)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:75
        if (t.bytes <= 0):
            unlink(instpkg)
        if (instfid != archfid):
            fclose(archfid)
            t=dir(archpkg)
# /home/lei/octave-4.0.2/scripts/pkg/private/create_pkgadddel.m:82
            if (t.bytes <= 0):
                unlink(archpkg)
    
    return
    
if __name__ == '__main__':
    pass
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} realsqrt (@var{x})
## Return the real-valued square root of each element of @var{x}.
##
## If any element results in a complex return value @code{realsqrt} aborts and
## issues an error.
## @seealso{sqrt, realpow, reallog}
## @end deftypefn
    
    
@function
def realsqrt(x=None,*args,**kwargs):
    varargin = realsqrt.varargin
    nargin = realsqrt.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (iscomplex(x) or any(ravel(x) < 0)):
            error('realsqrt: produced complex result')
        else:
            y=sqrt(x)
# /home/lei/octave-4.0.2/scripts/specfun/realsqrt.m:35
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{pf} =} factor (@var{q})
## @deftypefnx {Function File} {[@var{pf}, @var{n}] =} factor (@var{q})
## Return the prime factorization of @var{q}.
##
## The prime factorization is defined as @code{prod (@var{pf}) == @var{q}}
## where every element of @var{pf} is a prime number.  If @code{@var{q} == 1},
## return 1.
##
## With two output arguments, return the unique prime factors @var{pf} and
## their multiplicities.  That is, @code{prod (@var{pf} .^ @var{n}) == @var{q}}.
##
## Implementation Note: The input @var{q} must be less than
## @code{bitmax} (9.0072e+15) in order to factor correctly.
## @seealso{gcd, lcm, isprime, primes}
## @end deftypefn
    
    ## Author: Paul Kienzle
    
    ## 2002-01-28 Paul Kienzle
## * remove recursion; only check existing primes for multiplicity > 1
## * return multiplicity as suggested by Dirk Laurie
## * add error handling
    
    
@function
def factor(q=None,*args,**kwargs):
    varargin = factor.varargin
    nargin = factor.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isreal(q)) or logical_not(isscalar(q)) or q != fix(q)):
        error('factor: Q must be a real integer')
    
    ## Special case of no primes less than sqrt(q).
    if (q < 4):
        pf=copy(q)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:55
        n=1
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:56
        return pf,n
    
    q=double(q)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:60
    
    qorig=copy(q)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:61
    pf=matlabarray([])
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:62
    
    ## it has multiplicity 1, so no need to consider any factors greater
  ## than sqrt(q) directly.  [If there were two factors p1, p2 > sqrt(q),
  ## then q >= p1*p2 > sqrt(q)*sqrt(q) == q. Contradiction.]
    p=primes(sqrt(q))
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:67
    while (q > 1):

        ## Find prime factors in remaining q.
        p=p[rem(q,p) == 0]
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:70
        if (isempty(p)):
            ## Can't be reduced further, so q must itself be a prime.
            p=copy(q)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:73
        pf=matlabarray(cat(pf,p))
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:75
        q /= prod(p)

    
    pf=sort(pf)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:79
    
    q=prod(pf)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:82
    if (q != qorig):
        error('factor: Q too large to factor')
    else:
        if (q > bitmax):
            warning('factor: Q too large.  Answer is unreliable')
    
    ## Determine muliplicity.
    if (nargout > 1):
        idx=find(cat(0,pf) != cat(pf,0))
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:91
        pf=pf[idx[1:length(idx) - 1]]
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:92
        n=diff(idx)
# /home/lei/octave-4.0.2/scripts/specfun/factor.m:93
    
    return pf,n
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} reallog (@var{x})
## Return the real-valued natural logarithm of each element of @var{x}.
##
## If any element results in a complex return value @code{reallog} aborts and
## issues an error.
## @seealso{log, realpow, realsqrt}
## @end deftypefn
    
    
@function
def reallog(x=None,*args,**kwargs):
    varargin = reallog.varargin
    nargin = reallog.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (iscomplex(x) or any(ravel(x) < 0)):
            error('reallog: produced complex result')
        else:
            y=log(x)
# /home/lei/octave-4.0.2/scripts/specfun/reallog.m:35
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 2001-2015 Paul Kienzle
## Copyright (C) 2009 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} perms (@var{v})
## Generate all permutations of @var{v} with one row per permutation.
##
## The result has size @code{factorial (@var{n}) * @var{n}}, where @var{n}
## is the length of @var{v}.
##
## Example
##
## @example
## @group
## perms ([1, 2, 3])
## @result{}
##   1   2   3
##   2   1   3
##   1   3   2
##   2   3   1
##   3   1   2
##   3   2   1
## @end group
## @end example
##
## Programming Note: The maximum length of @var{v} should be less than or
## equal to 10 to limit memory consumption.
## @seealso{permute, randperm, nchoosek}
## @end deftypefn
    
    
@function
def perms(v=None,*args,**kwargs):
    varargin = perms.varargin
    nargin = perms.nargin

    if (nargin != 1):
        print_usage()
    
    vidx=uint8(cat(arange(1,length(v))).T)
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:53
    n=length(vidx)
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:54
    if (n == 0):
        p=matlabarray([])
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:57
    else:
        p=vidx[1]
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:59
        for j in arange(2,n).reshape(-1):
            B=copy(p)
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:61
            p=zeros(prod(arange(2,j)),n,'uint8')
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:62
            k=rows(B)
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:63
            idx=arange(1,k)
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:64
            for i in arange(j,1,- 1).reshape(-1):
                p[idx,1:i - 1]=B[:,1:i - 1]
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:66
                p[idx,i]=vidx[j]
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:67
                p[idx,i + 1:j]=B[:,i:j - 1]
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:68
                idx += k
    
    A=v[p]
# /home/lei/octave-4.0.2/scripts/specfun/perms.m:74
    return A
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} beta (@var{a}, @var{b})
## Compute the Beta function for real inputs @var{a} and @var{b}.
##
## The Beta function definition is
## @tex
## $$
##  B (a, b) = {\Gamma (a) \Gamma (b) \over \Gamma (a + b)}.
## $$
## @end tex
## @ifnottex
##
## @example
## beta (a, b) = gamma (a) * gamma (b) / gamma (a + b).
## @end example
##
## @end ifnottex
##
## The Beta function can grow quite large and it is often more useful to work
## with the logarithm of the output rather than the function directly.
## @xref{XREFbetaln,,betaln}, for computing the logarithm of the Beta function
## in an efficient manner.
## @seealso{betaln, betainc, betaincinv}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 13 June 1993
## Adapted-By: jwe
    
    
@function
def beta(a=None,b=None,*args,**kwargs):
    varargin = beta.varargin
    nargin = beta.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isreal(a)) or logical_not(isreal(b))):
        error('beta: A and B must be real')
    else:
        if (logical_not(size_equal(a,b)) and numel(a) != 1 and numel(b) != 1):
            error('beta: A and B must have consistent sizes')
    
    retval=real(exp(gammaln(a) + gammaln(b) - gammaln(a + b)))
# /home/lei/octave-4.0.2/scripts/specfun/beta.m:60
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Copyright (C) 1994-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Mapping Function} {} lcm (@var{x}, @var{y})
## @deftypefnx {Mapping Function} {} lcm (@var{x}, @var{y}, @dots{})
## Compute the least common multiple of @var{x} and @var{y}, or of the list of
## all arguments.
##
## All elements must be numeric and of the same size or scalar.
## @seealso{factor, gcd, isprime}
## @end deftypefn
    
    ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
## Created: 16 September 1994
## Adapted-By: jwe
    
    
@function
def lcm(varargin=None,*args,**kwargs):
    varargin = lcm.varargin
    nargin = lcm.nargin

    if (nargin < 2):
        print_usage()
    
    if (common_size(varargin[:]) != 0):
        error('lcm: all args must be the same size or scalar')
    else:
        if (logical_not(all(cellfun('isnumeric',varargin)))):
            error('lcm: all arguments must be numeric')
    
    l=varargin[1]
# /home/lei/octave-4.0.2/scripts/specfun/lcm.m:45
    for i in arange(2,nargin).reshape(-1):
        x=varargin[i]
# /home/lei/octave-4.0.2/scripts/specfun/lcm.m:47
        msk=(l == logical_and(0,x) == 0)
# /home/lei/octave-4.0.2/scripts/specfun/lcm.m:48
        l * x / gcd(l,x)
        l[msk]=0
# /home/lei/octave-4.0.2/scripts/specfun/lcm.m:50
    
    return l
    
if __name__ == '__main__':
    pass
    
    
    
    ## Copyright (C) 2001, 2013 David Billinghurst
## Copyright (C) 2001, 2013 Paul Kienzle
## Copyright (C) 2003, 2013 Jaakko Ruohio
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{k} =} ellipke (@var{m})
## @deftypefnx {Function File} {@var{k} =} ellipke (@var{m}, @var{tol})
## @deftypefnx {Function File} {[@var{k}, @var{e}] =} ellipke (@dots{})
## Compute complete elliptic integrals of the first K(@var{m}) and second
## E(@var{m}) kind.
##
## @var{m} must be a scalar or real array with -Inf @leq{} @var{m} @leq{} 1.
##
## The optional input @var{tol} controls the stopping tolerance of the
## algorithm and defaults to @code{eps (class (@var{m}))}.  The tolerance can
## be increased to compute a faster, less accurate approximation.
##
## When called with one output only elliptic integrals of the first kind are
## returned.
##
## Mathematical Note:
##
## Elliptic integrals of the first kind are defined as
##
## @tex
## $$
## {\rm K} (m) = \int_0^1 {dt \over \sqrt{(1 - t^2) (1 - m t^2)}}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##          1
##         /               dt
## K (m) = | ------------------------------
##         / sqrt ((1 - t^2)*(1 - m*t^2))
##        0
## @end group
## @end example
##
## @end ifnottex
##
## Elliptic integrals of the second kind are defined as
##
## @tex
## $$
## {\rm E} (m) = \int_0^1 {\sqrt{1 - m t^2} \over \sqrt{1 - t^2}} dt
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##          1
##         /  sqrt (1 - m*t^2)
## E (m) = |  ------------------ dt
##         /  sqrt (1 - t^2)
##        0
## @end group
## @end example
##
## @end ifnottex
##
## Reference: Milton @nospell{Abramowitz} and Irene A. @nospell{Stegun},
## @cite{Handbook of Mathematical Functions}, Chapter 17, Dover, 1965.
## @seealso{ellipj}
## @end deftypefn
    
    ## Author: David Billinghurst <David.Billinghurst@riotinto.com>
## Author: Paul Kienzle <pkienzle@users.sf.net>
## Author: Jaakko Ruohio
    
    
@function
def ellipke(m=None,tol=[],*args,**kwargs):
    varargin = ellipke.varargin
    nargin = ellipke.nargin

    if (nargin < 1 or nargin > 2):
        print_usage()
    
    sz=size(m)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:96
    if (logical_not(isreal(m))):
        error('ellipke: M must be real')
    else:
        if (any(m > 1)):
            error('ellipke: M must be <= 1')
    
    if (isempty(tol)):
        tol=eps(class_(m))
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:104
    else:
        if (logical_not((isreal(tol) and isscalar(tol) and tol > 0))):
            error('ellipke: TOL must be a real scalar > 0')
    
    k=e=zeros(sz)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:109
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:109
    
    idx_1=(m == 1)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:112
    k[idx_1]=Inf
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:113
    e[idx_1]=1
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:114
    idx_neginf=(m == - Inf)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:116
    k[idx_neginf]=0
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:117
    e[idx_neginf]=Inf
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:118
    
    ## ( Abramowitz and Stegun, Section 17.6 )
    Nmax=16
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:122
    idx=logical_and(logical_not(idx_1),logical_not(idx_neginf))
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:123
    if (any(idx)):
        idx_neg=find(m < logical_and(0,logical_not(idx_neginf)))
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:125
        mult_k=1.0 / sqrt(1 - m[idx_neg])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:126
        mult_e=sqrt(1 - m[idx_neg])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:127
        m[idx_neg]=- m[idx_neg] / (1 - m[idx_neg])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:128
        b=sqrt(1 - m[idx])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:129
        a=ones(size(b))
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:130
        c=sqrt(m[idx])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:131
        f=0.5
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:132
        sum=dot(f,c ** 2)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:133
        n=2
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:134
        do
        t=(a + b) / 2
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:136
        c=(a - b) / 2
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:137
        b=sqrt(multiply(a,b))
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:138
        a=copy(t)
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:139
        f *= 2
        sum += dot(f,c ** 2)
        until(all(c / a < tol) or (++ n > Nmax))
        if (n >= Nmax):
            error('ellipke: algorithm did not converge in %d iterations',Nmax)
        k[idx]=dot(0.5,pi) / a
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:146
        e[idx]=dot(dot(0.5,pi),(1 - sum)) / a
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:147
        k[idx_neg]=multiply(mult_k,k[idx_neg])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:148
        e[idx_neg]=multiply(mult_e,e[idx_neg])
# /home/lei/octave-4.0.2/scripts/specfun/ellipke.m:149
    
    return k,e
    
if __name__ == '__main__':
    pass
    
    ## Test complete elliptic functions of first and second kind
## against "exact" solution from Mathematica 3.0
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test against A&S Table 17.1
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test negative values against "exact" solution from Mathematica.
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2004-2015 Paul Kienzle
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
##
## Original version by Paul Kienzle distributed as free software in the
## public domain.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} nthroot (@var{x}, @var{n})
##
## Compute the real (non-complex) @var{n}-th root of @var{x}.
##
## @var{x} must have all real entries and @var{n} must be a scalar.
## If @var{n} is an even integer and @var{x} has negative entries then
## @code{nthroot} aborts and issues an error.
##
## Example:
##
## @example
## @group
## nthroot (-1, 3)
## @result{} -1
## (-1) ^ (1 / 3)
## @result{} 0.50000 - 0.86603i
## @end group
## @end example
## @seealso{realsqrt, sqrt, cbrt}
## @end deftypefn
    
    
@function
def nthroot(x=None,n=None,*args,**kwargs):
    varargin = nthroot.varargin
    nargin = nthroot.nargin

    if (nargin != 2):
        print_usage()
    
    if (iscomplex(x)):
        error('nthroot: X must not contain complex values')
    
    if (logical_not(isreal(n)) or logical_not(isscalar(n)) or n == 0):
        error('nthroot: N must be a real nonzero scalar')
    
    if (n == 3):
        y=cbrt(x)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:60
    else:
        if (n == - 3):
            y=1 / cbrt(x)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:62
        else:
            if (n < 0):
                y=1 / nthroot(x,- n)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:64
            else:
                ## Compute using power.
                integer_n=n == fix(n)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:67
                if (integer_n and mod(n,2) == 1):
                    y=multiply(abs(x) ** (1 / n),sign(x))
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:69
                else:
                    if (any(ravel(x) < 0)):
                        error('nthroot: N must be an odd integer if X contains negative values')
                    else:
                        y=x ** (1 / n)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:73
                if (integer_n and n > 0 and isfinite(n)):
                    if (isscalar(y) and y == 0):
                        ## Don't apply correction which leads to division by zero (bug #43492)
                        pass
                    else:
                        ## FIXME: What is this correction for?
                        y=(dot((n - 1),y) + x / (y ** (n - 1))) / n
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:81
                        y=merge(isfinite(y),y,x)
# /home/lei/octave-4.0.2/scripts/specfun/nthroot.m:82
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Bug #43492.  This should not generate a division by zero warning
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
## Copyright (C) 2010 VZLU Prague
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} isprime (@var{x})
## Return a logical array which is true where the elements of @var{x} are prime
## numbers and false where they are not.
##
## A prime number is conventionally defined as a positive integer greater than
## 1 (e.g., 2, 3, @dots{}) which is divisible only by itself and 1.  Octave
## extends this definition to include both negative integers and complex
## values.  A negative integer is prime if its positive counterpart is prime.
## This is equivalent to @code{isprime (abs (x))}.
##
## If @code{class (@var{x})} is complex, then primality is tested in the domain
## of Gaussian integers (@url{http://en.wikipedia.org/wiki/Gaussian_integer}).
## Some non-complex integers are prime in the ordinary sense, but not in the
## domain of Gaussian integers.  For example, @math{5 = (1+2i)*(1-2i)} shows
## that 5 is not prime because it has a factor other than itself and 1.
## Exercise caution when testing complex and real values together in the same
## matrix.
##
## Examples:
##
## @example
## @group
## isprime (1:6)
##     @result{} [0, 1, 1, 0, 1, 0]
## @end group
## @end example
##
## @example
## @group
## isprime ([i, 2, 3, 5])
##     @result{} [0, 0, 1, 0]
## @end group
## @end example
##
## Programming Note: @code{isprime} is appropriate if the maximum value in
## @var{x} is not too large (< 1e15).  For larger values special purpose
## factorization code should be used.
##
## Compatibility Note: @var{matlab} does not extend the definition of prime
## numbers and will produce an error if given negative or complex inputs.
## @seealso{primes, factor, gcd, lcm}
## @end deftypefn
    
    
@function
def isprime(x=None,*args,**kwargs):
    varargin = isprime.varargin
    nargin = isprime.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (any(fix(x) != x)):
            error('isprime: X contains non-integer entries')
    
    if (isempty(x)):
        t=copy(x)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:73
        return t
    
    if (iscomplex(x)):
        t=isgaussianprime(x)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:78
        return t
    
    ## Code strategy is to build a table with the list of possible primes
  ## and then quickly compare entries in x with the table of primes using
  ## lookup().  The table size is limited to save memory and computation
  ## time during its creation.  All entries larger than the maximum in the
  ## table are checked by straightforward division.
    
    x=abs(x)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:88
    
    maxn=max(ravel(x))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:89
    
    ## 1e7 threshold requires ~0.15 seconds of computation, 1e8 requires 1.8.
    maxp=min(maxn,max(sqrt(maxn),10000000.0))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:92
    pr=primes(maxp)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:93
    t=lookup(pr,x,'b')
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:94
    
    ## process any remaining large entries
    m=x[x > maxp]
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:97
    if (logical_not(isempty(m))):
        if (maxn <= intmax('uint32')):
            m=uint32(m)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:100
        else:
            if (maxn <= intmax('uint64')):
                m=uint64(m)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:102
            else:
                warning('isprime: X contains integers too large to be tested')
        ## Start by dividing through by the small primes until the remaining
    ## list of entries is small (and most likely prime themselves).
        pr=cast(pr[pr <= sqrt(maxn)],class_(m))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:109
        for p in pr.reshape(-1):
            m=m[rem(m,p) != 0]
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:111
            if (numel(m) < numel(pr) / 10):
                break
        ## Check the remaining list of possible primes against the
    ## remaining prime factors which were not tested in the for loop.
    ## This is just an optimization to use arrayfun over for loo
        pr=pr[pr > p]
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:120
        mm=arrayfun(lambda x=None: all(rem(x,pr)),m)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:121
        m=m[mm]
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:122
        if (logical_not(isempty(m))):
            m=cast(sort(m),class_(x))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:126
            t |= lookup(m,x,'b')
    
    return t
    
if __name__ == '__main__':
    pass
    
    
@function
def isgaussianprime(z=None,*args,**kwargs):
    varargin = isgaussianprime.varargin
    nargin = isgaussianprime.nargin

    ## Assume prime unless proven otherwise
    t=true(size(z))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:135
    x=real(z)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:137
    y=imag(z)
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:138
    
    ## that complex part if that part is 3 mod 4.
    xidx=y == logical_and(0,mod(x,4)) == 3
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:142
    yidx=x == logical_and(0,mod(y,4)) == 3
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:143
    t[xidx] &= isprime(x[xidx])
    t[yidx] &= isprime(y[yidx])
    
    zidx=logical_not((logical_or(xidx,yidx)))
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:149
    
    zabs=x[zidx] ** 2 + y[zidx] ** 2
# /home/lei/octave-4.0.2/scripts/specfun/isprime.m:150
    t[zidx] &= isprime(zabs)
    return t
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} factorial (@var{n})
## Return the factorial of @var{n} where @var{n} is a real non-negative integer.
##
## If @var{n} is a scalar, this is equivalent to @code{prod (1:@var{n})}.  For
## vector or matrix arguments, return the factorial of each element in the
## array.
##
## For non-integers see the generalized factorial function @code{gamma}.
## Note that the factorial function grows large quite quickly, and even
## with double precision values overflow will occur if @var{n} > 171.  For
## such cases consider @code{gammaln}.
## @seealso{prod, gamma, gammaln}
## @end deftypefn
    
    
@function
def factorial(n=None,*args,**kwargs):
    varargin = factorial.varargin
    nargin = factorial.nargin

    if (nargin != 1):
        print_usage()
    else:
        if (logical_not(isreal(n)) or any(ravel(n) < logical_or(0,ravel(n)) != fix(ravel(n)))):
            error('factorial: all N must be real non-negative integers')
    
    x=round(gamma(n + 1))
# /home/lei/octave-4.0.2/scripts/specfun/factorial.m:42
    
    ## This doesn't seem particularly worth copying--for example uint8 would
  ## saturate for n > 5.  If desired, however, the following code could be
  ## uncommented.
  # if (! isfloat (x))
  #   x = cast (x, class (n));
  # endif
    
    return x
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    ## Copyright (C) 1998-2015 Nicol N. Schraudolph
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Mapping Function} {} betaln (@var{a}, @var{b})
## Compute the natural logarithm of the Beta function for real inputs @var{a}
## and @var{b}.
##
## @code{betaln} is defined as
## @tex
## $$
##  {\rm betaln} (a, b) = \ln (B (a,b)) \equiv \ln ({\Gamma (a) \Gamma (b) \over \Gamma (a + b)}).
## $$
## @end tex
## @ifnottex
##
## @example
## betaln (a, b) = log (beta (a, b))
## @end example
##
## @end ifnottex
## and is calculated in a way to reduce the occurrence of underflow.
##
## The Beta function can grow quite large and it is often more useful to work
## with the logarithm of the output rather than the function directly.
## @seealso{beta, betainc, betaincinv, gammaln}
## @end deftypefn
    
    ## Author:   Nicol N. Schraudolph <nic@idsia.ch>
## Created:  06 Aug 1998
## Keywords: log beta special function
    
    
@function
def betaln(a=None,b=None,*args,**kwargs):
    varargin = betaln.varargin
    nargin = betaln.nargin

    if (nargin != 2):
        print_usage()
    
    if (logical_not(isreal(a)) or logical_not(isreal(b))):
        error('betaln: A and B must be real')
    else:
        if (logical_not(size_equal(a,b)) and numel(a) != 1 and numel(b) != 1):
            error('betaln: A and B must have consistent sizes')
    
    retval=gammaln(a) + gammaln(b) - gammaln(a + b)
# /home/lei/octave-4.0.2/scripts/specfun/betaln.m:60
    return retval
    
if __name__ == '__main__':
    pass
    
    
    ## Test input validation
    
    ## Copyright (C) 1996-2015 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Loadable Function} {[@var{j}, @var{ierr}] =} besselj (@var{alpha}, @var{x}, @var{opt})
## @deftypefnx {Loadable Function} {[@var{y}, @var{ierr}] =} bessely (@var{alpha}, @var{x}, @var{opt})
## @deftypefnx {Loadable Function} {[@var{i}, @var{ierr}] =} besseli (@var{alpha}, @var{x}, @var{opt})
## @deftypefnx {Loadable Function} {[@var{k}, @var{ierr}] =} besselk (@var{alpha}, @var{x}, @var{opt})
## @deftypefnx {Loadable Function} {[@var{h}, @var{ierr}] =} besselh (@var{alpha}, @var{k}, @var{x}, @var{opt})
## Compute Bessel or Hankel functions of various kinds:
##
## @table @code
## @item besselj
## Bessel functions of the first kind.  If the argument @var{opt} is supplied,
## the result is multiplied by @code{exp (-abs (imag (x)))}.
##
## @item bessely
## Bessel functions of the second kind.  If the argument @var{opt} is supplied,
## the result is multiplied by @w{@code{exp (-abs (imag (x)))}}.
##
## @item besseli
## Modified Bessel functions of the first kind.  If the argument @var{opt} is
## supplied, the result is multiplied by @w{@code{exp (-abs (real (x)))}}.
##
## @item besselk
## Modified Bessel functions of the second kind.  If the argument @var{opt} is
## supplied, the result is multiplied by @w{@code{exp (x)}}.
##
## @item besselh
## Compute Hankel functions of the first (@var{k} = 1) or second (@var{k} = 2)
## kind.  If the argument @var{opt} is supplied, the result is multiplied by
## @w{@code{exp (-I*@var{x})}} for @var{k} = 1 or @w{@code{exp (I*@var{x})}}
## for @var{k} = 2.
## @end table
##
## If @var{alpha} is a scalar, the result is the same size as @var{x}.
## If @var{x} is a scalar, the result is the same size as @var{alpha}.
## If @var{alpha} is a row vector and @var{x} is a column vector, the
## result is a matrix with @code{length (@var{x})} rows and
## @code{length (@var{alpha})} columns.  Otherwise, @var{alpha} and
## @var{x} must conform and the result will be the same size.
##
## The value of @var{alpha} must be real.  The value of @var{x} may be complex.
##
## If requested, @var{ierr} contains the following status information and is
## the same size as the result.
##
## @enumerate 0
## @item
## Normal return.
##
## @item
## Input error, return @code{NaN}.
##
## @item
## Overflow, return @code{Inf}.
##
## @item
## Loss of significance by argument reduction results in less than half of
## machine accuracy.
##
## @item
## Complete loss of significance by argument reduction, return @code{NaN}.
##
## @item
## Error---no computation, algorithm termination condition not met,
## return @code{NaN}.
## @end enumerate
## @end deftypefn
    
    
@function
def bessel(*args,**kwargs):
    varargin = bessel.varargin
    nargin = bessel.nargin

    error('bessel: you must use besselj, bessely, besseli, besselk, or besselh\n')
    return
    
if __name__ == '__main__':
    pass
    
    
    ## Copyright (C) 2000-2015 Kai Habel
## Copyright (C) 2008 Marco Caliari
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{l} =} legendre (@var{n}, @var{x})
## @deftypefnx {Function File} {@var{l} =} legendre (@var{n}, @var{x}, @var{normalization})
## Compute the Legendre function of degree @var{n} and order
## @var{m} = 0 @dots{} @var{n}.
##
## The value @var{n} must be a real non-negative integer.
##
## @var{x} is a vector with real-valued elements in the range [-1, 1].
##
## The optional argument @var{normalization} may be one of @qcode{"unnorm"},
## @qcode{"sch"}, or @qcode{"norm"}.  The default if no normalization is given
## is @qcode{"unnorm"}.
##
## When the optional argument @var{normalization} is @qcode{"unnorm"}, compute
## the Legendre function of degree @var{n} and order @var{m} and return all
## values for @var{m} = 0 @dots{} @var{n}.  The return value has one dimension
## more than @var{x}.
##
## The Legendre Function of degree @var{n} and order @var{m}:
##
## @tex
## $$
## P^m_n(x) = (-1)^m (1-x^2)^{m/2}{d^m\over {dx^m}}P_n (x)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##  m         m      2  m/2   d^m
## P(x) = (-1) * (1-x  )    * ----  P(x)
##  n                         dx^m   n
## @end group
## @end example
##
## @end ifnottex
##
## @noindent
## with Legendre polynomial of degree @var{n}:
##
## @tex
## $$
## P(x) = {1\over{2^n n!}}\biggl({d^n\over{dx^n}}(x^2 - 1)^n\biggr)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##           1    d^n   2    n
## P(x) = ------ [----(x - 1) ]
##  n     2^n n!  dx^n
## @end group
## @end example
##
## @end ifnottex
##
## @noindent
## @code{legendre (3, [-1.0, -0.9, -0.8])} returns the matrix:
##
## @example
## @group
##  x  |   -1.0   |   -0.9   |   -0.8
## ------------------------------------
## m=0 | -1.00000 | -0.47250 | -0.08000
## m=1 |  0.00000 | -1.99420 | -1.98000
## m=2 |  0.00000 | -2.56500 | -4.32000
## m=3 |  0.00000 | -1.24229 | -3.24000
## @end group
## @end example
##
## When the optional argument @code{normalization} is @qcode{"sch"}, compute
## the Schmidt semi-normalized associated Legendre function.  The Schmidt
## semi-normalized associated Legendre function is related to the unnormalized
## Legendre functions by the following:
##
## For Legendre functions of degree @var{n} and order 0:
##
## @tex
## $$
## SP^0_n (x) = P^0_n (x)
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##   0      0
## SP(x) = P(x)
##   n      n
## @end group
## @end example
##
## @end ifnottex
##
## For Legendre functions of degree n and order m:
##
## @tex
## $$
## SP^m_n (x) = P^m_n (x)(-1)^m\biggl({2(n-m)!\over{(n+m)!}}\biggl)^{0.5}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##   m      m         m    2(n-m)! 0.5
## SP(x) = P(x) * (-1)  * [-------]
##   n      n              (n+m)!
## @end group
## @end example
##
## @end ifnottex
##
## When the optional argument @var{normalization} is @qcode{"norm"}, compute
## the fully normalized associated Legendre function.  The fully normalized
## associated Legendre function is related to the unnormalized Legendre
## functions by the following:
##
## For Legendre functions of degree @var{n} and order @var{m}
##
## @tex
## $$
## NP^m_n (x) = P^m_n (x)(-1)^m\biggl({(n+0.5)(n-m)!\over{(n+m)!}}\biggl)^{0.5}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##   m      m         m    (n+0.5)(n-m)! 0.5
## NP(x) = P(x) * (-1)  * [-------------]
##   n      n                  (n+m)!
## @end group
## @end example
##
## @end ifnottex
## @end deftypefn
    
    ## Author: Marco Caliari <marco.caliari@univr.it>
    
    
@function
def legendre(n=None,x=None,normalization=None,*args,**kwargs):
    varargin = legendre.varargin
    nargin = legendre.nargin

    
    if (nargin < 2 or nargin > 3):
        print_usage()
    
    if (logical_not(isreal(n)) or logical_not(isscalar(n)) or n < 0 or n != fix(n)):
        error('legendre: N must be a real non-negative integer')
    else:
        if (logical_not(isreal(x)) or any(ravel(x) < logical_or(- 1,ravel(x)) > 1)):
            error('legendre: X must be real-valued vector in the range -1 <= X <= 1')
    
    if (nargin == 3):
        normalization=lower(normalization)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:177
    else:
        normalization='unnorm'
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:179
    
    unnorm=copy(false)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:182
    if 'unnorm' == (normalization):
        scale=1
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:185
        unnorm=copy(true)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:186
    else:
        if 'norm' == (normalization):
            scale=sqrt(n + 0.5)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:188
        else:
            if 'sch' == (normalization):
                scale=sqrt(2)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:190
            else:
                error('legendre: NORMALIZATION option must be "unnorm", "norm", or "sch"')
    
    scale=dot(scale,ones(size(x)))
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:195
    
    ##            m                 m              m
  ## (n-m+1) * P (x) = (2*n+1)*x*P (x)  - (n+1)*P (x)
  ##            n+1               n              n-1
  ## http://en.wikipedia.org/wiki/Associated_Legendre_function
    
    overflow=copy(false)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:203
    retval=zeros(cat(n + 1,size(x)))
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:204
    for m in arange(1,n).reshape(-1):
        lpm1=copy(scale)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:206
        lpm2=multiply(multiply((dot(2,m) - 1),x),scale)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:207
        lpm3=copy(lpm2)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:208
        for k in arange(m + 1,n).reshape(-1):
            lpm3a=multiply(multiply((dot(2,k) - 1),x),lpm2)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:210
            lpm3b=multiply((k + m - 2),lpm1)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:211
            lpm3=(lpm3a - lpm3b) / (k - m + 1)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:212
            lpm1=copy(lpm2)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:213
            lpm2=copy(lpm3)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:214
            if (logical_not(warned_overflow)):
                if (any(abs(lpm3a) > realmax) or any(abs(lpm3b) > realmax) or any(abs(lpm3) > realmax)):
                    overflow=copy(true)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:219
        retval[m,:]=ravel(lpm3)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:223
        if (unnorm):
            scale *= - (dot(2,m) - 1)
        else:
            scale *= (dot(2,m) - 1) / sqrt(dot((n - m + 1),(n + m)))
        scale * sqrt(1 - x ** 2)
    
    retval[n + 1,:]=ravel(scale)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:232
    if (isvector(x)):
        ## vector case is special
        retval=reshape(retval,n + 1,length(x))
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:236
    
    if (strcmp(normalization,'sch')):
        retval[1,:] / sqrt(2)
    
    if (overflow and logical_not(warned_overflow)):
        warning('legendre: overflow - results may be unstable for high orders')
        warned_overflow=copy(true)
# /home/lei/octave-4.0.2/scripts/specfun/legendre.m:245
    
    return retval
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2006, 2013 Sylvain Pelissier
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## Author: Sylvain Pelissier <sylvain.pelissier@gmail.com>
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} expint (@var{x})
## Compute the exponential integral:
## @tex
## $$
## {\rm E_1} (x) = \int_x^\infty {e^{-t} \over t} dt
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##            infinity
##           /
## E_1 (x) = | exp (-t)/t dt
##           /
##          x
## @end group
## @end example
##
## @end ifnottex
## Note: For compatibility, this functions uses the @sc{matlab} definition
## of the exponential integral.  Most other sources refer to this particular
## value as @math{E_1 (x)}, and the exponential integral as
## @tex
## $$
## {\rm Ei} (x) = - \int_{-x}^\infty {e^{-t} \over t} dt.
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##             infinity
##            /
## Ei (x) = - | exp (-t)/t dt
##            /
##          -x
## @end group
## @end example
##
## @end ifnottex
## The two definitions are related, for positive real values of @var{x}, by
## @tex
## $
## E_1 (-x) = -{\rm Ei} (x) - i\pi.
## $
## @end tex
## @ifnottex
## @w{@code{E_1 (-x) = -Ei (x) - i*pi}}.
## @end ifnottex
## @end deftypefn
    
    
@function
def expint(x=None,*args,**kwargs):
    varargin = expint.varargin
    nargin = expint.nargin

    if (nargin != 1):
        print_usage()
    
    y=copy(x)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:80
    
    if (isreal(x)):
        idx=(x >= 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:83
        y[idx]=- expint_Ei(- x[idx])
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:84
        idx=(x < 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:86
        y[idx]=- expint_Ei(- x[idx]) - dot(i,pi)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:87
    else:
        idx=(imag(x) > 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:89
        y[idx]=- expint_Ei(- x[idx]) - dot(i,pi)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:90
        idx=(imag(x) < 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:92
        y[idx]=- expint_Ei(- x[idx]) + dot(i,pi)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:93
        isreal_idx=(imag(x) == 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:95
        idx=(logical_and(isreal_idx,real(x)) >= 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:96
        y[idx]=- expint_Ei(- x[idx])
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:97
        idx=(logical_and(isreal_idx,real(x)) < 0)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:99
        y[idx]=- expint_Ei(- x[idx]) - dot(i,pi)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:100
    
    return y
    
if __name__ == '__main__':
    pass
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {@var{y} =} expint_Ei (@var{x})
## Compute the exponential integral:
## @verbatim
##                       infinity
##                      /
##    expint_Ei (x) = - | exp(-t)/t dt
##                      /
##                    -x
## @end verbatim
## @end deftypefn
    
    
@function
def expint_Ei(x=None,*args,**kwargs):
    varargin = expint_Ei.varargin
    nargin = expint_Ei.nargin

    y=zeros(size(x))
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:119
    F=lambda x=None: exp(- x) / x
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:120
    for t in arange(1,numel(x)).reshape(-1):
        xt=x[t]
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:123
        if (xt < 0 and imag(xt) == 0):
            ## Direct integration for most real inputs
            y[t]=- quad(F,- xt,Inf,cat(0,1e-10))
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:126
        else:
            if (xt > 2 and imag(xt) == 0):
                y[t]=Ei_2 - quad(F,- xt,- 2)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:129
            else:
                if (abs(xt) < 10):
                    ## Series Expansion for real (range [0,2]) or complex inputs (r < 10)
                    k=1
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:132
                    do
                    term=xt ** k / (dot(k,factorial(k)))
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:134
                    y[t] += term
                    until(abs(term) < eps(abs(y[t])) / 2 or k >= 100)
                    y[t]=0.577215664902 + log(xt) + y[t]
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:137
                else:
                    ## FIXME: This expansion is accurate to only 1e-13 at the beginning
      ##        near 10+i, although it becomes more accurate as the magnitude
      ##        of xt grows.
                    if (imag(xt) <= 0):
                        y[t]=- (xt ** 2 - dot(a1,xt) + a2) / (dot(dot((xt ** 2 - dot(b1,xt) + b2),(- xt)),exp(- xt))) - dot(i,pi)
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:147
                    else:
                        y[t]=conj(expint_Ei(conj(xt)))
# /home/lei/octave-4.0.2/scripts/specfun/expint.m:151
    
    return y
    
if __name__ == '__main__':
    pass
    
    ## Test against A&S Table 5.1
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    ## Series expansion (-2 < x < 0)
## Expected values from Mathematica
    
    
    
    
    
    
    
    
    ## (x < -2, x real)
    
    
    
    
    
    
    
    
    ## Complex values
    
    
    
    
    
    
    
    ## Exceptional values (-Inf, Inf, NaN, 0, 0.37250741078)
    
    
    
    
    
    
    
    
    ## Test input validation
    
    ## Copyright (C) 2001-2015 Rolf Fabian and Paul Kienzle
## Copyright (C) 2008 Jaroslav Hajek
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {@var{c} =} nchoosek (@var{n}, @var{k})
## @deftypefnx {Function File} {@var{c} =} nchoosek (@var{set}, @var{k})
##
## Compute the binomial coefficient of @var{n} or list all possible
## combinations of a @var{set} of items.
##
## If @var{n} is a scalar then calculate the binomial coefficient
## of @var{n} and @var{k} which is defined as
## @tex
## $$
##  {n \choose k} = {n (n-1) (n-2) \cdots (n-k+1) \over k!}
##                = {n! \over k! (n-k)!}
## $$
## @end tex
## @ifnottex
##
## @example
## @group
##  /   \
##  | n |    n (n-1) (n-2) @dots{} (n-k+1)       n!
##  |   |  = ------------------------- =  ---------
##  | k |               k!                k! (n-k)!
##  \   /
## @end group
## @end example
##
## @end ifnottex
## @noindent
## This is the number of combinations of @var{n} items taken in groups of
## size @var{k}.
##
## If the first argument is a vector, @var{set}, then generate all
## combinations of the elements of @var{set}, taken @var{k} at a time, with
## one row per combination.  The result @var{c} has @var{k} columns and
## @w{@code{nchoosek (length (@var{set}), @var{k})}} rows.
##
## For example:
##
## How many ways can three items be grouped into pairs?
##
## @example
## @group
## nchoosek (3, 2)
##    @result{} 3
## @end group
## @end example
##
## What are the possible pairs?
##
## @example
## @group
## nchoosek (1:3, 2)
##    @result{}  1   2
##        1   3
##        2   3
## @end group
## @end example
##
## Programming Note: When calculating the binomial coefficient @code{nchoosek}
## works only for non-negative, integer arguments.  Use @code{bincoeff} for
## non-integer and negative scalar arguments, or for computing many binomial
## coefficients at once with vector inputs for @var{n} or @var{k}.
##
## @seealso{bincoeff, perms}
## @end deftypefn
    
    ## Author: Rolf Fabian  <fabian@tu-cottbus.de>
## Author: Paul Kienzle <pkienzle@users.sf.net>
## Author: Jaroslav Hajek
    
    
@function
def nchoosek(v=None,k=None,*args,**kwargs):
    varargin = nchoosek.varargin
    nargin = nchoosek.nargin

    if (nargin != 2 or logical_not((isreal(k) and isscalar(k))) or logical_not((isnumeric(v) and isvector(v)))):
        print_usage()
    
    if (k < 0 or k != fix(k)):
        error('nchoosek: K must be an integer >= 0')
    else:
        if (isscalar(v) and (iscomplex(v) or v < k or v < 0 or v != fix(v))):
            error('nchoosek: N must be a non-negative integer >= K')
    
    n=length(v)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:104
    if (n == 1):
        ## Improve precision at next step.
        k=min(k,v - k)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:108
        C=round(prod((arange(v - k + 1,v)) / (arange(1,k))))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:109
        if (dot(dot(dot(C,2),k),eps) >= 0.5):
            warning('nchoosek: possible loss of precision')
    else:
        if (k == 0):
            C=zeros(1,0)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:114
        else:
            if (k == 1):
                C=ravel(v)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:116
            else:
                if (k == n):
                    C=ravel(v).T
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:118
                else:
                    if (k > n):
                        C=zeros(0,k,class_(v))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:120
                    else:
                        if (k == 2):
                            ## Can do it without transpose.
                            x=repelems(v[1:n - 1],cat([arange(1,n - 1)],[arange(n - 1,1,- 1)])).T
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:123
                            y=cat(1,cellslices(ravel(v),arange(2,n),dot(n,ones(1,n - 1)))[:])
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:124
                            C=matlabarray(cat(x,y))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:125
                        else:
                            if (k < n):
                                v=ravel(v).T
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:127
                                C=v[k:n]
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:128
                                l=arange(1,n - k + 1)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:129
                                for j in arange(2,k).reshape(-1):
                                    c=columns(C)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:131
                                    cA=cellslices(C,l,dot(c,ones(1,n - k + 1)),2)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:132
                                    l=c - l + 1
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:133
                                    b=repelems(v[k - j + 1:n - j + 1],cat([arange(1,n - k + 1)],[l]))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:134
                                    C=matlabarray(cat([b],[cA[:]]))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:135
                                    l=cumsum(l)
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:136
                                    l=matlabarray(cat(1,1 + l[1:n - k]))
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:137
                                C=C.T
# /home/lei/octave-4.0.2/scripts/specfun/nchoosek.m:139
    
    return C
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Test input validation
    
    
    ## Copyright (C) 2008-2015 David Bateman
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} realpow (@var{x}, @var{y})
## Compute the real-valued, element-by-element power operator.
##
## This is equivalent to @w{@code{@var{x} .^ @var{y}}}, except that
## @code{realpow} reports an error if any return value is complex.
## @seealso{power, reallog, realsqrt}
## @end deftypefn
    
    
@function
def realpow(x=None,y=None,*args,**kwargs):
    varargin = realpow.varargin
    nargin = realpow.nargin

    if (nargin != 2):
        print_usage()
    
    z=x ** y
# /home/lei/octave-4.0.2/scripts/specfun/realpow.m:34
    if (iscomplex(z)):
        error('realpow: produced complex result')
    
    return z
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    ## Copyright (C) 2000-2015 Paul Kienzle
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn {Function File} {} primes (@var{n})
## Return all primes up to @var{n}.
##
## The output data class (double, single, uint32, etc.) is the same as the
## input class of @var{n}.  The algorithm used is the Sieve of Eratosthenes.
##
## Notes: If you need a specific number of primes you can use the fact that the
## distance from one prime to the next is, on average, proportional to the
## logarithm of the prime.  Integrating, one finds that there are about
## @math{k} primes less than
## @tex
## $k \log (5 k)$.
## @end tex
## @ifnottex
## k*log (5*k).
## @end ifnottex
##
## See also @code{list_primes} if you need a specific number @var{n} of primes.
## @seealso{list_primes, isprime}
## @end deftypefn
    
    ## Author: Paul Kienzle
## Author: Francesco Potort
## Author: Dirk Laurie
    
    
@function
def primes(n=None,*args,**kwargs):
    varargin = primes.varargin
    nargin = primes.nargin

    if (nargin != 1):
        print_usage()
    
    if (logical_not(isscalar(n))):
        error('primes: N must be a scalar')
    
    if (n > 100000.0):
        ## Optimization: 1/6 less memory, and much faster (asymptotically)
    ## 100K happens to be the cross-over point for Paul's machine;
    ## below this the more direct code below is faster.  At the limit
    ## of memory in Paul's machine, this saves .7 seconds out of 7 for
    ## n = 3e6.  Hardly worthwhile, but Dirk reports better numbers.
        lenm=floor((n + 1) / 6)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:61
        lenp=floor((n - 1) / 6)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:62
        sievem=true(1,lenm)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:63
        sievep=true(1,lenp)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:64
        for i in arange(1,(sqrt(n) + 1) / 6).reshape(-1):
            if (sievem[i]):
                sievem[dot(7,i) - 1:dot(6,i) - 1:lenm]=false
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:68
                sievep[dot(5,i) - 1:dot(6,i) - 1:lenp]=false
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:69
            if (sievep[i]):
                sievep[dot(7,i) + 1:dot(6,i) + 1:lenp]=false
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:72
                sievem[dot(5,i) + 1:dot(6,i) + 1:lenm]=false
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:73
        p=sort(cat(2,3,dot(6,find(sievem)) - 1,dot(6,find(sievep)) + 1))
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:76
    else:
        if (n > 352):
            len_=floor((n - 1) / 2)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:78
            sieve=true(1,len_)
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:79
            for i in arange(1,(sqrt(n) - 1) / 2).reshape(-1):
                if (sieve[i]):
                    sieve[dot(3,i) + 1:dot(2,i) + 1:len_]=false
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:82
            p=matlabarray(cat(2,1 + dot(2,find(sieve))))
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:85
        else:
            a=matlabarray(cat(2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349))
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:87
            p=a[a <= n]
# /home/lei/octave-4.0.2/scripts/specfun/primes.m:93
    
    if (logical_not(isa(n,'double'))):
        cast(p,class_(n))
    
    return p
    
if __name__ == '__main__':
    pass
    
    
    
    
    ## Copyright (C) 1995-2015 Kurt Hornik
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.
    
    ## -*- texinfo -*-
## @deftypefn  {Function File} {} pow2 (@var{x})
## @deftypefnx {Function File} {} pow2 (@var{f}, @var{e})
## With one input argument, compute
## @tex
## $2^x$
## @end tex
## @ifnottex
## 2 .^ x
## @end ifnottex
## for each element of @var{x}.
##
## With two input arguments, return
## @tex
## $f \cdot 2^e$.
## @end tex
## @ifnottex
## f .* (2 .^ e).
## @end ifnottex
## @seealso{log2, nextpow2, power}
## @end deftypefn
    
    ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
## Created: 17 October 1994
## Adapted-By: jwe
    
    
@function
def pow2(f=None,e=None,*args,**kwargs):
    varargin = pow2.varargin
    nargin = pow2.nargin

    if (nargin == 1):
        y=2 ** f
# /home/lei/octave-4.0.2/scripts/specfun/pow2.m:48
    else:
        if (nargin == 2):
            y=multiply(f,(2 ** e))
# /home/lei/octave-4.0.2/scripts/specfun/pow2.m:50
        else:
            print_usage()
    
    return y
    
if __name__ == '__main__':
    pass
    
    
    
    
    
    
    
    
    